var g_ne = [[-2, 0, -1, 0, 0, 0, 0, 1, -1, 2],
            [-1, -1, -1, 0, 0, 0, -2, 1, 0, 1],
            [-1, -1, 0, -1, -2, 0, 0, 0, 0, 1],
            [-1, -1, 0, -1, 0, 0, 1, 0, -1, 1]];

var g_se = [[-1, -2, 0, -1, -2, 0, -1, 0, 0, 0],
            [-2, -1, 0, -1, -1, 0, 0, 0, -1, 1],
            [0, -1, -2, 0, 0, 0, -1, 1, 0, 1],
            [-1, -1, 0, 0, 1, 0, -1, 1, 0, 1]];

var g_sw = [[1, -2, 0, -1, 0, 0, 1, 0, 2, 0],
            [0, -1, 2, -1, 0, 0, 1, 0, 1, 1],
            [0, -1, 0, 0, 2, 0, 0, 1, 1, 1],
            [1, -1, -1, 0, 0, 0, 0, 1, 1, 1]];

var g_nw = [[0, 0, 1, 0, 2, 0, 0, 1, 1, 2],
            [1, -1, 0, 0, 1, 0, 0, 1, 2, 1],
            [0, -1, 1, -1, 0, 0, 2, 0, 0, 1],
            [0, -1, 1, -1, -1, 0, 0, 0, 1, 1]];

function append_with_shift(cells1, cells2, x, y) {
    for (var i = 0; i < cells2.length; i += 2) {
        cells1.push(cells2[i] + x)
        cells1.push(cells2[i+1] + y)
    }
}

function add_gliders(cells, gs, gcells, vx, vy, t) {
    for (var i = 0; i < gs.length; i += 2) {
        var phase = (t + gs[i+1]) % 4;
        if (phase < 0) phase += 4;
        var d = (t + gs[i+1] - phase) / 4;
        append_with_shift(cells, gcells[phase], gs[i] + vx * d, vy * d);
    }
}

function transform(cells, trans) {
    for (var i = 0; i < cells.length; i += 2) {
        var tmp    = trans[0] + cells[i] * trans[2] + cells[i+1] * trans[3];
        cells[i+1] = trans[1] + cells[i] * trans[4] + cells[i+1] * trans[5];
        cells[i]   = tmp;
    }
}

function compose(t1, t2) {
    var arr = [0,0,1,0,0,1];
    transform(arr, t1);
    transform(arr, t2);
    return [arr[0], arr[1], arr[2]-arr[0], arr[4]-arr[0], arr[3]-arr[1], arr[5]-arr[1]];
}

function inverse(t) {
    var det = t[2] * t[5] - t[3] * t[4];
    var arr = [0, 0, det * t[5], -det * t[3], -det * t[4], det * t[2]];
    var p = [-t[0], -t[1]];
    transform(p, arr);
    arr[0] = p[0];
    arr[1] = p[1];
    return arr;
}

function decodeCanon(apgcode) {

    var i;
    var chars = "0123456789abcdefghijklmnopqrstuvwxyz"

    for (i = 0; i < apgcode.length; i++) {
        if (apgcode[i] == "_") {
            i += 1;
            break;
        }
    }
    
    var blank = 0;
    var x = 0;
    var y = 0;
    var cells = []
    
    for (/**/; i < apgcode.length; i++) {
   
        var c = apgcode[i];
        if (blank) {
            x += chars.indexOf(c);
            blank = 0;
        } else if (c == 'y') {
            x += 4;
            blank = 1;
        } else if (c == 'x') {
            x += 3;
        } else if (c == 'w') {
            x += 2;
        } else if (c == 'z') {
            x = 0;
            y += 5;
        } else {
            v = chars.indexOf(c);
            for (var j = 0; j < 5; j++)
                if (v & (1 << j)) {
                    cells.push(x);
                    cells.push(y+j);
                }
            x += 1;
        }
    }

    return cells;
}

function display_edge(cells, edge, post_transform, offset) {

    var input_cells = decodeCanon(edge.input_code)
    add_gliders(input_cells, edge.gs_ne, g_ne,  1, -1, 0);
    add_gliders(input_cells, edge.gs_se, g_se,  1,  1, 0);
    add_gliders(input_cells, edge.gs_sw, g_sw, -1,  1, 0);
    add_gliders(input_cells, edge.gs_nw, g_nw, -1, -1, 0);

    var output_cells = decodeCanon(edge.output_code);

    var new_transform = compose(inverse(edge.transform), post_transform);

    transform(input_cells, new_transform);
    transform(output_cells, post_transform);

    append_with_shift(cells, input_cells, 0, offset);
    append_with_shift(cells, output_cells, 100, offset);

    return new_transform;

}

function get_synthesis(cells, apgcode) {
    
    var offset = 0;
    var cost = 0;
    var trans = [0,0,1,0,0,1];

    while (apgcode != "0") {
        
        if (!min_paths.hasOwnProperty(apgcode))
            return "unknown";

        var edge = min_paths[apgcode];

        trans = display_edge(cells, edge, trans, offset);

        apgcode = edge.input_code;
        cost += edge.cost;

        offset -= 100;
    }

    return cost;
}

function add_symbol(out_pair, num, symbol) {
    if (num == 0) return;
    if (num > 1) symbol = num.toString() + symbol;
    out_pair[1] += symbol.length;
    if (out_pair[1] > 77) {
        out_pair[0] += "<br>";
        out_pair[1] = symbol.length;
    }
    out_pair[0] += symbol;
}

function cells_to_rle(cells) {

    if (cells.length == 0) return "x = 0, y = 0, rule = B3/S23<br>!";

    var minx = 99999;
    var maxx = -99999;
    var miny = 99999;
    var maxy = -99999;

    for (var i = 0; i < cells.length; i += 2) {

        x = cells[i];
        y = cells[i+1];

        if (x > maxx) maxx = x;
        if (x < minx) minx = x;
        if (y > maxy) maxy = y;
        if (y < miny) miny = y;

    }

    var pairs = [];
    for (var i = 0; i < cells.length; i += 2)
        pairs.push((cells[i]-minx) + 1024 * cells[i+1]);
    pairs.sort(function(a,b){return a-b});

    for (var i = 0; i < pairs.length; i++) {
        cells[2*i] = pairs[i] & 1023;
        cells[2*i+1] = pairs[i] >> 10;
    }

    var w = maxx - minx + 1;
    var h = maxy - miny + 1;
    var output = "x = " + w.toString() + ", y = " + h.toString() + ", rule = B3/S23<br>";

    var x = cells[0];
    var y = cells[1];
    var on_start = cells[0];
    var off_start = 0;
    var out_pair = [output, 0];

    for (var i = 2; i < cells.length; i += 2) {

        if (cells[i] == x + 1 && cells[i+1] == y) {
            x++;
        } else {
            
            add_symbol(out_pair, on_start - off_start, "b");
            add_symbol(out_pair, x + 1 - on_start, "o");

            off_start = x + 1;

            var new_lines = cells[i+1] - y;
            if (new_lines > 0) {
                add_symbol(out_pair, new_lines, "$");
                off_start = 0;
            }

            x = on_start = cells[i];
            y = cells[i+1];
        }        
    }

    add_symbol(out_pair, on_start - off_start, "b");
    add_symbol(out_pair, x + 1 - on_start, "o");

    return out_pair[0] + "!";
    
}

function to_int_array(s) {
    if (s == "") return [];
    var sp = s.split(",");
    for (var i = 0; i < sp.length; i++)
        sp[i] = parseInt(sp[i]);
    return sp;
}

function apgcode_to_synthesis_rle(apgcode) {

    var cells = [];
    var cost = get_synthesis(cells, apgcode);
    
    if (cost == "unknown") 
        return cost;
    else {
        var rle = cells_to_rle(cells);
        return "#C " + apgcode + " costs " + cost + " gliders<br>" + rle;
    }

}

function string_to_edge(s) {

    var edge = new Object();
    var sp = s.split(";");

    edge.input_code = sp[0];
    edge.output_code = sp[1];
    edge.phase = parseInt(sp[2]);
    edge.gs_ne = to_int_array(sp[3]);
    edge.gs_se = to_int_array(sp[4]);
    edge.gs_sw = to_int_array(sp[5]);
    edge.gs_nw = to_int_array(sp[6]);
    edge.transform = to_int_array(sp[7]);
    edge.cost = (edge.gs_ne.length + edge.gs_se.length 
                 + edge.gs_sw.length + edge.gs_nw.length) / 2;
    
    return edge;

}

var min_paths = function(strings) {
    var out = new Object();
    for (var i = 0; i < strings.length; i++) {
        var edge = string_to_edge(strings[i]);
        out[edge.output_code] = edge;
    }
    return out;
}([
"0;xp2_032hv04a6ze;0;13,-42,28,-91,34,-124;5,5;19,24,22,11;-12,-82,-6,-77,3,-58;8,7,0,1,1,0",
"0;xp2_032hv04acze;1;14,-47,27,-82,33,-87;4,8;20,27,23,14;-15,-129,-9,-96,2,-63;8,8,0,1,1,0",
"0;xp2_033ze;1;;0,8;6,7;7,-37;1,1,0,1,1,0",
"0;xp2_033zs;1;;-14,65;10,8;-19,-94;3,22,1,0,0,-1",
"0;xp2_0696z7;0;;-3,19;9,8;-1,-32;3,2,1,0,0,1",
"0;xp2_0696zsy166;1;20,-39;1,6;20,27;-1,-81;19,7,0,-1,1,0",
"0;xp2_07z4aic;1;;-3,21;9,7;-7,-45;-2,10,0,1,-1,0",
"0;xp2_07z7;1;;1,5;7,7;3,-20;0,1,0,1,1,0",
"0;xp2_07zs;1;;-5,29;10,5;0,-42;5,4,1,0,0,1",
"0;xp2_0c48chbgzy1121z66zyhggg07;1;;-16,139,-8,85,-5,110,0,7,2,71;47,89;-14,-170,-10,-176;34,42,0,-1,-1,0",
"0;xp2_0c4o7hzggg11074;0;15,-53,22,-60,31,-100,42,-110;8,7,8,38;27,22,35,37;-8,-111,-3,-91;14,16,0,1,-1,0",
"0;xp2_0dbgyc7z2ldxsy2cicz011;0;;-10,47,-10,160,13,97,14,6;74,122,80,154;10,-173;33,47,0,1,-1,0",
"0;xp2_0s01110sy733zg8g222z0p4jzw11;0;20,-70;4,7,14,21;39,26;0,-85,4,-293,11,-97;7,-6,0,1,1,0",
"0;xp2_1110ok8;0;;0,8;8,11;-9,-52;2,8,0,1,-1,0",
"0;xp2_1110oo;0;;1,5;16,36;-5,-48;7,17,1,0,0,-1",
"0;xp2_1110s;0;;-1,14;13,5;9,-27;14,4,-1,0,0,-1",
"0;xp2_1118kic;0;;0,8;6,8;-2,-25;8,7,-1,0,0,1",
"0;xp2_111y0s;0;;0,7;7,12;-3,-29;1,1,0,1,1,0",
"0;xp2_111y1ey98kk8;0;28,-105;3,8;33,23,50,92;-15,-180;14,10,0,1,1,0",
"0;xp2_1784ozx34a4zzy67;1;;-5,29,-4,49,5,8;17,27,23,20,24,46,31,49;0,-82;19,22,0,-1,-1,0",
"0;xp2_253y2s;0;;-6,31;17,6;-4,-54,5,-44;4,12,1,0,0,-1",
"0;xp2_2552ze;1;;-5,28;12,5;0,-41;8,10,-1,0,0,-1",
"0;xp2_2552zy6e;0;;;2,5,17,29;-10,-41,-8,-59;5,13,0,-1,-1,0",
"0;xp2_2596zy1ggg070gggzy5e;0;;-3,21,1,43;15,5;-2,-91;17,20,0,-1,-1,0",
"0;xp2_2a54;0;7,-20;5,6;15,8;3,-22;6,2,0,1,1,0",
"0;xp2_318c;0;;0,8;6,8;1,-21;8,3,-1,0,0,1",
"0;xp2_33ws;0;;-1,13;10,6;5,-26;8,3,-1,0,0,1",
"0;xp2_33y97;0;;0,7;17,40;-5,-52;10,13,0,-1,-1,0",
"0;xp2_33yfs;1;23,-85;3,7;42,72;-14,-154;13,10,0,1,1,0",
"0;xp2_33ze;0;;1,5;10,22;-12,-68;4,6,1,0,0,1",
"0;xp2_33zy0888y1sx33;1;;-13,62,11,8;26,44,32,21,40,28;-5,-109;8,22,1,0,0,-1",
"0;xp2_33zy5e;1;;-2,16;6,7;-3,-33;5,-2,0,-1,1,0",
"0;xp2_33zyb7;0;;;4,16,8,7;-3,-29;13,5,-1,0,0,1",
"0;xp2_66x7e;1;;-21,91;16,8;-23,-107;7,25,0,-1,1,0",
"0;xp2_696o8gy8ezw32023;1;;-20,112,-1,38,0,64,1,6;38,40,46,43,54,102;-13,-173,2,-125;19,26,0,1,1,0",
"0;xp2_699m88gzx121ze;0;8,-19,12,-41;5,6;13,5;4,-33;12,9,-1,0,0,-1",
"0;xp2_7;0;;0,7;;-4,-31;7,3,1,0,0,1",
"0;xp2_7e;0;;-3,21;11,8;0,-34;1,8,0,1,1,0",
"0;xp2_7xs;1;;;2,9,10,5;-1,-21;1,4,0,-1,1,0",
"0;xp2_7zw6952;1;;;1,5;0,-17;-3,7,0,1,-1,0",
"0;xp2_7zx33;1;;;2,7,11,32;-4,-45;-3,12,0,1,-1,0",
"0;xp2_7zy733;1;;;2,7;-7,-37,6,-20;-4,4,1,0,0,-1",
"0;xp2_7zzzyhezyd1110s0111;1;;0,7;96,220;-16,-232;34,32,0,1,1,0",
"0;xp2_8o0u93z01221zy6e;0;24,-86;-7,53,2,27,7,6;23,8;-15,-179,0,-66;-2,21,1,0,0,-1",
"0;xp2_exgbhc84czx1221;0;15,-39,22,-45,30,-58;1,6,9,26;30,20;14,-56;10,5,0,1,1,0",
"0;xp2_g88mp2sgz11zy5e;0;16,-56,41,-98,50,-169;1,16;20,6,34,40;5,-103;22,15,0,-1,-1,0",
"0;xp2_ggg070gggzy0ezx8kk8w33;1;;-11,57,-3,22;9,6,20,45;-5,-69;1,4,1,0,0,1",
"0;xp2_gw7z3;0;;;2,8,11,8;-3,-20;1,0,1,0,0,1",
"0;xp2_og8lb8ozx32ggg070gggzy5e;1;26,-94,36,-114;-12,81;29,8;-8,-177,-6,-147,3,-130;16,20,-1,0,0,1",
"0;xp2_ow7z1;0;;;4,8;-5,-21,-4,-49;5,5,0,-1,1,0",
"0;xp2_s01110sx4aa4zw222;0;13,-45;3,6;22,33;-7,-71;5,2,0,1,1,0",
"0;xp2_s01110szw222;0;;0,7;;-5,-36;1,1,1,0,0,1",
"0;xp2_s01110szw222y2cc;0;;-4,25;13,8;8,-38;13,-1,0,-1,1,0",
"0;xp2_s01110szw222zzyacc;0;;0,10;6,6;-16,-93;3,-13,-1,0,0,1",
"0;xp2_w7zccx356zy066y0111;1;;-5,29;7,6;0,-41;4,-2,-1,0,0,1",
"0;xp2_wog4cj96ze;0;19,-49,20,-70,33,-93;1,7,3,37;29,27,30,10;-5,-106;11,11,1,0,0,-1",
"0;xp2_x2596zkq2koz12452xo4ozy51ggg;0;19,-66,37,-86;7,18;23,7,40,7;15,-70,18,-30;11,6,0,1,1,0",
"0;xp2_x62sgc453z7;0;;;6,25,14,8;-5,-37,-1,-43;-2,6,1,0,0,1",
"0;xp2_xccy3252zgw8kicz3;1;;;2,8;-3,-20;10,7,0,-1,-1,0",
"0;xp2_xggy02552w66xooz6ao74z032zy56996wgzyb3;0;14,-46,33,-122;5,5;26,9,27,33;-9,-110,-4,-127;-9,18,1,0,0,-1",
"0;xp2_y2696zyc8kcz66yje;1;15,-53,33,-87;-2,41,3,7,17,18;41,9;13,-67,23,-61;9,18,1,0,0,-1",
"0;xp2_y3352y469d2sgzwgggy8ey01023zey1ezw111;1;25,-71,30,-90;-4,58,0,8,10,33;26,21,38,16;-8,-157;20,6,0,-1,1,0",
"0;xs10_0cp3z32;0;15,-43;1,6;21,31;-1,-54,4,-74;12,8,-1,0,0,1",
"0;xs10_0drz32;0;;-5,35,0,7;18,48;-11,-67;4,3,-1,0,0,1",
"0;xs10_0j96z32;0;12,-40;1,5;22,28;-10,-88;7,16,-1,0,0,-1",
"0;xs10_1784213;0;;-13,61;18,8,26,61,43,106;-18,-124,-10,-118;12,18,1,0,0,-1",
"0;xs10_178ka4;0;11,-30;-1,11;26,8;-2,-90,-2,-31;11,11,0,-1,-1,0",
"0;xs10_178kk8;0;10,-32;1,20;18,5;0,-57;12,9,0,-1,-1,0",
"0;xs10_2530352;0;;;4,7;-5,-20,-1,-28;1,0,0,1,1,0",
"0;xs10_25a8426;0;;;4,10,13,5,21,21;-9,-34,-8,-58,2,-50;8,8,-1,0,0,-1",
"0;xs10_2eg853;0;9,-26;4,7;13,6;2,-51,7,-19;13,6,-1,0,0,1",
"0;xs10_2l3z123;0;;0,10;6,6;6,-36;-3,-6,0,1,-1,0",
"0;xs10_31eg8o;0;11,-37;2,25,3,8;20,11;9,-49;12,12,1,0,0,-1",
"0;xs10_3215ac;0;;-3,22;15,8;-3,-68,5,-35;10,6,-1,0,0,1",
"0;xs10_32qr;0;8,-24;2,6;13,12;-3,-37;10,6,0,-1,-1,0",
"0;xs10_33039c;0;7,-21;0,8;12,8;1,-23;4,2,0,-1,1,0",
"0;xs10_33zx696;0;;;1,6,10,16;-5,-28;6,8,0,-1,-1,0",
"0;xs10_358gkc;0;10,-33;1,20;10,8;3,-47;10,10,0,1,-1,0",
"0;xs10_35ako;0;9,-29;0,12;11,8;0,-24;6,9,-1,0,0,1",
"0;xs10_3jz343;0;;;1,5;-5,-18,0,-17;1,1,1,0,0,1",
"0;xs10_660696;0;;-2,15;9,6;0,-28;7,5,-1,0,0,1",
"0;xs10_69ar;0;11,-36;2,7;12,24;-2,-49;8,6,0,-1,1,0",
"0;xs10_g0s252z11;0;10,-32;1,5;17,20;-6,-63;7,8,0,-1,1,0",
"0;xs10_g8o652z01;0;8,-23;-1,11;9,8;-4,-41;-3,2,1,0,0,1",
"0;xs10_gg0696z11;0;;-2,17;6,7;0,-38;3,-1,1,0,0,1",
"0;xs10_ggka23z1;0;14,-47,19,-48;1,6;19,9,25,35;-1,-74;12,5,-1,0,0,1",
"0;xs10_ggka52z1;0;;-3,22;17,8;-3,-56,2,-34;7,8,0,-1,1,0",
"0;xs10_wg853z65;0;21,-56;0,8,11,26;39,36;3,-66,14,-84;22,9,0,-1,1,0",
"0;xs10_x696z66;0;;0,7;9,20;3,-33;9,9,-1,0,0,-1",
"0;xs10_xg853z321;0;;1,6;10,11;0,-48,3,-24;10,4,-1,0,0,1",
"0;xs11_03ia4z65;0;;-16,73,6,8;27,28,42,51;-11,-132,-4,-120,1,-86;15,23,1,0,0,-1",
"0;xs11_08o652z32;0;;-7,105,0,8;38,17,48,106;0,-170;19,22,0,1,1,0",
"0;xs11_17842ac;0;;-9,45;14,8,17,35;0,-57;12,7,-1,0,0,1",
"0;xs11_178c4go;0;;0,8;21,35,23,22;-3,-82,-2,-48;17,12,0,-1,1,0",
"0;xs11_178jd;0;23,-85;-16,72;28,6;-18,-156;3,22,0,-1,-1,0",
"0;xs11_2530f9;0;;-2,15,18,5;61,110;6,-123;30,19,0,1,-1,0",
"0;xs11_2560ui;0;;-7,38;14,8;-2,-51,2,-56;13,10,-1,0,0,-1",
"0;xs11_256o8go;0;12,-40;-3,22;13,26,16,8;-3,-53,7,-39;4,2,1,0,0,1",
"0;xs11_2596w33;0;;;4,15,8,8;-3,-27;6,4,-1,0,0,1",
"0;xs11_25a84ko;0;13,-34,17,-61;5,7;23,22;-3,-67;11,11,0,-1,-1,0",
"0;xs11_25icz65;0;11,-37;4,25;17,12,25,6;8,-62,15,-47;9,10,0,1,1,0",
"0;xs11_25iczx113;0;18,-62,31,-88,38,-94;10,38;23,5;15,-77;21,17,-1,0,0,-1",
"0;xs11_2ege13;0;13,-44;0,22;19,6;0,-34;7,7,-1,0,0,1",
"0;xs11_31461ac;0;;;3,8;-13,-88,-12,-55,-5,-20;4,11,0,1,-1,0",
"0;xs11_31e853;0;;-16,73,4,12;27,72,38,7;-1,-135;19,16,1,0,0,1",
"0;xs11_31eg84c;0;17,-61,26,-53,42,-81;0,41;49,8;10,-104,16,-80;23,16,-1,0,0,-1",
"0;xs11_3215a8o;0;15,-52,32,-93;1,23;17,7,37,40;-6,-68;8,10,1,0,0,1",
"0;xs11_3303lo;0;10,-32;1,20;16,6;3,-42;8,9,0,1,-1,0",
"0;xs11_3542156;0;69,-268,78,-152;4,7,7,111;68,103;8,-170,15,-266;39,21,0,1,1,0",
"0;xs11_354c826;0;10,-22;1,5,7,7;17,9;4,-39;4,3,1,0,0,1",
"0;xs11_3586246;0;;0,7;8,16,17,34;-10,-83,-6,-57;-2,-4,1,0,0,-1",
"0;xs11_358gka4;0;;-4,24,4,19;16,6;-3,-56;5,9,1,0,0,1",
"0;xs11_69jzx123;0;;-7,35,10,6;119,150,135,193;31,-440,32,-206;66,67,-1,0,0,-1",
"0;xs11_69lic;0;11,-36;4,8;17,24;9,-44;3,4,1,0,0,1",
"0;xs11_g0s253z11;0;;;1,5,11,20,15,39;-12,-51;-6,11,0,1,-1,0",
"0;xs11_g8ka52z11;0;;-6,34;9,5,13,33;-11,-68;11,14,-1,0,0,-1",
"0;xs11_g8o652z11;0;9,-20;1,5;10,8;-5,-56;6,5,1,0,0,-1",
"0;xs11_gg2596z11;0;;-1,11;8,5;4,-24;5,6,1,0,0,-1",
"0;xs11_ggka53z1;0;;-3,27,1,5;16,40;0,-54;7,11,1,0,0,-1",
"0;xs11_ggm952z1;0;9,-29;2,6;19,17;-6,-71;-1,8,0,1,1,0",
"0;xs11_w2596zz33;0;;-1,13;9,5;1,-26;-3,2,0,1,1,0",
"0;xs11_wg84213z65;0;;1,5,5,11;17,29;2,-73,8,-42;0,1,1,0,0,1",
"0;xs11_xg853zca1;0;;-4,24;11,8,21,33;-3,-77,-2,-53,7,-46;13,10,0,-1,1,0",
"0;xs12_02lmz643;0;;-4,24,1,30;15,7;-6,-67;10,6,-1,0,0,1",
"0;xs12_03loz643;0;19,-60;0,7,2,32;29,47;2,-84;15,8,0,-1,1,0",
"0;xs12_0bdz2552;0;;-9,210,0,7;89,132,98,209,111,65;0,-391;49,58,0,1,-1,0",
"0;xs12_0g8ge13z23;0;12,-40;4,6,11,11;24,17;4,-47,13,-46;9,13,1,0,0,-1",
"0;xs12_0g8ka52z121;0;;-2,47,1,6,1,58;;6,-70;13,20,1,0,0,1",
"0;xs12_0g8o652z121;0;;-17,86,-6,72,1,6;;-8,-98;18,4,-1,0,0,1",
"0;xs12_0gbaa4z121;0;;-9,49,-4,25;14,8,17,47;-13,-111;4,13,0,1,1,0",
"0;xs12_0ggc93z641;0;10,-32,17,-34;3,6;13,10,20,12;5,-38;13,3,0,-1,1,0",
"0;xs12_0ggka52z32;0;;;5,22,9,6,17,38;-12,-75,-9,-50;4,9,0,-1,1,0",
"0;xs12_0ggm93z32;0;8,-22,19,-49;3,7;14,10;2,-55;8,3,-1,0,0,1",
"0;xs12_0ggm96z32;0;19,-68,26,-55;7,7;23,35;9,-66;18,3,0,-1,1,0",
"0;xs12_0mk213z121;0;14,-48,23,-56;1,15,5,22;14,6;2,-60;15,7,0,-1,1,0",
"0;xs12_17842156;0;;-14,63,-2,77,6,7;48,78;-11,-121,-6,-136,11,-108;19,17,0,-1,1,0",
"0;xs12_178br;0;;-13,62;20,7,22,40;-10,-75;6,12,1,0,0,-1",
"0;xs12_178c2ko;0;41,-156;-1,71;45,8,69,21,74,84;3,-231,19,-97;39,33,0,-1,1,0",
"0;xs12_178c453;0;;-9,63,0,7;22,45;0,-76;10,16,0,-1,1,0",
"0;xs12_178ka52;0;;;1,5,13,14;-9,-36,-5,-51,-2,-27;5,7,-1,0,0,-1",
"0;xs12_178kia4;0;;-6,119,0,7;54,77,59,132;-8,-161;36,32,0,-1,-1,0",
"0;xs12_256069a4;0;;;4,8,7,27;-7,-40;2,2,0,-1,1,0",
"0;xs12_25606ak8;0;10,-33;5,21;16,8;-3,-95;13,16,0,-1,-1,0",
"0;xs12_256o8a6;0;13,-44;2,8;17,32;2,-48;8,7,-1,0,0,1",
"0;xs12_25a8og4c;0;14,-49;1,6,1,29;15,18;3,-46;12,9,-1,0,0,-1",
"0;xs12_25a8og8o;0;21,-74;-1,13,2,48;20,16,25,6,32,28;-5,-103;20,13,-1,0,0,-1",
"0;xs12_25iczw1252;0;17,-59;3,7;21,25,22,10,22,46,31,23;-6,-93,3,-74;15,8,-1,0,0,1",
"0;xs12_2ege123;0;20,-33,21,-75;10,8;28,21;2,-106,4,-82;13,17,0,-1,-1,0",
"0;xs12_2egm93;0;;;4,8;-5,-71,-5,-54,-5,-20;8,12,0,-1,-1,0",
"0;xs12_2egm96;0;7,-20;0,8;9,5;-1,-30;5,8,-1,0,0,-1",
"0;xs12_3123c4go;0;34,-127,37,-87;4,6,7,43;35,5,50,75;7,-96,14,-133;24,19,1,0,0,-1",
"0;xs12_3123cko;0;15,-53,23,-33;8,20;25,6;6,-47;17,7,0,-1,-1,0",
"0;xs12_31egma;0;12,-41;8,5;17,23;5,-56;9,0,-1,0,0,1",
"0;xs12_31eozx123;0;17,-60;0,47,1,6;20,21,28,48;-3,-142;6,3,1,0,0,1",
"0;xs12_321f84c;0;;;2,10,16,6;-6,-26,0,-94,7,-22,8,-36;11,8,-1,0,0,1",
"0;xs12_32qj4c;0;;-11,54,1,8;22,67;-9,-83;8,9,0,1,1,0",
"0;xs12_330f96;0;13,-43;-3,31;16,6;1,-59;7,11,1,0,0,-1",
"0;xs12_330fho;0;8,-24;9,5;16,12;7,-39;12,4,-1,0,0,1",
"0;xs12_33xciic;0;;-1,11;6,8;0,-24;7,5,-1,0,0,-1",
"0;xs12_354cga6;0;;-9,43,2,8;13,17,25,41;-5,-73,-5,-56;6,5,0,1,1,0",
"0;xs12_3560653;0;;0,7;10,25;-1,-49;-1,17,1,0,0,-1",
"0;xs12_3560ui;0;10,-24,15,-45;0,7;13,11;1,-44;0,9,1,0,0,-1",
"0;xs12_358m93;0;21,-76;0,25,6,24;26,5;-9,-92,3,-126,6,-82;20,13,0,-1,-1,0",
"0;xs12_35iczx113;0;16,-54;5,7;17,16;0,-55,1,-71,4,-28;11,3,-1,0,0,1",
"0;xs12_39c0f9;0;13,-42;-1,28;16,27,19,7,21,28;-4,-56,2,-61,4,-40;9,10,1,0,0,-1",
"0;xs12_3hu066;0;;;2,8,8,7;-5,-21,-1,-37;8,1,-1,0,0,1",
"0;xs12_3lozx352;0;11,-34;4,6;16,7;-5,-75,-1,-35;9,6,0,-1,-1,0",
"0;xs12_3pcz643;0;;-34,145,0,11;38,6,48,46,53,131;-29,-196,-8,-158;16,28,-1,0,0,-1",
"0;xs12_4ai3s4zx1;0;7,-21;0,8;21,8;-4,-53,-2,-35,8,-28;2,5,1,0,0,-1",
"0;xs12_4alla4;0;;-18,79,-1,50,2,30,5,5;33,78;-1,-160;20,18,1,0,0,1",
"0;xs12_4ap3z65;0;18,-64,25,-70,28,-48,30,-38,37,-76;4,7;24,6;13,-70;14,9,0,1,1,0",
"0;xs12_4s0c93z11;0;15,-50,23,-79,25,-66;4,8;16,22;-4,-66,-2,-79,-1,-47;7,15,0,1,-1,0",
"0;xs12_641j4czx11;0;;1,5;13,15;0,-61,4,-28;11,11,-1,0,0,-1",
"0;xs12_642tic;0;;-18,81,-5,55,2,33,9,5;23,18,29,38,36,39;-13,-108,0,-93;14,14,0,1,1,0",
"0;xs12_651i4ozx11;0;13,-44,22,-69;2,7;25,32;-3,-80;7,14,1,0,0,-1",
"0;xs12_66069ic;0;;-7,36;12,8,21,58;-8,-71;3,6,0,1,1,0",
"0;xs12_6960ui;0;10,-32;1,20;18,5;1,-42;5,6,1,0,0,1",
"0;xs12_696z696;0;;;2,8,11,16;-5,-28;-1,5,0,1,1,0",
"0;xs12_696zw2552;0;;;1,5;-5,-23,4,-18;-6,-1,0,1,1,0",
"0;xs12_8ljgzx252;0;;-18,81,0,49,9,5;28,39,39,80;-24,-153;15,19,-1,0,0,1",
"0;xs12_c93zx2552;0;;;4,5;-5,-39,-4,-17;-6,7,0,1,1,0",
"0;xs12_ck3123z11;0;;-12,87,0,7;29,69,36,73,38,28,45,57;-2,-126;22,26,1,0,0,1",
"0;xs12_ck3146z11;0;20,-72,30,-85;-1,33;24,6,41,59;-7,-126,2,-98;19,14,-1,0,0,1",
"0;xs12_drz346;0;22,-80;-7,35,2,7;37,67;-7,-133,-7,-105;10,15,1,0,0,1",
"0;xs12_g4q453z11;0;;-7,44,0,8;18,43,19,13;2,-56;6,14,1,0,0,1",
"0;xs12_g88a53z23;0;11,-35,21,-77;5,5;18,22,23,17;2,-83;6,16,1,0,0,-1",
"0;xs12_g8ka53z11;0;;-8,39,2,7;18,22;-10,-63,-4,-60;1,8,1,0,0,1",
"0;xs12_g8o653z11;0;8,-25;-1,13;9,7;-3,-33;1,7,-1,0,0,1",
"0;xs12_ggdbz65;0;13,-45,19,-42;5,13;13,10,19,7;1,-39;8,3,1,0,0,1",
"0;xs12_kc3213z11;0;20,-57,21,-76;3,18,9,14;31,7,31,44;-7,-115;12,11,1,0,0,1",
"0;xs12_o4q552z01;0;;-5,27;7,8,12,33;-4,-49;-2,12,1,0,0,-1",
"0;xs12_oo033zy766;0;;-8,40;21,8;4,-52;19,24,0,-1,-1,0",
"0;xs12_raar;0;8,-19;0,7;10,6;-1,-31;4,5,0,1,1,0",
"0;xs12_xg84213zca1;0;;-7,37,3,6;19,36;-4,-50,2,-60;15,4,-1,0,0,1",
"0;xs13_035iczca1;0;14,-47;3,10;18,7;-4,-46,1,-63;2,8,0,1,1,0",
"0;xs13_03hik8z252;0;36,-128,38,-85;0,7,3,71;52,59;-8,-252,16,-83;22,14,-1,0,0,1",
"0;xs13_08k8a52z321;0;;-10,103,-3,54,-1,13;38,5,50,100;-8,-116,-4,-152,-2,-185;22,27,1,0,0,-1",
"0;xs13_08ka96z321;0;15,-27,22,-71;-2,15;17,8;-7,-96;7,11,-1,0,0,-1",
"0;xs13_08o696z321;0;;-9,60,0,7;21,36;-4,-73;13,11,-1,0,0,1",
"0;xs13_08ob96z32;0;9,-22;1,5;11,10,18,10;3,-38,10,-34;4,7,0,1,-1,0",
"0;xs13_08u156z32;0;;-10,47,-4,28;15,7,18,46;2,-59;-1,12,0,1,-1,0",
"0;xs13_0cp3z69c;0;;-20,87,-8,101,-5,30,2,6;36,18,54,102;-17,-145,-12,-160;19,22,-1,0,0,1",
"0;xs13_0g853zol3;0;39,-88,48,-185,66,-255;0,13;44,30,51,7,61,75;-19,-235,8,-164;26,37,-1,0,0,-1",
"0;xs13_0g853zrm;0;20,-73,29,-77,33,-49;4,6,21,9;40,17;3,-90,12,-78,18,-85;24,11,0,-1,-1,0",
"0;xs13_0g8o653z121;0;9,-24,17,-53;-1,12;12,7;0,-46;0,12,1,0,0,-1",
"0;xs13_0g8o653z23;0;21,-76,32,-79;-2,23;20,8,25,43;-1,-130;2,9,0,1,1,0",
"0;xs13_0gbaicz121;0;17,-60;-3,40,3,7;18,35;7,-76;11,16,0,1,1,0",
"0;xs13_0ggc871z641;0;38,-124,55,-172;-5,27,5,14;46,75,53,6;5,-88,15,-137;32,18,-1,0,0,1",
"0;xs13_0ggka53z32;0;;-12,64,-5,44,0,8;18,10;-10,-91,2,-76;11,8,-1,0,0,1",
"0;xs13_0ggm952z32;0;12,-41;3,8;17,28;-2,-56;4,-3,0,-1,1,0",
"0;xs13_0ggo8b5z32;0;18,-60,23,-85;9,14;24,5,32,17,33,36;-2,-66,1,-75;12,7,0,1,1,0",
"0;xs13_0mk453z121;0;11,-21,16,-57;0,8;13,7;0,-49;2,8,0,1,-1,0",
"0;xs13_17871ac;0;19,-54;1,6;20,24;1,-37,5,-76;7,6,0,1,1,0",
"0;xs13_178ka53;0;;-9,45,0,7;16,14;-16,-82,-5,-58;6,8,0,-1,1,0",
"0;xs13_25303pm;0;;-11,60,-7,36,8,8;26,51;1,-73;6,18,1,0,0,-1",
"0;xs13_2530f96;0;;-5,30;7,6,12,30;-1,-51;5,11,0,1,-1,0",
"0;xs13_2530fho;0;;-7,35;11,8,18,35;-13,-67;7,5,0,-1,1,0",
"0;xs13_255q8a6;0;;-10,61,1,6;25,31;-9,-95,-6,-74;3,20,1,0,0,-1",
"0;xs13_256069ic;0;;-3,21;9,18,13,5;0,-41;2,8,1,0,0,-1",
"0;xs13_25606ako;0;13,-44;6,15;21,5;7,-27;6,6,1,0,0,-1",
"0;xs13_2560uh3;0;7,-20,15,-41;1,6;11,7;-2,-40;8,5,-1,0,0,1",
"0;xs13_2560uic;0;12,-38;2,6;16,26;-3,-62;10,5,0,-1,1,0",
"0;xs13_256o8gkc;0;;-6,31;10,7,16,30,26,50,32,76;-7,-88;7,19,1,0,0,-1",
"0;xs13_25960ui;0;;-4,24;7,5;-4,-58,0,-37;2,4,0,1,1,0",
"0;xs13_2596zy32552;0;;-4,41,-3,19;10,7;-3,-65;13,14,-1,0,0,-1",
"0;xs13_259m853;0;;-11,63,-6,34;14,17,21,7,30,41;-16,-97,-12,-106,-3,-75;11,21,0,-1,-1,0",
"0;xs13_259mge2;0;;-23,101,-14,95;23,5,39,108;-8,-129;18,28,-1,0,0,-1",
"0;xs13_25a8oge2;0;30,-76,44,-169;8,45;30,7,39,63;-7,-180;19,23,0,1,-1,0",
"0;xs13_25ac0f9;0;;-5,41,0,7;19,16;-4,-76,-4,-53;4,12,1,0,0,1",
"0;xs13_25iczw1256;0;16,-57,25,-70,25,-34,26,-55;4,6;30,21;4,-73;12,12,1,0,0,-1",
"0;xs13_2eg6p3zx1;0;;-2,17;14,8;2,-59,5,-29;4,5,0,1,1,0",
"0;xs13_2ege1e8;0;16,-55;-1,33,2,7;17,30;-2,-67;14,11,-1,0,0,1",
"0;xs13_3123qic;0;;-9,43,2,6;20,26;-12,-71,-7,-87;5,17,0,-1,-1,0",
"0;xs13_31248gzy21248c;0;13,-42;3,17;17,5,23,27;-5,-57,2,-77,6,-47,12,-46;8,8,1,0,0,1",
"0;xs13_3146178c;0;11,-35;1,6,6,17;17,18;3,-42;7,2,0,-1,1,0",
"0;xs13_3146o8a6;0;32,-57;0,7,7,44;39,11;6,-130;17,19,1,0,0,-1",
"0;xs13_31ege13;0;;-6,33;10,7;-8,-71,-3,-45;11,7,0,1,1,0",
"0;xs13_31egma4;0;;-9,44,-3,20;9,8,17,42;-8,-57;3,7,0,1,1,0",
"0;xs13_31eozca1;0;19,-59;0,8,4,28;28,46;1,-95,3,-69;8,8,0,1,1,0",
"0;xs13_31eozx1252;0;14,-49;3,5;14,14,16,37,25,31;-2,-58,2,-72;7,5,1,0,0,1",
"0;xs13_31kmiczw1;0;;-4,24;6,8,14,22;-6,-41;3,5,1,0,0,1",
"0;xs13_32132ako;0;17,-59,26,-89,29,-109;2,20;21,6,25,25;-12,-85;13,11,-1,0,0,1",
"0;xs13_321eg853;0;43,-109,65,-250;25,8;55,21,58,68;-2,-280,5,-132,6,-92,10,-98,22,-99;34,16,1,0,0,-1",
"0;xs13_321fgkc;0;;-4,25,8,8;19,28,20,9;-2,-84;7,8,0,-1,-1,0",
"0;xs13_32akg8426;0;22,-81,37,-115;6,21;34,6,41,45;-7,-82,2,-93,14,-86;16,19,1,0,0,-1",
"0;xs13_32qb96;0;14,-48;1,27;22,6;6,-39;12,7,0,1,-1,0",
"0;xs13_32qkzx346;0;;-13,66,-8,44,0,8;16,23,27,51;-19,-98,-4,-82;6,12,0,1,1,0",
"0;xs13_354264ko;0;;-13,62,-4,51;27,64,29,8;-8,-106;17,17,-1,0,0,1",
"0;xs13_354c0cic;0;9,-27;4,5;16,15;7,-30;13,6,-1,0,0,-1",
"0;xs13_354c0f9;0;8,-25;3,11;17,8;-4,-48,6,-27;13,4,-1,0,0,1",
"0;xs13_354djo;0;;;3,5;-31,-253,-26,-110,-5,-18,9,-37;17,7,-1,0,0,-1",
"0;xs13_358go8a6;0;13,-43,24,-49;0,18;16,8,26,14;7,-48;12,9,-1,0,0,-1",
"0;xs13_3hu06a4;0;9,-28;3,6;16,15;9,-47;16,2,0,-1,1,0",
"0;xs13_3pczw1156;0;10,-27,16,-54;4,15;18,5;7,-100,7,-48;3,6,1,0,0,-1",
"0;xs13_4ap3zw1252;0;19,-66,26,-72;3,54,5,5;28,12,35,34;-4,-105;15,9,0,1,1,0",
"0;xs13_652sga6;0;9,-23,13,-45;0,11;14,6;2,-39;-3,6,0,1,1,0",
"0;xs13_6952zy1cic;0;;;2,7,15,40;-10,-53;-1,13,0,1,-1,0",
"0;xs13_696zx8kic;0;;-4,26;16,6;2,-39;10,4,-1,0,0,1",
"0;xs13_6970bd;0;13,-45,19,-42;4,6;17,9;-4,-58;5,3,0,1,1,0",
"0;xs13_69e0mq;0;;-9,43;18,19,20,5;1,-56;12,10,0,-1,1,0",
"0;xs13_69jwo8zx121;0;;-11,53,-3,26,4,7;19,24,22,52,26,36;-6,-80,4,-65;9,17,0,1,-1,0",
"0;xs13_69jzwc96;0;20,-52,26,-94,34,-128;-3,39,6,29;30,5,30,33;-8,-113;10,14,0,1,1,0",
"0;xs13_69jzx12ko;0;;-18,79,-6,93,-4,61;30,6,37,58,52,94;-15,-137,-10,-152;19,28,-1,0,0,-1",
"0;xs13_8e13zdb;0;;-9,210,0,7;89,132,98,209,111,58;0,-377;57,57,0,-1,-1,0",
"0;xs13_c9jz39c;0;14,-47,21,-51;0,21,8,22;17,6,30,21;9,-51,16,-47;11,8,0,1,1,0",
"0;xs13_c9jzbd;0;13,-43,20,-47;1,17,8,22;17,6,30,21;9,-51,16,-47;19,8,0,-1,1,0",
"0;xs13_ci52zbd;0;12,-41,35,-85;5,21;18,8;2,-86,11,-78;10,13,0,1,-1,0",
"0;xs13_dbgzbd;0;13,-43,20,-47;1,17,8,22;17,6,29,17;10,-47,17,-43;11,8,0,1,1,0",
"0;xs13_djozx352;0;15,-49;1,6;15,37;-4,-81;12,9,-1,0,0,-1",
"0;xs13_g88m96z121;0;;-20,89,-4,59;33,7,33,54;-9,-102;12,20,0,-1,-1,0",
"0;xs13_g8ge96z121;0;8,-22,14,-47;1,7;14,9;-1,-47;4,4,1,0,0,1",
"0;xs13_g8ka23z56;0;14,-48;4,7,4,26;16,6,21,33;-9,-121;5,7,1,0,0,1",
"0;xs13_ggc871z65;0;16,-54,33,-97;0,37;21,5,34,41,37,23;0,-110,10,-96;15,15,0,1,-1,0",
"0;xs13_j5c48cz11;0;16,-56;1,5;24,38;-1,-54,6,-74,7,-51;11,11,0,-1,-1,0",
"0;xs13_j5c4goz11;0;15,-53,29,-103,39,-101;-4,39,1,8,7,17,11,34;36,41;6,-89,14,-68;19,16,-1,0,0,-1",
"0;xs13_j96zdb;0;;-20,87,-8,101,-4,30,3,6;37,18,54,102;-17,-145,-12,-160;17,30,1,0,0,-1",
"0;xs13_oe1246z23;0;23,-82;-6,33,3,5;36,34,39,70;-10,-125;11,21,1,0,0,-1",
"0;xs13_wg8o652z65;0;21,-76;2,18,11,6;23,33;10,-90;19,4,-1,0,0,1",
"0;xs13_wgila4z252;0;;-4,54,0,7,8,15;27,33,28,57;2,-72;12,12,0,1,1,0",
"0;xs14_03iarz65;0;21,-42,25,-79,27,-100;-2,29,0,8;26,28,29,13;1,-88;10,16,0,1,-1,0",
"0;xs14_065la4z321;0;24,-87,24,-27;13,12;27,5;17,-24,18,-91;20,4,0,-1,-1,0",
"0;xs14_08kai3z6221;0;15,-52,22,-50;5,17;14,10,21,8;1,-43;7,5,0,1,1,0",
"0;xs14_08o0e93z321;0;12,-40,22,-73;-1,28;18,8;-1,-76;12,5,-1,0,0,1",
"0;xs14_08o0e96z321;0;9,-27;1,8;10,15;-1,-34;2,9,1,0,0,-1",
"0;xs14_08o69a4z321;0;;-12,56,1,7;17,49,19,22;-4,-73;1,14,0,1,1,0",
"0;xs14_08u1e8z321;0;16,-54;5,10;19,6;-4,-115,-4,-55,2,-66;-1,16,1,0,0,-1",
"0;xs14_0bt066z32;0;15,-52,16,-22,24,-66;4,10;17,5;-1,-77,3,-39;15,9,-1,0,0,-1",
"0;xs14_0drzrm;0;16,-57,22,-53;-1,22,11,6;23,19,29,15;-2,-66,10,-50;9,8,0,1,1,0",
"0;xs14_0g02596z3452;0;;-6,32,6,6;;-9,-74,3,-48;5,7,0,1,1,0",
"0;xs14_0g8421e8z1226;0;;0,8;15,23;-1,-70,2,-36;12,7,-1,0,0,1",
"0;xs14_0g8ob96z23;0;8,-23,19,-47;4,11;18,8;3,-55;5,11,1,0,0,-1",
"0;xs14_0gbb8oz123;0;;-3,20;8,7,14,27;-6,-40;7,3,-1,0,0,1",
"0;xs14_0gbb8oz321;0;13,-44,27,-85;-2,32;17,8;0,-69;15,13,0,-1,-1,0",
"0;xs14_0gilicz641;0;13,-44,18,-39;2,11,4,22;20,6,27,10;6,-34,13,-34;9,4,0,1,1,0",
"0;xs14_0m2s53z121;0;19,-65,35,-105;-1,32,0,10,4,40,7,19;26,8,32,38;-6,-89,3,-73;18,17,-1,0,0,-1",
"0;xs14_0md1e8z32;0;13,-31,17,-61;3,18;15,6;-1,-55;12,6,0,-1,1,0",
"0;xs14_0ml9a4z121;0;23,-82;-6,54,1,8;33,48,43,15,43,34,44,69;2,-89,6,-117;24,19,-1,0,0,-1",
"0;xs14_0mp3zc96;0;27,-74;1,6,1,34;44,62;2,-130,2,-102;20,13,-1,0,0,1",
"0;xs14_178f1e8;0;12,-23,17,-58;6,11;20,6;0,-61;12,4,-1,0,0,1",
"0;xs14_1no3tg;0;8,-22;5,6;18,10;13,-26;9,2,0,1,1,0",
"0;xs14_256o8gka4;0;16,-57,24,-78;4,6;36,44;-11,-85,-10,-100,-2,-93,3,-59;13,17,0,-1,-1,0",
"0;xs14_2596zzzybcik8;0;;-5,76,1,6;;-4,-158,2,-88;10,11,1,0,0,1",
"0;xs14_259e0db;0;11,-36;2,8;16,19,20,16;-3,-37,-1,-57,3,-38;5,10,1,0,0,-1",
"0;xs14_259e0mq;0;12,-38;5,6;11,9;-6,-86,0,-56;1,-2,1,0,0,-1",
"0;xs14_25a8o0ui;0;16,-55,26,-74;6,8;21,24,32,43;-5,-83,9,-66;13,17,0,-1,-1,0",
"0;xs14_25iczw178c;0;11,-37,15,-34;3,7;19,21;6,-40;6,3,0,1,1,0",
"0;xs14_2lmz3kp;0;29,-106;3,8;38,80;-5,-93,6,-125;21,24,1,0,0,-1",
"0;xs14_312kozx12ko;0;22,-80,33,-71,39,-127;-2,21,1,58;21,8,32,57;-2,-110;20,14,0,-1,-1,0",
"0;xs14_31egm93;0;;-5,27;10,6;-11,-60,-6,-59;6,5,0,-1,1,0",
"0;xs14_31egm96;0;;-8,49,-3,22;16,7;-13,-78,-6,-87;7,3,1,0,0,-1",
"0;xs14_31ego8a6;0;;-5,30;8,6,11,26,20,57;-9,-75;4,12,0,-1,1,0",
"0;xs14_31eozx1256;0;17,-32,33,-96,36,-116;0,8;27,11;-7,-92,8,-24;19,10,0,-1,1,0",
"0;xs14_3213213zy566;0;13,-45;8,7;28,10;8,-23;13,0,0,1,1,0",
"0;xs14_32qczx1156;0;;-6,33,5,8;17,32,25,16;-4,-88,5,-70;14,15,-1,0,0,-1",
"0;xs14_32qj4ko;0;;-6,34,6,5;23,49;1,-61;12,10,-1,0,0,1",
"0;xs14_33gv146;0;19,-67,29,-67;-1,26,8,8;41,55;-7,-111,1,-110,3,-76;19,18,0,-1,-1,0",
"0;xs14_3560uh3;0;;-21,105,0,8;31,77;-18,-123,-4,-141,5,-117;16,21,-1,0,0,-1",
"0;xs14_358e12ko;0;31,-70,40,-123;-6,31,-5,49,9,28,10,7;46,58;-16,-274,4,-98,23,-171;13,25,1,0,0,-1",
"0;xs14_39e0e93;0;7,-19;4,6;14,6;11,-19;6,4,1,0,0,-1",
"0;xs14_39e0e96;0;12,-38;1,7;17,25;0,-57;13,6,0,-1,1,0",
"0;xs14_39e0eic;0;;-5,27;11,5;-13,-85,-7,-43;11,3,-1,0,0,1",
"0;xs14_39e0eio;0;;-2,36,0,10;19,8,25,49;3,-62;13,9,-1,0,0,1",
"0;xs14_3hu0696;0;;-6,48,0,7;19,40;1,-61;2,3,1,0,0,1",
"0;xs14_3hu0okc;0;;-8,40,2,6;12,26;-13,-76;7,12,0,-1,1,0",
"0;xs14_3p6853z11;0;27,-100,40,-68,44,-135,47,-115;-1,24;31,23,59,8;13,-135,21,-138,21,-69;34,15,1,0,0,-1",
"0;xs14_3pczw115a4;0;;-13,62,8,7;26,14,28,43;-9,-104,5,-97,7,-75;21,13,0,-1,1,0",
"0;xs14_3pczw12453;0;12,-41;3,5;18,8;-4,-42,2,-52;3,10,1,0,0,-1",
"0;xs14_3pczw6jo;0;28,-103,44,-107;4,6,4,50;29,5,45,9;13,-106,13,-62;27,12,0,-1,1,0",
"0;xs14_3pmzx3213;0;;-2,16,3,43,7,8;18,9,35,47;1,-116,6,-96;19,15,-1,0,0,-1",
"0;xs14_4a9b8ozx32;0;15,-51,30,-88;-1,39;20,8,27,12,30,35,36,30;-5,-94,1,-98,8,-94;12,20,0,1,-1,0",
"0;xs14_4a9j08ozx121;0;;-11,52,-9,67,-3,24;12,8,26,52,37,58;-4,-90;6,13,1,0,0,1",
"0;xs14_4a9jz0bd;0;12,-41,19,-47;2,14,7,22;16,6,28,17;9,-47,16,-43;10,7,0,1,1,0",
"0;xs14_4a9m88gzx121;0;;-2,38,1,6;21,45;0,-64;6,6,1,0,0,1",
"0;xs14_4a9raa4;0;11,-29;-2,16;17,8;-3,-67,7,-94;16,7,-1,0,0,-1",
"0;xs14_4a9ria4;0;9,-29,16,-42,28,-86;1,5;20,16;-8,-74,-1,-47,10,-36;11,11,0,-1,1,0",
"0;xs14_4aaraa4;0;;-18,79;22,29,26,5;-16,-131,-9,-100,-1,-91;4,12,0,1,1,0",
"0;xs14_4ap3z69c;0;;-20,87,-8,101,-4,30,3,8;39,23,54,102;-17,-145,-12,-160;19,22,-1,0,0,1",
"0;xs14_628c2dic;0;;-37,168,-6,33,0,8;30,42,36,47,47,69,52,154;-32,-181;15,29,0,-1,-1,0",
"0;xs14_64132qr;0;13,-43,20,-47,26,-36,28,-55;1,17,8,16;21,8;5,-65;11,7,1,0,0,1",
"0;xs14_64lb8ozw11;0;12,-40,22,-50;2,7;14,10,24,20;4,-53;8,5,0,1,1,0",
"0;xs14_65la4ozx11;0;;-9,46,6,8;19,9;-6,-65,1,-59;1,13,0,1,1,0",
"0;xs14_65p68ozx11;0;16,-56,25,-78;8,5;31,22,40,44;-2,-95;18,10,-1,0,0,1",
"0;xs14_65pa4ozx11;0;12,-41,18,-31;0,18;19,8;6,-30;10,8,1,0,0,-1",
"0;xs14_6960uic;0;;-8,39,1,8;;-4,-52,1,-56;6,5,0,1,1,0",
"0;xs14_6970796;0;7,-18;1,6;8,6;1,-28;10,2,0,-1,1,0",
"0;xs14_6970si6;0;;-1,33,1,5;16,14,20,42;7,-56;6,2,1,0,0,-1",
"0;xs14_6970sic;0;15,-51,17,-34;3,18;21,22,23,5;7,-38;15,5,-1,0,0,1",
"0;xs14_69960ui;0;;-3,22;6,6,15,19,17,43;-10,-68;7,13,0,-1,-1,0",
"0;xs14_69a4y04aic;0;;-11,52,1,6;;-14,-110,-2,-64;6,9,0,1,1,0",
"0;xs14_69akgkczx1;0;;-4,45,0,8;18,9,23,52;2,-65;11,6,0,1,1,0",
"0;xs14_69arzx123;0;9,-27,15,-47;5,7;21,14;1,-65;6,-1,0,1,1,0",
"0;xs14_69bo8a6;0;10,-32;4,6;19,20;-3,-63;8,11,0,1,-1,0",
"0;xs14_69bqic;0;;-4,23;10,8;-2,-36;11,2,0,-1,1,0",
"0;xs14_69e0eic;0;9,-28;2,8;11,12;-2,-32;2,3,1,0,0,1",
"0;xs14_69eg8ozw23;0;;-6,33,7,5;19,18,19,35,26,37;0,-72;7,13,0,1,-1,0",
"0;xs14_69f0f9;0;;-3,20;8,7,11,27;3,-51;6,-2,0,1,1,0",
"0;xs14_69la4ozx11;0;;-2,28,1,6;12,14;0,-40;10,5,-1,0,0,1",
"0;xs14_6is079c;0;11,-34;6,22;17,5;2,-51;8,11,1,0,0,1",
"0;xs14_8ehjkczw1;0;21,-49,38,-117;-7,36,4,26,8,6;37,33;-4,-104,3,-90;18,13,-1,0,0,1",
"0;xs14_8ehjzw1074;0;;0,7;11,29,17,16;-7,-80,-7,-45;10,8,-1,0,0,1",
"0;xs14_8k453zbd;0;17,-57,35,-80;-6,34,3,6;34,44;-4,-113,2,-79;8,20,1,0,0,-1",
"0;xs14_8u15a4z32;0;16,-51,29,-97;1,6;20,16,22,6,22,39,30,30;-10,-108,-3,-91;7,20,1,0,0,-1",
"0;xs14_c842arzx32;0;13,-42,20,-46;3,10,10,13;17,6,26,13,26,27;6,-65;18,11,0,-1,-1,0",
"0;xs14_c88a53z33;0;;1,6;13,23;-3,-60,-1,-36;7,10,1,0,0,-1",
"0;xs14_cai3zbd;0;;;15,8,16,51,31,81;-37,-210,-32,-180,-31,-156,-31,-122,-8,-94;-1,12,1,0,0,1",
"0;xs14_ck31246z023;0;11,-35,20,-63;2,8;19,23;-7,-72,2,-54;6,8,1,0,0,1",
"0;xs14_cp3z012156;0;;-9,44,1,17;17,8,17,35;3,-57;8,6,0,1,1,0",
"0;xs14_cp3zrm;0;13,-38,22,-58,29,-70;1,5,4,21;28,26;3,-57,9,-61;8,11,0,1,-1,0",
"0;xs14_djozxbd;0;12,-40,25,-57,28,-87;3,27,4,7;22,25;-9,-98,1,-72;7,8,1,0,0,1",
"0;xs14_drz012156;0;13,-44,20,-48;3,8,7,32;22,12;4,-66;12,7,0,1,1,0",
"0;xs14_drzrm;0;15,-53,21,-49;0,18,11,6;23,19,29,15;-1,-62,10,-50;9,8,0,1,1,0",
"0;xs14_g4s0796z11;0;13,-44;-2,32,0,12;22,24,24,7;4,-52;8,7,1,0,0,1",
"0;xs14_g4s079cz11;0;;-4,25;15,5,26,55;-13,-96,-7,-68;8,19,0,1,-1,0",
"0;xs14_g88b96z123;0;7,-20;0,8;7,7;-1,-36;-1,0,0,1,1,0",
"0;xs14_g88m952z121;0;;-4,26;6,6;-6,-57;9,3,-1,0,0,1",
"0;xs14_g88q552z121;0;15,-45;0,31,1,5;20,16;3,-84,5,-44;15,6,-1,0,0,-1",
"0;xs14_g8id96z121;0;11,-36;2,20;11,8,18,10;11,-34;8,3,1,0,0,1",
"0;xs14_g8o0e96z121;0;;-6,33;12,5,13,35;-3,-52;0,3,0,1,1,0",
"0;xs14_g8o69a4z121;0;;-4,24,7,6;15,17;2,-40;3,7,0,1,1,0",
"0;xs14_ggca53z65;0;16,-55,31,-111,48,-165;-2,42;21,7,38,16;8,-126,9,-107;23,15,-1,0,0,1",
"0;xs14_i5q453z11;0;7,-21,14,-49;0,7;14,9;0,-33;1,1,1,0,0,1",
"0;xs14_j1u066z11;0;7,-21;0,7;6,7;2,-20;0,1,1,0,0,1",
"0;xs14_j1u413z11;0;;0,8,2,26;21,39;5,-52;10,11,1,0,0,-1",
"0;xs14_j9a4zc93;0;12,-41,19,-47;2,14,7,22;16,6,29,21;8,-51,15,-47;10,10,0,1,-1,0",
"0;xs14_j9c826z23;0;40,-150,49,-135,59,-155,60,-198;1,58;46,95,48,78,53,8;-14,-172,-12,-230,-6,-149,4,-114;26,33,-1,0,0,-1",
"0;xs14_mmge13z1;0;15,-52;1,6;22,39;-5,-78;10,10,0,-1,1,0",
"0;xs14_mp3zw3146;0;21,-69,40,-89;-5,46,-4,23,11,17;25,5,36,49;-11,-131,3,-67,11,-84;13,10,0,1,-1,0",
"0;xs14_o4id1e8z01;0;;-3,20;10,8,16,32;-9,-52;1,7,1,0,0,1",
"0;xs14_o4s0796z01;0;;;2,7,11,22;-9,-35,-7,-46,-5,-63;-3,11,1,0,0,-1",
"0;xs14_o4s079cz01;0;;;2,7,18,38;-13,-82,-13,-51,-11,-62;-5,13,1,0,0,-1",
"0;xs14_ok2156z65;0;;-12,55,4,21;20,6,25,54,29,38;-7,-94,3,-79;15,19,-1,0,0,-1",
"0;xs14_ok21e8z65;0;41,-155,48,-170,66,-227;-24,142,-6,42;55,6,72,137;-36,-318,-20,-219;17,42,0,1,1,0",
"0;xs14_ra248cz23;0;12,-39,19,-43;4,5,10,12;17,5,26,12,26,26;6,-66;18,6,0,-1,1,0",
"0;xs14_w8k8a52z2521;0;;-8,95,-1,46,1,5;48,92;-6,-108,-2,-144,0,-177;21,25,1,0,0,-1",
"0;xs14_wg8ge13z643;0;16,-54,28,-60;0,28;18,8,30,14;12,-40;18,5,0,-1,1,0",
"0;xs14_wg8o653z65;0;12,-39;-1,26;14,11,20,7;-5,-81;3,15,0,1,-1,0",
"0;xs14_wgbq23z65;0;31,-76,50,-175,53,-202;11,5;43,63;-9,-191,1,-142,4,-151;24,25,-1,0,0,1",
"0;xs14_wggc453z643;0;;1,5;8,14,17,32;0,-45;3,10,1,0,0,-1",
"0;xs14_wggc871z6221;0;15,-35,21,-77;4,16;20,5;-6,-65,5,-43;6,6,1,0,0,1",
"0;xs14_wggka23z652;0;12,-40,33,-82;4,6,11,11;24,17;3,-87,4,-47,13,-46;9,14,0,1,-1,0",
"0;xs14_wggm96z643;0;;0,8;19,17,22,39;-6,-101,0,-51;8,16,1,0,0,-1",
"0;xs14_wkc3213z65;0;20,-70,41,-119;1,48;20,18,23,8,31,22;11,-80,12,-61;21,10,0,-1,1,0",
"0;xs14_wog853zdb;0;28,-97,37,-128;-8,70,-4,26,1,58,7,8;31,23,39,85;0,-142;16,24,1,0,0,-1",
"0;xs14_xg8o652zca1;0;;-5,148,-4,26,6,17;55,6,75,152;14,-165;23,36,1,0,0,-1",
"0;xs14_xgs252z4a43;0;16,-56,35,-95;-1,30;16,5,35,44;2,-70;9,9,0,1,1,0",
"0;xs15_035iczcip;0;;-11,54,0,8,0,34;25,58,27,19,34,39;4,-105;5,15,0,1,1,0",
"0;xs15_03lk46z643;0;;-20,88;22,60,27,8;-17,-100,-4,-125;6,17,0,1,-1,0",
"0;xs15_04al5a4z311;0;41,-157,48,-177,51,-169;-22,111,-12,94;40,81,47,115,50,7;-30,-189,-22,-279,-10,-128;22,28,0,1,1,0",
"0;xs15_06t1acz321;0;11,-33,18,-65;1,8;17,21;-5,-67;5,9,1,0,0,1",
"0;xs15_06t1e8z321;0;13,-42;6,5;19,30,22,13;-3,-57;12,2,-1,0,0,1",
"0;xs15_08kaarz321;0;;-13,109,-9,86,-8,41;20,5,29,47,41,99,42,48,50,104;-26,-209;22,24,-1,0,0,1",
"0;xs15_08o6996z321;0;;-4,26;11,7;-4,-76,3,-39;5,7,1,0,0,1",
"0;xs15_08o6picz32;0;;-21,93,-10,66,4,18,4,47;39,84,40,7;-3,-143;18,20,-1,0,0,1",
"0;xs15_09v0ccz321;0;19,-67,28,-84;9,7;44,55;-5,-123;11,14,1,0,0,-1",
"0;xs15_0at1acz321;0;;-3,37,1,5;20,20;1,-50;7,13,-1,0,0,-1",
"0;xs15_0bdge2z321;0;32,-86,50,-120,51,-197,66,-151;6,6,8,41;47,12,50,36,54,10;-2,-130,6,-141,10,-106,21,-104;20,12,0,1,-1,0",
"0;xs15_0c4gf9z2521;0;30,-82,50,-184;-13,70,-8,40,12,6;37,23,48,22,53,45;-3,-185,-3,-165;27,28,0,-1,-1,0",
"0;xs15_0cilicz321;0;;-11,76,-7,83,1,5,2,64;28,30,37,49,39,27,42,88;7,-161;19,20,0,-1,-1,0",
"0;xs15_0drzoja4;0;18,-61,35,-108;-1,14,0,33,6,6;21,15,34,48;-13,-123,-4,-91;12,20,1,0,0,-1",
"0;xs15_0g0s2qrz121;0;14,-36,16,-54;3,10;22,5;4,-50,6,-23;10,8,0,1,-1,0",
"0;xs15_0g4qajoz121;0;106,-326,110,-232,127,-343;-3,20,6,76;117,5,128,191,141,219;-6,-516,5,-313,6,-264,15,-240;68,67,1,0,0,-1",
"0;xs15_0g6picz343;0;;-2,25,1,5;11,16;6,-38;3,7,0,1,1,0",
"0;xs15_0g84cj96z32;0;;-34,219,-22,156,-17,78,6,6;61,146,79,193;-29,-231,-16,-352,3,-297;29,42,-1,0,0,1",
"0;xs15_0g8ehrz321;0;;-11,58,-2,16;15,6,17,41;-5,-70;11,9,-1,0,0,1",
"0;xs15_0g8k453zoo11;0;7,-21;4,9;19,8;3,-27;17,-3,0,-1,1,0",
"0;xs15_0ggdjoz643;0;17,-55,22,-78;13,8;29,12;3,-56,11,-87,16,-67;16,3,1,0,0,1",
"0;xs15_0gilicz346;0;;-5,29,3,16;22,5;0,-88,15,-41;14,12,1,0,0,-1",
"0;xs15_0gjlkcz641;0;26,-66,38,-121;1,6,8,34,11,15;36,9,47,35;0,-123,1,-137,11,-123,15,-47;26,14,-1,0,0,1",
"0;xs15_0gs25a4z1246;0;;-3,38,0,8,4,90;39,39,57,91;-13,-217,-6,-139;10,27,0,1,-1,0",
"0;xs15_0i5q453z121;0;18,-64,25,-81;2,7,3,28;28,21,32,8,39,22,43,51;2,-106;21,14,0,-1,1,0",
"0;xs15_0j1u066z121;0;;-6,33;7,7;-7,-67,-2,-46;8,15,-1,0,0,-1",
"0;xs15_0j1u0ooz121;0;13,-36,18,-62;3,5;19,23;-4,-72,4,-77;-7,17,0,1,-1,0",
"0;xs15_0ml9a4z641;0;22,-79,35,-93;2,21;27,44,29,32,35,23,35,67,38,7;-9,-110,-4,-134,7,-94;10,21,0,1,-1,0",
"0;xs15_1784cj96;0;36,-99,51,-123,56,-157,64,-248;-2,42,10,22,21,6;64,67;-3,-169,4,-157,7,-80,17,-211;22,24,-1,0,0,-1",
"0;xs15_178bpic;0;;-20,123,1,6;61,89,66,132,75,157;-24,-224,-8,-309,-5,-196,-2,-170;26,32,-1,0,0,1",
"0;xs15_178bqic;0;;0,9;10,8,15,27;4,-40;7,5,0,-1,1,0",
"0;xs15_178czw3553;0;;-5,42,1,5;16,33,18,16;1,-62;4,13,1,0,0,-1",
"0;xs15_253gv146;0;19,-67,29,-67,40,-125;-1,26,8,8;41,55;-6,-110,1,-110,3,-76;19,19,0,-1,-1,0",
"0;xs15_255q88czx23;0;49,-140,71,-232,76,-192;-10,84,1,5;75,127;-15,-248,-12,-272,-5,-176;32,38,0,-1,-1,0",
"0;xs15_25960uh3;0;;1,5,1,43;31,52;9,-64;9,14,0,1,-1,0",
"0;xs15_259e0e93;0;;;12,48,27,8;-15,-61,-11,-138;8,15,-1,0,0,-1",
"0;xs15_259e0eic;0;8,-22;8,7;14,8;3,-50;20,-1,-1,0,0,1",
"0;xs15_259e0eio;0;8,-24;8,9;14,6;12,-34;17,3,-1,0,0,1",
"0;xs15_259mge13;0;9,-28,20,-64;3,6;18,16;-1,-56;5,12,1,0,0,1",
"0;xs15_25a8ob96;0;;-9,45,3,8;19,20;-6,-57,-4,-73;9,7,0,1,1,0",
"0;xs15_25ao4cz2521;0;15,-50,23,-58;4,6;20,8,27,13;8,-26,13,-57;21,10,0,-1,-1,0",
"0;xs15_25is0796;0;13,-39,22,-79;3,5;16,27,24,23;-7,-68,4,-53,6,-70;8,12,1,0,0,-1",
"0;xs15_25is0sic;0;;-14,75,-7,35;25,42,26,6,27,68;-1,-88;6,23,1,0,0,-1",
"0;xs15_2eg6p56zx1;0;38,-132,45,-170;0,8,4,30,4,52;48,18,59,68,66,20,70,120;-13,-197,-8,-168,-1,-181;22,30,0,-1,-1,0",
"0;xs15_2lmge2z32;0;17,-60;-1,14,3,21;18,6,24,47;-7,-86,3,-64;10,11,-1,0,0,1",
"0;xs15_2lmz056zz33;0;;-7,38;13,34,14,7;9,-73;17,7,0,-1,-1,0",
"0;xs15_3123cj96;0;17,-59,31,-75;3,17;18,5,26,28;5,-41,16,-85;18,9,0,-1,-1,0",
"0;xs15_312kozy131e8;0;21,-77,37,-125;-2,49,7,37;26,6,39,64;6,-139;25,21,0,-1,-1,0",
"0;xs15_31461ug8o;0;;-14,89,-6,31,-2,72,1,7;23,19,41,92,42,73;-12,-148;9,16,0,1,1,0",
"0;xs15_3146pb8o;0;20,-58,31,-115,31,-94,38,-84;1,46,6,11;24,7,35,36;-7,-105;14,10,0,1,1,0",
"0;xs15_32138n96;0;115,-149,127,-169,135,-217,136,-160,148,-583,151,-226;62,81,76,81;139,8;47,-205,56,-228,61,-552;85,35,1,0,0,-1",
"0;xs15_3213ob96;0;15,-50;-1,38,1,8;28,21;-1,-68;13,8,-1,0,0,1",
"0;xs15_321fgc48c;0;;-15,89,-6,31,-3,72,1,7;23,19,40,92,41,73;-13,-148;12,24,0,-1,-1,0",
"0;xs15_32qbzx1156;0;17,-58,26,-59;0,29;19,23,27,5,29,26;4,-87,6,-66;19,10,0,-1,1,0",
"0;xs15_33gv1oo;0;;-2,17;11,7;-9,-71,-8,-50;1,6,0,1,1,0",
"0;xs15_354c0fho;0;;-24,104;26,76,29,7;-21,-116,-6,-124;13,16,-1,0,0,1",
"0;xs15_354cgc453;0;16,-43;1,6;21,31;-4,-86;10,13,1,0,0,-1",
"0;xs15_358gu156;0;10,-31;4,9;10,5;1,-43,3,-21;8,0,0,-1,1,0",
"0;xs15_35a842ako;0;16,-57,25,-64;5,35;28,5,36,44;9,-86;12,9,1,0,0,1",
"0;xs15_35a8o0ui;0;27,-71;-7,36,4,8;39,58;-5,-104,-5,-72,-3,-152;18,30,0,-1,-1,0",
"0;xs15_35is0qm;0;16,-56;1,21;18,34,19,10,23,7;2,-66,6,-47;8,11,1,0,0,-1",
"0;xs15_39c84czw253;0;10,-27,18,-63;4,7;16,15;-5,-62;3,13,1,0,0,-1",
"0;xs15_39c8a6z033;0;26,-96,41,-64,45,-98,48,-68;9,37;50,6;22,-94,23,-50;31,15,-1,0,0,-1",
"0;xs15_39cga6z321;0;16,-39,24,-88,24,-72,31,-82;2,5;28,26;4,-59,4,-45;9,9,1,0,0,-1",
"0;xs15_39e0djo;0;;-26,115,-9,43,8,6;40,114,41,22,44,12;-32,-233,-5,-175;20,20,0,1,1,0",
"0;xs15_39e0mp3;0;;-26,117,-9,45,0,14,3,24;36,8,40,116;-32,-231,-5,-173;24,20,0,-1,1,0",
"0;xs15_39m88czx56;0;;-14,72,-14,91,1,6,6,10;19,15,26,20,33,56,36,101;-8,-140;5,17,0,1,-1,0",
"0;xs15_39q453z32;0;;-9,43;13,5,17,52,29,34,35,33;-5,-103,-4,-75,0,-103;8,17,0,1,-1,0",
"0;xs15_39u066z32;0;23,-41,29,-39;-3,20;24,5;-5,-121,8,-118,8,-54;23,6,-1,0,0,-1",
"0;xs15_3h4e1e8z011;0;26,-91,32,-121,35,-102;1,21,7,17;31,6;-18,-125,-11,-110,-9,-175,5,-164;21,22,0,-1,-1,0",
"0;xs15_3hu069a4;0;;-7,48,-3,22;19,8,28,61;0,-74;6,16,0,1,1,0",
"0;xs15_3hu0o8a6;0;;-22,96;24,68,27,8;-19,-108,-4,-125;6,18,1,0,0,-1",
"0;xs15_3hu0ok46;0;;-24,104;26,76,27,6,32,7;-21,-116,-4,-131,1,-136;6,20,1,0,0,-1",
"0;xs15_3ia4zwd552;0;28,-102,48,-171;0,33,9,82;33,5,48,17,56,83;-6,-156;19,24,1,0,0,-1",
"0;xs15_3lk453z121;0;10,-32;2,8;18,5;-2,-33,0,-49;10,4,-1,0,0,1",
"0;xs15_3lkm96z01;0;9,-25;0,8;9,12;-1,-37;5,5,0,-1,1,0",
"0;xs15_3pm0e96;0;;-28,125,-11,53,1,32,3,7;42,124,45,28;-34,-239,-7,-181;24,28,0,-1,-1,0",
"0;xs15_3pm0eic;0;;-28,123,-11,51,-1,26;37,5,38,122,39,30;-34,-225,-7,-167;22,26,0,-1,-1,0",
"0;xs15_4a51i4ozx321;0;;-5,28,0,38;21,37,23,5,24,28,35,45;-4,-106,1,-80,5,-88;17,10,0,-1,1,0",
"0;xs15_4a970si6;0;14,-47;-1,29,2,7,4,34;30,35;-1,-82;16,13,-1,0,0,-1",
"0;xs15_4a970sic;0;11,-37;2,6;20,25;-3,-38,2,-43,4,-60;5,7,1,0,0,1",
"0;xs15_4a9b88gzx311;0;24,-86,30,-65,34,-108,36,-129,43,-158;2,8;32,52,39,27;-11,-129,6,-68;17,15,-1,0,0,1",
"0;xs15_4a9b8oz033;0;12,-39;1,23;16,6;-6,-60,-4,-145;5,1,0,1,-1,0",
"0;xs15_4a9mgmazx1;0;;-24,119,-13,79,-8,56,0,7;49,31,49,83,53,107,63,129;-25,-281,-20,-215,2,-141;15,41,1,0,0,-1",
"0;xs15_4a9ra96;0;13,-44,22,-40,25,-87;4,18;24,27,29,6;-7,-93,8,-81;18,15,-1,0,0,-1",
"0;xs15_4a9raic;0;;-4,23;9,6;-9,-68,4,-35;8,12,-1,0,0,-1",
"0;xs15_4aab8oz033;0;31,-72,42,-152,46,-174,47,-124;7,36,11,59,18,6;32,17,48,53;7,-164,18,-192;19,9,0,1,1,0",
"0;xs15_4al9aczw23;0;8,-24,14,-27,27,-66,34,-70;5,7;22,12;7,-73,12,-44;28,12,0,-1,-1,0",
"0;xs15_4ap3zrm;0;18,-61,36,-108;-1,14,0,33,6,6;21,15,35,48;-12,-123,-3,-91;15,11,-1,0,0,1",
"0;xs15_4ap3zw12156;0;14,-47,21,-53;4,8,6,35;23,15;3,-71;12,7,0,1,1,0",
"0;xs15_4ap5a4z321;0;51,-129,71,-161,73,-275;1,5,9,91;56,69,66,79,72,117,82,113;2,-294,8,-171;40,36,0,-1,-1,0",
"0;xs15_4apb8oz32;0;16,-54,37,-113,52,-136;-2,37,5,5;35,26,38,15,45,39;0,-110,7,-53;14,20,1,0,0,-1",
"0;xs15_4aqb8oz32;0;25,-92,27,-56;4,7,7,27;34,18,34,43;3,-108,7,-80;19,16,0,-1,-1,0",
"0;xs15_5b88a6z033;0;14,-36,18,-64;6,6;24,24;-1,-75;9,11,1,0,0,-1",
"0;xs15_64lb8ozw121;0;17,-40;-2,27,0,8,5,22;29,23;0,-86;10,7,0,1,1,0",
"0;xs15_65123qic;0;;-7,62,1,5;22,45;-7,-94;12,18,0,-1,-1,0",
"0;xs15_65lmzx346;0;12,-30;1,5;18,17;-1,-54;12,9,0,-1,-1,0",
"0;xs15_66xrdzx321;0;14,-49;6,8;23,12;-1,-45,4,-53;12,3,0,-1,1,0",
"0;xs15_699mkk8zx1;0;61,-234,82,-154;29,58;64,74,102,6;6,-164,12,-342;50,20,1,0,0,1",
"0;xs15_69aczw2553;0;9,-26,16,-55;1,7;12,14;-10,-76,-8,-51;1,5,1,0,0,1",
"0;xs15_69aczw6513;0;13,-44,21,-41;4,7;18,21;6,-60;16,9,0,1,1,0",
"0;xs15_69aczx3156;0;12,-40;-1,28,2,6,8,17;24,18;3,-59;15,5,0,-1,1,0",
"0;xs15_69aczx3552;0;;-6,33;16,8,20,55;-11,-68,-8,-77;13,16,0,-1,-1,0",
"0;xs15_69ajkk8zx1;0;22,-80,45,-131,52,-130;4,7;28,8,34,46,48,49;-2,-95,3,-114,7,-137,7,-120,8,-82;20,18,-1,0,0,-1",
"0;xs15_69bojd;0;;-9,43;9,20,11,6;-11,-67;5,18,0,1,-1,0",
"0;xs15_69eg8oz321;0;;-20,88,6,109;66,5,72,80,86,32,88,112;-19,-218,-7,-316,-5,-223;23,43,1,0,0,-1",
"0;xs15_6t1egoz11;0;;-1,30,1,5;19,13,20,46;1,-67;9,12,-1,0,0,-1",
"0;xs15_8ehegoz023;0;24,-87,55,-116;2,16,11,8;34,24,48,10,48,30;10,-152,22,-113;26,22,0,-1,-1,0",
"0;xs15_8ehjzw1256;0;7,-21,15,-44;4,9;16,8;9,-29;14,2,0,-1,1,0",
"0;xs15_8k4r9iczw1;0;52,-186,64,-194;-31,134,-25,138,2,8;61,131;-38,-434,-33,-203,-26,-410,-26,-190,-19,-184;25,51,1,0,0,1",
"0;xs15_8ljgzx115a4;0;19,-45,22,-81,33,-92;6,8;37,32;3,-107,3,-92;11,10,0,1,1,0",
"0;xs15_8u16426z32;0;;-11,128,-4,88,0,8;48,21,52,115;-8,-223;25,36,0,-1,-1,0",
"0;xs15_bdgmiczw1;0;;0,25,1,5;24,31;5,-44;15,8,0,-1,1,0",
"0;xs15_c48c93z253;0;12,-39;1,6;18,27,19,5;-1,-51,2,-67;4,4,0,1,1,0",
"0;xs15_c9jzw12ego;0;;-12,55,0,41,3,14;21,8,29,23;-12,-97,-9,-107,-2,-102;18,11,-1,0,0,1",
"0;xs15_ca1u8zx1252;0;17,-59,32,-95;-3,47,3,14;18,7,28,7,35,24;11,-65;19,5,0,-1,1,0",
"0;xs15_ca96zw3156;0;;-8,41,4,5;18,21;-5,-53,3,-56;15,8,0,-1,1,0",
"0;xs15_ca96zw3552;0;15,-51;2,8;26,39,28,22;-3,-52,0,-69;7,9,0,1,1,0",
"0;xs15_ci5diczw11;0;16,-56,31,-114;-2,25;19,5,19,44,29,29;-6,-109;13,16,-1,0,0,1",
"0;xs15_ci5q8a6zw1;0;36,-94,50,-133,60,-170,68,-168;0,8;37,16,48,54,58,14,60,82;5,-198,8,-218,12,-167;23,12,1,0,0,1",
"0;xs15_cilmzx346;0;11,-34;-2,19;10,8;-3,-31,3,-45;8,4,0,-1,1,0",
"0;xs15_cky233z3lo;0;;-24,116,0,7;35,16,36,115;-12,-135,-4,-151;17,33,-1,0,0,-1",
"0;xs15_g8idicz123;0;71,-271,78,-275;-36,154,-33,185,-18,149;80,184,95,5,96,191,99,213;-26,-505,-21,-226,-17,-254;41,70,0,-1,1,0",
"0;xs15_g8idioz123;0;85,-198,98,-384,100,-250;-6,186,9,118,17,123;92,6,99,149,113,46,115,164;1,-252,13,-223,15,-248;45,48,0,1,1,0",
"0;xs15_g8o6996z121;0;;-6,32,-1,46;18,7,20,30;6,-67;2,17,1,0,0,-1",
"0;xs15_g8o69icz121;0;;-8,40,6,6;17,28,30,38;-4,-54,1,-105,3,-67;15,11,0,-1,1,0",
"0;xs15_g9fgka4z11;0;66,-181,78,-110,80,-312;25,34;68,6,81,98;8,-370,18,-246,22,-220,23,-127,25,-306;49,21,0,-1,1,0",
"0;xs15_j1u06a4z11;0;11,-37;2,6;18,24;-7,-77;11,10,0,-1,1,0",
"0;xs15_j5c48a6z11;0;27,-98,42,-160;-8,54,-2,64;31,8,42,65,47,86;-10,-127,2,-137;10,20,0,1,1,0",
"0;xs15_j5q8a6z11;0;9,-29,15,-27;3,10;23,7,34,15;7,-48;9,10,-1,0,0,-1",
"0;xs15_o4s3pmz01;0;14,-27;-1,14;17,6;4,-70;4,-1,1,0,0,1",
"0;xs15_o5r8b5z01;0;24,-87,24,-72;-4,59,4,8;37,51,38,33;15,-114;15,20,0,-1,1,0",
"0;xs15_oe12koz056;0;20,-71,29,-84;6,36;31,24,36,59,42,7;-2,-94,3,-105;22,22,1,0,0,-1",
"0;xs15_oggm96z66;0;;-6,37,0,8;17,6;-8,-96,-1,-49,0,-68;8,11,0,-1,-1,0",
"0;xs15_ol3zmdz11;0;15,-42,17,-60,24,-65;1,8;18,15,26,29;-4,-77,3,-51;6,11,0,1,-1,0",
"0;xs15_ra248goz23;0;12,-39,19,-43,27,-64;4,5,10,12;17,5,26,12,26,26;5,-68;18,6,0,-1,1,0",
"0;xs15_rai3zx1ac;0;12,-38,21,-74,23,-61;2,20;17,26,18,6;-2,-61,0,-74;9,13,1,0,0,-1",
"0;xs15_w9v04a4z311;0;15,-52,30,-70,32,-93,39,-115;-1,23,-1,39;36,5;-15,-151,-9,-127,-4,-156,-2,-99;15,5,-1,0,0,1",
"0;xs15_wg8ob96z65;0;;-40,169;46,74,47,170,50,13,54,7;-22,-292;14,43,0,-1,-1,0",
"0;xs15_wmk453z643;0;;-26,112;28,84,29,7;-23,-124,-6,-124;6,16,0,1,1,0",
"0;xs15_xgbq23zca1;0;14,-38,21,-74,23,-61;4,20;19,26,20,6;-2,-61,0,-74;16,13,-1,0,0,-1",
"0;xs15_xok871z653;0;16,-57;-1,28,1,5;33,19;-10,-73,7,-97;13,14,1,0,0,-1",
"0;xs15_xoka52z653;0;14,-48,19,-38;2,16;14,9,26,5;2,-45;13,7,-1,0,0,1",
"0;xs16_031e8gz8k871;0;12,-39,22,-47;-2,27,9,8;24,19;8,-51;13,0,1,0,0,1",
"0;xs16_031e8gzc9311;0;45,-164,55,-162;0,7;45,7,58,52,62,93;8,-105,9,-288,9,-134,32,-276;39,19,0,-1,-1,0",
"0;xs16_03lka6z643;0;;-23,106,-6,34,7,15;39,105,42,6;-29,-226,-2,-168;26,24,-1,0,0,-1",
"0;xs16_04s0fhoz321;0;;-20,90,-7,36,0,7;31,36,35,94;-25,-118;15,19,0,-1,1,0",
"0;xs16_08kkm93z321;0;16,-56,22,-45,31,-83;2,22;21,5,36,32;2,-47,6,-66;12,8,0,1,1,0",
"0;xs16_08o0ehrz321;0;12,-40;1,20;22,6,25,28;10,-48;15,6,-1,0,0,1",
"0;xs16_08o0uh3z643;0;14,-48,24,-70;2,7;19,14,29,36;-1,-77;14,7,-1,0,0,1",
"0;xs16_08o6hrz643;0;;-6,31;8,5;-9,-75,-2,-44;3,9,1,0,0,1",
"0;xs16_08u1qrz32;0;;-19,83,-4,46,4,46;34,65,63,52,70,64,81,8;-13,-349,-12,-166,-7,-192,2,-206;28,45,-1,0,0,-1",
"0;xs16_0br8b5z32;0;17,-59,25,-87;1,7,4,33;30,34,35,7,35,34;-9,-93,5,-84;12,8,1,0,0,1",
"0;xs16_0ca952z2553;0;;1,6;14,19;-6,-64,-3,-32;2,8,0,1,-1,0",
"0;xs16_0ca952z6513;0;;;6,8,8,31,12,6;-10,-44,-9,-63;-2,11,0,1,-1,0",
"0;xs16_0g8ka952z3421;0;;-12,59,0,7;26,56;-10,-72,-1,-91;14,10,-1,0,0,1",
"0;xs16_0g8o653zbc1;0;12,-38,28,-60;3,25;23,26,24,8;11,-56;17,14,-1,0,0,-1",
"0;xs16_0g8o69a4z3421;0;;-6,32,-1,36;12,7;-17,-109,-4,-58;10,13,0,-1,1,0",
"0;xs16_0ggca96z3443;0;;-1,33,0,8;17,18,21,46;-5,-73;14,11,0,-1,1,0",
"0;xs16_0ggraa4z1226;0;16,-52,24,-87;1,24;17,5,25,40;-6,-68;6,8,1,0,0,1",
"0;xs16_0gjlicz346;0;10,-31,25,-78;5,7;22,18;1,-83;12,11,-1,0,0,-1",
"0;xs16_0gs2arz3421;0;15,-32,19,-67,21,-56;2,8;23,19;-11,-129,-10,-79,-1,-57,7,-47;5,10,1,0,0,-1",
"0;xs16_0md1e8z1226;0;12,-38,19,-45,34,-66,37,-91;5,7;26,14;8,-66,8,-47;20,7,0,-1,-1,0",
"0;xs16_0mkiarz32;0;;-12,58,-3,22;8,6,20,50,24,30;-14,-77,-4,-70;3,14,0,1,-1,0",
"0;xs16_0mp2sgz643;0;;-19,85,-1,25;26,5,31,41;-25,-129,-14,-114;12,17,-1,0,0,1",
"0;xs16_0o4i13zc45d;0;;-13,60,11,12;31,59,39,6;-8,-172,-5,-151,10,-130,13,-104;32,23,0,-1,-1,0",
"0;xs16_178bq2sg;0;14,-48,23,-55;4,7;23,24,35,36;2,-64,3,-77;12,7,0,1,1,0",
"0;xs16_178c1f84c;0;19,-69,26,-96,33,-90;4,8;29,25;4,-69,5,-102,11,-38;25,12,-1,0,0,-1",
"0;xs16_259aczx6513;0;;-6,32;9,19,13,7;-5,-78;-5,15,-1,0,0,-1",
"0;xs16_259e0eik8;0;;-6,31;9,18,13,8;-10,-76,-1,-44;5,5,1,0,0,1",
"0;xs16_259q453z032;0;13,-45,21,-58,32,-103;-3,29,10,7;22,23;-10,-127,-1,-59;16,13,0,-1,-1,0",
"0;xs16_25a8czw315a4;0;16,-54;2,8,4,20;26,34;-6,-68,-4,-80;6,8,0,1,1,0",
"0;xs16_25a8czy0315a4;0;14,-46,21,-74;2,13;15,6,22,34;-6,-67;4,6,1,0,0,1",
"0;xs16_25is079k8;0;16,-54,21,-39,26,-73;2,13,7,19;18,7,28,26;2,-67;10,6,0,1,1,0",
"0;xs16_2ege9a4zw23;0;;-8,41,2,8,5,30;35,31;-4,-74,0,-102;14,8,0,-1,1,0",
"0;xs16_2egu16413;0;31,-109,57,-193;-13,96,-11,51,-6,57;43,84,45,8;-13,-124;9,28,0,1,-1,0",
"0;xs16_2lla8oz641;0;31,-82,32,-118,34,-74;13,5;45,49;-9,-106,2,-117,17,-179,25,-129;13,19,0,1,-1,0",
"0;xs16_2llm853z01;0;34,-104,38,-144;1,40;41,91,42,43,48,87,49,5;-3,-137,4,-130;10,28,1,0,0,-1",
"0;xs16_31e86178c;0;21,-74,34,-58;9,8,21,10;39,38,52,22;4,-86,16,-88;26,8,0,-1,1,0",
"0;xs16_31e8gzy012ego;0;25,-91;12,79,15,38,22,8;39,14,50,63,60,72;21,-123;25,16,1,0,0,1",
"0;xs16_31km9a4z0121;0;24,-69,34,-126;0,8,4,12;30,52,41,57;-20,-219,-15,-134,-1,-101;7,33,1,0,0,-1",
"0;xs16_31kmiozw56;0;24,-47,34,-80,38,-133;0,7;43,24,54,35;3,-142,9,-55;33,24,-1,0,0,-1",
"0;xs16_32akozxc871;0;19,-63,35,-112;1,5;21,36;-10,-77,-5,-124;16,19,-1,0,0,-1",
"0;xs16_32q4ozx122ac;0;32,-120,41,-132;6,73;40,7,45,74,47,25;9,-132;27,14,0,-1,1,0",
"0;xs16_330fhar;0;29,-96,57,-171,61,-213;-2,25,1,6,2,64,7,44;47,50,54,84;-21,-203,-16,-183;23,19,-1,0,0,1",
"0;xs16_33y34alla4;0;;-11,71,-5,29,5,8,5,32;35,80;0,-106;7,24,1,0,0,1",
"0;xs16_33zy635861ac;0;20,-73,36,-110,48,-134;12,8;42,14,42,31;-2,-74;7,11,1,0,0,1",
"0;xs16_354miczx56;0;;-6,32,1,8;43,20,71,133;-19,-264,-2,-146,2,-194;23,33,-1,0,0,-1",
"0;xs16_39e0ehr;0;11,-20;0,8;22,8;8,-42,11,-20;14,1,-1,0,0,1",
"0;xs16_3hu0uh3;0;8,-24;6,7;17,12;4,-47;7,-1,0,1,1,0",
"0;xs16_3iaj2ak8zw1;0;19,-69,30,-86,34,-124;-5,56;18,7,34,22;-2,-127,1,-97;4,13,1,0,0,1",
"0;xs16_3lk453z321;0;;-11,57,1,5;22,47;-9,-69;6,9,1,0,0,1",
"0;xs16_3lka96z121;0;34,-112,36,-132,47,-172,58,-198;-3,20;44,48,44,74,55,100,56,8;-6,-163,12,-187;16,33,-1,0,0,-1",
"0;xs16_3p6o8ge2zw1;0;32,-121,41,-105,57,-160;6,32;54,6,54,38,54,90;5,-191,15,-102,20,-123;27,23,1,0,0,1",
"0;xs16_3pa3ia4zw11;0;45,-107,47,-127,58,-126,62,-239,62,-154;0,57;51,8;-3,-126;32,22,0,1,1,0",
"0;xs16_3pa4z4ajo;0;21,-76,40,-124;-2,15,-1,34,5,7;24,16,43,64;-11,-133,-5,-106,-4,-125;13,13,1,0,0,1",
"0;xs16_3pabp46;0;22,-81,31,-86,38,-85,39,-122;2,5;26,28,38,32;-7,-109,7,-70;17,23,0,-1,-1,0",
"0;xs16_3pajc48c;0;19,-66,26,-84,41,-77,49,-91;0,31,6,32,11,13,13,54;32,6;4,-132;20,14,-1,0,0,1",
"0;xs16_4a5p68ozx121;0;30,-112,38,-75,49,-96;0,20,8,63,16,10;47,7;13,-133;24,28,0,-1,-1,0",
"0;xs16_4a970sia4;0;13,-43;2,18;21,5;8,-30;13,2,0,-1,1,0",
"0;xs16_4a9fg4czx32;0;;-4,25,-2,36,3,6;11,7;-7,-76,0,-50;10,12,-1,0,0,-1",
"0;xs16_4a9jc4ozx121;0;22,-81,31,-98;-4,28,5,45;26,30,30,5;7,-76;16,11,0,-1,-1,0",
"0;xs16_4a9jzx12ego;0;19,-69,45,-119;3,17,7,36;22,5,37,56;-18,-164,-10,-151,5,-145;12,21,1,0,0,1",
"0;xs16_4a9l6o8zx121;0;28,-94,36,-131,38,-91,43,-116;-6,32,-6,52,-3,59,2,63,6,7,6,28;30,40,45,68;-11,-128,-5,-155,5,-82;7,19,1,0,0,1",
"0;xs16_4aab96z033;0;13,-30,16,-55;4,7;20,17;-3,-66;7,10,0,1,-1,0",
"0;xs16_4aab96zx33;0;;-14,64,1,7;19,26,20,50;-11,-76;3,19,1,0,0,-1",
"0;xs16_4aab9k8zx32;0;;-21,96,-6,34;32,8,44,70,45,26;-27,-183,-18,-164,-4,-110,1,-109;24,25,-1,0,0,1",
"0;xs16_4aajkczx56;0;71,-206,76,-257,87,-263,104,-407;-24,193,-5,131,6,6;78,29,84,105,86,143;-14,-221,-13,-234,-11,-359;35,48,-1,0,0,-1",
"0;xs16_4aar2pm;0;51,-77,67,-259;2,7;65,61;-8,-244,9,-293,19,-73;25,42,0,-1,-1,0",
"0;xs16_4ap78cz321;0;29,-106,35,-133,53,-143;6,38,11,8;44,28,49,6;-9,-114;21,13,1,0,0,1",
"0;xs16_4aq32acz032;0;11,-34;2,17;11,10,18,5;3,-35,12,-34;7,6,0,1,-1,0",
"0;xs16_5b8r5426;0;;-10,50,-7,59;31,6,34,34,40,56,44,120;-24,-136,-23,-152,-20,-180;13,24,0,1,1,0",
"0;xs16_5b8raic;0;;-4,50,0,7;21,33,42,63;-8,-140,-4,-75,0,-118,0,-101;16,23,0,-1,-1,0",
"0;xs16_5b8ri96;0;;-34,144,-24,122;49,7,68,148,70,168;-35,-268,-30,-347,-30,-181;5,41,1,0,0,1",
"0;xs16_641vg356;0;19,-67,29,-67;-1,26,8,8;41,55;-6,-110,1,-110,3,-76;19,12,0,-1,1,0",
"0;xs16_6421344og84c;0;22,-79,30,-86,38,-88,45,-94,52,-123;5,7,7,17;25,5,32,34,39,40,47,42,55,49;6,-111,8,-121;17,14,1,0,0,1",
"0;xs16_65lmzx34a4;0;12,-41,26,-58;-1,28,13,6;26,11;5,-49;19,4,-1,0,0,1",
"0;xs16_660uhar;0;23,-63;-5,39,0,8;29,24,29,50;-6,-123,2,-86,2,-65;6,14,0,1,-1,0",
"0;xs16_695q4gozw23;0;43,-150;-15,112,-9,46,5,24;43,8,48,59,51,37,53,89;-19,-293,-14,-178,-8,-159,0,-124;21,27,-1,0,0,1",
"0;xs16_695q4ozw321;0;59,-203;-20,124,-1,103,0,8;62,133;-27,-215,-24,-362,-8,-207;15,43,1,0,0,1",
"0;xs16_695q84ozx121;0;20,-60;0,8,5,24;26,19,33,30,46,48;9,-75,12,-100;12,12,1,0,0,-1",
"0;xs16_69960uic;0;14,-46;3,5;21,34;3,-63;7,19,-1,0,0,-1",
"0;xs16_699mgmazx1;0;11,-23;0,7;12,7;-6,-53,-4,-67;8,3,0,-1,1,0",
"0;xs16_69aczw6953;0;;-14,63;12,32,21,65,22,5;11,-99;-4,11,0,-1,1,0",
"0;xs16_69aczx3596;0;17,-55;0,32,1,6;21,25;-3,-74,-2,-48;5,7,0,1,1,0",
"0;xs16_69ari96;0;17,-58,25,-93;2,6;20,20,22,39;-10,-81,-7,-155,-6,-84,0,-51;8,13,0,-1,1,0",
"0;xs16_69b88czw652;0;14,-29;1,5;15,17,23,7;4,-57;8,10,0,1,-1,0",
"0;xs16_69bob96;0;7,-21;0,8;9,6;0,-33;0,9,1,0,0,-1",
"0;xs16_69e0ehr;0;11,-37;1,8;12,25;2,-37;4,3,0,1,1,0",
"0;xs16_69egmiczx1;0;;-5,33,1,5;12,24;1,-45;-1,4,0,1,1,0",
"0;xs16_69f0ci96;0;7,-21,15,-51;3,5;12,9;0,-46,4,-70;2,2,0,-1,1,0",
"0;xs16_69f0f96;0;;-5,27;12,5;-7,-69,1,-39;6,9,1,0,0,1",
"0;xs16_69is079c;0;;-4,24,3,6;16,32;-3,-45;7,8,-1,0,0,1",
"0;xs16_69is0si6;0;11,-34;3,7;13,22;-13,-101;5,16,0,1,-1,0",
"0;xs16_69ngbr;0;;1,5;8,14,15,22;2,-48;12,10,0,-1,-1,0",
"0;xs16_69r4koz023;0;;-19,84,-4,53,-3,20;21,8,36,62,36,81;-14,-101;15,10,-1,0,0,1",
"0;xs16_69raa4z32;0;17,-48,25,-48,30,-71;-1,12,6,8;21,9;-7,-88,2,-95,3,-72;18,6,0,-1,1,0",
"0;xs16_6a88brzx32;0;16,-57,23,-82,41,-107;2,17,11,6;27,43,32,20;-3,-86,-1,-112,7,-81;18,13,0,-1,1,0",
"0;xs16_8e13kcz0ca1;0;15,-50;0,18;19,8,26,18,27,38;-4,-56,-2,-69;14,16,0,-1,-1,0",
"0;xs16_8ehjzw1012ko;0;7,-21,14,-24,23,-57;2,8;18,9;2,-46,7,-23;3,1,0,1,1,0",
"0;xs16_8k4r2pmzw1;0;;-41,226,-20,89;56,7,73,58,75,230;-46,-361,-38,-253,-27,-301;7,49,0,1,1,0",
"0;xs16_8kid96z641;0;;-9,45,5,8;19,39,23,23;-1,-60;12,11,0,-1,-1,0",
"0;xs16_8kk31e8z641;0;;-9,57,-1,11;16,6,21,54,28,42;-3,-73;14,11,0,-1,1,0",
"0;xs16_8kkja952zx1;0;33,-125;-4,39,0,14,7,22;39,6,51,18,56,88,60,113;-12,-158,-6,-171;23,34,-1,0,0,-1",
"0;xs16_8ljgzx1pl2;0;26,-70,29,-106;7,7;42,22,45,58;0,-121;15,13,0,1,1,0",
"0;xs16_bt06426z32;0;;-18,82;22,8,43,69,50,146,50,171,53,117;-45,-211,-41,-192,-29,-223,-17,-183;10,39,1,0,0,-1",
"0;xs16_c48c93z2552;0;;-8,39,4,5;17,6,17,38;-8,-84;12,5,-1,0,0,1",
"0;xs16_c4lb8oz321;0;;-7,38;14,37,22,34,25,14,28,5;-5,-95,-3,-112,6,-98;11,17,-1,0,0,-1",
"0;xs16_c4o0e96z321;0;;;2,7,18,38;-13,-51,-11,-62;1,8,-1,0,0,1",
"0;xs16_c88m552z311;0;;-3,20,1,27;11,5,17,10,25,27;4,-69;9,12,0,1,-1,0",
"0;xs16_c88q552z311;0;23,-75,32,-121;5,7,9,27;31,9,33,61,40,31,44,53;2,-292,6,-111;6,21,0,1,-1,0",
"0;xs16_c8al56z311;0;16,-56;1,5;22,30,28,24,34,44;-10,-59,-4,-83,0,-97;10,16,0,1,-1,0",
"0;xs16_c9bkkozw32;0;;-25,107,-21,115,-7,68,7,6;51,53,54,128;-11,-178,5,-141;19,38,0,1,-1,0",
"0;xs16_c9jzw122c826;0;24,-88,27,-68,31,-92,34,-85,44,-117,51,-141;-2,28,7,7;32,20,44,28,44,56;-3,-129,8,-92;23,22,-1,0,0,-1",
"0;xs16_ca168ozc8421;0;15,-52,35,-98;-1,27,2,39;26,7;-6,-82,5,-51;9,10,0,1,1,0",
"0;xs16_ca51i4ozx321;0;;-6,32,-1,42,7,6;22,41,25,32,36,49;-5,-110,0,-84,4,-92;11,17,1,0,0,-1",
"0;xs16_caikm96zw1;0;23,-85,38,-79;8,53;31,7,52,51;-7,-225,-4,-181,15,-66,16,-97,17,-76;19,10,0,1,-1,0",
"0;xs16_ccy1rrz33;0;9,-26;1,6;15,14;3,-34;11,2,-1,0,0,1",
"0;xs16_ci4o0uh3zw1;0;;-26,113;33,6,34,85,40,29;-23,-147,-2,-159,3,-126;16,25,-1,0,0,-1",
"0;xs16_ciarzx3213;0;;-11,69,-3,20,1,33,4,12,4,41;22,6;-22,-236,-13,-118,-1,-92;14,15,0,1,1,0",
"0;xs16_cim453z641;0;;-6,32,1,8;43,20,72,133;-18,-264,-1,-146,3,-194;19,33,1,0,0,-1",
"0;xs16_djozx358go;0;21,-74,34,-69;-4,56,5,5,5,32;30,14;-5,-140;12,12,1,0,0,1",
"0;xs16_g0j960uiz11;0;12,-40;-2,22;23,7,25,28;-6,-46,-3,-60,0,-85,2,-64;8,9,1,0,0,1",
"0;xs16_g88e13z178c;0;16,-55;1,18;19,8,19,42;-1,-61;8,14,0,-1,-1,0",
"0;xs16_g88m996z1221;0;;-11,51;14,6;-6,-63;11,6,-1,0,0,1",
"0;xs16_g88q596z1221;0;11,-31;-2,15;11,8;-3,-49,0,-28;2,10,1,0,0,-1",
"0;xs16_g88r2qkz121;0;65,-253,76,-224;3,131;68,80,78,5;-1,-242,8,-143;39,31,-1,0,0,-1",
"0;xs16_gbbo8a6z11;0;19,-67;0,7;22,55,24,19;-2,-94;15,13,0,-1,1,0",
"0;xs16_ggm9acz1243;0;18,-48;1,6,2,22;22,36;-4,-62,-3,-78;13,8,0,-1,1,0",
"0;xs16_h7ob96z11;0;;-4,25;6,7,14,18;-6,-54;3,9,1,0,0,-1",
"0;xs16_j1u0696z11;0;;-4,23;11,7,12,33;-7,-63;-2,6,0,1,1,0",
"0;xs16_j1u0uiz11;0;13,-43,15,-30;4,8;13,8;2,-30,4,-43;6,2,0,1,1,0",
"0;xs16_j5o64koz11;0;23,-85,37,-136,48,-168;-6,52,-1,13;31,19,34,5,50,72,58,50;-18,-186,0,-105;13,22,-1,0,0,-1",
"0;xs16_j9c8a6z123;0;11,-37,19,-60;-2,24;11,6;-9,-72,-2,-48;8,9,-1,0,0,-1",
"0;xs16_kc32156z123;0;16,-55,18,-45,29,-81;1,7;18,12,20,33,25,26;-3,-57,0,-79;9,13,1,0,0,-1",
"0;xs16_kc32qkz0113;0;18,-63,43,-120;-3,51,0,21,13,8;31,42,43,10;-7,-101;22,11,0,-1,1,0",
"0;xs16_m2s0796z11;0;13,-44;-2,32;22,24,24,7;4,-52;8,7,1,0,0,1",
"0;xs16_m2s079cz11;0;13,-28;0,8;26,16;6,-58,9,-36;9,7,1,0,0,-1",
"0;xs16_mkkb2acz1;0;;-10,50,2,8,7,25;;-8,-104,-3,-74,2,-84;20,13,0,-1,1,0",
"0;xs16_mligz1w696;0;;;1,6,11,10;-16,-111,-6,-22,-5,-59,2,-35;-2,-4,0,1,1,0",
"0;xs16_mmy1rrz11;0;8,-24;0,8;13,12;3,-28;10,2,-1,0,0,1",
"0;xs16_o4ic0fhoz01;0;;-24,105;30,77,31,6,38,29;-21,-131,-2,-151,3,-118;15,18,-1,0,0,1",
"0;xs16_o8blgozw56;0;57,-138;0,7,0,124,12,60,16,39,20,54,27,40;93,122;-7,-220,0,-206,4,-221,8,-200,20,-253,20,-136;45,29,-1,0,0,1",
"0;xs16_ra16426z23;0;12,-41,20,-70;4,6;18,25,27,28;-5,-68,0,-68,7,-64;7,14,1,0,0,-1",
"0;xs16_w6ic0f9z321;0;14,-48;-4,30;23,7,25,28;-8,-54,-5,-68,0,-85,2,-64;8,10,1,0,0,1",
"0;xs16_w8o69a4z6521;0;;-10,49;20,53,21,30,22,6;1,-77,8,-66;15,19,0,-1,-1,0",
"0;xs16_wggca53z6521;0;11,-24,18,-64;4,11;17,6;-10,-77,9,-39;3,3,1,0,0,1",
"0;xs16_wml1e8z643;0;34,-127,43,-138,54,-181;8,61;36,42,55,5,58,71;-14,-175,-7,-167,3,-147;25,24,-1,0,0,1",
"0;xs16_wo443123zbd;0;18,-63;11,20;20,7,46,24;8,-135,16,-97;25,15,-1,0,0,-1",
"0;xs16_xg842132acz321;0;;-13,61,0,15,1,35,10,6;28,29,38,44;-13,-107,-10,-117,-3,-104;16,11,0,-1,1,0",
"0;xs16_xj96z0mdz32;0;;-16,76,-4,116,1,5,4,110,8,54;54,43,64,121,65,92,77,112;-1,-187;32,32,-1,0,0,-1",
"0;xs16_xmk453z4a43;0;;-32,152,-4,25;29,8,42,124,43,47;-29,-164,-12,-164;10,25,0,1,1,0",
"0;xs16_y2696z4aa4zyd66;0;;-2,18;6,6,30,75;-13,-90;14,23,0,-1,-1,0",
"0;xs17_0brz4ab413;0;14,-48,21,-52;0,20,8,17;21,7,26,35;0,-69;16,15,-1,0,0,-1",
"0;xs17_252z08kk8gzy034a4;0;;-9,107,-3,21,-2,58;43,8,53,104;-7,-120,-3,-156,-1,-189;17,21,0,1,1,0",
"0;xs17_2552y0ciczw6a4;0;;-9,45,2,20;15,8,28,46;-7,-64,-5,-74;12,17,0,-1,-1,0",
"0;xs17_354mp3zcc;0;;-2,18;10,5,11,25;-6,-54;6,7,0,-1,1,0",
"0;xs17_35a88gzca511;0;14,-47;1,6,5,28;23,6;0,-57,10,-47;8,12,0,1,-1,0",
"0;xs17_69baa4z253;0;;-14,64,1,6;19,26,20,50;-11,-76;8,19,-1,0,0,-1",
"0;xs17_o4s3qp3z01;0;14,-49,14,-29,30,-112;-2,17;21,5;-6,-99,2,-83;12,14,-1,0,0,-1",
"0;xs18_09v0ca52z321;0;;-6,32,1,5,1,25;16,26;-6,-64;3,10,1,0,0,-1",
"0;xs18_0brzcib413;0;13,-35,20,-52,28,-81;0,8,6,22;26,22;-8,-93,-1,-69;18,8,0,-1,1,0",
"0;xs18_0dbgz259ar;0;42,-158,63,-180,65,-226;6,8;47,79,69,49;1,-170,2,-203,4,-92;30,28,-1,0,0,-1",
"0;xs18_0gw628c4871z343;0;;-12,63,-7,41,1,5;39,20,49,73;-18,-189,6,-107,7,-85;29,23,-1,0,0,1",
"0;xs18_1784264kozx66;0;;-25,107,5,30;57,5,81,166;-21,-241,3,-228,10,-179;37,31,0,-1,-1,0",
"0;xs18_32ak8zy0113y0cic;0;18,-41;-3,28,1,6,4,20;28,5;0,-100;15,12,0,-1,-1,0",
"0;xs18_c9jx66z354c;0;;-7,38;12,7,16,46;-16,-100;-5,14,1,0,0,-1",
"0;xs18_g6p56z11y12552;0;;-7,38;10,21,16,8;-2,-54;11,5,0,-1,1,0",
"0;xs18_g8g031460696z121;0;20,-53,21,-75;-6,41;33,6;0,-138;6,16,1,0,0,1",
"0;xs18_g8g031460uiz121;0;23,-65,24,-87;-9,53;33,7,42,30;-7,-150;6,19,1,0,0,1",
"0;xs18_gbrz56o8go;0;15,-51,28,-84;6,30;19,9,24,6,36,23;-7,-91,-6,-106;13,7,1,0,0,1",
"0;xs18_j1u0uh3z11;0;14,-47;-3,34,3,7;15,8;-1,-65;6,14,1,0,0,-1",
"0;xs18_j5o652zdd;0;17,-59,36,-95,46,-123;-2,47;21,9,26,6,35,33,42,34;-1,-135,4,-106;15,16,1,0,0,-1",
"0;xs18_o80g8k8w33zwdb;0;27,-56,27,-31,37,-140;15,18;42,7;7,-132;27,11,-1,0,0,1",
"0;xs18_og8objozzx33;0;22,-81,29,-92;-4,53,0,20,9,32;22,8,36,29;-9,-113,5,-85;16,12,-1,0,0,1",
"0;xs18_rry466zx653;0;30,-108,36,-101;1,5;37,15;-8,-83,-5,-153;18,23,-1,0,0,-1",
"0;xs19_08e13zc93zx2552;0;18,-45,19,-67;-4,33;33,8;0,-133;18,14,0,-1,1,0",
"0;xs19_0gw628c48a52z343;0;21,-57,22,-79;-7,45;34,6;-4,-139,0,-142;6,16,1,0,0,1",
"0;xs19_2lmz3kpzx352;0;38,-93,49,-189,60,-157;1,80,13,8;52,8;10,-170;26,32,-1,0,0,-1",
"0;xs19_39eg8ozrq1;0;29,-109;-12,97,-7,37,-1,70;43,8,48,88;-14,-200,-14,-182;10,20,1,0,0,1",
"0;xs19_4ai3146zx123y433;0;17,-58,18,-40,32,-116;3,28;35,6;1,-104,12,-102;22,15,-1,0,0,-1",
"0;xs19_6246pa4z25521;0;45,-170;-7,145,0,26,2,6,13,61;68,146,75,75,77,59;-4,-239;26,21,1,0,0,1",
"0;xs19_6ik8a52z121y5cc;0;33,-88,45,-163,55,-191;-17,75,-2,39;33,8,44,61,51,62;-16,-203,-11,-174;11,28,0,1,-1,0",
"0;xs19_9f0cia4zy7653;0;11,-37;0,25;10,6;-1,-49;15,4,0,-1,-1,0",
"0;xs19_i5q8a52zdd;0;25,-77;1,5,4,13;30,39,39,6,39,64;-3,-118,0,-79;19,15,0,-1,1,0",
"0;xs19_y533zzz3146k46zx123;0;35,-120,57,-205,64,-163;1,5,11,30;69,60;-7,-200,-5,-121,0,-188;13,30,0,1,-1,0",
"0;xs19_y533zzz3146k46zx321;0;21,-64,43,-149;1,5;46,33,52,52;-7,-144,-5,-65,0,-132,10,-125,16,-134;6,23,0,1,-1,0",
"0;xs20_033zj9ajkcz11;0;28,-40,44,-166;9,24,15,28,28,8;40,9;21,-140;44,10,0,-1,-1,0",
"0;xs20_033zzdj8ria4;0;;-6,65,0,8;24,33,27,21;-8,-122,0,-77;15,16,1,0,0,1",
"0;xs20_0354kmz0gg0146z1221;0;;-15,68;35,40,37,5;-12,-152,12,-103,13,-81;15,21,0,1,-1,0",
"0;xs20_06icw352z2ehp;0;21,-49,25,-73,28,-105,29,-62;10,36;25,5,37,21;0,-85;20,14,1,0,0,-1",
"0;xs20_0gw628c0fhoz343;0;;-13,60;31,32,35,5;-10,-136,12,-95,13,-73;25,13,-1,0,0,1",
"0;xs20_0iu0dbxccz641;0;;-6,31,9,6;23,8,36,30;-4,-128,-2,-91,10,-43;11,15,0,1,-1,0",
"0;xs20_33xgzw6s1e96zw11;0;13,-43,31,-93;-1,30;17,19,19,8;-1,-80,9,-48;5,11,0,1,-1,0",
"0;xs20_35acggx696zy01023;0;17,-41,18,-63;-3,29;32,5;-3,-144,5,-121;17,19,-1,0,0,-1",
"0;xs20_3hu0og4czy5696;0;;-11,53,5,14;21,24,22,6,32,57;-16,-107;14,19,0,1,-1,0",
"0;xs20_4a6y9696x8kczy7cc;0;28,-68,35,-113,36,-98,51,-196;-6,41;30,7,53,55;3,-110;22,32,0,-1,-1,0",
"0;xs20_64kb9k8woozw121;0;16,-54,24,-55,32,-82;3,5,3,23,9,22;29,11,38,42;4,-81,5,-93;17,16,0,-1,-1,0",
"0;xs20_6960tby1cczy023;0;22,-81,29,-92;-4,53,0,20,9,32;21,8,36,29;-9,-113,5,-85;10,11,0,1,1,0",
"0;xs20_696wggzwgilc1z032;0;;-24,113,-5,29;35,114,41,6,47,30;-20,-195,-7,-234;4,22,0,1,1,0",
"0;xs20_697079iczxcc;0;;;1,6;-9,-46,-5,-19,-2,-32;-2,1,0,1,1,0",
"0;xs20_8ox2552zjicz56;0;;1,6;8,13,13,10;-2,-52;-2,7,0,1,-1,0",
"0;xs20_g8g031460uh3z121;0;;-11,53,3,14;17,24,18,6,30,57;-16,-99;13,7,0,1,1,0",
"0;xs20_j1u0oi6z11zy2oo;0;;;2,7;-5,-20,-2,-41,10,-29;-3,3,0,1,-1,0",
"0;xs20_ya33x33zo4ow4aa4z01;0;;-24,113,-7,36;13,27,14,8,35,103;-21,-125;2,29,0,1,-1,0",
"0;xs21_0gw628c2djoz343;0;;-16,77,1,5,13,15;31,25,32,7,38,76;-22,-223,5,-165;24,9,0,1,1,0",
"0;xs21_178j1246zw11zw8kk8;0;19,-69,35,-122;2,11,11,6;26,9,39,5;-5,-145,1,-105,13,-24;11,11,1,0,0,-1",
"0;xs21_321j4k8zx11zzy5ccwoo;0;;-8,42;29,5,33,104;-33,-244,-31,-217,-31,-143;12,22,0,-1,1,0",
"0;xs21_ckljgx696zx1023;0;44,-132,45,-154,61,-234;-12,82;44,7,44,24,58,112,71,99;-14,-193,-6,-237,6,-125;25,37,-1,0,0,-1",
"0;xs21_gieg8ox35a4z1023;0;;-13,60,4,6;20,19,26,11,27,34,27,59;2,-72;12,16,0,1,1,0",
"0;xs22_0g88g069a4xck8zw11z33;0;;-15,76,0,7;11,20,19,24,30,84;-9,-101;5,9,0,1,1,0",
"0;xs22_2552z0o8zkq3og4c;0;;-8,42;16,8,17,34;-18,-91,-15,-98;-11,6,0,1,1,0",
"0;xs22_2596wok8z2eg853;0;16,-54;2,8,6,16,13,7;26,36,30,13;4,-66;11,7,0,1,1,0",
"0;xs22_3lm88gy92552z32011;0;;-11,54;23,8,23,22,26,43;-9,-102,0,-82,7,-67;11,18,0,-1,-1,0",
"0;xs22_4a9r8jdyccic;0;;-20,192,-9,128,-5,156,0,8;74,116,83,166,84,192;-19,-227;41,58,-1,0,0,-1",
"0;xs22_4aic871w696zx123;0;13,-44,27,-68;4,8;21,10,37,31;6,-48,8,-72,12,-81;13,7,0,1,1,0",
"0;xs22_4aq4871zw123y0696;0;19,-65,24,-86,33,-90;9,8;24,41,36,16;-14,-134,3,-101,10,-54;12,7,0,1,1,0",
"0;xs22_dj8r5gzy011zy54aa4;0;37,-83,40,-138,40,-69,58,-166;-3,22,1,38,21,6;50,28,59,56;3,-133,9,-84,18,-89,26,-211;22,14,0,1,1,0",
"0;xs22_g8e13xcicz011db;0;20,-62,24,-89,32,-97;-2,49,5,27;21,8;-1,-110,7,-75;18,20,-1,0,0,-1",
"0;xs22_o861acy18k8z023zyb652;0;;-22,95;21,13,25,7;-22,-148,-19,-128,-8,-108;0,30,0,1,-1,0",
"0;xs22_xkq2raiczo4oz01;0;19,-46,27,-79,31,-102;-6,34;22,6;3,-98;23,18,0,-1,-1,0",
"0;xs23_33y3o48gzwooy2116aic;0;10,-24,15,-53;2,5;13,11;-4,-42;15,1,-1,0,0,1",
"0;xs23_64kb2ak8z032y1696;0;16,-55,23,-50,39,-82,41,-122,46,-110;-2,37,14,5;39,11;1,-103;18,18,1,0,0,-1",
"0;xs23_o4iege2y32596z0121;0;31,-114,38,-142;-15,101,-4,27,0,7;50,101;-21,-209,-6,-144;22,37,0,-1,-1,0",
"0;xs23_wmll2y96952z65201;0;;-3,19;11,28,12,5;1,-45;10,4,-1,0,0,1",
"0;xs24_4akg8k8y26520oozx346;0;;-13,76,-8,42,9,5;19,27,21,15,27,44;-11,-97,-7,-104;9,16,-1,0,0,-1",
"0;xs24_y0259m861aczjjz11;0;23,-55;1,5;40,36,50,43,52,25;3,-56,12,-74,16,-99,25,-92;32,8,0,-1,1,0",
"0;xs24_y1696z2552wgw2552zy1343;0;;;1,6;-4,-19;-6,-2,1,0,0,1",
"0;xs25_652y4o4czcicy117853;0;;0,7;11,24;-10,-99,1,-37;8,2,0,-1,1,0",
"0;xs25_x8kc3pcy0ck8zy3123zcc;0;23,-82,38,-102,42,-133;-5,62,-2,70,4,6;39,30;-2,-131,2,-106;11,21,1,0,0,-1",
"0;xs27_ojd44og4czy6ciczya4a6;0;16,-55,23,-77,32,-108;4,8;23,29,34,43;-9,-106,-7,-130,-1,-81;7,9,0,1,1,0",
"0;xs28_o8bp4oz01221zy66996zya33;0;9,-28,27,-52;2,6;30,15;6,-92,11,-51,17,-82,22,-27;17,13,0,-1,-1,0",
"0;xs28_y5696zy92552zzc4go0ooz4a43;0;17,-60,36,-85,43,-129;11,22;28,7;-7,-103,-2,-111,3,-294;11,-12,1,0,0,1",
"0;xs31_033zy533wccz8k48gy1cczw1162ac;0;;-5,38,1,6;13,6,16,38;-3,-60;15,13,0,-1,-1,0",
"0;xs31_w696z33wo4ozy0g1zw2lc3213zx11;0;;-16,74;15,7,22,61;-14,-86,-3,-93;-7,16,0,1,-1,0",
"0;xs32_y5696zgs2ug6246y02552zzw66;0;;-5,37,-1,12;8,6,20,18;-9,-90,0,-51;15,-2,-1,0,0,1",
"0;xs32_y7696z2596zzy0og4s0gzy234521zzyu66;0;35,-132,44,-96,64,-192;-11,62,11,8;65,56;-18,-202,12,-74,14,-87,17,-126;58,50,-1,0,0,-1",
"0;xs33_66y1354cgn96zy06952zzy4cic;0;;-31,158,-19,84;33,8,47,75,54,174;-54,-389,-23,-236;-5,55,1,0,0,-1",
"0;xs35_69a4wcicz0ggowgz122cl91y5gzyb343;0;19,-59,26,-76,33,-95;0,8,6,26,8,36;30,14,41,33;-6,-100;31,9,-1,0,0,1",
"0;xs39_y3696zw25520oox33z6a8kicy066zx146;0;;-12,86,-7,37;28,7,31,35,36,67,37,39;-18,-144,2,-99;28,28,0,-1,-1,0",
"0;xs4_33;0;;;1,5;-2,-17;-1,1,1,0,0,1",
"0;xs5_253;0;;0,7;;2,-20;6,2,-1,0,0,1",
"0;xs6_25a4;0;;-1,13;6,6;4,-33;7,2,1,0,0,1",
"0;xs6_696;0;;;1,6;-2,-18;-2,1,1,0,0,1",
"0;xs6_bd;0;12,-39;4,8;18,27;-2,-65;8,8,-1,0,0,1",
"0;xs7_178c;0;;;2,8;-3,-21;-2,1,0,1,1,0",
"0;xs7_2596;0;;0,7;;-3,-27;5,4,-1,0,0,-1",
"0;xs7_25ac;0;;-2,18;9,7;0,-31;7,2,-1,0,0,1",
"0;xs7_3lo;0;8,-25;2,12;12,7;3,-33;6,5,0,1,1,0",
"0;xs8_033zoo;0;;0,7;8,16;-2,-32;9,4,0,-1,1,0",
"0;xs8_178k8;0;11,-35;1,22;11,7;2,-34;4,8,1,0,0,-1",
"0;xs8_25ak8;0;;-2,18;6,5;-3,-35;2,4,1,0,0,1",
"0;xs8_31248c;0;;-6,34;13,33,14,5;-11,-68;12,12,-1,0,0,1",
"0;xs8_312ko;0;11,-21;1,6;13,9;3,-39;11,8,-1,0,0,-1",
"0;xs8_32qk;0;9,-28;3,6;9,9;7,-30;11,4,-1,0,0,-1",
"0;xs8_33w66;0;;;2,7;-1,-19;-1,2,1,0,0,1",
"0;xs8_33x33;0;;0,8;10,7;10,-21;6,7,1,0,0,1",
"0;xs8_33yj66;0;30,-110;4,6;58,98;-20,-202;17,13,0,1,1,0",
"0;xs8_33zcc;0;;;1,6;-9,-63,-5,-19;-1,1,1,0,0,1",
"0;xs8_35ac;0;9,-26;1,5;15,13;-1,-41;8,-2,1,0,0,1",
"0;xs8_3pm;0;8,-22;1,8;8,9;2,-26;4,0,-1,0,0,1",
"0;xs8_6996;0;;;1,5;-4,-18;-1,-1,1,0,0,1",
"0;xs8_69ic;0;;-4,25;6,7;-3,-37;5,6,0,-1,1,0",
"0;xs8_rr;0;;;1,6;-5,-18;-1,1,1,0,0,1",
"0;xs9_178426;0;;-11,51,6,5,9,29;32,30;-6,-98;14,16,0,1,-1,0",
"0;xs9_178ko;0;10,-32;5,15;17,5;1,-39;6,1,0,-1,1,0",
"0;xs9_253033;0;;0,7;9,12;3,-24;1,4,1,0,0,-1",
"0;xs9_25a84c;0;12,-38;5,6;17,25;1,-55;5,12,0,1,-1,0",
"0;xs9_25ako;0;;-5,28;13,8;0,-41;12,10,-1,0,0,-1",
"0;xs9_312453;0;;-5,27;7,8,11,29;-3,-52;4,7,-1,0,0,1",
"0;xs9_31248go;0;11,-35,18,-37;1,23;23,5;-5,-75;4,7,0,1,1,0",
"0;xs9_31ego;0;9,-27;0,8;11,14;-2,-43;3,1,1,0,0,1",
"0;xs9_4aar;0;;-6,32;14,8;-3,-44;6,3,0,1,1,0",
"0;xs9_g0g853z11;0;8,-22;1,5;7,9;-2,-45;6,3,-1,0,0,1",
"xp2_032hv04a4ze;xs14_32hv04a4;0;10,-54;;;;1,0,1,0,0,1",
"xp2_032hv04a6ze;xs15_32hv04a6;0;10,-54;;;;1,0,1,0,0,1",
"xp2_032hv04acze;xs15_32hv04ac;0;10,-54;;;;1,0,1,0,0,1",
"xp2_033ze;xs14_0j5s26z121;0;9,-81,24,-111;;;-14,-86,-13,-99,2,-121;-6,6,0,1,1,0",
"xp2_033zs;xp2_33y2ey733;1;24,-110;;;-20,-98;2,0,0,-1,1,0",
"xp2_066yb33z33zy3ezx1110s0111;xp2_okiary27ezw65;1;;12,-59,23,-168;;8,-89;0,0,0,1,1,0",
"xp2_0696z4a96y07;xs14_0drz69k8;0;-2,-124;-6,-67;-9,-83;;6,9,-1,0,0,-1",
"xp2_0696z7;xs13_3lozx3123;0;;-15,-21,5,-109,11,-96;6,-78,12,-12;-5,-74;-1,1,0,1,1,0",
"xp2_0696zsy166;xs22_x696zj5o64213z11;0;-5,-49,20,-112;-7,-20,-3,-39;-4,-55;-14,-96;-4,12,0,1,1,0",
"xp2_07w8ozc8421;xs15_3213kcz6421;0;-7,-59,0,-71;-2,-65,3,-56;-9,-66;;0,1,1,0,0,1",
"xp2_07z4aic;xp2_0696z4a96y07;1;4,-62;;;-13,-74;-5,9,0,1,-1,0",
"xp2_07z7;xs14_0j5oz3kp;0;16,-106,18,-87;-19,-41,-13,-127;-10,-59,-8,-78;7,-155,13,-69;5,2,0,-1,1,0",
"xp2_07z8kk8gzx343;xs22_4acwo4q552z253x1;0;2,-60;;;0,-60;5,2,0,-1,1,0",
"xp2_07zs;xs16_1no3qic;0;;5,-45;1,-24;13,-48;6,3,-1,0,0,-1",
"xp2_0c48chbgzy1121z66zyhggg07;xs15_255q826zx23;0;11,-92;;;1,-132;7,6,0,-1,-1,0",
"xp2_0c4o7hzggg11074;xs16_wck5b8oz311;0;9,-52;;;;1,7,0,1,-1,0",
"xp2_0ca248gx4a96zg314611z3;xs16_69j0j9czx11;0;;;12,-72;-12,-110;1,1,0,1,1,0",
"xp2_0dbgyc7z2ldxsy2cicz011;xs16_62461686246;0;;;14,-39;0,-123;3,0,0,-1,1,0",
"xp2_0ggg2596zzck8;xs22_0358mkl3zy21z4aa4;0;8,-175,22,-122;;22,-62;-18,-111;0,13,1,0,0,-1",
"xp2_0ggw7z1221y0696zw352;xs15_25icga6z023;0;13,-183,21,-170,27,-165;-16,-12;;-11,-152;4,3,1,0,0,1",
"xp2_0j9c826z121y57;xs14_0j9c826z121;0;;;;4,-46;0,0,1,0,0,1",
"xp2_0nz34b8o;xs16_32q4goz4a43;0;;-12,-12,3,-58;1,-63;-12,-84,4,-48;4,9,-1,0,0,-1",
"xp2_0s01110sy733zg8g222z0p4jzw11;xs12_25a842ac;0;;5,-90,20,-90;;;0,8,0,1,1,0",
"xp2_0s01110szgggy0oo;xs20_32qkg8gzxca10cc;0;;;15,-32;4,-56,13,-53;1,10,1,0,0,-1",
"xp2_1110ok8;xs15_0bq1e8z321;0;6,-50;;7,-37;-7,-62,4,-51,9,-31;4,1,1,0,0,1",
"xp2_1110oo;xs15_6ikm952z01;0;;;2,-74,3,-58;12,-28,16,-59;3,5,0,1,-1,0",
"xp2_1110s;xp2_wggg2596ze;0;-6,-32;;-9,-66;;4,-4,-1,0,0,1",
"xp2_1118kic;xp2_0ggg2596zzck8;0;-6,-29;;-10,-96;;-1,4,1,0,0,-1",
"xp2_111y0s;xs23_g8e13w4a96z0113123;0;0,-76,10,-76;-11,-16,-5,-21;;;0,2,1,0,0,1",
"xp2_111y1ey98kk8;xs15_08u16413z32;0;12,-130,22,-233,30,-144;;;-2,-156,3,-99;-2,-2,1,0,0,1",
"xp2_111zydcic;xs17_gjlka4z1ac;0;-4,-111,9,-85,14,-106;8,-84,17,-78;22,-80;;23,-2,-1,0,0,1",
"xp2_1784ozx34a4zzy67;xs14_1784ozx34a4;0;;;;-6,-81;0,0,1,0,0,1",
"xp2_1hhz0121o4ozy11xoo;xs19_o97o4cx66zw121;0;14,-69;;;;8,6,-1,0,0,1",
"xp2_253y2s;xs28_g88r58goz0121y169a4zw352;0;8,-213;-19,-69,-13,-102,-8,-152;;-24,-147,-16,-202;0,3,-1,0,0,1",
"xp2_2552ze;xs20_253ggzwoh4f033;0;3,-140;-20,-18;-5,-43;-15,-89;3,-1,0,-1,1,0",
"xp2_2552zy6e;xp2_7zy1c4owggzy3116ipy9352zyi66;0;17,-243,17,-129;15,-70;23,-44;4,-122;17,13,-1,0,0,-1",
"xp2_256xe;xp2_1hhz0121o4ozy11xoo;0;-8,-52;3,-77;-14,-94;;6,3,0,-1,-1,0",
"xp2_2596zy1ggg070gggzy5e;xp2_w33033zxo8y2sz32qi96y7cczy5ezy11110s0111;1;8,-92;-25,-46;-2,-128;-11,-107;2,-5,1,0,0,1",
"xp2_25a4z7;xs15_259m86246;0;4,-83,9,-112;-16,-13;-2,-78;-16,-126,-9,-110;-1,-1,0,1,1,0",
"xp2_2a54;xs16_2eg6p2sgzx1;0;1,-50;-3,-34,7,-38;5,-38;-7,-50,3,-46;-2,-1,1,0,0,1",
"xp2_318c;xs12_08o6413z32;0;;-4,-40;-6,-46,11,-12;-5,-70;4,-1,-1,0,0,1",
"xp2_318c;xs13_0gil96z32;0;-12,-24;6,-53;-2,-40;;3,-3,-1,0,0,1",
"xp2_318c;xs14_354c32ac;0;-4,-24,-1,-61;3,-50;7,-49,10,-12;-3,-62;0,-2,0,1,1,0",
"xp2_318c;xs16_4s3iak8zw121;0;-4,-25,11,-55;5,-61;-4,-56,9,-30;4,-55;4,-1,-1,0,0,1",
"xp2_33ws;xp2_ccyboow7z66;0;-10,-42;-18,-12,-13,-33;;;-17,4,1,0,0,-1",
"xp2_33x8kiczy87;xs14_08lb8oz321;0;;17,-79,18,-98,19,-142;10,-82;;9,0,0,-1,-1,0",
"xp2_33xca6zwe;xp2_w7zccx356zy77;0;;16,-75;12,-73;;0,8,1,0,0,-1",
"xp2_33y2ey733;xp2_69araa4zyes;1;18,-108;19,-87;4,-103;;19,-3,-1,0,0,1",
"xp2_33y766zy1ezxg88ge9a4zy01221;xs16_0ggm9icz1243;0;2,-165,5,-76;;;;3,10,0,1,1,0",
"xp2_33y97;xp2_33zy2ggg07zgz3;1;;19,-89;-1,-78,0,-97;;0,1,0,1,-1,0",
"xp2_33yfs;xs19_wg8gka6w33z2543;0;-2,-113;;9,-63;0,-115;5,6,-1,0,0,-1",
"xp2_33ze;xs16_c8al96z311;0;4,-126,23,-107;;8,-63;6,-95,6,-80;-2,3,1,0,0,1",
"xp2_33zo4oya4aa4z01zy1111;xs16_i5p64koz11;0;;;11,-46;2,-161,13,-95;6,6,0,-1,-1,0",
"xp2_33zy0888y1sx33;xs20_62s53y0ccz39c;0;;;12,-76;-27,-366,23,-48;7,6,-1,0,0,-1",
"xp2_33zy2ggg07zgz3;xs16_6s1raa4zw1;0;22,-350;-12,-107;-21,-147,-14,-111,0,-257;;6,7,-1,0,0,1",
"xp2_33zy5e;xs10_33zy4okc;0;;;;-3,-62;0,0,1,0,0,1",
"xp2_33zyb7;xp2_33zo4oya4aa4z01zy1111;0;24,-165;-11,-13,10,-95;9,-83;;0,0,0,1,1,0",
"xp2_352zy2e;xs14_9v04a4z32;0;;;5,-35,6,-58,19,-50;5,-88,9,-44;7,-1,0,-1,1,0",
"xp2_358gzsw23;xs15_3213kcz0ca1;0;6,-101,11,-92;-17,-23,-10,-35;;-19,-102;-1,8,1,0,0,-1",
"xp2_3iakg8oz643xs;xs17_3iakg8oz643;0;;;;0,-49;0,0,1,0,0,1",
"xp2_4acy1ggg070gggxcczcicy5ezxggog4cz0252ac;xs16_0gs2dioz641;0;;-3,-15;18,-22;;1,12,0,1,1,0",
"xp2_66x7e;xs15_8kk8a52z641;0;11,-121;-9,-21,-8,-113;17,-12,21,-129;-15,-182;6,14,1,0,0,-1",
"xp2_696o8gy8ezw32023;xs16_c48q552z321;0;;17,-78;;;0,6,0,1,-1,0",
"xp2_699m88gzx121ze;xs15_699m88gzx121;0;11,-65;;;;0,0,1,0,0,1",
"xp2_69araa4zyes;xs15_4aara96;0;;;;7,-58;6,0,-1,0,0,1",
"xp2_70ggg07;xp2_0s01110szgggy0oo;0;-7,-34;;4,-77;11,-32;-1,4,1,0,0,-1",
"xp2_70ggzw12hu0ok8;xs15_c88a53z352;0;;-3,-13;;;2,9,0,1,-1,0",
"xp2_7;xp2_7y7e;1;;;-15,-130;13,-20;2,-11,0,-1,1,0",
"xp2_7;xp2_7zwok8;0;;-10,-12;;-14,-81;0,0,-1,0,0,1",
"xp2_7;xp2_7zy07;1;;;-3,-66;9,-20;6,-3,0,-1,1,0",
"xp2_7;xs11_178b52;0;;2,-25;1,-27;2,-20;-3,-2,1,0,0,1",
"xp2_7;xs13_bdggkczw1;0;-8,-33,0,-61;-5,-36;0,-28;-9,-50;-3,2,-1,0,0,-1",
"xp2_7;xs13_c88a52z33;0;;-8,-12;8,-18;-2,-35;4,0,0,-1,1,0",
"xp2_7;xs14_3loz1qm;0;-11,-32,2,-68;3,-79;-17,-91,-10,-67,-8,-46;-14,-83,-2,-46;-3,4,-1,0,0,-1",
"xp2_7;xs14_3lozpi6;0;;-8,-129;-16,-78,-2,-111,6,-124;-18,-90,5,-121;-5,-2,0,1,-1,0",
"xp2_7;xs15_354qajo;0;;-19,-93;-13,-121,-8,-55,-6,-118;-10,-54,7,-56,13,-29;-6,-1,0,1,1,0",
"xp2_7;xs15_3lc2koz32;0;-25,-44,-4,-73;-7,-63;-10,-80,-6,-53;9,-20;-4,-1,0,1,1,0",
"xp2_7;xs15_3p6o8a6zw1;0;;-9,-22,12,-62,14,-80;-15,-92,-6,-63,3,-12;;6,-12,0,-1,1,0",
"xp2_7;xs16_0mk453z3443;0;;2,-36;-1,-31;-8,-46;-3,2,1,0,0,-1",
"xp2_7;xs16_178bp2sg;0;-7,-20;9,-63,12,-82;4,-62,6,-72;5,-46;3,-6,0,1,1,0",
"xp2_7;xs16_35s2s53zx1;0;-14,-36,-8,-66;-11,-32,-10,-58;-16,-78,4,-69,9,-32;-18,-86,2,-77,12,-36;-4,-2,0,1,1,0",
"xp2_7;xs16_3pc0qmzw23;0;;-12,-105,0,-123,6,-123,7,-140;-10,-54,-7,-146,2,-128,8,-94;-22,-106,-4,-136;-4,3,1,0,0,-1",
"xp2_7;xs16_6970si96;0;;4,-35;-3,-48,0,-64;1,-20;8,5,-1,0,0,-1",
"xp2_7;xs16_69acga6zx32;0;;3,-48,7,-69;-10,-54,-5,-62,5,-40;4,-32;5,1,-1,0,0,-1",
"xp2_7;xs16_c4o79cz321;0;;10,-54;5,-34,6,-57;12,-40;3,-3,1,0,0,1",
"xp2_7;xs18_bdggx696zw1023;0;-6,-95;1,-134,18,-108,19,-90;-3,-100;-1,-109;-1,-2,0,1,-1,0",
"xp2_7;xs18_oe12koy0ooz23;0;;-6,-155;-18,-91,-16,-107,-8,-165;-23,-106,-15,-80;-12,5,1,0,0,-1",
"xp2_7;xs19_cahegoz023z33;0;-11,-30,9,-50;-9,-17;0,-18;-4,-38;-10,1,0,1,1,0",
"xp2_7;xs20_03jz254rai3zy01;0;;6,-38;9,-85;9,-70,9,-56,15,-66;0,2,0,1,-1,0",
"xp2_7;xs22_8ka9mggzx12218kk8;0;-12,-20;8,-118,17,-137;8,-105;9,-85;2,-2,1,0,0,-1",
"xp2_7;xs23_y32596zwgzq6h156z0121;0;-15,-43,0,-66;-8,-25,-6,-44,-1,-68;-10,-54;-16,-94;-8,9,1,0,0,-1",
"xp2_7;xs25_x252zzck8wckg8gzxoi6221;0;-24,-20,-15,-60;7,-129,10,-160,13,-184;-12,-175,-1,-153;15,-202,16,-79;-6,-16,0,1,1,0",
"xp2_7;xs6_356;0;;;;-6,-38;1,1,-1,0,0,1",
"xp2_7e;xs13_2lmge2z01;0;3,-38;0,-27;-2,-26;;2,-3,-1,0,0,1",
"xp2_7e;xs13_g6q453z11;0;6,-72;-8,-12;-7,-57;;-3,0,-1,0,0,1",
"xp2_7e;xs14_69jzxpic;0;3,-70;-8,-13,-7,-36;1,-58;5,-48,6,-25;-4,-1,0,1,1,0",
"xp2_7e;xs16_252s0gzy01078k8;0;4,-57;-7,-13,2,-38;0,-45;-4,-50,5,-25;5,-3,0,-1,1,0",
"xp2_7e;xs16_25a4ozx34ak8;0;1,-62,13,-67;-3,-41;-9,-55,3,-50;1,-53;5,-2,0,-1,1,0",
"xp2_7e;xs16_31eozw3ego;0;5,-57;-11,-12,-1,-51;-1,-45;-1,-63,9,-24;3,-3,-1,0,0,1",
"xp2_7e;xs16_5b8r9ic;0;-16,-73;-23,-163;-22,-107,-16,-108,-14,-134;12,-42;-9,-13,0,1,1,0",
"xp2_7wggg070gggzy3ezx66zxoo;xp2_s01110szgy566y166z3;1;6,-88;;;;10,1,0,-1,1,0",
"xp2_7xs;xp2_wgggx7xszey1e;0;;13,-67;0,-127,5,-56;;12,4,-1,0,0,-1",
"xp2_7y7e;xs12_32akg84c;0;8,-58;0,-95,11,-59;5,-46;;7,7,0,1,-1,0",
"xp2_7zw6952;xp2_33x8kiczy87;1;20,-95;;;-8,-83;6,13,0,-1,-1,0",
"xp2_7zw6952;xp2_gy2252z3;1;;-9,-12;13,-30;;5,1,0,-1,1,0",
"xp2_7zwok8;xs16_8u15a4z1226;0;-10,-48;-1,-160,5,-156,14,-140,15,-241;-13,-128;;4,10,-1,0,0,-1",
"xp2_7zx33;xs17_ciligozwca4;0;2,-199,8,-136;-16,-56,-13,-12,-9,-37;17,-23;-18,-275;2,4,0,-1,-1,0",
"xp2_7zy07;xs16_0mp2sgz1243;0;-8,-56;0,-96,5,-90,16,-164;-2,-125;11,-60,18,-40;-5,3,0,1,1,0",
"xp2_7zy1c4owggzy3116ipy9352zyi66;xs16_0gjp6413z32;0;;-2,-23;;10,-80;11,7,0,-1,1,0",
"xp2_7zy733;xs23_ggdb8ow8kicz03421;0;2,-56,11,-59;9,-60;1,-72,7,-41;;10,5,-1,0,0,-1",
"xp2_7zzcczw2552;xs16_o8bap3z23;0;14,-182;-15,-80,9,-50;-4,-111,14,-34;-4,-200;4,9,-1,0,0,-1",
"xp2_7zzzyhezyd1110s0111;xp2_ggg070gggzy0ezzxck8zyls;0;;15,-75;;17,-120;25,24,-1,0,0,-1",
"xp2_8o0u93z01221zy6e;xs15_0at1e8z321;0;;;;-4,-70;5,6,-1,0,0,-1",
"xp2_c9jy2sz9f023;xs16_32qj43146;0;;;11,-12;;0,8,0,1,-1,0",
"xp2_ccyboow7z66;xs16_08u164koz32;0;19,-87;;15,-146;4,-103,6,-79;-1,8,0,1,-1,0",
"xp2_exgbhc84czx1221;xs16_69akg4czx56;0;;-4,-13;;;3,6,0,1,-1,0",
"xp2_g2552ggg070gggz3xsy0e;xs15_354q96zx23;0;;7,-127;1,-58;;7,3,0,-1,1,0",
"xp2_g88gx7y1696z0121;xs16_8k871aczggz11;0;15,-97;;;0,-70;15,0,1,0,0,1",
"xp2_g88mp2sgz11zy5e;xs16_0raik8z643;0;;;;-3,-65;7,5,0,-1,-1,0",
"xp2_g8gyjggdbgz1218kicy2sy6643w11zy5ca4;xs16_0gjp6426z32;0;;;6,-107;;30,7,0,-1,-1,0",
"xp2_ggg070gggzy0ezx8kk8w33;xp2_y87zy6ccx356zya66y0111zz6io0kcz3201;1;39,-206;;13,-170,37,-12,44,-14;;26,15,0,-1,1,0",
"xp2_ggg070gggzy0ezy4g8gz0ey1320fga6zyecc;xs15_4a9b88gzx321;0;21,-104;-3,-15;;-3,-118;7,13,0,1,1,0",
"xp2_ggg070gggzy0ezyb2552zy67;xs32_x32q4gf9zy211xooy166z33yd66;0;;15,-79,22,-99;15,-87,29,-63;;3,16,0,1,-1,0",
"xp2_ggg070gggzy0ezzxck8zyls;xs40_253y3gs248gzy3oo124311zx33yko4ozyq1w8kk8;0;40,-171;;11,-189,35,-29;4,-275,8,-219;-2,21,1,0,0,-1",
"xp2_gilmgmaz1w10s;xs17_3iar2qkzw1;0;;;;-1,-49;0,5,1,0,0,-1",
"xp2_gw7z3;xp2_g2552ggg070gggz3xsy0e;1;-1,-36;-8,-20,4,-42;-6,-53;;-5,5,0,1,-1,0",
"xp2_gy2252z3;xs20_0c4lb871zoo11;0;14,-85,27,-123;;;-9,-134,-2,-94;1,9,0,1,-1,0",
"xp2_j96z11we;xs15_ck3123z643;0;22,-98;;13,-39,20,-27;-6,-88,-1,-97;0,7,1,0,0,-1",
"xp2_j96z11we;xs15_ck3146z643;0;22,-98;10,-53;;-6,-88,4,-72;0,7,1,0,0,-1",
"xp2_og8lb8ozx32ggg070gggzy5e;xs16_c48n98czx23;0;;;21,-13;;0,6,1,0,0,-1",
"xp2_okiary27ezw65;xs16_178jt246;0;;;14,-12;;4,0,0,-1,1,0",
"xp2_ow7z1;xs16_4ai3hik8zx11;0;9,-84;-13,-12,7,-94;-1,-64;-9,-114,11,-32;4,-1,0,-1,1,0",
"xp2_phhzw65kczy1hhj;xs16_wggkq23zc452;0;18,-82;;3,-26;;7,3,-1,0,0,1",
"xp2_s01110sx4aa4zw222;xs22_4aakl3zx56y24aa4;0;25,-185,31,-216;-14,-34;32,-16;-23,-214,-12,-203,-10,-290;10,11,-1,0,0,-1",
"xp2_s01110sy8ciczw222yf66;xs19_4a9jwcczx1qm;0;;9,-95,16,-78;4,-100,38,-164;32,-263;2,8,0,1,-1,0",
"xp2_s01110szgy566y166z3;xs15_4s3iarzw1;0;24,-118,32,-142;11,-145;;-10,-130,-6,-107;22,18,-1,0,0,1",
"xp2_s01110szw222;xp2_70ggg07;0;;;;-6,-63;0,4,1,0,0,-1",
"xp2_s01110szw222;xp2_ggg070gggzy0ezyb2552zy67;1;;;2,-109;21,-40,22,-82;-1,7,0,1,-1,0",
"xp2_s01110szw222;xp2_s01110sy8ciczw222yf66;0;;15,-75;22,-82;24,-96;0,6,1,0,0,-1",
"xp2_s01110szw222;xs15_2lla8oz121;0;;-4,-118,14,-101;-4,-107,8,-69;19,-41;15,-7,-1,0,0,1",
"xp2_s01110szw222y2cc;xs20_09v0ckz32w110oo;0;20,-173;-9,-16;26,-31;-13,-159;7,9,-1,0,0,-1",
"xp2_s01110szw222zzyacc;xp2_066yb33z33zy3ezx1110s0111;1;10,-132;;;-19,-146;-4,18,1,0,0,-1",
"xp2_w33033zxo8y2sz32qi96y7cczy5ezy11110s0111;xs15_ci9b8oz023;0;;8,-65;18,-19;-8,-115;5,14,-1,0,0,-1",
"xp2_w7zccx356zy066y0111;xp2_33xca6zwe;0;9,-61;1,-27;;;4,12,0,1,-1,0",
"xp2_w7zccx356zy77;xp2_4acy1ggg070gggxcczcicy5ezxggog4cz0252ac;0;;-6,-97,1,-77;-10,-98,-2,-80;;-3,-4,1,0,0,1",
"xp2_w888033z70gggy5g8hv04aczy923zy3e;xs17_0g8hv04acz23;0;14,-84,23,-111;;;;13,5,1,0,0,1",
"xp2_wggg2596ze;xs20_4a5lmzw11023zya33;0;-1,-64,16,-102;-2,-79,2,-70;-12,-90;;0,7,-1,0,0,-1",
"xp2_wgggx7xszey1e;xs16_2egu16426;0;;1,-74;-3,-75,11,-150;;6,3,-1,0,0,-1",
"xp2_wo8a53ze;xs15_wo8a53zbd;0;5,-91,10,-120;-17,-13;;-17,-134,-10,-118;0,0,1,0,0,1",
"xp2_wo8b5ze;xs14_wo8b5zbd;0;5,-91,10,-120;-17,-13;;-17,-134,-10,-118;0,0,1,0,0,1",
"xp2_wog4cj96ze;xs13_3146pic;0;6,-45;;;;2,4,1,0,0,-1",
"xp2_wraa4ze;xs15_wraa4zbd;0;5,-91,10,-120;-17,-13;;-17,-134,-10,-118;0,0,1,0,0,1",
"xp2_x2596zkq2koz12452xo4ozy51ggg;xs16_69ir9ic;0;;3,-57;20,-13;;0,6,0,1,1,0",
"xp2_x62sgc453z7;xs14_354cgs26;0;8,-46;;;;10,0,-1,0,0,1",
"xp2_x696zccy6888zy67y17zy433;xs16_ciligzx254c;0;32,-139;;7,-77,17,-114,26,-98;1,-141;3,11,0,1,-1,0",
"xp2_xccy3252zgw8kicz3;xs8_252zy166;0;18,-86;-10,-13;;;14,0,-1,0,0,1",
"xp2_xggg070gggzy3ezy066z6952zzx111;xs19_0j9cga6z121zw33;0;11,-262;;20,-44;1,-117,2,-132;3,4,0,1,1,0",
"xp2_xggy02552w66xooz6ao74z032zy56996wgzyb3;xs15_32qjc48c;0;;21,-95;31,-25;;4,4,0,-1,1,0",
"xp2_y0oo033zyb66ze;xs15_0drzmdz11;0;6,-120,11,-195;-3,-90;-22,-196,0,-75;;4,5,0,-1,1,0",
"xp2_y2696zyc8kcz66yje;xp2_g8gyjggdbgz1218kicy2sy6643w11zy5ca4;1;29,-150;;10,-74;0,-144;-1,16,1,0,0,-1",
"xp2_y2ggg070gggzy6ezxciczcczx4a96;xs16_0g9fgka4z121;0;6,-167;;26,-12;-5,-129;0,25,1,0,0,-1",
"xp2_y3352y469d2sgzwgggy8ey01023zey1ezw111;xs16_0ggml96z641;0;;13,-90;;2,-103;18,6,0,1,-1,0",
"xp2_y87zy6ccx356zya66y0111zz6io0kcz3201;xs14_j5c2koz11;0;;6,-35;;;0,26,1,0,0,-1",
"xp2_y97z2ego4cw33y5ccz06421y0653;xs15_gjlc2koz1;0;;;16,-27;3,-90;5,6,0,-1,1,0",
"xp2_ye7zxoozy3cczccy3ca6zzxcq1dqxgzy0121w2543;xs28_04air9icy54aa4zcik8;0;;;;-10,-141;3,32,0,1,-1,0",
"xs10_0cp3z32;xs12_3pczw1246;0;;9,-46;7,-40;;0,6,1,0,0,-1",
"xs10_0cp3z32;xs12_3pczw1ac;0;;;-2,-70;8,-36;0,6,1,0,0,-1",
"xs10_0cp3z32;xs14_0cp3033z32;0;;9,-46;12,-47;13,-109;0,0,1,0,0,1",
"xs10_0cp3z32;xs15_0cp3zragz01;0;;;;-8,-54;0,0,1,0,0,1",
"xs10_0cp3z32;xs15_2560628c4go;0;-8,-36;;-5,-88;9,-51;4,-4,0,-1,1,0",
"xs10_0cp3z32;xs15_3pczw230352;0;-1,-70;;-6,-46;-13,-89;3,0,-1,0,0,1",
"xs10_0cp3z32;xs16_0cp3z32c84c;0;-12,-75,-5,-87;-1,-105,2,-52,4,-96;-14,-106,-10,-62;;3,6,-1,0,0,-1",
"xs10_0drz32;xs11_0cp3z65;0;;2,-62,14,-66;-9,-73,2,-65;;3,6,-1,0,0,-1",
"xs10_0drz32;xs12_312312ko;0;2,-60;;;-12,-66;2,0,0,-1,1,0",
"xs10_0drz32;xs12_g853zdb;0;11,-94;-11,-12;;;2,8,-1,0,0,-1",
"xs10_0drz32;xs13_3ia4zc93;0;-4,-37;3,-69,6,-59;;7,-36;0,-2,1,0,0,1",
"xs10_0drz32;xs14_0cp3zoj6;0;;-1,-43,8,-58;-8,-70,-5,-38,-1,-46;;0,-3,1,0,0,1",
"xs10_0drz32;xs14_cp3033z32;0;-3,-67;-16,-81;;-12,-66;2,6,-1,0,0,-1",
"xs10_0drz32;xs15_03pczok452;0;-4,-37;-2,-60,6,-59;;7,-36;-1,6,1,0,0,-1",
"xs10_0drz32;xs15_08o652zoj6;0;-4,-36;5,-57,18,-93;-9,-76,1,-54;8,-38;0,-3,1,0,0,1",
"xs10_0drz32;xs15_08o652zrm;0;-16,-52,-8,-36,-6,-57,7,-114;-7,-41;;-12,-104;2,9,-1,0,0,-1",
"xs10_0drz32;xs15_0cp3zgbqz01;0;-9,-36;;-6,-88;8,-51;3,6,-1,0,0,-1",
"xs10_0drz32;xs15_2lmzg6dz11;0;;4,-26;;;0,-4,1,0,0,1",
"xs10_0drz32;xs15_3pczw1248a6;0;-4,-48;6,-81;-10,-97,4,-39;7,-36;0,6,1,0,0,-1",
"xs10_0drz32;xs15_cp3z3ego;0;-4,-51,-4,-36;-4,-54,1,-88,8,-67;0,-72;;2,6,-1,0,0,-1",
"xs10_0drz32;xs15_oi60652z65;0;-1,-66;;-6,-42;-13,-85;2,7,-1,0,0,-1",
"xs10_0drz32;xs15_rdz0qbgzw1;0;14,-112;-12,-27;17,-12;;2,0,-1,0,0,1",
"xs10_0drz32;xs15_rdzgarz01;0;;;;-8,-50;2,0,-1,0,0,1",
"xs10_0drz32;xs16_0drz32c84c;0;19,-86,23,-130;;14,-63,21,-51;-7,-120,-5,-76,-2,-129;0,0,1,0,0,1",
"xs10_0drz32;xs16_25a8og8og4c;0;-6,-82,-4,-51,-4,-36;-4,-54,-2,-98,8,-67;-7,-112,0,-72;;-2,-4,0,1,1,0",
"xs10_0drz32;xs16_3pczw1248gzy356;0;;13,-94;-4,-71,-2,-82,3,-85;7,-47,19,-36;0,6,1,0,0,-1",
"xs10_0drz32;xs16_ck3123z39c;0;-13,-75,-6,-87;-2,-105,1,-52,3,-96;-15,-106,-11,-62;;2,-2,-1,0,0,1",
"xs10_0drz32;xs16_ck3146z39c;0;-3,-36;-9,-44,-7,-32,-2,-60,2,-42;-7,-54;-12,-70;2,-2,-1,0,0,1",
"xs10_0j96z32;xs12_0j96z346;0;10,-94,19,-99;-12,-12;12,-12;;0,0,1,0,0,1",
"xs10_0j96z32;xs12_69jzx1ac;0;;-11,-13;;-17,-90,-10,-83;3,0,-1,0,0,1",
"xs10_0j96z32;xs13_03ia4z69c;0;;-11,-12;12,-13;-10,-83,-7,-93;3,8,-1,0,0,-1",
"xs10_0j96z32;xs13_25icz69c;0;10,-158;-12,-76;15,-61,19,-74,19,-12;-12,-144;3,8,-1,0,0,-1",
"xs10_0j96z32;xs14_0j96066z32;0;;8,-42;13,-43;12,-113;0,0,1,0,0,1",
"xs10_0j96z32;xs14_3pczwpic;0;9,-70,13,-62,16,-94;;;-12,-82,-3,-67;-1,9,1,0,0,-1",
"xs10_0j96z32;xs14_69jzw23033;0;-3,-71;-16,-85;;-12,-70;3,0,-1,0,0,1",
"xs10_0j96z32;xs15_069jz8ka43;0;10,-94;-12,-12;16,-14;-8,-99,-5,-80,1,-84;4,0,-1,0,0,1",
"xs10_0j96z32;xs15_0j960652z32;0;16,-74;9,-61;11,-42;;0,0,1,0,0,1",
"xs10_0j96z32;xs15_0j96zragz01;0;;;;-8,-54;0,0,1,0,0,1",
"xs10_0j96z32;xs15_25606248gkc;0;14,-112;-12,-27;17,-12;;-1,10,0,1,-1,0",
"xs10_0j96z32;xs15_2560651248c;0;-9,-36;;-6,-88;8,-51;3,-4,0,-1,1,0",
"xs10_0j96z32;xs15_25606a84213;0;-5,-51;9,-88;;12,-36;0,-4,0,1,1,0",
"xs10_0j96z32;xs15_25606iczx65;0;-6,-36,-5,-73;-1,-76,12,-98;-1,-95;;-3,-1,1,0,0,1",
"xs10_0j96z32;xs15_354k8zcip;0;;-11,-12;12,-13;-10,-83,-2,-84;3,9,-1,0,0,-1",
"xs10_0j96z32;xs15_69jzw230352;0;-1,-70;;-6,-46;-13,-89;3,0,-1,0,0,1",
"xs10_0j96z32;xs15_69jzw23ck8;0;-16,-52,-8,-36,-6,-57,7,-114;-7,-41;;-12,-104;3,0,-1,0,0,1",
"xs10_0j96z32;xs16_0g842156zrm;0;-5,-92,7,-111,12,-112;-13,-60,-9,-54;-13,-74;;3,7,0,-1,-1,0",
"xs10_0j96z32;xs16_0j96z32c84c;0;19,-86,23,-130;;14,-63,21,-51;-7,-120,-5,-76,-2,-129;0,0,1,0,0,1",
"xs10_0j96z32;xs16_69jzx1248gzy456;0;5,-109,10,-106,12,-95;-23,-12,-11,-23;;-17,-118;3,0,-1,0,0,1",
"xs10_0j96z32;xs17_69jzw230o8a6;0;4,-63;-11,-12;;;3,0,-1,0,0,1",
"xs10_0j96z32;xs18_o4q231248a6z01;0;8,-96;;12,-27,12,-12;-12,-91,0,-78;0,10,0,1,-1,0",
"xs10_1784213;xs14_31e88gzwca1;0;-5,-24;3,-49;;;-2,-2,0,1,1,0",
"xs10_1784213;xs14_4ai3146zw23;0;;-2,-63,7,-78;-9,-90,-6,-58,-2,-66;;0,3,0,1,-1,0",
"xs10_1784213;xs14_64k871z65;0;;-16,-12,-10,-86;14,-16;;-1,0,0,1,1,0",
"xs10_1784213;xs15_08e1248cz253;0;;3,-22;;;-1,3,1,0,0,-1",
"xs10_1784213;xs15_0c8421e8z253;0;-5,-24;;-2,-76;12,-39;7,3,-1,0,0,-1",
"xs10_1784213;xs15_0ggs252z12ko;0;-1,-24;0,-25;;;-3,3,0,1,-1,0",
"xs10_1784213;xs15_25606248ge2;0;18,-82;13,-77;13,-58;;10,-1,-1,0,0,1",
"xs10_1784213;xs15_2eg8421ego;0;13,-63;12,-58;;1,-78,9,-45;0,-1,1,0,0,1",
"xs10_1784213;xs15_69jzx124871;0;13,-74;12,-58;3,-49,17,-51;9,-67;8,-5,-1,0,0,1",
"xs10_1784213;xs15_ml2zhik8z1;0;;;;7,-24;10,0,0,-1,1,0",
"xs10_1784213;xs16_31248716413;0;;-20,-103;-14,-104,-9,-169;-27,-142;6,0,-1,0,0,1",
"xs10_1784213;xs16_31248716426;0;-3,-97,-1,-59,2,-88;-14,-67,-11,-29,-7,-79;;-16,-98;6,0,-1,0,0,1",
"xs10_1784213;xs16_c9jzwh952zw11;0;-20,-103;;-27,-142;-14,-104,-9,-169;-4,-2,0,1,1,0",
"xs10_1784213;xs16_dbgzwh952zw11;0;-14,-72,-11,-24,-7,-84;-3,-102,-1,-54,2,-93;-16,-103;;-4,-2,0,1,1,0",
"xs10_1784ko;xs14_ghn84koz1;0;;-16,-12,-10,-86;14,-16;;-1,0,1,0,0,1",
"xs10_1784ko;xs14_wggm93z643;0;-5,-28;3,-53;;;5,-2,0,-1,1,0",
"xs10_1784ko;xs15_0g4q23z8ld;0;16,-89;13,-62;;8,-70;0,5,0,1,-1,0",
"xs10_1784ko;xs15_0gjlozc96;0;-1,-64,5,-83;0,-64;-4,-74;-15,-90,-8,-79;-3,4,0,1,-1,0",
"xs10_1784ko;xs15_0ok4871z4a6;0;;-10,-12;15,-27;-7,-96;6,0,-1,0,0,1",
"xs10_1784ko;xs15_2lmzw342ac;0;;3,-22;;;-1,-4,1,0,0,1",
"xs10_1784ko;xs15_g4q23zdl8;0;20,-90;9,-61;15,-42;;0,4,0,1,-1,0",
"xs10_1784ko;xs15_wggs252zc96;0;-1,-28;0,-29;;;-3,4,0,1,-1,0",
"xs10_1784ko;xs16_0ghn84koz32;0;6,-86,7,-108;;;-18,-102,-10,-95,-8,-75;-2,0,1,0,0,1",
"xs10_1784ko;xs16_3542ug8426;0;-4,-50,5,-83;-7,-56,-4,-47;;-15,-90,-8,-79;5,4,-1,0,0,-1",
"xs10_1784ko;xs16_c9jzw11dio;0;-20,-99;;-27,-138;-14,-100,-9,-165;-4,-2,0,1,1,0",
"xs10_178ka4;xs13_178n96;0;;12,-58;4,-45;;0,0,1,0,0,1",
"xs10_178ka4;xs13_2eg8jdzx1;0;;9,-46;7,-53;14,-37;0,-1,1,0,0,1",
"xs10_178ka4;xs14_032qk8z253;0;;;8,-26;6,-28;0,-1,0,1,1,0",
"xs10_178ka4;xs14_04ak871z311;0;;-10,-16;16,-86,22,-12;;6,0,-1,0,0,1",
"xs10_178ka4;xs14_178ka4z311;0;;-16,-12,-10,-86;16,-16;;0,0,1,0,0,1",
"xs10_178ka4;xs15_2lmzw34a52;0;;3,-22;;;-1,-4,1,0,0,1",
"xs10_178ka4;xs15_xgila4z4a43;0;-1,-28;0,-29;;;5,-3,0,-1,1,0",
"xs10_178ka4;xs16_c9jzw19la4;0;-20,-99;;-27,-138;-14,-100,-9,-165;-4,-2,0,1,1,0",
"xs10_178kk8;xp2_0nz34b8o;0;;12,-58;;8,-76;9,4,0,-1,-1,0",
"xs10_178kk8;xs14_0g8kk871z23;0;18,-156,24,-106;12,-62;;;7,0,-1,0,0,1",
"xs10_178kk8;xs14_178kk871;0;18,-86;12,-132,18,-82;;;0,0,1,0,0,1",
"xs10_178kk8;xs15_2lmzw34aa4;0;;3,-22;;;-1,-4,1,0,0,1",
"xs10_178kk8;xs15_wggs252z696;0;-1,-28;0,-29;;;-3,4,0,1,-1,0",
"xs10_178kk8;xs16_c9jzw11dic;0;-20,-99;;-27,-138;-14,-100,-9,-165;-4,-2,0,1,1,0",
"xs10_178kk8;xs16_ggm96zpi6;0;;-20,-99;-14,-100,-9,-165;-27,-138;5,0,0,-1,1,0",
"xs10_178kk8;xs18_178kk8zccz33;0;11,-84;-7,-12;;;0,0,1,0,0,1",
"xs10_2530352;xs16_259e0e952;0;-2,-20;;;8,-20;-1,3,1,0,0,-1",
"xs10_25a8426;xs12_25akg84c;0;-3,-24;-1,-22;;;-1,-1,1,0,0,1",
"xs10_25a8426;xs13_0j5ozbc1;0;-4,-35;2,-66;-11,-78;;6,0,0,-1,1,0",
"xs10_25a8426;xs13_1784215a4;0;14,-67;11,-54;;5,-71,8,-49;8,3,-1,0,0,-1",
"xs10_25a8426;xs14_0j5o0ooz121;0;15,-97;-6,-12;;-12,-163;6,0,0,-1,1,0",
"xs10_25a8426;xs14_178ka248c;0;;;-9,-74;-17,-102,-11,-152;-2,4,1,0,0,-1",
"xs10_25a8426;xs14_25iczoj6;0;;;9,-36,13,-12,16,-32;1,-65,10,-44;0,0,0,1,1,0",
"xs10_25a8426;xs14_g8ge13z1ac;0;-11,-24;-4,-75,10,-97;-9,-91;;-2,3,0,1,-1,0",
"xs10_25a8426;xs14_g8k871z1ac;0;-14,-24,-8,-98;;;10,-28;-2,3,0,1,-1,0",
"xs10_25a8426;xs14_g8ka23z1ac;0;;;-15,-94,-9,-144;-11,-82;-2,3,0,1,-1,0",
"xs10_25a8426;xs14_g8o652z1ac;0;-2,-24;-2,-30;;;-2,3,0,1,-1,0",
"xs10_25a8426;xs15_02lmz2520123;0;13,-88;-7,-27;16,-12;;0,7,1,0,0,-1",
"xs10_25a8426;xs15_0mk215a4z121;0;-4,-24;;-1,-68;11,-39;7,3,-1,0,0,-1",
"xs10_25a8426;xs15_25606248a52;0;19,-86;12,-73;14,-54;;10,0,-1,0,0,1",
"xs10_25a8426;xs15_256064215a4;0;;;;6,-24;10,3,-1,0,0,-1",
"xs10_25a8426;xs15_25a8421ego;0;14,-67;11,-54;;0,-82,8,-49;0,0,1,0,0,1",
"xs10_25a8426;xs16_0ck3146z4a43;0;13,-62;-8,-12;15,-16;-7,-94,-5,-74,0,-82,4,-48;8,0,0,-1,1,0",
"xs10_25a8426;xs16_0j5oz1254ko;0;0,-86,1,-68;-17,-12,-9,-37,-7,-25;;;6,0,0,-1,1,0",
"xs10_25a8426;xs17_08o032acz69k8;0;;11,-54;4,-45;;9,3,0,-1,-1,0",
"xs10_2eg853;xs12_31eg853;0;2,-78;-9,-20;;-12,-78;-1,0,1,0,0,1",
"xs10_2eg853;xs13_4ai30o8zx121;0;;3,-67,9,-89,16,-82;-12,-101,-5,-65;12,-28;6,-2,-1,0,0,1",
"xs10_2eg853;xs14_02eg853z311;0;;-17,-12,-11,-86;15,-16;;-1,0,1,0,0,1",
"xs10_2eg853;xs14_03hik8z643;0;-4,-28;2,-45;;;5,-1,0,-1,1,0",
"xs10_2eg853;xs14_358ge2z311;0;;-11,-16;15,-86,21,-12;;5,0,-1,0,0,1",
"xs10_2eg853;xs15_08e12koz253;0;;2,-18;;;-1,4,1,0,0,-1",
"xs10_2eg853;xs15_0g3ia4z8ld;0;17,-78;12,-73;12,-54;;0,-1,0,1,1,0",
"xs10_2eg853;xs15_0ok21e8z4a6;0;-6,-28;;-3,-80;11,-43;6,4,-1,0,0,-1",
"xs10_2eg853;xs15_358gu248c;0;0,-68,6,-87;-1,-60;-3,-70;-16,-94,-9,-83;5,0,-1,0,0,1",
"xs10_2eg853;xs15_8kih3zx34a4;0;0,-28;-1,-21;;;5,4,0,-1,-1,0",
"xs10_2eg853;xs15_g3ia4zdl8;0;13,-77;16,-74;;11,-58;0,0,0,1,1,0",
"xs10_2eg853;xs15_ml2z124871;0;;7,-38;;;5,-4,-1,0,0,1",
"xs10_2eg853;xs16_0358ge2z6511;0;13,-75,15,-95,23,-102;;;-4,-108,-3,-86;6,0,-1,0,0,1",
"xs10_2eg853;xs16_03hik8z6ip;0;-19,-103;;-26,-134;-15,-104,-10,-169;5,-1,0,-1,1,0",
"xs10_2eg853;xs16_03hik8zmq1;0;-13,-76,-10,-28,-6,-88;-4,-98,-2,-50,1,-89;-15,-99;;5,-1,0,-1,1,0",
"xs10_2eg853;xs16_0c9jz259ho;0;;-21,-95;-13,-96,-8,-161;-28,-142;-4,4,0,1,-1,0",
"xs10_2eg853;xs16_31248f12ko;0;-3,-54,6,-87;-8,-52,-5,-43;;-16,-94,-9,-83;-4,4,1,0,0,-1",
"xs10_2eg853;xs16_4ai3zx1248gzy4123;0;;16,-86;-1,-63,1,-74,6,-77;10,-39,22,-28;0,4,0,1,-1,0",
"xs10_2eg853;xs16_w2eg853z6511;0;7,-90,8,-112;;;-19,-106,-11,-99,-9,-79;-2,0,1,0,0,1",
"xs10_2l3z123;xs16_25is0si52;0;;;7,-26;7,-36,9,-67;2,-1,0,1,1,0",
"xs10_31eg8o;xs11_321eg8o;0;-6,-28;-1,-36;-4,-51;;-1,0,1,0,0,1",
"xs10_31eg8o;xs12_0gjl8z56;0;-1,-70;-1,-63;-6,-54;-8,-66;-2,4,0,1,-1,0",
"xs10_31eg8o;xs12_31eg8426;0;;8,-42;;5,-52,12,-31;0,0,1,0,0,1",
"xs10_31eg8o;xs12_g88b52z23;0;-6,-30;;-6,-54;;-1,4,0,1,-1,0",
"xs10_31eg8o;xs13_0ggm93z56;0;-5,-28;1,-58;;;-2,4,0,1,-1,0",
"xs10_31eg8o;xs13_3ia4zw1156;0;16,-91,16,-74;;14,-37;;7,5,0,-1,-1,0",
"xs10_31eg8o;xs14_0gil96z56;0;-8,-28;2,-54;;;-2,4,0,1,-1,0",
"xs10_31eg8o;xs14_31eg8og4c;0;;;10,-36,14,-12,17,-32;-2,-81,7,-60;0,0,1,0,0,1",
"xs10_31eg8o;xs14_31eg8oz311;0;;-16,-12,-10,-86;16,-16;;0,0,1,0,0,1",
"xs10_31eg8o;xs15_08k453z8ld;0;;;;3,-28;0,5,0,1,-1,0",
"xs10_31eg8o;xs15_0g88b5z8ld;0;;-7,-54;-7,-73;-12,-78;5,-1,0,-1,1,0",
"xs10_31eg8o;xs15_0oge123z4a6;0;-6,-43;8,-80;;11,-28;-1,4,1,0,0,-1",
"xs10_31eg8o;xs15_354k8zw122ac;0;15,-71;8,-42;;-3,-86,5,-53;0,0,0,1,1,0",
"xs10_31eg8o;xs15_69iczx11da;0;;-2,-60;-6,-54;;-3,-2,0,1,1,0",
"xs10_31eg8o;xs15_8k453zdl8;0;20,-90;9,-61;15,-42;;0,4,0,1,-1,0",
"xs10_31eg8o;xs15_g88b5zdl8;0;-1,-28;;;;5,0,0,-1,1,0",
"xs10_31eg8o;xs15_ml2z10784c;0;-10,-28;;-7,-80;7,-43;0,-4,1,0,0,1",
"xs10_31eg8o;xs16_031eg8oz6511;0;8,-86,9,-108;;;-18,-102,-10,-95,-8,-75;-1,0,1,0,0,1",
"xs10_31eg8o;xs16_03iajoz643;0;;-14,-87,-11,-78;23,-12;-21,-187;0,7,1,0,0,-1",
"xs10_31eg8o;xs16_wg8jq23z643;0;29,-187;-15,-12;19,-78,22,-87;;0,7,1,0,0,-1",
"xs10_31eg8o;xs16_wo8ge13z39c;0;30,-193;-12,-26,-7,-111;35,-12;;7,0,-1,0,0,1",
"xs10_31eg8o;xs16_wo8ge13zbd;0;17,-138,21,-94,24,-154;;24,-33;-3,-140,-1,-84,2,-111;7,0,-1,0,0,1",
"xs10_31eg8o;xs16_x8ka53zad11;0;;-1,-61;;-7,-58;-3,4,0,1,-1,0",
"xs10_31eg8o;xs17_8k453z110c453;0;;8,-42;5,-33;;0,4,0,1,-1,0",
"xs10_31eg8o;xs18_6996z0g88a6z023;0;3,-59;-8,-12;;;-6,5,0,1,-1,0",
"xs10_3215ac;xs12_35icz65;0;;-11,-15,-4,-36;;-7,-58;5,3,0,-1,-1,0",
"xs10_3215ac;xs13_17842ako;0;;-4,-37,-1,-59;-6,-55;-7,-58;-2,-1,1,0,0,1",
"xs10_3215ac;xs15_08k453zca43;0;;-4,-37,4,-70;-6,-55;-7,-58;-3,3,0,1,-1,0",
"xs10_3215ac;xs15_0ci53z8ld;0;;-2,-12;;;5,-1,0,-1,1,0",
"xs10_3215ac;xs15_256o8gka6;0;-21,-40,-13,-24,-11,-45,2,-102;-2,-69;;-7,-92;-3,4,1,0,0,-1",
"xs10_3215ac;xs15_ci53zdl8;0;-6,-58;;-11,-74;-8,-77;5,0,0,-1,1,0",
"xs10_3215ac;xs16_35iczw116413;0;-26,-24;;-21,-173;8,-123,13,-38;5,3,0,-1,-1,0",
"xs10_3215ac;xs16_ca51248gzy41246;0;-4,-49,-2,-68,3,-91;-11,-44;;-19,-106,-7,-69;5,0,-1,0,0,1",
"xs10_3215ac;xs16_ggc48a53z56;0;-15,-49;-1,-95,2,-68,4,-124;-15,-138,-12,-78,-8,-122;;-2,3,1,0,0,-1",
"xs10_3215ac;xs17_8o032acz34ac;0;4,-49;;;-7,-58;-3,0,0,1,1,0",
"xs10_32qr;xs13_0gbb8oz121;0;;7,-38;-4,-52,-3,-34;;5,4,-1,0,0,-1",
"xs10_32qr;xs14_c88e13z33;0;;-2,-39;-6,-46;;3,-2,-1,0,0,1",
"xs10_32qr;xs14_o8brzx123;0;;9,-46;5,-39;;0,4,1,0,0,-1",
"xs10_32qr;xs15_09f033z253;0;;-2,-12;;;3,-1,0,-1,1,0",
"xs10_32qr;xs15_0rq23z4a6;0;;-12,-12;13,-27;-9,-96;4,0,-1,0,0,1",
"xs10_32qr;xs15_ml2zd54c;0;14,-96;-8,-27;17,-12;;3,8,-1,0,0,-1",
"xs10_32qr;xs15_o8brzx1252;0;;5,-30;2,-27;;0,4,1,0,0,-1",
"xs10_32qr;xs15_oggs252z66;0;;1,-27;-2,-30;;3,-3,-1,0,0,1",
"xs10_32qr;xs16_5b88b5z033;0;;1,-14;2,-14;;4,-2,-1,0,0,1",
"xs10_32qr;xs16_o8brzxc93;0;-10,-42,-5,-127;24,-177;;29,-28;0,4,1,0,0,-1",
"xs10_32qr;xs16_rb8ozxc93;0;-26,-28;;-21,-177;8,-127,13,-42;3,4,-1,0,0,-1",
"xs10_32qr;xs16_wo8brzbd;0;-15,-41;-1,-87,2,-60,4,-116;-15,-130,-12,-70,-8,-114;;-2,4,1,0,0,-1",
"xs10_32qr;xs16_wrb8ozbd;0;;11,-114,15,-70,18,-130;-1,-116,1,-60,4,-87;18,-41;5,4,-1,0,0,-1",
"xs10_32qr;xs18_wggo8brz696;0;0,-58;-6,-29,6,-64;-6,-61,-6,-46;;-4,4,1,0,0,-1",
"xs10_32qr;xs18_wggrb8oz696;0;;9,-61,9,-46;-3,-64,9,-29;3,-58;7,4,-1,0,0,-1",
"xs10_33039c;xs12_314606io;0;;-11,-73,-5,-125;-17,-105,-12,-78;;-2,-1,1,0,0,1",
"xs10_33039c;xs12_35606io;0;-3,-52;1,-69;-13,-82;;-1,-1,1,0,0,1",
"xs10_33039c;xs12_39c0ca6;0;2,-73;-4,-48;;-14,-86;5,3,-1,0,0,-1",
"xs10_33039c;xs12_bdz3146;0;-7,-73;;-6,-69;-10,-95,-7,-58;-2,0,0,1,1,0",
"xs10_33w6io;xs14_39c0fho;0;6,-53;-7,-19;;-8,-66;6,4,-1,0,0,-1",
"xs10_33zx696;xp2_x696zccy6888zy67y17zy433;1;;;2,-148,5,-82;12,-76,19,-44;0,8,1,0,0,-1",
"xs10_33zy4okc;xs18_653zy5oozy96996;0;-3,-48;-2,-49;;;10,9,-1,0,0,-1",
"xs10_3542ac;xs15_0ca2453z253;0;;-9,-12;14,-27;-6,-88;6,0,-1,0,0,1",
"xs10_3542ac;xs15_0g6p3z8ld;0;;-7,-54;-7,-73;-12,-78;5,-1,0,-1,1,0",
"xs10_3542ac;xs15_g6p3zdl8;0;-6,-58;;-11,-74;-8,-77;5,0,0,-1,1,0",
"xs10_358gkc;xs12_69jzx1246;0;-5,-45;;-11,-74,-4,-67;;5,4,0,-1,-1,0",
"xs10_358gkc;xs15_02lmzog943;0;19,-86;10,-65;14,-46;;9,0,0,-1,1,0",
"xs10_358gkc;xs15_0g0j96z8ld;0;;-7,-54;-7,-73;-12,-78;5,-1,0,-1,1,0",
"xs10_358gkc;xs15_0ml12koz121;0;;10,-87,11,-54;4,-74,17,-44;4,-93;6,4,-1,0,0,-1",
"xs10_358gkc;xs15_0ok2156z4a6;0;-6,-43;8,-80;;11,-28;-1,4,1,0,0,-1",
"xs10_358gkc;xs15_g0j96zdl8;0;-6,-58;;-11,-74;-8,-77;5,0,0,-1,1,0",
"xs10_358gkc;xs15_ml2z1248a6;0;;;-2,-38;;0,-4,1,0,0,1",
"xs10_358gkc;xs16_6512koz3123;0;;13,-62,17,-106;-1,-96,1,-52,4,-105;8,-87,15,-75;5,4,-1,0,0,-1",
"xs10_358gkc;xs16_69jzx1248gzy4123;0;-17,-28,-5,-39;-1,-77,4,-74,6,-63;-11,-86;;5,4,0,-1,-1,0",
"xs10_358gkc;xs17_ggxok2156z1226;0;-5,-28;-2,-31;;;-5,4,1,0,0,-1",
"xs10_358gkc;xs18_6512koz4aa43;0;-13,-28,-6,-45;5,-93;0,-91,0,-76;12,-46;5,4,-1,0,0,-1",
"xs10_39cw66;xs14_g4c0fhoz11;0;15,-70;;14,-15;-1,-57;0,5,1,0,0,-1",
"xs10_3jz343;xs22_3lc2pmz011zy3cic;0;-12,-87,-5,-225;-22,-128,-12,-102;-25,-118,-9,-69;;-4,4,-1,0,0,-1",
"xs10_4al96;xs14_069la4z311;0;;;-14,-82,-8,-132;-12,-78;4,-1,0,-1,1,0",
"xs10_4al96;xs16_4al96zx1156;0;-14,-28,-6,-53,-4,-41;-3,-78,-2,-60;;;4,4,0,-1,-1,0",
"xs10_660696;xs16_c9b871z33;0;;17,-143;-2,-77;11,-24;6,2,0,-1,-1,0",
"xs10_69ar;xs14_raiczx113;0;-14,-28,-8,-102;;;10,-32;3,4,-1,0,0,-1",
"xs10_69ar;xs15_0ggra96z32;0;13,-77,13,-62;;7,-42;-7,-80,-2,-94,5,-45;6,0,-1,0,0,1",
"xs10_69ar;xs15_256069ar;0;;-8,-42;-6,-61;-13,-74;-4,0,1,0,0,1",
"xs10_69ar;xs15_4a6069ar;0;-5,-54;;-10,-62;-9,-73;-4,0,1,0,0,1",
"xs10_69ar;xs15_69arzx1252;0;9,-46;;;-2,-43;0,0,1,0,0,1",
"xs10_69ar;xs16_178b50ui;0;-12,-103,-9,-94;;-19,-171;17,-28;3,4,0,-1,-1,0",
"xs10_69ar;xs16_69arz0bd;0;6,-90,9,-73,11,-119;-16,-12;;-16,-133,-13,-83,-9,-117;0,0,1,0,0,1",
"xs10_69ar;xs16_69arzxc93;0;28,-193;-14,-26,-9,-111;33,-12;;0,0,1,0,0,1",
"xs10_69ar;xs16_ciarzw6226;0;-13,-28;23,-171;;13,-94,16,-103;0,4,1,0,0,-1",
"xs10_69ar;xs16_ciarzxc93;0;-10,-42,-5,-127;24,-177;;29,-28;0,4,1,0,0,-1",
"xs10_69ar;xs16_j9czd596;0;;-27,-12;15,-111,20,-26;-22,-193;3,8,-1,0,0,-1",
"xs10_69ar;xs16_raiczx1156;0;;2,-70,3,-92;-16,-86,-8,-79,-6,-59;;3,4,-1,0,0,-1",
"xs10_69ar;xs16_wggra96z252;0;13,-77,13,-62,15,-116;;7,-42,14,-54;-7,-80,-5,-116,5,-45;7,0,-1,0,0,1",
"xs10_69ar;xs16_wra96zbd;0;15,-130,19,-86,22,-146;;22,-25;-5,-132,-3,-76,0,-103;5,0,-1,0,0,1",
"xs10_69ar;xs16_wraiczbd;0;;11,-114,15,-70,18,-130;-1,-116,1,-60,4,-87;18,-41;5,4,-1,0,0,-1",
"xs10_69ar;xs18_wggraicz696;0;;9,-61,9,-46;-3,-64,9,-29;3,-58;7,4,-1,0,0,-1",
"xs10_69ar;xs26_6996y4ciiczy02egma;0;15,-70;13,-66;4,-69;4,-73;9,8,0,-1,-1,0",
"xs10_bdz33;xs15_bt0652z32;0;4,-86,13,-77;-9,-23,8,-42;;3,-58;0,6,1,0,0,-1",
"xs10_drz32;xs13_0drz254c;0;;-11,-12;12,-13;-10,-83,-7,-93;-1,0,1,0,0,1",
"xs10_drz32;xs15_0drz254ko;0;;-11,-12;12,-13;-10,-83,-2,-84;-1,0,1,0,0,1",
"xs10_drz32;xs15_8o652zrm;0;-5,-36;4,-57,17,-93;-10,-76,0,-54;7,-38;0,-3,1,0,0,1",
"xs10_drz32;xs15_drzragz01;0;;;;-8,-46;0,0,1,0,0,1",
"xs10_drz32;xs15_g842156zdb;0;-5,-48;5,-81;-11,-97,3,-39;6,-36;0,-2,1,0,0,1",
"xs10_drz32;xs15_ml2zmdz11;0;-10,-36;;-7,-88;7,-51;0,-4,1,0,0,1",
"xs10_drz32;xs16_ck3123zbd;0;-14,-75,-7,-87;-3,-105,0,-52,2,-96;-16,-106,-12,-62;;1,-2,-1,0,0,1",
"xs10_drz32;xs16_ck3146zbd;0;-4,-36;-10,-44,-8,-32,-3,-60,1,-42;-8,-54;-13,-70;1,-2,-1,0,0,1",
"xs10_drz32;xs16_rdz01248gzy256;0;;12,-94;-5,-71,-3,-82,2,-85;6,-47,18,-36;0,6,1,0,0,-1",
"xs10_drz32;xs18_gs2552zdmz11;0;-5,-51,-5,-36;-5,-54,7,-67;-1,-72;;1,-4,-1,0,0,1",
"xs10_g0s252z11;xs12_0g0s252z321;0;4,-60;-12,-12;;-10,-71;-1,0,1,0,0,1",
"xs10_g0s252z11;xs12_0gila4z32;0;13,-62;;;7,-47;6,5,0,-1,-1,0",
"xs10_g0s252z11;xs13_0gjla4z32;0;12,-114,27,-118;;20,-36;;6,5,0,-1,-1,0",
"xs10_g0s252z11;xs13_31231ego;0;18,-82;;11,-23;1,-70;7,1,-1,0,0,1",
"xs10_g0s252z11;xs13_31248ge13;0;20,-90;;4,-75,11,-70;5,-74;8,5,-1,0,0,-1",
"xs10_g0s252z11;xs13_dj8gzx346;0;;10,-50;6,-57;15,-33;5,-2,-1,0,0,1",
"xs10_g0s252z11;xs13_wggm93z252;0;6,-82;-10,-12;;;-2,0,0,1,1,0",
"xs10_g0s252z11;xs14_0178k8z6511;0;13,-91;;15,-86,21,-12;-9,-108;7,5,0,-1,-1,0",
"xs10_g0s252z11;xs14_032ak8z6511;0;16,-148,22,-98;14,-70;;;7,5,0,-1,-1,0",
"xs10_g0s252z11;xs14_03iak8z643;0;-11,-32,-5,-106;;;13,-36;0,-2,1,0,0,1",
"xs10_g0s252z11;xs14_69iczx1156;0;;10,-50;7,-59;;7,-1,0,-1,1,0",
"xs10_g0s252z11;xs14_ci96zw1156;0;12,-58;;;5,-67;7,0,0,-1,1,0",
"xs10_g0s252z11;xs14_wg8k871z643;0;16,-78;14,-140,20,-90;;;0,-2,1,0,0,1",
"xs10_g0s252z11;xs14_wg8ka23z643;0;-5,-36;;;13,-106,19,-32;0,-2,1,0,0,1",
"xs10_g0s252z11;xs14_wgil96z252;0;7,-78;-13,-12;;;-2,0,0,1,1,0",
"xs10_g0s252z11;xs14_xoge13z253;0;;8,-42;2,-48;;7,5,-1,0,0,-1",
"xs10_g0s252z11;xs15_035ak8z6511;0;;;11,-27;3,-80,4,-56,14,-32;7,5,0,-1,-1,0",
"xs10_g0s252z11;xs15_0g0s252z8ld;0;13,-104;-11,-27;16,-12;;-1,0,1,0,0,1",
"xs10_g0s252z11;xs15_0g88a52z8ld;0;-2,-74;;-7,-58;-12,-93;5,6,0,-1,-1,0",
"xs10_g0s252z11;xs15_69iczx115a4;0;3,-80;;;-11,-74;-3,7,0,1,-1,0",
"xs10_g0s252z11;xs15_g0s252zdl8;0;;-15,-12;12,-27;-12,-104;0,0,1,0,0,1",
"xs10_g0s252z11;xs15_g88a52zdl8;0;;-6,-12;;;5,5,0,-1,-1,0",
"xs10_g0s252z11;xs16_0g8ge13z3kp;0;-4,-32,13,-71;;1,-90;11,-68,12,-80;6,5,-1,0,0,-1",
"xs10_g0s252z11;xs16_0g8k453z3kp;0;-2,-41,15,-70;12,-94,13,-110;8,-76;;0,-1,0,1,1,0",
"xs10_g0s252z11;xs16_31eg8gzca221;0;13,-75,15,-95,23,-102;;;0,-108,1,-86;8,5,0,-1,-1,0",
"xs10_g0s252z11;xs16_32hjkcz252;0;-11,-60,-7,-32;-5,-74,-3,-38,0,-103;-11,-117,-4,-101;;-2,0,0,1,1,0",
"xs10_g0s252z11;xs16_354k8gzca221;0;;;12,-25,14,-37,22,-12;4,-68,5,-86;0,5,0,1,-1,0",
"xs10_g0s252z11;xs16_xg8ge13zc8701;0;;;6,-72,7,-90;10,-45,12,-57,20,-32;0,-3,1,0,0,1",
"xs10_g0s252z11;xs16_xg8ge13zca221;0;;11,-67,13,-87,21,-94;2,-100,3,-78;;8,5,-1,0,0,-1",
"xs10_g0s252z11;xs16_xg8ka53z4a43;0;4,-81;;-2,-38;;5,8,-1,0,0,-1",
"xs10_g0s252z11;xs18_6996z0g88a6z121;0;-3,-32;-2,-39;;;-6,0,0,1,1,0",
"xs10_g8ka52z01;xs13_g8ka52z56;0;;10,-50;6,-57;15,-33;5,5,-1,0,0,-1",
"xs10_g8ka52z01;xs16_0g8ka52z3kp;0;-4,-32,13,-71;;1,-90;11,-68,12,-80;6,5,-1,0,0,-1",
"xs10_g8o652z01;xs14_358gzx23ck8;0;-4,-43;;-3,-74;6,-63,12,-32;7,-4,-1,0,0,1",
"xs10_g8o652z01;xs15_0ggca96z1243;0;;-7,-27;-3,-42;6,-47;6,5,0,-1,-1,0",
"xs10_g8o652z01;xs15_256o8br;0;;;7,-24;1,-43,8,-32;0,5,1,0,0,-1",
"xs10_g8o652z01;xs15_g88m596z121;0;-2,-37,0,-59;8,-62,10,-50;8,-55;-10,-74;5,5,0,-1,-1,0",
"xs10_g8o652z01;xs16_0g8o652z3kp;0;-4,-32,13,-71;;1,-90;11,-68,12,-80;6,5,-1,0,0,-1",
"xs10_g8o652z01;xs16_g8idicz1252;0;-2,-47,0,-65;-12,-34,8,-72,12,-58;10,-45,12,-27;-12,-78,-8,-92,12,-54;0,-1,1,0,0,1",
"xs10_g8o652z01;xs16_xog842156z253;0;;-15,-37;-2,-38;-10,-90,-7,-97;5,7,-1,0,0,-1",
"xs10_gg0696z11;xp2_7zzcczw2552;0;-10,-100;;;-18,-102;-12,5,0,1,-1,0",
"xs10_ggka23z1;xs13_0g8gka23z23;0;;12,-58;7,-51;12,-46;7,5,-1,0,0,-1",
"xs10_ggka23z1;xs14_178k46z311;0;-2,-69;-10,-54;-12,-78,-6,-128;;0,-1,1,0,0,1",
"xs10_ggka23z1;xs15_0o4871zdl8;0;;-11,-38;-3,-57;-16,-94;5,5,0,-1,-1,0",
"xs10_ggka23z1;xs15_1784ozx122ac;0;1,-57,9,-90;;-2,-38;-11,-75;5,0,0,-1,1,0",
"xs10_ggka23z1;xs15_2lmzw342sg;0;;;7,-12;;9,-1,0,-1,1,0",
"xs10_ggka23z1;xs15_ggkq23z1ac;0;-9,-32,-2,-49;1,-65,7,-70;4,-66;8,-60;5,5,-1,0,0,-1",
"xs10_ggka23z1;xs15_xggka23z4a43;0;;7,-38;4,-35;;8,5,-1,0,0,-1",
"xs10_ggka23z1;xs16_354k8ge2zw23;0;;;12,-25,14,-37,22,-12;0,-84,1,-102;6,7,0,-1,-1,0",
"xs10_ggka23z1;xs16_c9jzw115a8o;0;;-31,-12;13,-111,18,-26;-26,-201;-2,9,1,0,0,-1",
"xs10_ggka23z1;xs16_dbgzw115a8o;0;;13,-122,17,-78,20,-138;1,-124,3,-68,6,-95;20,-49;7,-4,-1,0,0,1",
"xs10_ggka23z1;xs16_g853z115b8o;0;-9,-32,-2,-49;1,-65,10,-68;-3,-86,0,-65;;5,-4,-1,0,0,1",
"xs10_ggka23z1;xs16_ggka23zpi6;0;-21,-32;;-16,-181;13,-131,18,-46;5,5,-1,0,0,-1",
"xs10_ggka52z1;xs13_0g8gka52z23;0;3,-71;-12,-26;;-12,-78;-2,0,1,0,0,1",
"xs10_ggka52z1;xs13_g8k871z56;0;;16,-75;3,-63;9,-32;0,0,0,1,1,0",
"xs10_ggka52z1;xs14_03iak8z6221;0;-11,-32,-5,-106;;;13,-36;0,-2,1,0,0,1",
"xs10_ggka52z1;xs14_ggka52sgz1;0;16,-148,22,-98;14,-70;;;0,0,1,0,0,1",
"xs10_ggka52z1;xs14_wg8k871z4701;0;-5,-36;;;13,-106,19,-32;0,-2,0,1,1,0",
"xs10_ggka52z1;xs14_wg8k871z6221;0;16,-78;14,-140,20,-90;;;0,-2,1,0,0,1",
"xs10_ggka52z1;xs14_xok871z253;0;;8,-42;2,-48;;0,-2,0,1,1,0",
"xs10_ggka52z1;xs15_0o4a52zdl8;0;;-11,-38;-3,-57;-16,-94;5,5,0,-1,-1,0",
"xs10_ggka52z1;xs15_25a4ozx122ac;0;1,-57,9,-90;;-2,-38;-11,-75;5,0,0,-1,1,0",
"xs10_ggka52z1;xs15_2lmzw34ak8;0;3,-32;;;;-4,6,0,1,-1,0",
"xs10_ggka52z1;xs15_wg8k871z6521;0;;10,-50;8,-36;12,-34;0,-2,0,1,1,0",
"xs10_ggka52z1;xs15_xggka52z4a43;0;6,-55;;;-7,-58;-3,0,1,0,0,1",
"xs10_ggka52z1;xs16_0g8k871z3kp;0;-2,-41,15,-70;12,-94,13,-110;8,-76;;0,-1,0,1,1,0",
"xs10_ggka52z1;xs16_0g8ka23z3kp;0;-4,-32,13,-71;;1,-90;11,-68,12,-80;6,5,-1,0,0,-1",
"xs10_ggka52z1;xs16_c9jzw115ak8;0;;-31,-12;13,-111,18,-26;-26,-201;-2,9,1,0,0,-1",
"xs10_ggka52z1;xs16_dbgzw115ak8;0;4,-115,7,-88,9,-144;-20,-29;;-20,-158,-17,-98,-13,-142;-2,9,1,0,0,-1",
"xs10_ggka52z1;xs16_ggka52zpi6;0;26,-201;-18,-26,-13,-111;31,-12;;0,0,1,0,0,1",
"xs10_wg853z65;xs13_358gzxo9a4;0;;-12,-12;13,-13;-11,-91,-8,-101;5,0,-1,0,0,1",
"xs10_wg853z65;xs15_358gzy01248gkc;0;-1,-52;9,-85;-7,-101,7,-43;10,-40;0,7,1,0,0,-1",
"xs10_wg853z65;xs15_wg853zmlz121;0;;;;-9,-66;0,0,1,0,0,1",
"xs10_wg853z65;xs15_xg8421egoz321;0;;-12,-12;13,-13;-11,-91,-3,-92;-1,0,0,1,1,0",
"xs10_wg853z65;xs15_xg853z0mlz121;0;-6,-40;;-3,-92;11,-55;6,7,-1,0,0,-1",
"xs10_x696z66;xp2_y2ggg070gggzy6ezxciczcczx4a96;1;17,-104;18,-82;2,-93,18,-14;;0,-11,1,0,0,1",
"xs10_xg853z321;xs12_358gzy012ko;0;;;0,-46,5,-45,11,-44;9,-36;9,-1,0,-1,1,0",
"xs10_xg853z321;xs13_4ai3zx1248c;0;;-9,-21,-6,-43;-1,-39;-12,-82;-2,7,0,1,-1,0",
"xs10_xg853z321;xs14_3pczw1248go;0;;3,-43,12,-58;-4,-70,-1,-38,3,-46;;7,-3,-1,0,0,1",
"xs10_xg853z321;xs15_0g842130352z32;0;;-7,-12;;;6,6,-1,0,0,-1",
"xs10_xg853z321;xs15_25606agzy31246;0;14,-112;-12,-27;17,-12;;-1,10,0,1,-1,0",
"xs10_xg853z321;xs15_31248gzy21248a6;0;-5,-75,9,-73;-9,-43;-1,-50;-12,-82;6,0,0,-1,1,0",
"xs10_xg853z321;xs15_wg8421egoz65;0;;-9,-21,-1,-54;-1,-39;-12,-82;6,7,-1,0,0,-1",
"xs10_xg853z321;xs15_wg84260652z65;0;-5,-36;;-2,-88;12,-51;7,6,0,-1,-1,0",
"xs10_xg853z321;xs15_xg853zrahz01;0;;-16,-12;13,-27;-13,-112;0,0,1,0,0,1",
"xs10_xg853z321;xs16_qmxg853zw321;0;-10,-64,-6,-36;-6,-70,-4,-34,-1,-99;-10,-113,-3,-97;;-2,0,1,0,0,1",
"xs10_xg853z321;xs16_y3g84213zwg8421z65;0;;17,-94;0,-71,2,-82,7,-85;11,-47,23,-36;12,6,-1,0,0,-1",
"xs11_0253zc93;xs16_0c9jzcic32;0;-7,-50,-5,-71;-7,-32,4,-68;0,-69;10,-44;3,8,-1,0,0,-1",
"xs11_03ia4z65;xs15_0358gzoge221;0;;-1,-39;-5,-46;;-1,7,1,0,0,-1",
"xs11_03ia4z65;xs15_064k871zca1;0;16,-78;12,-132,18,-82;;;0,-1,1,0,0,1",
"xs11_03ia4z65;xs15_4ai3146zx56;0;-7,-60,-4,-40,0,-64;-5,-56,4,-77;;;4,0,-1,0,0,1",
"xs11_03ia4z65;xs16_0354k8z8kihzx1;0;;-12,-12;13,-13;-11,-91,-3,-92;4,10,-1,0,0,-1",
"xs11_03ia4z65;xs16_08e1248goz253;0;;-1,-12;;;4,-1,0,-1,1,0",
"xs11_03ia4z65;xs16_0g88e1248goz121;0;;2,-27;-1,-30;;4,-3,0,-1,1,0",
"xs11_03ia4z65;xs16_69jzx1248ge2;0;5,-71,19,-129;-12,-12;13,-24;-11,-113;-5,9,0,1,-1,0",
"xs11_064213z33;xs15_g2u0ol3z11;0;14,-66;;10,-29;3,-53;5,6,0,-1,-1,0",
"xs11_08o652z32;xs12_08o653z32;0;;11,-54;7,-48;;0,0,1,0,0,1",
"xs11_08o652z32;xs13_0g8o6413z23;0;;;-1,-91,0,-75;6,-67,14,-36;0,-1,0,1,1,0",
"xs11_08o652z32;xs13_0ggca52z641;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs11_08o652z32;xs13_w8o652zca1;0;11,-94;-11,-12;;;-1,0,1,0,0,1",
"xs11_08o652z32;xs14_djozx3146;0;;16,-79;3,-67;9,-36;7,0,0,-1,1,0",
"xs11_08o652z32;xs14_djozx39c;0;;10,-53;6,-60;15,-36;5,-2,-1,0,0,1",
"xs11_08o652z32;xs15_032qk8zc93;0;-11,-36,-5,-110;;;13,-40;0,-2,1,0,0,1",
"xs11_08o652z32;xs15_08o652sgz32;0;16,-148,22,-98;14,-70;;;0,0,1,0,0,1",
"xs11_08o652z32;xs15_31248gozy33146;0;-4,-47;;-3,-78;6,-67,12,-36;7,-4,0,-1,1,0",
"xs11_08o652z32;xs15_358gzx23c4go;0;15,-81;7,-69,13,-62;12,-44;;9,-2,0,-1,1,0",
"xs11_08o652z32;xs15_3pczw23ck8;0;9,-70,13,-62,16,-94;;;-12,-82,-3,-67;-1,9,1,0,0,-1",
"xs11_08o652z32;xs15_xoge13zc93;0;;17,-78;0,-101,14,-67;13,-65;0,-2,1,0,0,1",
"xs11_08o652z32;xs15_xok453zc93;0;;14,-103;-5,-109,9,-87;16,-36;0,-2,1,0,0,1",
"xs11_08o652z32;xs15_xok871zc93;0;16,-78;14,-140,20,-90;;;0,-2,1,0,0,1",
"xs11_08o652z32;xs15_xoka23zc93;0;-5,-40;;;13,-110,19,-36;0,-2,1,0,0,1",
"xs11_08o652z32;xs16_08o652z3ego;0;8,-96;;12,-27,12,-12;-12,-91,-5,-112,0,-78;0,0,1,0,0,1",
"xs11_08o652z32;xs16_08o652zragz01;0;;;;-8,-62;0,0,1,0,0,1",
"xs11_08o652z32;xs16_0j5og4cz343;0;-5,-66;;-5,-50,-2,-60,2,-69;6,-62;-2,0,0,1,1,0",
"xs11_08o652z32;xs16_256o8zy023ck8;0;-16,-52,-8,-36,-6,-57,7,-114;-7,-41;;-12,-104;5,0,-1,0,0,1",
"xs11_08o652z32;xs16_3146o8br;0;;2,-29,9,-46;2,-34;;0,6,0,1,-1,0",
"xs11_08o652z32;xs16_g4c32qrz11;0;;;7,-28;1,-47,8,-36;0,1,1,0,0,1",
"xs11_08o652z32;xs16_xoka53zc93;0;;10,-63;6,-76;12,-36;0,-2,1,0,0,1",
"xs11_0brz65;xs13_0ok213zca1;0;;;-5,-85;4,-86,7,-40;0,-1,1,0,0,1",
"xs11_0c93z253;xs15_3lk48cz0146;0;16,-104;;20,-12;-5,-103;0,7,1,0,0,-1",
"xs11_0c93z253;xs16_628c1fgkc;0;14,-66;;;-4,-78,2,-51;4,0,0,-1,1,0",
"xs11_0cp3z65;xs15_3146248c4go;0;10,-74,14,-66,17,-98;;;-13,-86,-4,-71;3,0,0,-1,1,0",
"xs11_0cp3z65;xs16_0cp3zmlz121;0;;;;-9,-58;0,0,1,0,0,1",
"xs11_0cp3z65;xs16_3146248ge13;0;;-12,-12;13,-13;-11,-91,-3,-92;3,0,0,-1,1,0",
"xs11_0cp3z65;xs16_w8o652zgb6z11;0;-3,-40;6,-61,19,-97;-8,-80,2,-58;9,-42;0,-3,1,0,0,1",
"xs11_0drz65;xs14_3ia4zol3;0;-4,-41;3,-73,6,-63;;7,-40;0,-2,1,0,0,1",
"xs11_0drz65;xs15_0cp3zmdz11;0;10,-74,14,-66,17,-98;;;-13,-86,-4,-71;2,10,-1,0,0,-1",
"xs11_0drz65;xs16_08o652zgb6z11;0;-4,-40;5,-61,18,-97;-9,-80,1,-58;8,-42;0,-3,1,0,0,1",
"xs11_0drz65;xs16_0drzmlz121;0;;;;-9,-54;0,0,1,0,0,1",
"xs11_0drz65;xs16_0g842156zol3;0;-4,-52;6,-85;-10,-101,4,-43;7,-40;0,-2,1,0,0,1",
"xs11_0drz65;xs16_2lmz0mdz32;0;;4,-26;;;0,-4,1,0,0,1",
"xs11_0drz65;xs16_31eg8426426;0;;-12,-12;13,-13;-11,-91,-3,-92;3,10,0,-1,-1,0",
"xs11_0drz65;xs16_31eg84c8426;0;-4,-41;-2,-64,6,-63;;7,-40;-1,-3,0,1,1,0",
"xs11_0drz65;xs16_354c84c8426;0;-4,-55,-4,-40;-4,-58,1,-92,8,-71;0,-76;;-1,-3,0,1,1,0",
"xs11_0g0s252z121;xs13_wggka52z252;0;;10,-50;4,-40;;7,6,0,-1,-1,0",
"xs11_0g0s252z121;xs14_dj8gzx34a4;0;;11,-54;7,-61;16,-37;6,-2,-1,0,0,1",
"xs11_0g0s252z121;xs15_8ka23zw115a4;0;;;-11,-78,-5,-128;-15,-98;-2,6,0,1,-1,0",
"xs11_0g0s252z121;xs15_8kai3zx34a4;0;;-14,-16;16,-86,22,-12;;0,8,1,0,0,-1",
"xs11_0g0s252z121;xs15_ci96zw115a4;0;;-6,-47;-1,-38;;-2,6,0,1,-1,0",
"xs11_0g0s252z121;xs15_xg8k871z4a43;0;;11,-54;5,-65;12,-45;0,-2,1,0,0,1",
"xs11_0g0s252z121;xs15_xg8ka23z4a43;0;;-20,-12,-14,-86;16,-16;;6,8,-1,0,0,-1",
"xs11_0g0s252z121;xs15_xg8o652z4a43;0;;9,-46;3,-52;;0,-2,1,0,0,1",
"xs11_0gbrz23;xs16_039u0ooz311;0;;16,-119;6,-64,14,-85,14,-12,23,-71;-7,-99,1,-130,4,-108,5,-71;6,6,0,-1,-1,0",
"xs11_17842ac;xs13_31eg84ko;0;1,-78;-8,-28;;-11,-78;-1,-1,1,0,0,1",
"xs11_17842ac;xs15_4ai3146z321;0;;-2,-63,7,-78;-9,-90,-6,-58,-2,-66;;0,3,0,1,-1,0",
"xs11_17842ac;xs15_69n842ac;0;7,-145,9,-107;-18,-12,-6,-144,-1,-175;-11,-162;;-1,0,1,0,0,1",
"xs11_17842ac;xs15_g88e13zc96;0;-5,-24;3,-49;;;-2,3,0,1,-1,0",
"xs11_17842ac;xs15_ghn842acz1;0;;-16,-12,-10,-86;14,-16;;-1,0,1,0,0,1",
"xs11_17842ac;xs16_0ggs252zpic;0;-1,-24;0,-25;;;-3,3,0,1,-1,0",
"xs11_17842ac;xs16_25308e12453;0;-2,-64;-5,-42;;-9,-70;-4,3,1,0,0,-1",
"xs11_17842ac;xs16_2lmzw342156;0;;3,-22;;;-1,-4,1,0,0,1",
"xs11_17842ac;xs16_g88c453zc96;0;-5,-39,-5,-24;-5,-42,0,-76,7,-55;-1,-60;;-2,3,0,1,-1,0",
"xs11_17842ac;xs16_gjlozpic;0;-1,-68,5,-87;0,-68;-4,-78;-15,-94,-8,-83;-3,3,0,1,-1,0",
"xs11_17842sg;xs15_3ia4zw1178c;0;;;15,-12;-1,-69;0,0,0,1,1,0",
"xs11_17842sg;xs15_ghn842sgz1;0;;10,-83;-6,-100;12,-102,18,-28;7,4,-1,0,0,-1",
"xs11_17842sg;xs16_069m453z311;0;8,-82;-8,-33,-3,-52,14,-80;-14,-90,-4,-73;;0,4,0,1,-1,0",
"xs11_17842sg;xs16_3ia4zw1178k8;0;;;11,-12;2,-45;0,0,0,1,1,0",
"xs11_178b52;xs15_178b52sg;0;16,-148,22,-98;14,-70;;;0,0,1,0,0,1",
"xs11_178b52;xs15_ciarzw1226;0;16,-78;14,-140,20,-90;;;0,3,0,1,-1,0",
"xs11_178b52;xs15_mlic0ccz1;0;15,-97;-6,-12;;-12,-163;5,0,0,-1,1,0",
"xs11_178b52;xs16_cilmzx1156;0;-5,-39,-5,-24;-5,-42,0,-76,7,-55;-1,-60;;5,3,0,-1,-1,0",
"xs11_178b52;xs16_cilmzx34a4;0;-1,-24;0,-25;;;5,3,0,-1,-1,0",
"xs11_178c48c;xs16_02lmzggmdz1;0;;;10,-12;;10,0,0,-1,1,0",
"xs11_178c48c;xs16_0ggs252zrm;0;-1,-24;0,-25;;;-3,3,0,1,-1,0",
"xs11_178c48c;xs16_178c48ge13;0;15,-70;10,-51;4,-66,12,-33;;0,0,1,0,0,1",
"xs11_178c4go;xs13_32qczx1ac;0;16,-74;;;6,-68;0,0,0,1,1,0",
"xs11_178c4go;xs15_0cq23146z32;0;;-2,-63,7,-78;-9,-90,-6,-58,-2,-66;;0,4,0,1,-1,0",
"xs11_178c4go;xs15_3pczw1178c;0;-5,-28;3,-53;;;6,4,0,-1,-1,0",
"xs11_178c4go;xs16_0cq23ck8z32;0;-24,-121;-21,-150,4,-188;-33,-166,-6,-203,1,-184,11,-170;9,-165;0,4,0,1,-1,0",
"xs11_178c4go;xs16_178c4go0ok8;0;;;11,-12;;0,0,1,0,0,1",
"xs11_178c4go;xs16_2lmzw34628c;0;;3,-22;;;-1,-4,1,0,0,1",
"xs11_178c4go;xs16_3pczw1132ac;0;-5,-43,-5,-28;-5,-46,0,-80,7,-59;-1,-64;;6,4,0,-1,-1,0",
"xs11_178c4go;xs16_3pczw1178k8;0;-1,-28;0,-29;;;6,4,0,-1,-1,0",
"xs11_178cw66;xs15_03lk46z6221;0;13,-79;;15,-12;-4,-75;7,0,0,-1,1,0",
"xs11_178jd;xs13_g0s2pmz11;0;1,-70;-8,-20;;-11,-70;-1,4,1,0,0,-1",
"xs11_178jd;xs15_0g8kiarz23;0;;-10,-16;16,-86,22,-12;;0,6,0,1,-1,0",
"xs11_178jd;xs15_0ggs2pmz32;0;-5,-28;3,-53;;;-2,4,1,0,0,-1",
"xs11_178jd;xs15_178kiar;0;;-16,-12,-10,-86;16,-16;;0,6,0,1,-1,0",
"xs11_178jd;xs16_178jt066;0;16,-74,22,-98;;7,-73;-5,-59,6,-89;0,0,1,0,0,1",
"xs11_178jd;xs16_4a60gs2pm;0;-2,-56;-5,-34;;-9,-62;-4,4,1,0,0,-1",
"xs11_178jd;xs16_wggs2pmz252;0;-1,-28;0,-29;;;-3,4,1,0,0,-1",
"xs11_178jd;xs16_wgs2pmz643;0;-5,-43,-5,-28;-5,-46,0,-80,7,-59;-1,-64;;-2,4,1,0,0,-1",
"xs11_178jd;xs16_wmp2sgz643;0;;5,-64;-3,-59,4,-80,9,-46;9,-43,9,-28;6,4,-1,0,0,-1",
"xs11_178jd;xs17_696zw259ar;0;15,-70;;;2,-58;9,6,0,-1,-1,0",
"xs11_178ka6;xs15_06ak871z311;0;;-10,-16;16,-86,22,-12;;6,0,-1,0,0,1",
"xs11_178ka6;xs16_okai3zx34a4;0;;;6,-22;5,-28;0,4,0,1,-1,0",
"xs11_178ka6;xs16_xgjla4z4a43;0;-1,-28;0,-29;;;5,-3,0,-1,1,0",
"xs11_178kic;xs11_17842sg;0;9,-51;;14,-12;4,-37;0,0,1,0,0,1",
"xs11_178kic;xs15_wgil96z643;0;-5,-28;3,-53;;;5,-2,0,-1,1,0",
"xs11_178kic;xs16_xgil96z4a43;0;-1,-28;0,-29;;;5,-3,0,-1,1,0",
"xs11_253039c;xs14_39c0f96;0;4,-61;;;-10,-74;6,3,-1,0,0,-1",
"xs11_2530f9;xs12_6530f9;0;0,-56;;;-8,-62;0,0,1,0,0,1",
"xs11_2530f9;xs14_35ac0f9;0;;-15,-36;;-22,-118,-7,-114;-1,3,1,0,0,-1",
"xs11_2530f9;xs14_3iarz056;0;4,-70;-6,-23;;-13,-82;5,3,0,-1,-1,0",
"xs11_2530f9;xs14_69ic0f9;0;-1,-48,6,-81;-10,-12;;;-1,3,1,0,0,-1",
"xs11_2530f9;xs14_9f03pm;0;1,-65;-12,-25;;-7,-58;5,0,-1,0,0,1",
"xs11_2530f9;xs14_c88a52z352;0;;;11,-12;7,-24,8,-38;7,0,0,-1,1,0",
"xs11_2530f9;xs14_gilmz1w252;0;;;10,-12,11,-26;8,-24;0,3,0,1,-1,0",
"xs11_2530f9;xs14_rai3zx123;0;;-9,-12,-6,-34,-3,-53;;-11,-92;5,0,0,-1,1,0",
"xs11_2530f9;xs15_178ko0ui;0;3,-69;-8,-33;;-7,-58;-2,4,1,0,0,-1",
"xs11_2530f9;xs15_2530fpzx32;0;10,-74,14,-66,17,-98;;;-5,-86,4,-71;0,0,1,0,0,1",
"xs11_2530f9;xs15_32ako0ui;0;2,-58;-6,-15;;-9,-66;-2,4,1,0,0,-1",
"xs11_2530f9;xs15_354ko0ui;0;-2,-79,12,-101;-13,-12;;-11,-95;-2,4,1,0,0,-1",
"xs11_2530f9;xs15_3iarzw1226;0;;;-15,-90,-9,-140;-11,-78;5,3,0,-1,-1,0",
"xs11_2530f9;xs15_c88e13z352;0;;;13,-12;-1,-61;7,0,0,-1,1,0",
"xs11_2530f9;xs15_gilmz1w346;0;;;2,-49;10,-24;0,3,0,1,-1,0",
"xs11_2530f9;xs15_pf0352z23;0;11,-71,18,-95;11,-54;1,-67,9,-37;-4,-83;5,0,-1,0,0,1",
"xs11_2530f9;xs15_rai3zx1246;0;10,-70;-9,-12,-3,-43;13,-14;;5,0,0,-1,1,0",
"xs11_2530f9;xs16_09f0352z253;0;;;;-1,-34;6,0,-1,0,0,1",
"xs11_2530f9;xs16_35ako0ui;0;1,-71;-9,-15;;-7,-58;-2,4,1,0,0,-1",
"xs11_2530f9;xs16_c88c453z352;0;9,-72;;13,-27,13,-12;-5,-67,2,-88,7,-54;7,0,0,-1,1,0",
"xs11_2530f9;xs16_gilmz1w1156;0;;6,-60;-2,-55,5,-76,10,-42;10,-39,10,-24;0,3,0,1,-1,0",
"xs11_2530f9;xs16_gilmz1w34a4;0;;;5,-25;6,-24;0,3,0,1,-1,0",
"xs11_2530f9;xs16_gilmz1w696;0;;14,-66;;4,-89,7,-64;0,3,0,1,-1,0",
"xs11_2530f9;xs16_mligz1w34a4;0;;;9,-12;2,-37;0,0,0,1,1,0",
"xs11_253zdb;xs16_0dbgzcic32;0;-8,-50,-6,-71;-8,-32,3,-68;-1,-69;9,-44;2,8,-1,0,0,-1",
"xs11_25606io;xs14_65lmzw1023;0;;2,-53;-8,-66;;0,-1,0,1,1,0",
"xs11_2560ui;xs12_32qb8o;0;-9,-28;;-4,-64;;1,-1,0,1,1,0",
"xs11_2560ui;xs13_0gbq23z121;0;-3,-28;-1,-26;;;5,-1,0,-1,1,0",
"xs11_2560ui;xs14_0c88a52z253;0;;;12,-12;6,-32,7,-46;7,0,0,-1,1,0",
"xs11_2560ui;xs14_25a88cz0253;0;;;11,-12,12,-26;7,-32;7,-1,0,-1,1,0",
"xs11_2560ui;xs14_321560ui;0;-4,-31;2,-62;-11,-74;;-2,0,1,0,0,1",
"xs11_2560ui;xs14_4s0f96z11;0;;2,-49;-8,-62;;5,-1,-1,0,0,1",
"xs11_2560ui;xs14_8o0ojdz23;0;-10,-33;-1,-57;-5,-50;;5,-2,-1,0,0,1",
"xs11_2560ui;xs14_8o0uh3z23;0;-6,-28;3,-68;-3,-54;;5,-2,-1,0,0,1",
"xs11_2560ui;xs15_0c88e13z253;0;;;14,-12;-2,-69;7,0,0,-1,1,0",
"xs11_2560ui;xs15_0g8kc0f9z23;0;-4,-35;7,-71;-10,-70;;-2,4,1,0,0,-1",
"xs11_2560ui;xs15_178kc0f9;0;;;-9,-70;-17,-98,-11,-148;-2,4,1,0,0,-1",
"xs11_2560ui;xs15_178kozx6226;0;-14,-28,-8,-102;;;10,-32;-2,-2,0,1,1,0",
"xs11_2560ui;xs15_31e88cz0253;0;;;3,-45;9,-28;7,-1,0,-1,1,0",
"xs11_2560ui;xs15_cp3z230352;0;11,-78,15,-70,18,-102;;;-6,-90,3,-75;5,7,-1,0,0,-1",
"xs11_2560ui;xs15_drz230352;0;12,-75,19,-99;10,-50;2,-63,10,-33;-5,-87;5,7,-1,0,0,-1",
"xs11_2560ui;xs15_wgbq23z643;0;-11,-28;-4,-79,10,-101;-9,-95;;5,-2,0,-1,1,0",
"xs11_2560ui;xs15_xkc0f9zca1;0;-7,-28,-1,-59;8,-70;-4,-85;;-2,4,1,0,0,-1",
"xs11_2560ui;xs16_0iu0652z4a6;0;;;;-2,-38;6,0,-1,0,0,1",
"xs11_2560ui;xs16_0oggm96z4a6;0;18,-82;;8,-73,11,-48;;8,0,0,-1,1,0",
"xs11_2560ui;xs16_0oggs252z4a6;0;;;10,-12;1,-45;8,0,0,-1,1,0",
"xs11_2560ui;xs16_252sggozw4a6;0;;;6,-21;5,-28;8,-2,0,-1,1,0",
"xs11_2560ui;xs16_32qbgzx1256;0;-4,-41;2,-78;-8,-62;;5,4,0,-1,-1,0",
"xs11_2560ui;xs16_69mggoz04a6;0;;13,-62;;3,-93,6,-68;8,-1,0,-1,1,0",
"xs11_2560ui;xs16_9f032qr;0;-3,-28,4,-39;-2,-20;;;5,1,-1,0,0,1",
"xs11_2560ui;xs16_wiu0652z643;0;10,-80;;14,-27,14,-12;-6,-75,1,-96,6,-62;7,0,-1,0,0,1",
"xs11_256o8go;xs13_ggca23z65;0;;-5,-69,-4,-57;-10,-74,-2,-73;;-1,4,0,1,-1,0",
"xs11_256o8go;xs13_ggca52z65;0;-3,-28;-1,-26;;;-1,4,0,1,-1,0",
"xs11_256o8go;xs14_djozx3123;0;-10,-37;-1,-61;-5,-54;;0,-2,1,0,0,1",
"xs11_256o8go;xs15_32qk8zdb;0;;;-9,-74;-17,-102,-11,-152;-2,4,0,1,-1,0",
"xs11_256o8go;xs15_8o652sgz32;0;-8,-32;;;10,-102,16,-28;0,4,0,1,-1,0",
"xs11_256o8go;xs15_wog84213zdb;0;-7,-28,-1,-59;8,-70;-4,-85;;-2,4,0,1,-1,0",
"xs11_256o8go;xs15_woge13zdb;0;-11,-28;-4,-79,10,-101;-9,-95;;-2,4,0,1,-1,0",
"xs11_256o8go;xs15_wok453zdb;0;-8,-69;-9,-71,5,-105;-12,-82;;-2,4,0,1,-1,0",
"xs11_256o8go;xs15_wok871zdb;0;-14,-28,-8,-102;;;10,-32;-2,4,0,1,-1,0",
"xs11_256o8go;xs15_woka23zdb;0;-6,-45;1,-65;-5,-54;;-2,4,0,1,-1,0",
"xs11_256o8go;xs15_xg84c3213z321;0;-3,-79;-7,-48;-8,-66,-2,-73;;-4,4,1,0,0,-1",
"xs11_256o8go;xs16_0j5og8oz343;0;;-9,-12,-6,-34,-2,-59;-2,-68;-11,-108;0,7,1,0,0,-1",
"xs11_256o8go;xs16_25303123ck8;0;;;11,-12;;10,4,-1,0,0,-1",
"xs11_256o8go;xs16_256o8zx23ck8;0;16,-96;;11,-49;1,-106,14,-49,16,-28,24,-44;0,0,0,1,1,0",
"xs11_256o8go;xs16_6246o8br;0;-3,-28,4,-39;-2,-20;;;6,5,-1,0,0,-1",
"xs11_256o8go;xs16_kc32qrz11;0;;3,-38;-4,-50,3,-33;;1,4,0,1,-1,0",
"xs11_256o8go;xs16_woka53zdb;0;-4,-45;2,-82;-8,-66;;-2,4,0,1,-1,0",
"xs11_256w696;xs16_69ara96;0;-8,-118,11,-151;-16,-85,5,-144,11,-173;-15,-98,-9,-161,3,-139;1,-151;-1,-1,1,0,0,1",
"xs11_256zy3cic;xs16_69q3213z32;0;3,-120,6,-105,13,-125,14,-102;-18,-24,-14,-12,-2,-103;;;7,7,-1,0,0,1",
"xs11_2596w33;xs17_696zw4a96wcc;0;6,-60;-9,-12;;;-2,8,1,0,0,-1",
"xs11_2596w33;xs23_3jgy4cicz3421gzx343;0;1,-66,17,-98;;;-10,-110,-10,-78;7,0,0,-1,1,0",
"xs11_2596zzycoo;xs16_c88ge13zca1;0;5,-113;11,-117;3,-102,14,-111,20,-48;19,-68;9,0,0,-1,1,0",
"xs11_25a84ko;xs12_3542ako;0;-5,-28;3,-54;;;6,4,-1,0,0,-1",
"xs11_25a84ko;xs13_0o4a52z643;0;-3,-28;-1,-26;;;-1,4,0,1,-1,0",
"xs11_25a84ko;xs14_0g6p3zbc1;0;-4,-35;2,-66;-11,-78;;6,0,0,-1,1,0",
"xs11_25a84ko;xs14_0o4a53z643;0;-13,-48;;-20,-114,-5,-110;;-1,4,0,1,-1,0",
"xs11_25a84ko;xs15_0ci52sgz321;0;;3,-52,9,-46;-4,-55,4,-59;;0,4,0,1,-1,0",
"xs11_25a84ko;xs15_0cid96z321;0;;7,-38;1,-44;;0,4,0,1,-1,0",
"xs11_25a84ko;xs15_0g8ge13zc96;0;-11,-28;-4,-79,10,-101;-9,-95;;-2,4,0,1,-1,0",
"xs11_25a84ko;xs15_0g8k871zc96;0;-14,-28,-8,-102;;;10,-32;-2,4,0,1,-1,0",
"xs11_25a84ko;xs15_0g8ka23zc96;0;;;-15,-94,-9,-144;-11,-82;-2,4,0,1,-1,0",
"xs11_25a84ko;xs15_0g8o652zc96;0;-2,-28;-2,-34;;;-2,4,0,1,-1,0",
"xs11_25a84ko;xs15_178ka2453;0;;;-9,-74;-17,-102,-11,-152;-2,4,1,0,0,-1",
"xs11_25a84ko;xs16_0g8ka53zc96;0;-4,-28;-11,-17,-1,-41,0,-65;;;-2,4,0,1,-1,0",
"xs11_25akg8o;xs14_0g8jdzbc1;0;-4,-35;2,-66;-11,-78;;6,0,0,-1,1,0",
"xs11_25akg8o;xs14_0o4a52zc452;0;16,-75;9,-46;;3,-79,6,-57;0,5,0,1,-1,0",
"xs11_25akg8o;xs14_o4a5123z23;0;-10,-37;-1,-61;-5,-54;;0,4,1,0,0,-1",
"xs11_25akg8o;xs16_25a4ozw254ko;0;16,-75;9,-46;;-2,-90,6,-57;0,0,0,1,1,0",
"xs11_25icz65;xs13_25akg8426;0;-3,-40;-1,-38;;;-1,-1,0,1,1,0",
"xs11_25icz65;xs14_025icz4a9o;0;;-12,-12;13,-13;-11,-91,-8,-101;-1,0,1,0,0,1",
"xs11_25icz65;xs14_25icz69k8;0;11,-166;-13,-76;16,-61,20,-74,20,-12;-13,-152;0,0,1,0,0,1",
"xs11_25icz65;xs14_358gzmp21;0;-10,-40;-1,-64;-5,-57;;0,7,1,0,0,-1",
"xs11_25icz65;xs15_178ka248go;0;-8,-44;;;10,-114,16,-40;4,-2,0,-1,1,0",
"xs11_25icz65;xs15_3146248gka4;0;10,-74,14,-66,17,-98;;;-13,-86,-4,-71;-1,10,0,1,-1,0",
"xs11_25icz65;xs15_g853z1252sg;0;-6,-40;1,-60;-5,-49;;3,7,-1,0,0,-1",
"xs11_25icz65;xs15_g853z125a8o;0;-14,-40,-8,-114;;;10,-44;3,7,-1,0,0,-1",
"xs11_25icz65;xs16_25a842132ac;0;9,-104;;13,-27,13,-12;-13,-99,-6,-120,-1,-86;0,0,0,1,1,0",
"xs11_25icz65;xs16_25a84215ak8;0;11,-102;-13,-12;17,-14;-9,-107,-6,-88,0,-92;0,0,0,1,1,0",
"xs11_25icz65;xs16_25iczmlz121;0;;;;-9,-58;0,0,1,0,0,1",
"xs11_25icz65;xs16_31eg84215a4;0;;-12,-12;13,-13;-11,-91,-3,-92;3,10,0,-1,-1,0",
"xs11_25icz65;xs16_69jzx1248a52;0;5,-71,19,-129;-12,-12;13,-24;-11,-113;-5,9,0,1,-1,0",
"xs11_25icz65;xs16_w8o652zci9gzw1;0;7,-116,20,-111,22,-98,30,-146;-12,-30;;-9,-99;3,10,-1,0,0,-1",
"xs11_25iczx113;xs14_0g4q23zbc1;0;-10,-36;-1,-60;-5,-53;;0,6,1,0,0,-1",
"xs11_25iczx113;xs15_03iak8zc452;0;-8,-40;;;10,-110,16,-36;5,-2,-1,0,0,1",
"xs11_25iczx113;xs15_178k46z2521;0;-4,-78;-8,-45;;-18,-102,-12,-152;0,7,1,0,0,-1",
"xs11_25iczx113;xs15_25iczx1178c;0;17,-78;;;1,-71;0,0,1,0,0,1",
"xs11_25iczx113;xs15_32q4gzx121e8;0;-6,-41;1,-61;-5,-50;;5,6,-1,0,0,-1",
"xs11_25iczx113;xs15_32q4gzx1254c;0;-14,-36,-8,-110;;;10,-40;5,6,-1,0,0,-1",
"xs11_25iczx113;xs15_wci52sgz311;0;;;-9,-70;-17,-98,-11,-148;5,0,-1,0,0,1",
"xs11_25iczx113;xs15_xok4871z253;0;;3,-48;-3,-42;;5,-2,0,-1,1,0",
"xs11_25iczx113;xs16_25iczw1pl3;0;7,-93,13,-98;-15,-12,-8,-29;14,-40;-2,-94;0,0,1,0,0,1",
"xs11_25iczx113;xs16_25iczx1178k8;0;13,-62;;;-2,-59;0,0,1,0,0,1",
"xs11_25izw1156;xs14_ggkq23z56;0;5,-63,19,-86;-7,-21;5,-38;-4,-74;5,1,-1,0,0,1",
"xs11_2ege13;xs13_0gbaa4z123;0;;11,-54;;11,-30;0,-1,0,1,1,0",
"xs11_2ege13;xs13_0gbaa4z321;0;;10,-50;6,-39;12,-31;0,-1,0,1,1,0",
"xs11_2ege13;xs13_2ege1246;0;15,-70;11,-56;6,-65;7,-64;0,0,1,0,0,1",
"xs11_2ege13;xs14_0gbaa4z343;0;;;5,-50;11,-44,12,-28;0,-1,0,1,1,0",
"xs11_2ege13;xs14_0gbaa4z643;0;;;4,-58;10,-28;0,-1,0,1,1,0",
"xs11_2ege13;xs15_03lkk8z643;0;-4,-28;2,-45;;;5,-1,0,-1,1,0",
"xs11_2ege13;xs15_0gbaa4z3452;0;;;3,-54;13,-28;0,-1,0,1,1,0",
"xs11_2ege13;xs15_0mkk871z32;0;;-17,-12,-11,-86;15,-16;;-1,0,0,1,1,0",
"xs11_2ege13;xs15_31ege2z311;0;;-11,-16;15,-86,21,-12;;5,0,-1,0,0,1",
"xs11_2ege13;xs15_3pczwd552;0;;;7,-36,11,-12,14,-32;1,-57,10,-36;8,-1,0,-1,1,0",
"xs11_2ege13;xs15_gbaa4zdb;0;;18,-188,18,-150;-15,-190;21,-28;0,0,0,1,1,0",
"xs11_2ege13;xs16_2ege132ac;0;12,-73,12,-58;;6,-62;-2,-76,3,-90,10,-41;0,0,1,0,0,1",
"xs11_2ege13;xs16_31egu248c;0;0,-68,6,-87;-1,-60;-3,-70;-16,-94,-9,-83;5,0,-1,0,0,1",
"xs11_2ege13;xs16_69iczxd552;0;;11,-54;7,-60;;8,-2,0,-1,1,0",
"xs11_2ege13;xs16_8kkl3zx34a4;0;0,-28;-1,-21;;;5,4,0,-1,-1,0",
"xs11_2ege13;xs16_gbaa4zdl8;0;;;;6,-28;0,0,0,1,1,0",
"xs11_2ege13;xs17_x8ka53z255d;0;12,-58;;6,-61;;8,4,0,-1,-1,0",
"xs11_2lmz641;xs12_628c0f9;0;-3,-42;;-10,-58;;-1,7,0,1,-1,0",
"xs11_2lmz641;xs13_39cz6952;0;;;-4,-65;6,-40;0,7,1,0,0,-1",
"xs11_2lmz641;xs14_628c0f96;0;-7,-40;-1,-51;;;-1,7,0,1,-1,0",
"xs11_2lmz641;xs14_628c2d96;0;-8,-44,-3,-40;-4,-44;;;-1,7,0,1,-1,0",
"xs11_2lmz641;xs15_31248c2c826;0;-7,-40,-4,-62,-1,-81;;-9,-104;;-1,-3,0,1,1,0",
"xs11_2lmz641;xs15_3542arzx32;0;;-3,-92,-2,-48;-12,-66,-2,-63;;-3,1,1,0,0,1",
"xs11_31461ac;xs12_358mic;0;;1,-40,8,-42,13,-66;-1,-50;;6,3,-1,0,0,-1",
"xs11_31461ac;xs13_04ap3zca1;0;;-4,-52;-6,-58;;6,-1,0,-1,1,0",
"xs11_31461ac;xs13_3pa4zw1246;0;-5,-24;5,-58;;;6,3,0,-1,-1,0",
"xs11_31461ac;xs15_04ap3zoj6;0;-5,-36,4,-57;-9,-32,-6,-12,-2,-36;;;6,-1,0,-1,1,0",
"xs11_31461ac;xs15_gjl8628cz1;0;-5,-28;;;13,-98,19,-24;7,3,-1,0,0,-1",
"xs11_31461ac;xs16_0g8o652zpi6;0;11,-83;;14,-46;-20,-130,-12,-82,-10,-95,3,-100;9,0,0,-1,1,0",
"xs11_31461ac;xs16_253031461ac;0;-1,-24;;;;-4,0,1,0,0,1",
"xs11_31461ac;xs16_256o8zx4ajo;0;-1,-65;-22,-28,-14,-12,-12,-33,1,-90;-6,-80;;-3,-3,0,1,1,0",
"xs11_31461ac;xs16_31eozoja4;0;-5,-45,2,-94,7,-80;-1,-66;;-7,-77,-7,-62;-3,3,0,1,-1,0",
"xs11_31e853;xs12_321e853;0;-6,-24;-1,-32;-4,-47;;-1,0,1,0,0,1",
"xs11_31e853;xs13_352sga6;0;-7,-31;-1,-39;-5,-50;;-1,-1,1,0,0,1",
"xs11_31e853;xs13_358e1246;0;-2,-64;-1,-65;-6,-56;-10,-70;5,0,-1,0,0,1",
"xs11_31e853;xs14_3542sga6;0;-5,-24;1,-54;;;-2,-1,1,0,0,1",
"xs11_31e853;xs15_0j9aczc93;0;-5,-36,4,-57;-9,-32,-6,-12,-2,-36;;;5,-1,0,-1,1,0",
"xs11_31e853;xs15_6952sga6;0;-8,-24;2,-50;;;-2,-1,1,0,0,1",
"xs11_31e853;xs15_j9aczdb;0;-16,-24;20,-186;-13,-184,-13,-146;;5,0,0,-1,1,0",
"xs11_31e853;xs16_0jhe853z121;0;5,-108,18,-103,20,-90,28,-138;-6,-54;;-3,-91;-1,0,1,0,0,1",
"xs11_31e853;xs16_31eoz359c;0;-5,-41,2,-90,7,-76;-1,-62;;-7,-73,-7,-58;-3,3,0,1,-1,0",
"xs11_31e853;xs16_69iczwc953;0;;-2,-60;-6,-54;;-3,-2,0,1,1,0",
"xs11_31e853;xs16_ck5jzw116a4;0;;11,-80;4,-90,17,-33,19,-12,27,-28;6,-65;0,3,0,1,-1,0",
"xs11_31e853;xs16_j9aczdl8;0;-1,-24;;;;5,0,0,-1,1,0",
"xs11_31eg84c;xs13_0gjl8z1ac;0;-2,-68;-1,-69;-6,-60;-10,-74;6,0,0,-1,1,0",
"xs11_31eg84c;xs14_8ljgzx69c;0;-5,-28;1,-58;;;6,4,0,-1,-1,0",
"xs11_31eg84c;xs15_0gil96z1ac;0;-8,-28;2,-54;;;-2,4,0,1,-1,0",
"xs11_31eg84c;xs15_178k453zx23;0;;-16,-12,-10,-86;16,-16;;0,6,0,1,-1,0",
"xs11_31eg84c;xs16_08k453zok452;0;15,-71;10,-50;;-1,-86,7,-53;9,0,0,-1,1,0",
"xs11_31eg84c;xs16_0g8421egoz346;0;15,-82;10,-50;5,-41,19,-43;7,-75;8,4,-1,0,0,-1",
"xs11_32132ac;xs12_32132qk;0;16,-74;;12,-33;1,-62;0,0,1,0,0,1",
"xs11_32132ac;xs13_25b8og8o;0;16,-74;;14,-26;;7,4,-1,0,0,-1",
"xs11_32132ac;xs15_cq23123z32;0;26,-114;;21,-134,21,-96;22,-132;6,0,-1,0,0,1",
"xs11_32132ac;xs15_drz0123146;0;6,-55,15,-70;;;-7,-82,-4,-50,0,-58;0,0,0,1,1,0",
"xs11_32132ac;xs15_gs2596z56;0;18,-82;;;4,-68;7,0,0,-1,1,0",
"xs11_32132ac;xs16_08k453zoge3;0;;-4,-41,4,-74;-6,-59;-7,-62;-3,3,0,1,-1,0",
"xs11_32132ac;xs16_0o4a952zbd;0;;;14,-12;0,-74;8,0,0,-1,1,0",
"xs11_32132ac;xs16_256064264ko;0;;-2,-12;;;-4,-1,1,0,0,1",
"xs11_32132ac;xs16_256o8go8a6;0;-21,-40,-13,-24,-11,-45,2,-102;-2,-69;;-7,-92;-3,4,1,0,0,-1",
"xs11_32132ac;xs16_ca23123z352;0;11,-54;;;;6,0,-1,0,0,1",
"xs11_32132ac;xs16_g842156z178c;0;-10,-55,4,-53;-4,-63;-6,-70;-7,-62;-2,0,0,1,1,0",
"xs11_32132ac;xs16_gs259a4z56;0;10,-119,13,-98,20,-106;-11,-12;14,-46;;7,0,0,-1,1,0",
"xs11_3215a8o;xs14_0o4871zc452;0;;-4,-41,-1,-63;-6,-59;-7,-62;6,-1,0,-1,1,0",
"xs11_3215a8o;xs16_0g8jt066z23;0;;4,-87;-3,-99,8,-25;11,-28,17,-28;0,4,0,1,-1,0",
"xs11_3215a8o;xs16_0o4871zgarz01;0;;-2,-12;;;6,-1,0,-1,1,0",
"xs11_3215a8o;xs16_1784ozw254ko;0;;-4,-41,4,-74;-6,-59;-7,-62;6,4,0,-1,-1,0",
"xs11_3215a8o;xs16_256o8gka23;0;-21,-44,-13,-28,-11,-49,2,-106;-2,-73;;-7,-96;-3,4,1,0,0,-1",
"xs11_3215a8o;xs16_354k8zx12pm;0;16,-75;9,-46;;-2,-90,6,-57;9,6,0,-1,-1,0",
"xs11_3215a8o;xs16_dj8gzx32ak8;0;12,-58;;;1,-55;0,0,0,1,1,0",
"xs11_3215a8o;xs16_g842156z121e8;0;-10,-55,4,-53;-4,-63;-6,-70;-7,-62;-2,0,0,1,1,0",
"xs11_321eg8o;xs13_321eg8426;0;;-11,-19,-4,-40;;-7,-62;6,4,-1,0,0,-1",
"xs11_321eg8o;xs15_2eg88b5zw23;0;;-15,-12,-9,-86;17,-16;;0,6,0,1,-1,0",
"xs11_321eg8o;xs15_cp3z122qk;0;;;11,-36,15,-12,18,-32;-1,-81,8,-60;9,4,0,-1,-1,0",
"xs11_321eg8o;xs16_354k8zw122qk;0;;-4,-41,4,-74;-6,-59;-7,-62;-3,-2,0,1,1,0",
"xs11_32acw66;xs15_ggkc0fhoz1;0;13,-79;;15,-12;-4,-75;0,5,1,0,0,-1",
"xs11_32acwoo;xs15_32ac0fho;0;;8,-55;1,-51;10,-28;0,0,1,0,0,1",
"xs11_3303lo;xs12_25303lo;0;-7,-28,1,-41;-3,-27;;;-1,0,1,0,0,1",
"xs11_354c826;xs12_5b8og4c;0;-3,-45;2,-50;-7,-62;;0,-1,1,0,0,1",
"xs11_354c826;xs13_25b8og4c;0;-5,-38;;-7,-62;;-1,-1,1,0,0,1",
"xs11_354c826;xs13_6421eozx32;0;-5,-24;2,-61,10,-60;2,-54;;0,-2,0,1,1,0",
"xs11_354c826;xs15_31eozoj6;0;;;9,-36,13,-12,16,-32;1,-65,10,-44;0,0,0,1,1,0",
"xs11_354c826;xs15_gs2596z146;0;;-1,-56;-9,-70;;-1,3,0,1,-1,0",
"xs11_354c826;xs16_0o4a952z39c;0;-5,-24;3,-62;;;-2,3,0,1,-1,0",
"xs11_354c826;xs16_256064132ac;0;;;;6,-24;10,3,-1,0,0,-1",
"xs11_354c826;xs16_ca23146z352;0;;;-2,-42;;0,3,1,0,0,-1",
"xs11_354c826;xs16_gs259a4z146;0;-5,-58;;-11,-94,-4,-86,-1,-107;14,-24;-1,3,0,1,-1,0",
"xs11_3586246;xs13_35426853;0;15,-70;11,-54;;7,-64,16,-33;7,0,-1,0,0,1",
"xs11_3586246;xs14_178426853;0;14,-66;11,-55;8,-59,11,-37;;8,0,-1,0,0,1",
"xs11_3586246;xs15_178ki6zx65;0;;-16,-12,-10,-86;14,-16;;-1,5,0,1,-1,0",
"xs11_3586246;xs16_03pa4zoge3;0;;11,-69,11,-54;1,-72,6,-86,13,-37;5,-74;0,-1,0,1,1,0",
"xs11_3586246;xs16_08o652zoja4;0;14,-92;;9,-61;3,-102,16,-45,18,-24,26,-40;9,0,0,-1,1,0",
"xs11_3586246;xs16_0c9jz253056;0;26,-185;-14,-26,-9,-111,9,-157;4,-146,31,-12;;5,7,-1,0,0,-1",
"xs11_3586246;xs16_0g8o652z1qm;0;-1,-65;-22,-28,-14,-12,-12,-33,1,-90;-6,-80;;-3,3,0,1,-1,0",
"xs11_3586246;xs16_25606426853;0;;;9,-12;;10,0,-1,0,0,1",
"xs11_3586246;xs16_31eg84cga6;0;14,-66;11,-55;3,-70,11,-37;;9,-1,-1,0,0,1",
"xs11_3586246;xs16_3pa4zw1248a6;0;14,-66;11,-66;11,-59;1,-57,15,-59;0,0,0,1,1,0",
"xs11_358gka4;xs12_358gka6;0;;11,-54;9,-48;;0,0,1,0,0,1",
"xs11_358gka4;xs12_ci52zw1246;0;-15,-28,-5,-37;-2,-57,6,-57;;;6,4,0,-1,-1,0",
"xs11_358gka4;xs13_25akg853;0;;11,-54;11,-39;;7,0,-1,0,0,1",
"xs11_358gka4;xs13_32akg853;0;;;1,-75,2,-59;6,-59,14,-28;7,0,-1,0,0,1",
"xs11_358gka4;xs13_358gzw8k96;0;-3,-28;-5,-36,1,-37,6,-38;;;-3,-1,0,1,1,0",
"xs11_358gka4;xs13_651i4ozw121;0;;4,-65,9,-46,14,-68;1,-45;9,-30;0,-1,0,1,1,0",
"xs11_358gka4;xs13_ci52zw1248c;0;-5,-28;2,-60;-4,-50;;6,4,0,-1,-1,0",
"xs11_358gka4;xs14_358gka246;0;;16,-74;5,-62;9,-39;0,0,1,0,0,1",
"xs11_358gka4;xs14_358gka53;0;;10,-106,25,-110;;18,-52;0,0,1,0,0,1",
"xs11_358gka4;xs14_g8421e8z1252;0;-7,-28;10,-65,17,-101;-11,-82,-4,-89,2,-67;;-1,4,0,1,-1,0",
"xs11_358gka4;xs15_031i4oz4a611;0;;;9,-26;7,-28;0,-1,0,1,1,0",
"xs11_358gka4;xs15_031i4ozc4521;0;18,-86;14,-140,20,-90;;;0,-1,0,1,1,0",
"xs11_358gka4;xs15_08kai3zc8421;0;18,-156,24,-106;14,-70;;;8,0,0,-1,1,0",
"xs11_358gka4;xs15_4a51248gzy41246;0;-9,-53,-2,-57;-3,-50,5,-71;-5,-86;-10,-74;6,4,-1,0,0,-1",
"xs11_358gka4;xs15_ggka512koz1;0;;12,-58;7,-50;9,-31;8,4,-1,0,0,-1",
"xs11_358gka4;xs15_ok215a4z65;0;-5,-92;-1,-105;-11,-106,-9,-168,-3,-118;15,-28;0,4,1,0,0,-1",
"xs11_358gka4;xs16_031i4ozca521;0;;10,-50;10,-36;12,-42;0,-1,0,1,1,0",
"xs11_358gka4;xs16_4a512kozx643;0;-10,-28,-7,-52;3,-79,8,-73,18,-93;-3,-74,1,-106;;6,4,-1,0,0,-1",
"xs11_358gka4;xs16_ci52zw123ck8;0;-1,-65;-22,-28,-14,-12,-12,-33,1,-90;-6,-80;;6,4,0,-1,-1,0",
"xs11_358gka4;xs16_ml2z1248a52;0;;;-2,-42;;0,-4,1,0,0,1",
"xs11_35a8426;xs14_1784215ac;0;14,-67;11,-54;;5,-71,8,-49;8,3,-1,0,0,-1",
"xs11_35a8426;xs15_35iczoj6;0;;;9,-36,13,-12,16,-32;1,-65,10,-44;0,0,0,1,1,0",
"xs11_35a8426;xs16_08o652z69ko;0;14,-66;12,-60;7,-48,17,-30;7,-51,20,-35;9,3,0,-1,-1,0",
"xs11_35a8426;xs16_0ci53zoge3;0;14,-81,14,-66;;8,-62;-2,-84,3,-98,10,-49;0,4,0,1,-1,0",
"xs11_35a8426;xs16_256064215ac;0;;;;6,-24;10,3,-1,0,0,-1",
"xs11_35a8426;xs16_31eg842ako;0;14,-67;11,-54;;0,-82,8,-49;9,4,-1,0,0,-1",
"xs11_35a8426;xs16_ci53zw1248a6;0;14,-78;11,-54;4,-45,18,-47;8,-71;0,3,0,1,-1,0",
"xs11_3lowcc;xs15_0kc0fhoz32;0;13,-87;;15,-12;-6,-83;0,6,1,0,0,-1",
"xs11_3lozcc;xs15_312460uh3;0;16,-74;;12,-21;1,-61;0,0,0,1,1,0",
"xs11_4ai3zx123;xs15_03ia4oz65x11;0;;;-8,-66;-18,-102,-12,-152;-2,6,0,1,-1,0",
"xs11_4ai3zx123;xs15_31248gzc8711;0;;9,-46;5,-39;;5,6,-1,0,0,-1",
"xs11_4ai3zx123;xs15_3pczw124871;0;;;7,-33,16,-12;1,-60,5,-36,8,-56;8,7,0,-1,-1,0",
"xs11_4ai3zx123;xs15_w64k871z6421;0;;;-14,-86,-8,-136;-12,-82;5,-1,-1,0,0,1",
"xs11_4ai3zx123;xs16_031248gz8k8711;0;;5,-30;2,-27;;6,6,-1,0,0,-1",
"xs11_4ai3zx123;xs16_354m96z321;0;;-4,-52;-6,-67,-1,-66,16,-26;6,-59,16,-36;5,0,-1,0,0,1",
"xs11_4ai3zx123;xs16_g84213z1pl3;0;-11,-36,-4,-53;-1,-69,5,-74;2,-70;6,-64;0,6,1,0,0,-1",
"xs11_4ai3zx123;xs16_g8421e8zdl8;0;;;12,-12;;0,6,0,1,-1,0",
"xs11_696zy2253;xs14_39c88czw252;0;;6,-113,12,-77;7,-52;4,-107,7,-155,14,-40;3,0,-1,0,0,1",
"xs11_69jzx123;xs16_g842156zdl8;0;;;12,-12;;0,6,0,1,-1,0",
"xs11_69jzx56;xs14_4ai3zxpic;0;12,-101,15,-91;-9,-13;16,-12;;5,9,-1,0,0,-1",
"xs11_69jzx56;xs15_wj96zmdz11;0;14,-158,20,-208,22,-146;-18,-12;16,-76;-2,-145;4,0,-1,0,0,1",
"xs11_69jzx56;xs15_xj96zg6dz11;0;8,-71,17,-86;;;-13,-98,-10,-66,-6,-74;5,0,-1,0,0,1",
"xs11_69jzx56;xs16_62s0g842156zx1;0;7,-92,15,-91;-9,-13;16,-12;;0,10,0,1,-1,0",
"xs11_69jzx56;xs16_651248go8a6;0;5,-86,10,-120,17,-99;-9,-27,-9,-12;;-5,-104;0,0,0,1,1,0",
"xs11_69jzx56;xs16_69jzx1248gkc;0;15,-113;-9,-24;16,-12;-15,-129,-1,-71;0,0,1,0,0,1",
"xs11_69jzx56;xs16_wj96zmlz121;0;13,-62;;;;4,0,-1,0,0,1",
"xs11_bdz352;xs10_bdz33;0;;;;-11,-62;0,0,1,0,0,1",
"xs11_bdz352;xs12_31230f9;0;19,-86;;12,-14;;0,0,0,1,1,0",
"xs11_bdz352;xs13_0bdz6952;0;12,-93;-12,-12;;;-1,0,1,0,0,1",
"xs11_bdz352;xs14_31230fho;0;16,-78;;11,-12;-3,-82;0,0,0,1,1,0",
"xs11_bdz352;xs14_64268m96;0;6,-81;-7,-21;;-12,-66;2,0,0,-1,1,0",
"xs11_bdz352;xs14_bdz3553;0;;;16,-12;-4,-79;0,0,1,0,0,1",
"xs11_bdz352;xs15_3lk48cz056;0;7,-103;-18,-12;;-14,-104;2,7,-1,0,0,-1",
"xs11_bdz352;xs16_6426gu156;0;0,-51,6,-78;;;-12,-66;2,0,0,-1,1,0",
"xs11_dbz352;xs12_32130f9;0;19,-86;;12,-14;;0,0,0,1,1,0",
"xs11_dbz352;xs13_31e86246;0;12,-80;;12,-12;-8,-86;-1,7,0,1,-1,0",
"xs11_dbz352;xs14_32130fho;0;16,-78;;11,-12;-3,-82;0,0,0,1,1,0",
"xs11_dbz352;xs14_dbz3553;0;;;16,-12;-4,-79;0,0,1,0,0,1",
"xs11_dbz352;xs14_ml96z56;0;15,-103,24,-106;;;-3,-99;0,7,1,0,0,-1",
"xs11_dbz352;xs15_0bdz25b8o;0;;-21,-12,-15,-86;17,-16;;2,0,-1,0,0,1",
"xs11_dbz352;xs15_31248c2c84c;0;18,-132;;10,-53,13,-34,16,-12;;3,10,0,-1,-1,0",
"xs11_dbz352;xs15_ra2453z23;0;11,-91,21,-94;;;-3,-76,-1,-104;0,6,1,0,0,-1",
"xs11_dbz352;xs16_dbz35ako;0;14,-95;;16,-12;-4,-108;0,0,1,0,0,1",
"xs11_g0s253z11;xs13_0g0s253z321;0;4,-60;-12,-12;;-10,-71;-1,0,1,0,0,1",
"xs11_g0s253z11;xs13_0g0s256z321;0;;-11,-12;;-11,-76;5,6,-1,0,0,-1",
"xs11_g0s253z11;xs13_8ljgzx256;0;-4,-50,4,-83;-2,-52;;-11,-74;-2,5,0,1,-1,0",
"xs11_g0s253z11;xs14_wggm93z652;0;6,-82;-10,-12;;;-2,0,0,1,1,0",
"xs11_g0s253z11;xs14_wggm96z652;0;5,-74;-12,-12,-11,-28;;;-2,0,0,1,1,0",
"xs11_g0s253z11;xs15_0178kcz6511;0;13,-91;;15,-86,21,-12;-9,-108;7,5,0,-1,-1,0",
"xs11_g0s253z11;xs15_3pczw115ac;0;-4,-52,-1,-32,3,-56;-10,-16,-1,-37;;;-3,6,0,1,-1,0",
"xs11_g0s253z11;xs15_g88a53zdb;0;25,-214;-21,-12;;-18,-212,-18,-174;5,5,0,-1,-1,0",
"xs11_g0s253z11;xs15_wgil96z652;0;7,-78;-13,-12;;;-2,0,0,1,1,0",
"xs11_g0s253z11;xs16_69iczx115ac;0;3,-80;;;-11,-74;-3,7,0,1,-1,0",
"xs11_g0s253z11;xs16_ci96zw115ac;0;7,-79;-13,-13,-8,-40;-4,-46;;-3,6,0,1,-1,0",
"xs11_g0s253z11;xs16_g88a53zdl8;0;;-6,-12;;;5,5,0,-1,-1,0",
"xs11_g0s256z11;xs13_0g88b52z123;0;;-11,-12;;-11,-76;-1,0,0,1,1,0",
"xs11_g0s256z11;xs14_08u1acz321;0;10,-90;-10,-12,-4,-37,5,-56;-1,-66;;0,-1,1,0,0,1",
"xs11_g0s256z11;xs14_wggm93z256;0;6,-82;-10,-12;;;-2,0,0,1,1,0",
"xs11_g0s256z11;xs15_03iakoz643;0;-11,-32,-5,-106;;;13,-36;0,-2,1,0,0,1",
"xs11_g0s256z11;xs15_25a8oge13;0;;7,-38;8,-25;3,-43;8,5,-1,0,0,-1",
"xs11_g0s256z11;xs15_wg8kq23z643;0;-5,-36;;;13,-106,19,-32;0,-2,1,0,0,1",
"xs11_g0s256z11;xs15_wgil96z256;0;7,-78;-13,-12;;;-2,0,0,1,1,0",
"xs11_g0s256z11;xs16_31eg8o653;0;14,-66;;8,-36;3,-54;0,5,1,0,0,-1",
"xs11_g0s256z11;xs16_69iczx11da4;0;3,-80;;;-11,-74;-3,7,0,1,-1,0",
"xs11_g0s453z11;xs13_0ggs256z32;0;;-11,-12;;-11,-76;5,6,-1,0,0,-1",
"xs11_g0s453z11;xs16_69iczx1178c;0;;;2,-70;10,-32;7,-3,-1,0,0,1",
"xs11_g88a52z23;xs13_0ggka52z56;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs11_g88a52z23;xs13_0ggm96z56;0;-1,-36;9,-61;;;0,-1,1,0,0,1",
"xs11_g88a52z23;xs13_0gila4z56;0;-2,-36;8,-61;;;0,-1,1,0,0,1",
"xs11_g88a52z23;xs13_25a88gzwca1;0;11,-82,18,-89;;12,-12;;5,0,-1,0,0,1",
"xs11_g88a52z23;xs14_0ggka53z56;0;;10,-106,25,-110;;18,-44;0,-1,1,0,0,1",
"xs11_g88a52z23;xs14_0ggm952z56;0;;;9,-12;;0,-1,1,0,0,1",
"xs11_g88a52z23;xs14_0gjla4z56;0;-10,-36;;-17,-102,-2,-98;;0,-1,1,0,0,1",
"xs11_g88a52z23;xs14_31248ge123;0;-9,-36;6,-80;-2,-100,5,-77;;0,-3,0,1,1,0",
"xs11_g88a52z23;xs14_dj8gzx3426;0;;16,-79;3,-67;9,-36;7,0,0,-1,1,0",
"xs11_g88a52z23;xs14_g88b5zdb;0;-7,-36;2,-60;-2,-53;;4,6,-1,0,0,-1",
"xs11_g88a52z23;xs15_0178k8zad11;0;-2,-61;-8,-54;-12,-78,-6,-128;;0,-2,1,0,0,1",
"xs11_g88a52z23;xs15_032ak8zad11;0;-11,-36,-5,-110;;;13,-40;0,-2,1,0,0,1",
"xs11_g88a52z23;xs15_8kai3zx3426;0;16,-148,22,-98;14,-70;;;7,0,0,-1,1,0",
"xs11_g88a52z23;xs15_ci96zw11da;0;-1,-36;6,-73;;;5,-2,-1,0,0,1",
"xs11_g88a52z23;xs15_cp3z122ak8;0;4,-83,13,-98;;;-15,-110,-12,-78,-8,-86;0,9,1,0,0,-1",
"xs11_g88a52z23;xs15_x8k871zad11;0;16,-78;14,-140,20,-90;;;0,-2,1,0,0,1",
"xs11_g88a52z23;xs15_x8ka23zad11;0;-5,-40;;;13,-110,19,-36;0,-2,1,0,0,1",
"xs11_g88a52z23;xs15_x8o652zad11;0;;;7,-42;7,-36;0,-2,1,0,0,1",
"xs11_g88a52z23;xs16_035ak8zad11;0;;4,-74,5,-54,15,-70;-2,-53;;0,-2,1,0,0,1",
"xs11_g88a52z23;xs16_0g88a52zgarz01;0;9,-46;;;;-1,0,1,0,0,1",
"xs11_g88a52z23;xs16_25a88gzx254ko;0;3,-84,11,-83;-11,-13;12,-12;;5,0,-1,0,0,1",
"xs11_g88a52z23;xs16_31eozw122ak8;0;1,-78,6,-112,13,-91;-11,-27,-11,-12;;-7,-96;-2,9,1,0,0,-1",
"xs11_g88a52z23;xs16_4a4owj96zx121;0;11,-105;-11,-24;12,-12;-17,-121,-3,-63;6,0,0,-1,1,0",
"xs11_g88a52z23;xs16_8o652z122ak8;0;10,-81,23,-117;-11,-12;13,-14;-16,-100,-6,-78;0,9,1,0,0,-1",
"xs11_g8ka52z11;xs13_0g8ka52z321;0;;;0,-57;10,-32;0,-1,1,0,0,1",
"xs11_g8ka52z11;xs14_g8ka53z56;0;;10,-50;6,-57;15,-33;5,5,-1,0,0,-1",
"xs11_g8ka52z11;xs15_03iak8z6521;0;-11,-32,-5,-106;;;13,-36;0,-2,1,0,0,1",
"xs11_g8ka52z11;xs15_xoka53z253;0;;;7,-38;7,-32;7,5,-1,0,0,-1",
"xs11_g8ka52z11;xs16_wg8ka53z6521;0;;10,-50;8,-36;12,-34;0,-2,1,0,0,1",
"xs11_g8o652z11;xs14_w8o653zca1;0;;7,-79,10,-72,13,-62;;13,-62;0,-1,0,1,1,0",
"xs11_g8o652z11;xs15_032qk8z653;0;-11,-32,-5,-106;;;13,-36;0,-2,1,0,0,1",
"xs11_g8o652z11;xs15_358gzx23cko;0;-4,-43;;-3,-74;6,-63,12,-32;7,-4,-1,0,0,1",
"xs11_g8o652z11;xs16_356o8br;0;;;7,-24;1,-43,8,-32;0,5,1,0,0,-1",
"xs11_g8o652z11;xs16_xoka53z653;0;;10,-50;8,-36;12,-34;0,-2,1,0,0,1",
"xs11_gg2596z11;xs16_ca9b8oz0252;0;-14,-32,-13,-54;7,-138,12,-139;;-9,-182;9,-2,0,-1,-1,0",
"xs11_ggka53z1;xs14_0g8gka53z23;0;3,-71;-12,-26;;-12,-78;-2,0,1,0,0,1",
"xs11_ggka53z1;xs15_178ka6z311;0;-2,-69;-10,-54;-12,-78,-6,-128;;0,-1,1,0,0,1",
"xs11_ggka53z1;xs15_wggka53z643;0;3,-67;;;-11,-74;-2,0,1,0,0,1",
"xs11_ggka53z1;xs16_2lmzw34ako;0;3,-32;;;;-4,6,0,1,-1,0",
"xs11_ggka53z1;xs16_354k8zx125ac;0;1,-57,9,-90;;-2,-38;-11,-75;-3,7,0,1,-1,0",
"xs11_ggka53z1;xs16_xg8kq23z4a43;0;;7,-38;4,-36;;8,5,-1,0,0,-1",
"xs11_ggka53z1;xs16_xggka53z4a43;0;6,-55;;;-7,-58;-3,0,1,0,0,1",
"xs11_ggm952z1;xs15_ggm952sgz1;0;16,-148,22,-98;14,-70;;;0,0,1,0,0,1",
"xs11_ggm952z1;xs15_wo4k871z6221;0;16,-78;14,-140,20,-90;;;0,-2,1,0,0,1",
"xs11_ggm952z1;xs16_xggm952z4a43;0;6,-55;;;-7,-58;-3,0,1,0,0,1",
"xs11_w2596zz33;xs17_2552y3oozzy98kic;0;4,-118;;;-25,-130;-11,14,1,0,0,-1",
"xs11_w4a96z66;xp2_xggg070gggzy3ezy066z6952zzx111;1;12,-94;9,-80;-13,-90;-20,-110;5,18,-1,0,0,-1",
"xs11_wg84213z65;xs13_31248gzy212ko;0;;-12,-25;;-18,-110,-11,-103;7,0,-1,0,0,1",
"xs11_wg84213z65;xs14_4ai3zx1248go;0;;-12,-12;13,-13;-11,-91,-8,-101;-1,9,1,0,0,-1",
"xs11_wg84213z65;xs15_wg84213213z65;0;6,-145;-12,-76;22,-12;-18,-146,-16,-208,-10,-158;0,0,0,1,1,0",
"xs11_wg84213z65;xs15_xg8426413zca1;0;;;9,-40,13,-16,16,-36;3,-61,12,-40;0,-1,1,0,0,1",
"xs11_wg84213z65;xs15_y3g853zwg8421z65;0;-2,-40;10,-71,17,-95;3,-68,11,-57;11,-72;0,-5,1,0,0,1",
"xs11_wg84213z65;xs16_wg842130352z65;0;;;;-9,-74;0,0,0,1,1,0",
"xs11_wg84213z65;xs16_wg842132acz65;0;9,-104;;13,-27,13,-12;-13,-99,-6,-120,-1,-86;0,0,0,1,1,0",
"xs11_wg84213z65;xs16_wg84215ak8z65;0;11,-102;-13,-12;17,-14;-9,-107,-6,-88,0,-92;0,0,0,1,1,0",
"xs11_wg84213z65;xs16_xg8421egozca1;0;;-12,-12;13,-13;-11,-91,-3,-92;-1,0,0,1,1,0",
"xs11_xg853zca1;xs15_xg853zcq1z32;0;-9,-44;9,-134,15,-184,17,-122;7,-121;11,-108;6,8,-1,0,0,-1",
"xs11_xg853zca1;xs15_y0g853z0cq1z32;0;;3,-43,12,-58;-4,-70,-1,-38,3,-46;;7,8,-1,0,0,-1",
"xs11_xg853zca1;xs16_358gzy0hik8zx32;0;;-13,-12;14,-13;-12,-99,-4,-100;6,0,-1,0,0,1",
"xs11_xg853zca1;xs16_xg853zca1z352;0;;;;-10,-74;0,0,1,0,0,1",
"xs12_025iczca1;xs14_25a4ozok21;0;-2,-44;0,-42;;;0,-1,1,0,0,1",
"xs12_025iczca1;xs14_ci52zw1248go;0;3,-84,9,-85,14,-86;-11,-12;;;4,0,-1,0,0,1",
"xs12_025iczca1;xs15_31248gka246;0;-9,-44;0,-68;-4,-61;;0,8,0,1,-1,0",
"xs12_025iczca1;xs15_31248gka53;0;-12,-44;;-19,-110,-4,-106;;0,8,0,1,-1,0",
"xs12_025iczca1;xs15_4a51248gka4;0;12,-174;-14,-76;17,-61,21,-74,21,-12;-14,-160;4,0,0,-1,1,0",
"xs12_025iczca1;xs15_4ai3zwg9iczx1;0;;-13,-12;14,-13;-12,-99,-9,-109;-1,10,1,0,0,-1",
"xs12_025iczca1;xs16_025iczcq1z32;0;7,-153;-13,-76;23,-12;-19,-154,-17,-216,-11,-166;0,0,1,0,0,1",
"xs12_025iczca1;xs16_0358gzggka43z1;0;-13,-44,-7,-118;;;11,-48;-1,8,1,0,0,-1",
"xs12_025iczca1;xs16_g8o651248goz01;0;;4,-40;-2,-34;;4,-2,0,-1,1,0",
"xs12_025iczca1;xs16_ggka51248goz1;0;-5,-44;2,-64;-4,-53;;4,-2,0,-1,1,0",
"xs12_025iczca1;xs16_w25icz0cq1z32;0;11,-78,15,-70,18,-102;;;-14,-90,-5,-75;-1,0,1,0,0,1",
"xs12_025iczca1;xs16_wg853zgjka4z1;0;-7,-48;;;11,-118,17,-44;5,8,-1,0,0,-1",
"xs12_02lmz643;xs13_253032ak8;0;6,-79;-14,-12;;-13,-92;3,0,0,-1,1,0",
"xs12_02lmz643;xs13_253032qk;0;3,-72;;;-13,-74,-11,-84;3,0,0,-1,1,0",
"xs12_02lmz643;xs15_02lla4z643;0;;8,-42;4,-57;3,-53;0,0,1,0,0,1",
"xs12_02lmz643;xs15_354c0f96;0;-6,-40;0,-51;;;0,7,0,1,-1,0",
"xs12_02lmz643;xs15_354cgc2ko;0;;10,-71;2,-71,5,-87;9,-40;0,7,0,1,-1,0",
"xs12_02lmz643;xs16_03lk48cz643;0;;10,-76;3,-75;14,-40;0,0,1,0,0,1",
"xs12_03loz643;xs12_0ol3zca1;0;12,-80,15,-70;;;-12,-86,-1,-68;4,0,-1,0,0,1",
"xs12_03loz643;xs13_25a8og84c;0;6,-79;-14,-12;;-13,-92;-1,8,0,1,-1,0",
"xs12_03loz643;xs13_5b8og84c;0;3,-72;;;-13,-74,-11,-84;-1,7,0,1,-1,0",
"xs12_03loz643;xs14_031eozok21;0;-4,-40;3,-72;-3,-62;;-1,7,1,0,0,-1",
"xs12_03loz643;xs14_25b8og84c;0;;-13,-12;;-13,-92;-1,8,0,1,-1,0",
"xs12_03loz643;xs14_35a8og84c;0;6,-76;-14,-12;;-12,-87;-1,8,0,1,-1,0",
"xs12_03loz643;xs14_6421eozx65;0;-2,-50,6,-83;-4,-36;;-13,-74;-2,7,1,0,0,-1",
"xs12_03loz643;xs14_g84213z178c;0;-2,-40;-4,-48,2,-49,7,-50;;;3,-1,-1,0,0,1",
"xs12_03loz643;xs14_j96z178c;0;-5,-40;5,-74,14,-79;;7,-40;3,-1,-1,0,0,1",
"xs12_03loz643;xs15_0ci52zoge3;0;-5,-104;5,-138;-5,-124;10,-89,14,-102,14,-40;0,-2,1,0,0,1",
"xs12_03loz643;xs15_31eoz4a9o;0;-4,-40;;-3,-63,0,-73;7,-41;0,7,1,0,0,-1",
"xs12_03loz643;xs15_gs2453z1ac;0;8,-98;-12,-12;;;3,8,-1,0,0,-1",
"xs12_03loz643;xs15_gs2552z1ac;0;7,-90;-14,-12,-13,-28;;;3,8,-1,0,0,-1",
"xs12_03loz643;xs16_0o4a96z3lo;0;1,-70;-11,-12;;-21,-110;3,9,-1,0,0,-1",
"xs12_03loz643;xs16_0rdzg0t6z11;0;-4,-104;0,-117;-10,-118,-8,-180,-2,-130;16,-40;0,-3,1,0,0,1",
"xs12_03loz643;xs16_3146248c453;0;;4,-50,8,-42,11,-74;-5,-62,4,-47;;0,-3,0,1,1,0",
"xs12_03loz643;xs16_cq231246z32;0;27,-230;-23,-12;;-20,-228,-20,-190;3,7,0,-1,-1,0",
"xs12_03loz643;xs16_gs2596z1ac;0;9,-94;-15,-12;;;3,8,-1,0,0,-1",
"xs12_03loz643;xs19_354czx6248c453;0;;-1,-55;-6,-46;;-5,-3,0,1,1,0",
"xs12_08o6413z32;xs14_w8o6413zca1;0;;12,-58;10,-52;;0,-1,0,1,1,0",
"xs12_08o6413z32;xs14_xog853zc93;0;;;1,-70;11,-36;0,-2,1,0,0,1",
"xs12_08o6413z32;xs16_08o6413zrm;0;5,-137;-11,-76;21,-12;-17,-138,-15,-200,-9,-150;0,0,1,0,0,1",
"xs12_08o6413z32;xs16_3pczw23c4go;0;;;8,-36,12,-12,15,-32;2,-57,11,-36;9,-1,0,-1,1,0",
"xs12_08o653z32;xs16_08o6413z69k8;0;20,-90;15,-103,21,-127;4,-111,7,-119,11,-40,13,-88;7,-68;0,0,0,1,1,0",
"xs12_08o653z32;xs16_0ggc93zci9gzw1;0;-9,-36;8,-82;-4,-126,-2,-70,2,-133,5,-113;14,-69,20,-69;5,6,-1,0,0,-1",
"xs12_08o653z32;xs16_3pczw23cko;0;9,-70,13,-62,16,-94;;;-12,-82,-3,-67;-1,9,1,0,0,-1",
"xs12_0bdz2552;xs16_259ak8zwbd;0;5,-83,11,-87;-10,-12;;;4,8,-1,0,0,-1",
"xs12_0bdz2552;xs16_25akl3zx65;0;9,-97;-10,-12;;-14,-87;-2,7,1,0,0,-1",
"xs12_0cq23z65;xs16_0cq23123z65;0;;13,-103;-2,-99,9,-93;6,-93,10,-40,13,-89;0,0,1,0,0,1",
"xs12_0g0s252z321;xs15_dj8gzx34ac;0;;11,-54;7,-61;16,-37;6,-2,-1,0,0,1",
"xs12_0g0s252z321;xs15_wgjla4z652;0;13,-118,28,-122;;21,-40;;7,6,0,-1,-1,0",
"xs12_0g0s252z321;xs16_8k871zw115ac;0;14,-91;;16,-86,22,-12;-8,-108;8,0,0,-1,1,0",
"xs12_0g0s252z321;xs16_8ka23zw115ac;0;17,-152,23,-102;15,-74;;;8,0,0,-1,1,0",
"xs12_0g0s252z321;xs16_8kai3zx34ac;0;-10,-36,-4,-110;;;14,-40;6,-2,-1,0,0,1",
"xs12_0g0s252z321;xs16_xg8k871zca43;0;17,-82;15,-144,21,-94;;;0,-2,1,0,0,1",
"xs12_0g0s252z321;xs16_xg8ka23zca43;0;-4,-40;;;14,-110,20,-36;0,-2,1,0,0,1",
"xs12_0g0s252z321;xs16_xg8o652zca43;0;;9,-46;3,-52;;0,-2,1,0,0,1",
"xs12_0g0s256z121;xs14_wggka52z256;0;11,-85;-11,-12;;;-1,0,0,1,1,0",
"xs12_0g0s256z121;xs14_wggka53z252;0;;9,-46;3,-52;;7,6,0,-1,-1,0",
"xs12_0g0s256z121;xs14_wggm96z256;0;1,-63;;;-11,-78;-1,0,0,1,1,0",
"xs12_0g0s256z121;xs14_wgila4z256;0;1,-46;-5,-12;;;-1,0,0,1,1,0",
"xs12_0g0s256z121;xs15_dj8gzx34a6;0;5,-85;-16,-13;;-11,-78;0,8,1,0,0,-1",
"xs12_0g0s256z121;xs15_g88b52zdb;0;0,-51;-2,-50;-7,-62;;6,5,0,-1,-1,0",
"xs12_0g0s256z121;xs15_wggka53z256;0;;-19,-24;;-26,-138,-11,-134;-1,0,0,1,1,0",
"xs12_0g0s256z121;xs15_wggm952z256;0;;;;-8,-66;-1,0,0,1,1,0",
"xs12_0g0s256z121;xs15_wgjla4z256;0;-15,-40,0,-96;;-10,-74;;-1,0,0,1,1,0",
"xs12_0g0s256z121;xs16_8k871zw11da4;0;-10,-36,-4,-110;8,-84;-2,-67;;-2,6,0,1,-1,0",
"xs12_0g0s256z121;xs16_8ka23zw11da4;0;;;-11,-78,-5,-128;-15,-98;-2,6,0,1,-1,0",
"xs12_0g0s256z121;xs16_8kai3zx34a6;0;;-14,-16;16,-86,22,-12;;0,8,1,0,0,-1",
"xs12_0g0s256z121;xs16_ci96zw11da4;0;;-6,-47;-1,-38;;-2,6,0,1,-1,0",
"xs12_0g0s256z121;xs16_g88a52z178k8;0;;8,-42;9,-29;4,-47;0,1,0,1,1,0",
"xs12_0g0s256z121;xs16_xg8k871z6a43;0;7,-89;-12,-21;;-11,-78;6,8,-1,0,0,-1",
"xs12_0g0s256z121;xs16_xg8ka23z6a43;0;;-20,-12,-14,-86;16,-16;;6,8,-1,0,0,-1",
"xs12_0g0s256z121;xs16_xg8o652z6a43;0;9,-76;;;-9,-70;6,8,-1,0,0,-1",
"xs12_0g0s256z121;xs19_33wkczx34315a4;0;-7,-62;-2,-65,11,-80;1,-70;-11,-78,10,-60;8,-3,0,-1,1,0",
"xs12_0g8ge13z23;xs13_0ggka23z56;0;;10,-59;7,-44;12,-36;0,0,0,1,1,0",
"xs12_0g8ge13z23;xs13_wggka23z252;0;;12,-60;7,-47;13,-36;0,-1,0,1,1,0",
"xs12_0g8ge13z23;xs14_8ljgzx254c;0;16,-74;12,-60;7,-69;8,-68;8,0,0,-1,1,0",
"xs12_0g8ge13z23;xs14_wggka23z256;0;;12,-60;;12,-36;0,-1,0,1,1,0",
"xs12_0g8ge13z23;xs15_32q4gzx1078c;0;9,-89;-12,-12;;-14,-104;-1,8,1,0,0,-1",
"xs12_0g8ge13z23;xs15_wggka23z696;0;;;6,-58;12,-52,13,-36;0,-1,0,1,1,0",
"xs12_0g8ge13z23;xs15_wggka23zc96;0;;;5,-66;11,-36;0,-1,0,1,1,0",
"xs12_0g8ge13z23;xs16_0178k46z6511;0;-10,-36,-4,-110;10,-92;-2,-75;;-1,0,0,1,1,0",
"xs12_0g8ge13z23;xs16_0g8ge13z6jo;0;4,-87,13,-102;;;-15,-114,-12,-82,-8,-90;0,0,1,0,0,1",
"xs12_0g8ge13z23;xs16_0g8ge13zmr;0;1,-97,12,-135;-14,-41;;-16,-147,-13,-86,-9,-123;0,0,1,0,0,1",
"xs12_0g8ge13z23;xs16_0ggka23zrm;0;;19,-196,19,-158;-14,-198;22,-36;0,0,0,1,1,0",
"xs12_0g8ge13z23;xs16_178k453z311;0;14,-107;;16,-86,22,-12;-12,-124;6,6,0,-1,-1,0",
"xs12_0g8ge13z23;xs16_3pczw115a8o;0;;;8,-36,12,-12,15,-32;2,-57,11,-36;9,-1,0,-1,1,0",
"xs12_0g8ge13z23;xs16_xg8ge13zca23;0;9,-85;-11,-12;;;-2,0,1,0,0,1",
"xs12_0g8ge13z23;xs16_xgil96zc452;0;;;4,-62;14,-36;8,6,0,-1,-1,0",
"xs12_0g8ka52z121;xs14_wg8ka52z2521;0;;;1,-61;11,-36;0,-1,1,0,0,1",
"xs12_0g8ka52z121;xs15_0g8ka52zbc1;0;;11,-54;7,-61;16,-37;6,6,-1,0,0,-1",
"xs12_0g8ka52z121;xs15_wg8ka52z6521;0;;-25,-12,-10,-68;;-20,-126;-1,0,1,0,0,1",
"xs12_0g8ka52z121;xs16_8kai3zw125a4;0;;;-11,-78,-5,-128;-15,-98;-2,6,0,1,-1,0",
"xs12_0g8ka52z121;xs16_xg8k871z4a521;0;;11,-54;5,-65;12,-45;0,-2,1,0,0,1",
"xs12_0g8ka52z121;xs16_xg8ka52z4a611;0;;;8,-42;8,-36;8,6,-1,0,0,-1",
"xs12_0g8ka52z23;xs14_wg8k871z2521;0;;10,-50;4,-40;;7,6,-1,0,0,-1",
"xs12_0g8ka52z23;xs15_0g8k871zbc1;0;;11,-54;7,-61;16,-37;6,6,-1,0,0,-1",
"xs12_0g8ka52z23;xs15_0g8ka23zbc1;0;;17,-79;4,-67;10,-36;0,0,0,1,1,0",
"xs12_0g8ka52z23;xs15_32q4gzx125a4;0;9,-89;-12,-12;;-14,-104;-1,8,1,0,0,-1",
"xs12_0g8ka52z23;xs16_xg8k871z8e121;0;17,-82;15,-144,21,-94;;;0,-2,1,0,0,1",
"xs12_0g8ka52z23;xs16_xg8k871zc4521;0;-4,-40;;;14,-110,20,-36;8,6,-1,0,0,-1",
"xs12_0g8ka52z23;xs16_xg8ka52zca23;0;9,-85;-11,-12;;;-2,0,1,0,0,1",
"xs12_0g8o652z121;xs14_wggca52z2521;0;;;1,-61;11,-36;0,-1,1,0,0,1",
"xs12_0g8o652z121;xs14_xoka52z253;0;2,-67;;;-12,-82;6,7,-1,0,0,-1",
"xs12_0g8o652z121;xs15_0g8o652zbc1;0;5,-85;-16,-13;;-11,-78;0,0,1,0,0,1",
"xs12_0g8o652z121;xs15_256o8gzy21248c;0;-1,-72;;-4,-61;-14,-90,-5,-92;6,0,-1,0,0,1",
"xs12_0g8o652z121;xs15_358gzw116ak8;0;;8,-83,11,-76,14,-66;;14,-66;9,-1,0,-1,1,0",
"xs12_0g8o652z121;xs15_kq23zw35a4;0;-10,-36,-4,-110;;8,-126;6,-134,14,-40;5,-2,-1,0,0,1",
"xs12_0g8o652z121;xs16_178kozy135a4;0;-4,-40;;;14,-110,20,-36;8,-2,0,-1,1,0",
"xs12_0g8o652z121;xs16_31248gozy335a4;0;-3,-47;;-2,-78;7,-67,13,-36;8,-4,0,-1,1,0",
"xs12_0g8o652z121;xs16_8kai3zw116a4;0;;;-11,-78,-5,-128;-15,-98;-2,6,0,1,-1,0",
"xs12_0g8o652z121;xs16_8kq23zx35a4;0;-10,-36,-4,-110;;;14,-40;6,-2,-1,0,0,1",
"xs12_0g8o652z121;xs16_xg8k871z4a611;0;6,-87;-10,-12;;-13,-95;-2,0,0,1,1,0",
"xs12_0g8o652z121;xs16_xg8o652z4a611;0;4,-66;-8,-12;;;-2,0,1,0,0,1",
"xs12_0g8o652z23;xs14_wggc871z2521;0;;10,-50;4,-40;;7,6,-1,0,0,-1",
"xs12_0g8o652z23;xs14_wggc871z4701;0;;8,-73,16,-74;10,-57,11,-69;;0,-1,1,0,0,1",
"xs12_0g8o652z23;xs15_358gzw1162sg;0;;15,-100;;7,-77,10,-58,13,-36;7,-3,-1,0,0,1",
"xs12_0g8o652z23;xs15_358gzw116a8o;0;;8,-83,11,-76,14,-66;;14,-66;9,-1,0,-1,1,0",
"xs12_0g8o652z23;xs15_wggc871z6521;0;;11,-110,26,-114;;19,-48;7,6,-1,0,0,-1",
"xs12_0g8o652z23;xs16_178kozy131e8;0;17,-82;15,-144,21,-94;;;8,-2,-1,0,0,1",
"xs12_0g8o652z23;xs16_178kozy1354c;0;-4,-40;;;14,-110,20,-36;8,-2,0,-1,1,0",
"xs12_0g8o652z23;xs16_31248gozy331e8;0;16,-85;8,-73,14,-66;13,-48;;10,-2,-1,0,0,1",
"xs12_0g8o652z23;xs16_31248gozy3354c;0;-3,-47;;-2,-78;7,-67,13,-36;8,-4,0,-1,1,0",
"xs12_0g8o652z23;xs16_8kq23zx31e8;0;-10,-36,-4,-110;;;14,-40;6,-2,-1,0,0,1",
"xs12_0g8o652z23;xs16_8kq23zx354c;0;17,-152,23,-102;15,-74;;;8,0,0,-1,1,0",
"xs12_0gbaa4z121;xs14_0g6p2sgz121;0;14,-66;;;6,-51;6,6,0,-1,-1,0",
"xs12_0gbaa4z121;xs14_0g8ge1e8z23;0;11,-99,12,-115;-15,-12,-7,-43;;;5,7,0,-1,-1,0",
"xs12_0gbaa4z121;xs14_0gbaa4z1252;0;12,-64;;;-6,-54;0,0,1,0,0,1",
"xs12_0gbaa4z121;xs14_2ege12ko;0;7,-86,13,-84,16,-74;-8,-36;16,-26;;1,0,0,1,1,0",
"xs12_0gbaa4z121;xs14_4aabgzx1252;0;11,-85;-11,-12;;;5,0,-1,0,0,1",
"xs12_0gbaa4z121;xs15_0gbaa4z1256;0;13,-122,28,-126;;21,-12;;0,0,1,0,0,1",
"xs12_0gbaa4z121;xs15_4aabgzx3452;0;;-7,-12;;;5,0,-1,0,0,1",
"xs12_0gbaa4z121;xs15_g8ge1e8z56;0;8,-91;-10,-12;;-17,-103;5,6,0,-1,-1,0",
"xs12_0gbaa4z121;xs16_0178k8z255d;0;17,-152,23,-102;;13,-37;7,-78;5,8,-1,0,0,-1",
"xs12_0gbaa4z121;xs16_032ak8z255d;0;;-14,-16;16,-86,22,-12;;5,8,-1,0,0,-1",
"xs12_0gbaa4z121;xs16_252s0s4z06221;0;17,-152,23,-102;13,-66;;;0,6,0,1,-1,0",
"xs12_0gbaa4z121;xs16_25a88gzc8711;0;;0,-39;-4,-46;;0,6,1,0,0,-1",
"xs12_0gbaa4z121;xs16_8kai3ggzx343;0;-2,-36,4,-66;-9,-17,-1,-53;;;-2,6,0,1,-1,0",
"xs12_0gbaa4z121;xs16_ci96zwd552;0;;;12,-12;-7,-97;0,8,1,0,0,-1",
"xs12_0gbaa4z121;xs16_wmkk871z252;0;17,-82;13,-136,19,-86;;;0,-1,1,0,0,1",
"xs12_0gbaa4z121;xs16_x8k871z255d;0;;;-5,-54;-21,-114,-15,-164;5,8,-1,0,0,-1",
"xs12_0gbaa4z121;xs16_x8ka23z255d;0;6,-87;-10,-12;;-13,-95;5,8,-1,0,0,-1",
"xs12_0gbaa4z121;xs16_x8o652z255d;0;4,-66;-8,-12;;;5,8,-1,0,0,-1",
"xs12_0ggc93z641;xs13_3lozx3146;0;;10,-50;7,-35;7,-40;7,1,0,-1,1,0",
"xs12_0ggc93z641;xs14_358gzw116io;0;;;0,-74;10,-40;6,-2,-1,0,0,1",
"xs12_0ggc93z641;xs14_xok213zc93;0;;11,-54;9,-48;;0,-1,1,0,0,1",
"xs12_0ggc93z641;xs16_0ggc93zmc1z11;0;-10,-40;8,-130,14,-180,16,-118;6,-117;10,-104;5,7,-1,0,0,-1",
"xs12_0ggc93z641;xs16_wggc93zg6c1z11;0;;2,-43,11,-58;-5,-70,-2,-38,2,-46;;6,7,-1,0,0,-1",
"xs12_0ggka52z32;xs14_wg8ka52z643;0;;10,-50;4,-40;;7,6,0,-1,-1,0",
"xs12_0ggka52z32;xs14_wggka52z652;0;8,-74;-10,-13;;-14,-90;-1,0,1,0,0,1",
"xs12_0ggka52z32;xs15_0g8ge13zbc1;0;;17,-79;4,-67;10,-36;0,0,0,1,1,0",
"xs12_0ggka52z32;xs15_0g8k453zbc1;0;;11,-54;7,-61;16,-37;6,6,-1,0,0,-1",
"xs12_0ggka52z32;xs15_wggka52zc96;0;6,-88;;;-12,-82;-1,0,1,0,0,1",
"xs12_0ggka52z32;xs16_0178ka4z6511;0;-1,-69;-9,-54;-11,-78,-5,-128;;0,-1,1,0,0,1",
"xs12_0ggka52z32;xs16_0ggka52sgz32;0;17,-152,23,-102;15,-74;;;0,0,1,0,0,1",
"xs12_0ggka52z32;xs16_0ggka52zrm;0;-13,-144;-18,-122,-18,-84;;-23,-126;0,0,1,0,0,1",
"xs12_0ggka52z32;xs16_8kai3zw122ac;0;-10,-36,-4,-110;;;14,-40;6,-2,-1,0,0,1",
"xs12_0ggka52z32;xs16_xg8ge13z4a611;0;;9,-46;3,-52;;0,-2,0,1,1,0",
"xs12_0ggka52z32;xs16_xg8ge13z8e121;0;-4,-40;;;14,-110,20,-36;0,-2,0,1,1,0",
"xs12_0ggka52z32;xs16_xg8ge13zc4521;0;17,-82;15,-144,21,-94;;;0,-2,0,1,1,0",
"xs12_0ggka52z32;xs16_xgil96z4a52;0;5,-80;;;-15,-94;6,8,-1,0,0,-1",
"xs12_0ggm93z32;xs15_wggm93zc96;0;6,-84;;;-12,-78;-1,0,1,0,0,1",
"xs12_0ggm93z32;xs16_32q48a6z321;0;17,-152,23,-102;11,-58;;;6,6,0,-1,-1,0",
"xs12_0ggm93z32;xs16_wgil96zc96;0;5,-76;;;-15,-90;5,8,-1,0,0,-1",
"xs12_0ggm93z32;xs17_2lmgmaz056;0;8,-80;0,-50,12,-58;6,-48;-13,-92;-1,0,1,0,0,1",
"xs12_0ggm96z32;xs15_wggm93z696;0;6,-84;;;-12,-78;5,8,-1,0,0,-1",
"xs12_0ggm96z32;xs16_032q4ozca221;0;-11,-36,-5,-110;;;13,-40;0,-2,1,0,0,1",
"xs12_0ggm96z32;xs16_wgil96z696;0;5,-76;;;-15,-90;5,8,-1,0,0,-1",
"xs12_0ggs252z32;xs13_0ggs253z32;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs12_0ggs252z32;xs14_wggka23z643;0;;8,-73,16,-74;10,-57,11,-69;;7,6,0,-1,-1,0",
"xs12_0ggs252z32;xs14_wggka52z643;0;;10,-50;4,-40;;7,6,0,-1,-1,0",
"xs12_0ggs252z32;xs14_wggs252z256;0;;-11,-14;;-13,-86;-1,0,1,0,0,1",
"xs12_0ggs252z32;xs14_wgila4z643;0;14,-66;;;8,-51;7,6,0,-1,-1,0",
"xs12_0ggs252z32;xs15_dj8gzx32ac;0;;11,-54;7,-61;16,-37;6,-2,-1,0,0,1",
"xs12_0ggs252z32;xs15_g88e13zdb;0;19,-86;;12,-27;2,-74;0,1,0,1,1,0",
"xs12_0ggs252z32;xs15_wggm952z643;0;;8,-42;;;7,6,0,-1,-1,0",
"xs12_0ggs252z32;xs15_wgjla4z643;0;13,-118,28,-122;;21,-40;;7,6,0,-1,-1,0",
"xs12_0ggs252z32;xs16_0ggs252sgz32;0;17,-152,23,-102;15,-74;;;0,0,1,0,0,1",
"xs12_0ggs252z32;xs16_0ggs25a8oz32;0;14,-91;;16,-86,22,-12;-8,-108;0,0,1,0,0,1",
"xs12_0ggs252z32;xs16_8kai3zx32ac;0;-10,-36,-4,-110;;;14,-40;6,-2,-1,0,0,1",
"xs12_0ggs252z32;xs16_ci96zw1178c;0;13,-62;;;6,-71;8,0,0,-1,1,0",
"xs12_0ggs252z32;xs16_xg8k871zca23;0;17,-82;15,-144,21,-94;;;0,-2,1,0,0,1",
"xs12_0ggs252z32;xs16_xg8ka23zca23;0;-4,-40;;;14,-110,20,-36;0,-2,1,0,0,1",
"xs12_0ggs252z32;xs16_xg8o652zca23;0;;9,-46;3,-52;;0,-2,1,0,0,1",
"xs12_0gila4z32;xs14_025ak8z6511;0;-1,-36;1,-34;;;0,-1,1,0,0,1",
"xs12_0gila4z32;xs15_0mlla4z32;0;-5,-36;1,-47;;;0,0,1,0,0,1",
"xs12_0gila4z32;xs15_354k8gzwbc1;0;-8,-36;1,-60;-3,-53;;0,6,1,0,0,-1",
"xs12_0gila4z32;xs15_3ihla4z32;0;-2,-36;4,-67;-9,-79;;0,0,1,0,0,1",
"xs12_0gila4z32;xs15_wgila4zc96;0;6,-84;;;-12,-78;-1,0,1,0,0,1",
"xs12_0gila4z32;xs16_03iak8gz643w1;0;17,-152,23,-102;13,-66;;;7,6,0,-1,-1,0",
"xs12_0gila4z32;xs16_178k8gzca221;0;-4,-36;3,-56;-3,-45;;0,-2,1,0,0,1",
"xs12_0gila4z32;xs16_256o8gzca221;0;;5,-40;-1,-34;;0,-2,1,0,0,1",
"xs12_0gila4z32;xs16_32ak8gzca221;0;-12,-36,-6,-110;;;12,-40;0,-2,1,0,0,1",
"xs12_0gila4z32;xs16_3iak8zw122ac;0;-6,-40;;;12,-110,18,-36;6,-2,-1,0,0,1",
"xs12_0gila4z32;xs16_4aligzx4a96;0;5,-76;;;-15,-90;5,0,-1,0,0,1",
"xs12_0gila4z32;xs16_w4ak871z6511;0;17,-82;13,-136,19,-86;;;0,-1,1,0,0,1",
"xs12_0gjl8z56;xs14_0358gz2lp1;0;12,-90,19,-97;;13,-12;;4,9,-1,0,0,-1",
"xs12_0gjl8z56;xs15_3ia4zw1pl2;0;;-13,-29,-13,-12;;-13,-111;-1,9,1,0,0,-1",
"xs12_0gjl8z56;xs16_2eg88b5zx56;0;17,-152,23,-102;11,-58;;;6,7,-1,0,0,-1",
"xs12_0gjl8z56;xs16_4s0gjl8zw56;0;-2,-40,4,-70;-9,-21,-1,-57;;;-2,0,1,0,0,1",
"xs12_0gjl8z56;xs16_641321eg84c;0;5,-83,14,-98;;;-16,-110,-13,-78,-9,-86;0,10,0,1,-1,0",
"xs12_0mk213z121;xs13_0kc0f9z32;0;;-9,-30;;-16,-94;-1,0,0,1,1,0",
"xs12_0mk213z121;xs15_08o0uh3z65;0;4,-86;-8,-24;;-13,-82;-2,0,0,1,1,0",
"xs12_0mk213z121;xs15_0kc0f96z32;0;5,-71;-13,-12;;;-1,0,0,1,1,0",
"xs12_0ml2zca1;xs13_0bq23z65;0;;13,-62;;6,-46;0,1,1,0,0,1",
"xs12_0ml2zca1;xs15_0ml56zca1;0;;;4,-55;10,-44;0,0,1,0,0,1",
"xs12_0ml2zca1;xs15_3lozpia4;0;-5,-44;-1,-91,2,-75;-6,-75;;0,8,1,0,0,-1",
"xs12_0ml2zca1;xs16_0ol3zca2213;0;-10,-44;1,-79;-6,-80;;3,8,-1,0,0,-1",
"xs12_0ol3zca1;xs16_3pczwdmzx23;0;;0,-43,9,-58;-7,-70,-4,-38,0,-46;;4,-3,-1,0,0,1",
"xs12_17842156;xs16_0j96z1226413;0;;-2,-67,7,-82;-9,-94,-6,-62,-2,-70;;7,3,0,-1,-1,0",
"xs12_17842156;xs16_0j96z122ego;0;-5,-24;3,-49;;;7,3,0,-1,-1,0",
"xs12_17842156;xs16_64k871z69c;0;;-16,-12,-10,-86;14,-16;;-1,0,0,1,1,0",
"xs12_178421e8;xs16_3ia4z1226413;0;;-2,-67,7,-82;-9,-94,-6,-62,-2,-70;;7,3,0,-1,-1,0",
"xs12_178421e8;xs16_3ia4z122ego;0;;;15,-12;1,-61;0,0,0,1,1,0",
"xs12_17842ak8;xs15_04ai3zmp21;0;22,-98;;15,-23;1,-86;0,4,0,1,-1,0",
"xs12_17842ak8;xs16_0g88e13z8k96;0;-5,-28;3,-53;;;-2,4,0,1,-1,0",
"xs12_17842ak8;xs16_0g8k871zo9a4;0;18,-82;;15,-15;3,-74;9,0,0,-1,1,0",
"xs12_17842ak8;xs16_17842ak871;0;20,-94;14,-140,20,-90;;;0,0,1,0,0,1",
"xs12_17842ak8;xs16_ghn842ak8z1;0;16,-116;-16,-12,-10,-86;;-8,-99;-1,0,1,0,0,1",
"xs12_17842ak8;xs16_gs248a52z146;0;;-2,-67,7,-82;-9,-94,-6,-62,-2,-70;;0,4,1,0,0,-1",
"xs12_1784c826;xs14_32qkzok21;0;;12,-58;12,-52;;0,0,0,1,1,0",
"xs12_1784c826;xs16_03pcz6221e8;0;;-16,-12,-10,-86;14,-16;;7,0,0,-1,1,0",
"xs12_1784c826;xs16_cp3z122ego;0;-5,-24;3,-49;;;7,3,0,-1,-1,0",
"xs12_178br;xs16_0ggs2qrz32;0;-5,-28;3,-53;;;-2,4,1,0,0,-1",
"xs12_178br;xs16_6ags2qr;0;-10,-28,-8,-54,0,-47,2,-85;-11,-58,-6,-30,0,-70;-9,-88;;-2,4,1,0,0,-1",
"xs12_178br;xs16_ca2s53z311;0;-1,-42;-8,-12,-3,-42,3,-45,11,-58;-1,-52;;4,-2,-1,0,0,1",
"xs12_178br;xs20_178brzy36996;0;;;15,-12;-2,-83;0,0,1,0,0,1",
"xs12_178c0ca4;xs12_32qczx113;0;12,-61;;11,-14;-3,-50;0,0,0,1,1,0",
"xs12_178c0ca4;xs13_178c0f9;0;;10,-52;;15,-24;0,0,1,0,0,1",
"xs12_178c0ca4;xs14_178c2ego;0;;10,-50;10,-44;8,-46;0,0,1,0,0,1",
"xs12_178c0ca4;xs15_178c0f96;0;;14,-66;6,-53;;0,0,1,0,0,1",
"xs12_178c0ca4;xs15_178c2c871;0;;8,-73,16,-74;12,-57,13,-69;;0,0,1,0,0,1",
"xs12_178c0ca4;xs15_178c2cga6;0;17,-78;;3,-58,10,-65,11,-49;7,-72,10,-47;0,0,1,0,0,1",
"xs12_178c0ca4;xs15_178c2d96;0;;10,-50,15,-74;3,-58;;0,0,1,0,0,1",
"xs12_178c0ca4;xs15_2ego0uh3;0;;9,-46;5,-60;12,-28;0,-1,1,0,0,1",
"xs12_178c0ca4;xs16_178c2c84213;0;;8,-83,11,-76,14,-66;;14,-74;0,0,1,0,0,1",
"xs12_178c0ca4;xs16_h7o31e8z11;0;;;4,-102,5,-54;7,-61,17,-24;6,3,-1,0,0,-1",
"xs12_178c0ck8;xs13_32qbzx113;0;15,-80;;20,-12;;6,5,0,-1,-1,0",
"xs12_178c0ck8;xs15_32aczw3553;0;19,-86;;;1,-73;0,0,0,1,1,0",
"xs12_178c0ck8;xs16_g0t3oge2z11;0;;17,-78;8,-69;11,-58;7,-1,-1,0,0,1",
"xs12_178c2ko;xs16_3pa4zw1178c;0;-5,-28;3,-53;;;6,4,0,-1,-1,0",
"xs12_178c2ko;xs16_gjl862sgz1;0;;10,-83;-6,-100;12,-102,18,-28;7,4,-1,0,0,-1",
"xs12_178c453;xs13_2ego8b5;0;;13,-62;4,-50;9,-45;0,-1,1,0,0,1",
"xs12_178c453;xs14_25b8oge2;0;;13,-62;;11,-38;7,-1,-1,0,0,1",
"xs12_178c453;xs14_2ego8a53;0;;14,-66;4,-50;10,-37;0,-1,1,0,0,1",
"xs12_178c453;xs14_4ai31e8z011;0;;4,-54;-4,-60,4,-61;11,-24;6,3,-1,0,0,-1",
"xs12_178c453;xs15_cq23z012156;0;;12,-58;6,-64;;0,3,0,1,-1,0",
"xs12_178c453;xs15_cq23z012552;0;;13,-78,14,-66;5,-60;;0,3,0,1,-1,0",
"xs12_178c453;xs16_0o4a96z354c;0;;11,-54;-1,-64;19,-24;8,3,0,-1,-1,0",
"xs12_178c453;xs16_cq231e8z32;0;;23,-102;25,-120;18,-146,18,-108;6,3,-1,0,0,-1",
"xs12_178c453;xs16_gs2596z1226;0;;15,-70;7,-56;;7,3,0,-1,-1,0",
"xs12_178c453;xs16_oe132acz023;0;;-2,-63,7,-78;-9,-90,-6,-58,-2,-66;;0,3,1,0,0,-1",
"xs12_178c453;xs16_oe132acz23;0;-8,-65;-5,-73,6,-111;-10,-123,-7,-62,-3,-99;;0,3,1,0,0,-1",
"xs12_178k871;xs16_178k871z311;0;;-16,-12,-10,-86;16,-16;;0,0,1,0,0,1",
"xs12_178ka23;xs15_3iakg8oz23;0;13,-62;;18,-13;1,-69;0,0,0,1,1,0",
"xs12_178ka23;xs16_3iak871z23;0;13,-62;;14,-21;-1,-73;6,0,-1,0,0,1",
"xs12_178ka23;xs16_gs25a8oz146;0;;-2,-63,7,-78;-9,-90,-6,-58,-2,-66;;0,4,1,0,0,-1",
"xs12_178ka23;xs16_gs25a8oz56;0;-8,-65;-5,-73,6,-111;-10,-123,-7,-62,-3,-99;;0,4,1,0,0,-1",
"xs12_178ka52;xs14_03iak8z2521;0;;10,-50;4,-40;;0,-1,0,1,1,0",
"xs12_178ka52;xs15_178ka5123;0;;17,-78;4,-66;10,-35;0,0,1,0,0,1",
"xs12_178ka52;xs15_o4a52sgz23;0;;11,-54;7,-61;16,-37;6,4,-1,0,0,-1",
"xs12_178ka52;xs16_0g8ka52sgz23;0;17,-82;15,-144,21,-94;;;8,4,-1,0,0,-1",
"xs12_178ka52;xs16_0ggs25ak8z32;0;-5,-28;3,-53;;;-2,4,1,0,0,-1",
"xs12_178ka52;xs16_178ka52sg;0;17,-152,23,-102;15,-74;;;0,0,1,0,0,1",
"xs12_178ka52;xs16_178ka52z311;0;;-16,-12,-10,-86;16,-16;;0,0,1,0,0,1",
"xs12_178ka52;xs16_25ak871z311;0;;-10,-16;16,-86,22,-12;;6,0,-1,0,0,1",
"xs12_178ka52;xs16_8kai3zw121e8;0;;13,-63;6,-55;10,-28;0,4,0,1,-1,0",
"xs12_178kia4;xs16_0o4ai3zc4521;0;18,-156,24,-106;14,-70;;;8,0,0,-1,1,0",
"xs12_252sga6;xs14_4a52sga6;0;-2,-51;;;-8,-66;-1,0,1,0,0,1",
"xs12_252sga6;xs14_ca9jzw1226;0;;-5,-69,-4,-57;-10,-74,-2,-73;;6,4,0,-1,-1,0",
"xs12_252sga6;xs14_ca9jzw1252;0;-3,-28;-1,-26;;;6,4,0,-1,-1,0",
"xs12_252sga6;xs15_6ags25ac;0;;-15,-40;;-22,-122,-7,-118;6,0,-1,0,0,1",
"xs12_252sga6;xs15_o4871acz23;0;-10,-37;-1,-61;-5,-54;;0,4,1,0,0,-1",
"xs12_252sga6;xs16_178k871ac;0;;;-9,-74;-17,-102,-11,-152;-2,4,1,0,0,-1",
"xs12_252sga6;xs16_178k8zxc953;0;-14,-28,-8,-102;;;10,-32;-2,-2,0,1,1,0",
"xs12_252sga6;xs16_256o8zxc953;0;;3,-52;-3,-46;;-2,-2,0,1,1,0",
"xs12_252sga6;xs16_32ak871ac;0;14,-108;-16,-12,-10,-86;;-8,-91;-2,4,1,0,0,-1",
"xs12_252sga6;xs16_32ak8zxc953;0;-6,-45;1,-65;-5,-54;;-2,-2,0,1,1,0",
"xs12_252sga6;xs16_4a952sga6;0;0,-71;;;-7,-62;-2,0,1,0,0,1",
"xs12_2530354c;xs13_32ac0f9;0;;-11,-12;;-6,-64;7,3,-1,0,0,-1",
"xs12_2530354c;xs15_32ac0f96;0;4,-65;;;-10,-78;7,3,-1,0,0,-1",
"xs12_25303lo;xs13_3lo0ui;0;;-11,-12;;-6,-64;6,4,-1,0,0,-1",
"xs12_25303lo;xs15_3hu0ol3;0;5,-68;-8,-12;;-5,-54;0,4,1,0,0,-1",
"xs12_25303lo;xs15_3lo0uic;0;4,-61;;;-10,-74;6,4,-1,0,0,-1",
"xs12_256064ko;xs13_0o4871z643;0;14,-82;1,-44,5,-68;-9,-74,-1,-50;-1,-71;2,2,1,0,0,-1",
"xs12_256064ko;xs13_32arzx123;0;-9,-28;;-4,-64;;1,-1,0,1,1,0",
"xs12_256064ko;xs14_3146164ko;0;-1,-57;-7,-48;-2,-64;-9,-74;-1,0,1,0,0,1",
"xs12_256064ko;xs15_3iaczw178c;0;;-5,-73,-4,-61;-10,-78,-2,-77;;-1,-1,0,1,1,0",
"xs12_256064ko;xs15_69lmzx346;0;-14,-28,-5,-61;3,-89;;;0,-1,0,1,1,0",
"xs12_256064ko;xs16_0g8e13zg853z11;0;-8,-70;;-8,-70,-5,-80,-2,-87;;7,-1,0,-1,1,0",
"xs12_256064ko;xs16_4s0c453z643;0;-11,-28,-1,-65;3,-66,4,-114;;;1,4,1,0,0,-1",
"xs12_256069a4;xs15_0mk453z3421;0;-6,-24;3,-64;-3,-50;;0,3,0,1,-1,0",
"xs12_256069a4;xs15_25960uic;0;;2,-57;-8,-70;;7,3,-1,0,0,-1",
"xs12_25606a8o;xs13_0gbq23z23;0;-9,-28;;-4,-64;;1,4,0,1,-1,0",
"xs12_25606ak8;xs15_25aczw31156;0;-6,-28;3,-68;-3,-54;;7,4,0,-1,-1,0",
"xs12_25606ak8;xs15_25aczw3553;0;;2,-57;-8,-70;;7,4,0,-1,-1,0",
"xs12_256o8a6;xs13_256o8a52;0;;13,-62;5,-49;10,-42;0,0,1,0,0,1",
"xs12_256o8a6;xs13_256o8b5;0;;12,-58;5,-46;8,-49;0,0,1,0,0,1",
"xs12_256o8a6;xs14_256o8a53;0;;13,-62;5,-46;9,-41;0,0,1,0,0,1",
"xs12_256o8a6;xs14_256o8b52;0;;12,-58;;10,-42;0,0,1,0,0,1",
"xs12_256o8a6;xs14_8ehjzw1226;0;;-5,-69,-4,-57;-10,-74,-2,-73;;6,4,0,-1,-1,0",
"xs12_256o8a6;xs14_8ehjzw1252;0;-3,-28;-1,-26;;;6,4,0,-1,-1,0",
"xs12_256o8a6;xs15_0jhe8zbc1;0;-4,-35;2,-66;-11,-78;;6,0,0,-1,1,0",
"xs12_256o8a6;xs15_2552sgz0253;0;;12,-74,13,-62;6,-56;;7,-1,0,-1,1,0",
"xs12_256o8a6;xs15_3542sgz0253;0;;11,-54;7,-60;;7,-1,0,-1,1,0",
"xs12_256o8a6;xs15_o4c32acz23;0;-10,-37;-1,-61;-5,-54;;0,4,1,0,0,-1",
"xs12_256o8a6;xs15_wkc32acz65;0;-7,-28,-4,-50,-1,-69;;-9,-92;;-1,4,1,0,0,-1",
"xs12_256o8a6;xs16_0256o8z69521;0;;10,-50;0,-60;18,-28;0,-1,0,1,1,0",
"xs12_256o8a6;xs16_178kc32ac;0;;;-9,-74;-17,-102,-11,-152;-2,4,1,0,0,-1",
"xs12_256o8a6;xs16_178kozxc871;0;-14,-28,-8,-102;;;10,-32;-2,-2,0,1,1,0",
"xs12_256o8a6;xs16_256o8a6z0321;0;5,-55;;;-7,-62;0,0,1,0,0,1",
"xs12_256o8a6;xs16_cq23ck8z32;0;;22,-98;26,-116;17,-150,17,-112;6,4,-1,0,0,-1",
"xs12_256o8a6;xs16_xg84c32acz321;0;;-7,-48;-8,-66,-2,-73;-10,-85;-4,4,1,0,0,-1",
"xs12_256o8a6;xs20_0256o8a6zciic;0;5,-69;;;-8,-66;-1,0,1,0,0,1",
"xs12_2596zca4;xs16_178jd2ko;0;17,-109,28,-137;;;-1,-113,4,-44;16,-2,0,-1,1,0",
"xs12_25a842ac;xs15_354215ako;0;-13,-52;;-20,-118,-5,-114;;7,3,-1,0,0,-1",
"xs12_25a842ac;xs15_g8jdzpic;0;-4,-39;2,-70;-11,-82;;-2,3,0,1,-1,0",
"xs12_25a842ac;xs16_069jz25a9o;0;;;-9,-78;-17,-106,-11,-156;7,0,0,-1,1,0",
"xs12_25a842ac;xs16_g8k871zpic;0;-14,-24,-8,-98;;;10,-28;-2,3,0,1,-1,0",
"xs12_25a842ac;xs16_g8ka23zpic;0;;;-15,-98,-9,-148;-11,-86;-2,3,0,1,-1,0",
"xs12_25a842ac;xs16_g8o652zpic;0;-2,-24;-2,-30;;;-2,3,0,1,-1,0",
"xs12_25a8og4c;xs13_35a8og4c;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs12_25a8og4c;xs14_0o4871z39c;0;-9,-28,-1,-59;5,-67,6,-83;;;-1,4,0,1,-1,0",
"xs12_25a8og4c;xs14_0o4a52z39c;0;-3,-28;-1,-26;;;-1,4,0,1,-1,0",
"xs12_25a8og4c;xs14_25a8og8426;0;;11,-54;13,-48;;0,0,1,0,0,1",
"xs12_25a8og4c;xs14_25a8og853;0;;;4,-46;10,-28;0,0,1,0,0,1",
"xs12_25a8og4c;xs14_cp3z012552;0;-4,-28;6,-53;;;7,4,0,-1,-1,0",
"xs12_25a8og4c;xs14_gs25a4z146;0;;6,-48;0,-38;;0,4,0,1,-1,0",
"xs12_25a8og4c;xs15_0g8jdz6jo;0;-4,-39;2,-70;-11,-82;;-2,4,0,1,-1,0",
"xs12_25a8og4c;xs15_0o4a53z39c;0;-13,-52;;-20,-118,-5,-114;;-1,4,0,1,-1,0",
"xs12_25a8og4c;xs15_0o4a96z39c;0;-1,-28;;;;-1,4,0,1,-1,0",
"xs12_25a8og4c;xs15_cq23146z32;0;;7,-45;3,-52;12,-28;1,4,1,0,0,-1",
"xs12_25a8og4c;xs15_gs25acz146;0;;7,-94,22,-98;;15,-32;0,4,0,1,-1,0",
"xs12_25a8og4c;xs16_0g8k871z6jo;0;-14,-28,-8,-102;;;10,-32;-2,4,0,1,-1,0",
"xs12_25a8og4c;xs16_0g8ka23z6jo;0;;;-15,-98,-9,-148;-11,-86;-2,4,0,1,-1,0",
"xs12_25a8og4c;xs16_0g8o652z6jo;0;-2,-28;-2,-34;;;-2,4,0,1,-1,0",
"xs12_25a8og4c;xs16_25a8og4c826;0;;;11,-36,15,-12,18,-32;1,-73,10,-52;0,0,1,0,0,1",
"xs12_25a8og4c;xs16_3iak8z6jo;0;;;-9,-78;-17,-106,-11,-156;-2,4,0,1,-1,0",
"xs12_25a8og4c;xs16_gs252sgz146;0;;3,-52,9,-46;-4,-55,4,-59;;0,4,0,1,-1,0",
"xs12_25a8og8o;xs14_0o4871zbd;0;-9,-28,-1,-59;5,-67,6,-83;;;-1,4,0,1,-1,0",
"xs12_25a8og8o;xs14_0o4a52zbd;0;-3,-28;-1,-26;;;-1,4,0,1,-1,0",
"xs12_25a8og8o;xs14_gs25a4z56;0;;6,-48;0,-38;;0,4,0,1,-1,0",
"xs12_25a8og8o;xs15_0g8jdzmr;0;-4,-39;2,-70;-11,-82;;-2,4,0,1,-1,0",
"xs12_25a8og8o;xs15_0o4a96zbd;0;-1,-28;;;;-1,4,0,1,-1,0",
"xs12_25a8og8o;xs15_gs25acz56;0;;7,-94,22,-98;;15,-32;0,4,0,1,-1,0",
"xs12_25a8og8o;xs16_0g8k871zmr;0;-14,-28,-8,-102;;;10,-32;-2,4,0,1,-1,0",
"xs12_25a8og8o;xs16_0g8ka23zmr;0;;;-15,-98,-9,-148;-11,-86;-2,4,0,1,-1,0",
"xs12_25a8og8o;xs16_0g8o652zmr;0;-2,-28;-2,-34;;;-2,4,0,1,-1,0",
"xs12_25a8og8o;xs16_3iak8zmr;0;;;-9,-78;-17,-106,-11,-156;-2,4,0,1,-1,0",
"xs12_25a8og8o;xs16_gs252sgz56;0;-8,-32;;;10,-102,16,-28;0,4,0,1,-1,0",
"xs12_25akg84c;xs15_0g8jdz3kp;0;-4,-39;2,-70;-11,-82;;-2,4,0,1,-1,0",
"xs12_25akg84c;xs15_1784215ak8;0;16,-75;11,-54;;5,-79,8,-57;9,4,-1,0,0,-1",
"xs12_25akg84c;xs16_25akg84c826;0;;;11,-36,15,-12,18,-32;1,-73,10,-52;0,0,1,0,0,1",
"xs12_25akg84c;xs16_3iak8z3kp;0;;;-9,-78;-17,-106,-11,-156;-2,4,0,1,-1,0",
"xs12_25akg84c;xs16_o4a52sgz056;0;;3,-52,9,-46;-4,-55,4,-59;;0,4,0,1,-1,0",
"xs12_25iczw1252;xs14_25a4ozx34a4;0;;-4,-39;-6,-54;;-1,-1,1,0,0,1",
"xs12_25iczw1252;xs15_25iczw125ac;0;-13,-44;;-20,-110,-5,-106;;5,7,-1,0,0,-1",
"xs12_25iczw1252;xs15_25iczw12pm;0;-10,-40;-1,-64;-5,-57;;5,7,-1,0,0,-1",
"xs12_25iczw1252;xs16_03iak8z8k96;0;;-18,-12,-12,-86;20,-16;;0,9,1,0,0,-1",
"xs12_25iczw1252;xs16_25iczw123ck8;0;;3,-48;-3,-42;;5,7,-1,0,0,-1",
"xs12_25iczw1252;xs16_25iczw1252sg;0;-6,-41;1,-61;-5,-50;;5,7,-1,0,0,-1",
"xs12_25iczw1252;xs16_25iczw125a8o;0;;-12,-16;20,-86,26,-12;;0,0,1,0,0,1",
"xs12_25iczw1252;xs16_69diczx1252;0;;;10,-22;4,-40;6,7,-1,0,0,-1",
"xs12_25iczw1252;xs16_wci52sgz2521;0;;;7,-49,15,-13;0,-70,6,-40;0,7,1,0,0,-1",
"xs12_2ege123;xs14_2ege1248c;0;13,-62;;10,-40,17,-19;;0,0,1,0,0,1",
"xs12_2ege123;xs16_05b88gzc8711;0;-4,-28;2,-45;;;6,-1,0,-1,1,0",
"xs12_2ege123;xs16_0mkk871z56;0;;-17,-12,-11,-86;15,-16;;-1,0,0,1,1,0",
"xs12_2ege123;xs16_2eg88b5zx113;0;;-11,-16;15,-86,21,-12;;6,6,0,-1,-1,0",
"xs12_2ege123;xs16_cp3z1qaa4;0;;;3,-65,12,-44;7,-52,11,-28,14,-48;9,0,0,-1,1,0",
"xs12_2egm93;xs16_03lkicz643;0;-4,-28;2,-45;;;5,-1,0,-1,1,0",
"xs12_2egm93;xs16_0j9mge2z23;0;17,-152,23,-102;11,-58;;;6,0,-1,0,0,1",
"xs12_2egm93;xs16_3lkiarz01;0;;-7,-32;16,-33,26,-12;-14,-103,6,-69;5,0,0,-1,1,0",
"xs12_2egm96;xs16_mkid1e8z1;0;13,-82;14,-87,24,-106;-2,-83,18,-37;;6,4,-1,0,0,-1",
"xs12_2egm96;xs16_wcid1e8z311;0;-5,-32;;;13,-102,19,-28;7,4,-1,0,0,-1",
"xs12_2egm96;xs20_2llicz1226y1cc;0;-7,-43,1,-90,3,-72;-3,-49;-10,-76;-13,-82;5,0,0,-1,1,0",
"xs12_2ll2z641;xs16_0c9jz651252;0;-3,-40;2,-69;-7,-59;;3,7,-1,0,0,-1",
"xs12_2ll2z641;xs16_0j9cz1259a4;0;-3,-40;-2,-55,4,-59;;;-1,7,1,0,0,-1",
"xs12_2lmzca1;xs11_0brz65;0;;6,-34;;;0,1,1,0,0,1",
"xs12_2lmzca1;xs12_0cq23z65;0;;4,-33;8,-13;3,-44;0,1,1,0,0,1",
"xs12_2lmzca1;xs13_32arz065;0;-3,-44;;-10,-60;;-1,1,1,0,0,1",
"xs12_2lmzca1;xs14_3loz32ac;0;-3,-44;3,-62;-3,-56;;0,8,1,0,0,-1",
"xs12_2lmzca1;xs15_3hu0og84c;0;-2,-44;-2,-58;-7,-54;;-2,0,0,1,1,0",
"xs12_2lmzca1;xs15_cai3z3lo;0;-9,-44,-1,-75;5,-83,6,-99;;;2,-1,-1,0,0,1",
"xs12_2lmzca1;xs15_ml56z1ac;0;-7,-44;-1,-55;;;2,0,-1,0,0,1",
"xs12_2lmzca1;xs15_ml96z1ac;0;-8,-48,-3,-44;-4,-48;;;2,0,-1,0,0,1",
"xs12_2lmzca1;xs16_3542arzx65;0;;-3,-92,-2,-48;-12,-66,-2,-63;;-3,1,1,0,0,1",
"xs12_2lmzca1;xs16_ol3z6ahzw23;0;-7,-44,-4,-66,-1,-85;;-9,-108;;2,8,-1,0,0,-1",
"xs12_31230f9;xs15_25a88czwdb;0;;;11,-12,12,-26;9,-24;8,-2,0,-1,1,0",
"xs12_31230f9;xs16_31e88czwdb;0;;;3,-49;11,-24;8,-2,0,-1,1,0",
"xs12_31230f9;xs16_64km96zw56;0;;;1,-91,3,-68;18,-24;7,3,0,-1,-1,0",
"xs12_31230f9;xs16_bdz31178c;0;;;14,-12;0,-61;0,0,0,1,1,0",
"xs12_31230f9;xs16_bq23146z32;0;11,-78,15,-70,18,-102;;;-4,-90,5,-75;6,0,0,-1,1,0",
"xs12_312312ko;xs13_g84213zdb;0;11,-95,24,-106;;20,-26;3,-97;8,0,0,-1,1,0",
"xs12_312312ko;xs14_0g84213zrm;0;15,-91,22,-98;;16,-37;;9,0,0,-1,1,0",
"xs12_312312ko;xs15_g8421e8zdb;0;9,-70,20,-118,21,-94;-7,-19;;-1,-77;8,0,0,-1,1,0",
"xs12_312312ko;xs16_g8426413zdb;0;8,-63,17,-78;;;-7,-90,-4,-58,0,-66;8,0,0,-1,1,0",
"xs12_312312ko;xs16_ok213213z65;0;14,-134,20,-184,22,-122;-12,-12;16,-76;4,-121;7,0,-1,0,0,1",
"xs12_3123c4go;xs16_0ggc93zg6dz11;0;-5,-36,4,-57;-9,-32,-6,-12,-2,-36;;;7,-1,0,-1,1,0",
"xs12_3123c4go;xs16_3123123c4go;0;-10,-76,-8,-146,-2,-120;2,-123;-6,-126;-16,-102;-3,0,1,0,0,1",
"xs12_3123c4go;xs16_3123146o8go;0;17,-142;19,-86;13,-104,19,-130,21,-60;1,-139;10,4,-1,0,0,-1",
"xs12_3123c4go;xs16_31248gzy123c4go;0;-5,-41;1,-78;-10,-78;;-3,-5,1,0,0,1",
"xs12_3123c4go;xs16_xcp3zkc32z11;0;;;7,-41,16,-20;5,-52,9,-28,12,-48;10,0,0,-1,1,0",
"xs12_3123cko;xs16_08o653zoj6;0;-5,-36,4,-57;-9,-32,-6,-12,-2,-36;;;6,-1,0,-1,1,0",
"xs12_3123cko;xs16_0kc3213z34a4;0;13,-90;-12,-12;19,-45,25,-45;-7,-134,-5,-78,-1,-141,2,-121;6,0,-1,0,0,1",
"xs12_3123cko;xs16_3123c48gka4;0;20,-123,26,-147;17,-78;12,-56;1,-131,4,-139,8,-60,10,-108;0,0,1,0,0,1",
"xs12_3123cko;xs16_356o8gzy212ko;0;-5,-37;1,-74;-10,-74;;6,4,0,-1,-1,0",
"xs12_3123cko;xs16_8o653zrm;0;-10,-72,-8,-142,-2,-116;2,-119;-6,-122;-16,-98;6,0,0,-1,1,0",
"xs12_314606io;xs16_0j9cz343146;0;;;2,-87,4,-64;17,-28;0,-1,0,1,1,0",
"xs12_31460ui;xs14_32qbzx1246;0;-5,-28;5,-62;;;6,4,0,-1,-1,0",
"xs12_31460ui;xs14_32qbzx1ac;0;;-4,-52;-6,-58;;6,4,0,-1,-1,0",
"xs12_31460ui;xs15_039cz4a5113;0;;;12,-12,13,-26;8,-32;0,-1,0,1,1,0",
"xs12_31460ui;xs16_039czc87113;0;;;4,-45;10,-28;0,-1,0,1,1,0",
"xs12_31460ui;xs16_0bq23146z32;0;12,-82,16,-74,19,-106;;;-5,-94,4,-79;6,0,0,-1,1,0",
"xs12_31460ui;xs16_0c88e13zc93;0;;;15,-12;-1,-69;8,0,0,-1,1,0",
"xs12_31460ui;xs16_0j9cz343113;0;;;2,-87,4,-64;17,-28;0,-1,0,1,1,0",
"xs12_31eg8426;xs14_25b88gzwca1;0;-6,-38;;-6,-62;;-1,-1,0,1,1,0",
"xs12_31eg8426;xs15_0ggm93z12ko;0;-5,-28;1,-58;;;-2,4,0,1,-1,0",
"xs12_31eg8426;xs16_0gil96z12ko;0;-8,-28;2,-54;;;-2,4,0,1,-1,0",
"xs12_31eg8426;xs16_354k871z065;0;;-16,-12,-10,-86;16,-16;;0,0,0,1,1,0",
"xs12_31eg853;xs15_03hik8zc96;0;-5,-28;1,-58;;;6,-1,0,-1,1,0",
"xs12_31eg853;xs16_03hik8z69a4;0;-8,-28;2,-54;;;6,-1,0,-1,1,0",
"xs12_31eg853;xs16_31eg853z311;0;;-16,-12,-10,-86;16,-16;;0,0,1,0,0,1",
"xs12_31eg853;xs16_3hik871z32;0;;-10,-16;16,-86,22,-12;;6,0,0,-1,1,0",
"xs12_31egma;xs13_0gba96z121;0;-7,-30;-1,-41;-6,-54;;5,-1,0,-1,1,0",
"xs12_31egma;xs13_321egma;0;-6,-28;-1,-36;-4,-51;;-1,0,1,0,0,1",
"xs12_31egma;xs14_0gba96z123;0;-6,-30;;-6,-54;;5,-1,0,-1,1,0",
"xs12_31egma;xs14_0gba96z321;0;-7,-31;-1,-39;-5,-50;;5,-1,0,-1,1,0",
"xs12_31egma;xs14_6421egma;0;-1,-70;-1,-63;-6,-54;-8,-66;-2,0,1,0,0,1",
"xs12_31egma;xs15_0gba96z343;0;-7,-28,-6,-44;0,-50;;;5,-1,0,-1,1,0",
"xs12_31egma;xs15_0gba96z643;0;-5,-28;1,-58;;;5,-1,0,-1,1,0",
"xs12_31egma;xs16_0gamge13z23;0;18,-156,24,-106;12,-62;;;7,0,-1,0,0,1",
"xs12_31egma;xs16_0gba96z3452;0;-8,-28;2,-54;;;5,-1,0,-1,1,0",
"xs12_31egma;xs16_3pczwd596;0;-5,-36,4,-57;-9,-32,-6,-12,-2,-36;;;-3,-1,0,1,1,0",
"xs12_31egma;xs16_69abgzx3452;0;-4,-44;-6,-46;-14,-86;;5,4,0,-1,-1,0",
"xs12_31egma;xs16_gba96zdb;0;-16,-28;20,-190;-13,-188,-13,-150;;5,0,0,-1,1,0",
"xs12_31eozx123;xs14_31eozx1253;0;-6,-36;;-6,-60;;5,6,-1,0,0,-1",
"xs12_31eozx123;xs15_31eozx12156;0;;;16,-12;-2,-90;0,0,1,0,0,1",
"xs12_31eozx123;xs16_g88c453zdb;0;-16,-36;20,-198;-13,-196,-13,-158;;5,0,0,-1,1,0",
"xs12_31eozx123;xs16_wgs2596z643;0;;;19,-12;-3,-86;0,7,1,0,0,-1",
"xs12_32130f9;xs15_25a88czwbd;0;;;11,-12,12,-26;9,-24;8,-2,0,-1,1,0",
"xs12_32130f9;xs15_mk4871z56;0;17,-80;;15,-12;0,-65;7,0,0,-1,1,0",
"xs12_32130f9;xs16_31e88czwbd;0;;;3,-49;11,-24;8,-2,0,-1,1,0",
"xs12_32130f9;xs16_c88e13zbd;0;;;14,-12;0,-61;8,0,0,-1,1,0",
"xs12_32130f9;xs16_ra23146z23;0;11,-78,15,-70,18,-102;;;-4,-90,5,-75;6,0,0,-1,1,0",
"xs12_32130f9;xs17_32138f12ko;0;7,-48;;12,-23;-5,-54,5,-41;0,0,1,0,0,1",
"xs12_32132qk;xs16_0drzc45213;0;18,-86;14,-140,20,-90;;;0,-1,0,1,1,0",
"xs12_32132qk;xs16_cp3z1226426;0;12,-82,16,-74,19,-106;;;-5,-94,4,-79;6,7,-1,0,0,-1",
"xs12_3215ako;xs14_35akg8426;0;;-11,-19,-4,-40;;-7,-62;6,4,-1,0,0,-1",
"xs12_3215ako;xs15_0o4a53zc452;0;;-4,-41,-1,-63;-6,-59;-7,-62;6,-1,0,-1,1,0",
"xs12_321e853;xs14_ca9jzca1;0;0,-66;-4,-40;;-7,-62;6,3,0,-1,-1,0",
"xs12_321e853;xs16_cp3zpia6;0;-8,-44,-5,-24,-1,-48;-6,-40,3,-61;;;-3,0,0,1,1,0",
"xs12_321e853;xs16_drzpia6;0;3,-123;-11,-68,-9,-138,-3,-112;-15,-94;-7,-126;-3,0,0,1,1,0",
"xs12_321f84c;xs14_321f84ko;0;-11,-29,-2,-60;;-6,-58;-8,-66;6,3,-1,0,0,-1",
"xs12_321f84c;xs14_358gu246;0;;10,-50;-2,-62,5,-38,12,-18;5,-57;7,-1,-1,0,0,1",
"xs12_321f84c;xs15_17842ug8o;0;;-4,-41,-1,-63;-6,-59;-7,-62;-2,-1,1,0,0,1",
"xs12_321f84c;xs15_25iczw11db;0;-2,-124;-6,-94;-13,-148,-13,-86,-9,-119;-8,-130;-2,-2,0,1,1,0",
"xs12_321f84c;xs16_cp3z32qm;0;;;10,-36,14,-12,17,-32;0,-73,9,-52;9,3,0,-1,-1,0",
"xs12_321f84c;xs16_drz32qm;0;3,-123;-11,-68,-9,-138,-3,-112;-15,-94;-7,-126;-3,0,0,1,1,0",
"xs12_32akg84c;xs14_01784ozc8421;0;;9,-46;3,-62,9,-39,14,-20;;0,-1,0,1,1,0",
"xs12_32akg84c;xs14_1784ozok21;0;;11,-54;;8,-56,15,-35;0,0,0,1,1,0",
"xs12_32akg84c;xs14_32akg84ko;0;16,-74;12,-58;12,-52,21,-21;;0,0,1,0,0,1",
"xs12_32akg84c;xs15_0g4q23z3kp;0;-7,-54;-2,-59;-7,-66;;-2,4,0,1,-1,0",
"xs12_32akg84c;xs15_1784215a8o;0;16,-75;11,-54;;5,-79,8,-57;9,4,-1,0,0,-1",
"xs12_32akg84c;xs16_0g0s453z3kp;0;;-2,-55;-6,-62;;-2,4,0,1,-1,0",
"xs12_32akg84c;xs16_1784q23zw65;0;-5,-82;-7,-57;;-17,-106,-11,-156;0,0,0,1,1,0",
"xs12_32akg84c;xs16_32132akg84c;0;-6,-28;-10,-58,6,-87;-9,-91;-7,-93,-7,-78;-3,0,1,0,0,1",
"xs12_32akg84c;xs16_32akg84c826;0;;;11,-36,15,-12,18,-32;1,-73,10,-52;0,0,1,0,0,1",
"xs12_32qb8o;xs15_3iab8oz121;0;;7,-46;-4,-60,-3,-42;;5,4,-1,0,0,-1",
"xs12_32qb8o;xs15_9f0s4zx1252;0;;6,-42,7,-60;-4,-46;;5,4,0,-1,-1,0",
"xs12_32qb8o;xs16_32qb8og4c;0;;;10,-36,14,-12,17,-32;-2,-81,7,-60;0,0,1,0,0,1",
"xs12_32qb8o;xs16_32qb8oz321;0;;9,-46;5,-39;;5,4,-1,0,0,-1",
"xs12_32qb8o;xs16_9f0s4zx1156;0;;-2,-47;-6,-54;;5,4,0,-1,-1,0",
"xs12_32qczx113;xs16_32qczx1178c;0;;-2,-47;-6,-54;;5,6,-1,0,0,-1",
"xs12_32qj4c;xs14_04s39cz321;0;;6,-34,11,-57;-3,-42;;5,-1,0,-1,1,0",
"xs12_32qj4c;xs14_64pb8ozx11;0;;5,-54;-9,-70,-4,-46;;5,4,-1,0,0,-1",
"xs12_32qj4c;xs15_c93s4zx1252;0;;6,-42,7,-60;-4,-46;;5,4,0,-1,-1,0",
"xs12_32qj4c;xs16_0drz320f9;0;23,-102;9,-110;5,-107;5,-120,11,-146,13,-76;8,4,0,-1,-1,0",
"xs12_32qj4c;xs16_32qj4c826;0;;;9,-36,13,-12,16,-32;-1,-73,8,-52;0,0,1,0,0,1",
"xs12_32qj4c;xs16_4s39cz39c;0;-8,-48,-5,-28,-1,-52;-6,-44,3,-65;;;5,0,0,-1,1,0",
"xs12_32qj4c;xs16_64pb8oz321;0;;9,-46;5,-39;;5,4,-1,0,0,-1",
"xs12_32qj4c;xs16_c93s4zx1156;0;;-2,-47;-6,-54;;5,4,0,-1,-1,0",
"xs12_32qj4c;xs17_064pb8oz2521;0;;5,-30;2,-27;;6,4,-1,0,0,-1",
"xs12_32qkwcc;xs16_wck0fhoz311;0;13,-62;;15,-13;0,-63;0,6,1,0,0,-1",
"xs12_32qkwoo;xs16_32qk0fho;0;;7,-38;6,-39;9,-37;0,0,1,0,0,1",
"xs12_330312ko;xs14_wg8og853z65;0;;-6,-59;-6,-62,-3,-96;;7,-3,-1,0,0,1",
"xs12_330f96;xs14_31460uic;0;;-11,-73,-5,-125;-17,-105,-12,-78;;-2,-1,1,0,0,1",
"xs12_330fho;xs13_32hu0oo;0;13,-67;;15,-12;2,-52;6,4,-1,0,0,-1",
"xs12_330fho;xs14_330fh84c;0;15,-70;;6,-56;2,-79,10,-46;0,0,1,0,0,1",
"xs12_330fho;xs14_c88b52z33;0;15,-70;;15,-14;;6,0,0,-1,1,0",
"xs12_330fho;xs15_0mk453zca1;0;-4,-40,-3,-63;-10,-35,-2,-52;-10,-70;;5,-1,0,-1,1,0",
"xs12_330fho;xs15_330fh8426;0;15,-87,16,-104;-8,-12;9,-51,16,-36;2,-74;0,0,1,0,0,1",
"xs12_330fho;xs15_oggm93z66;0;;;14,-12;0,-74;7,0,0,-1,1,0",
"xs12_330fho;xs16_0jhu0ooz32;0;;;1,-53;9,-28;6,4,-1,0,0,-1",
"xs12_330fho;xs16_35s2acz321;0;;5,-52;-7,-58,1,-45,7,-42,12,-12;5,-42;5,-2,-1,0,0,1",
"xs12_330fho;xs16_ogil96z66;0;15,-72;;19,-12;;7,0,0,-1,1,0",
"xs12_330fho;xs18_033z628czw31156;0;-8,-71,-2,-66;1,-86;;-13,-82;-7,-2,0,1,1,0",
"xs12_330fho;xs18_3hu0oi6y0cc;0;2,-90;-9,-67,-3,-62;-12,-78;;5,4,-1,0,0,-1",
"xs12_33xciic;xs15_g6pajoz11;0;12,-111;-11,-25,-10,-41,0,-103;;-7,-70,-4,-100,-1,-148;5,-2,0,1,1,0",
"xs12_354cga6;xs13_4ap3zw1213;0;-3,-45;2,-50;-7,-62;;6,4,0,-1,-1,0",
"xs12_354cga6;xs14_4ap3zw1253;0;-5,-38;;-7,-62;;6,4,0,-1,-1,0",
"xs12_354cga6;xs14_4ap3zw1256;0;-4,-37;2,-50;-8,-66;;6,4,0,-1,-1,0",
"xs12_354cga6;xs14_8k461acz023;0;-5,-28;2,-65,10,-64;2,-58;;0,4,1,0,0,-1",
"xs12_354cga6;xs16_06ik871z643;0;;-9,-16;17,-86,23,-12;;7,0,0,-1,1,0",
"xs12_354cga6;xs16_0gs2596z1246;0;;-1,-56;-9,-70;;-1,4,0,1,-1,0",
"xs12_354cga6;xs16_2eg8e13zx123;0;5,-79,13,-75;;;-8,-66,-2,-72;0,6,0,1,-1,0",
"xs12_354cga6;xs16_ok461acz65;0;-12,-146,-12,-108;-19,-120;-17,-102;;0,4,1,0,0,-1",
"xs12_354qic;xs13_0g6p56z121;0;-5,-31;3,-70,8,-61;-13,-82,2,-55;;5,-1,0,-1,1,0",
"xs12_354qic;xs16_0dj8b5z321;0;18,-103,28,-122;9,-66;;-6,-99,14,-53;6,0,0,-1,1,0",
"xs12_3560653;xs16_c88e13z356;0;;11,-54;10,-39;4,-58;7,2,0,-1,-1,0",
"xs12_35606io;xs16_w4s0c93z6511;0;2,-58;-4,-39;-5,-54;;-1,4,1,0,0,-1",
"xs12_3560ui;xs15_25a88cz0653;0;;;11,-12,12,-26;7,-32;7,-1,0,-1,1,0",
"xs12_3560ui;xs16_0c88e13z653;0;;;14,-12;-2,-69;7,0,0,-1,1,0",
"xs12_3560ui;xs16_31e88cz0653;0;;;3,-45;9,-28;7,-1,0,-1,1,0",
"xs12_3560ui;xs16_cp3z230356;0;11,-78,15,-70,18,-102;;;-6,-90,3,-75;5,7,-1,0,0,-1",
"xs12_35861ac;xs16_gjl861acz1;0;;-16,-12,-10,-86;14,-16;;-1,0,1,0,0,1",
"xs12_358gka6;xs13_ci53zw1246;0;-9,-38;0,-77;-13,-86,0,-75;;6,4,0,-1,-1,0",
"xs12_358gka6;xs14_ci53zw1248c;0;-5,-49;;-11,-78,-4,-71;;6,4,0,-1,-1,0",
"xs12_358gka6;xs15_g8421e8z1256;0;-7,-28;10,-65,17,-101;-11,-82,-4,-89,2,-67;;-1,4,0,1,-1,0",
"xs12_358gka6;xs16_ok215acz65;0;-5,-92;-1,-105;-11,-106,-9,-168,-3,-118;15,-28;0,4,1,0,0,-1",
"xs12_358m93;xs12_358m96;0;;;4,-42;10,-28;0,0,1,0,0,1",
"xs12_358m93;xs13_358mp3;0;14,-66;;;2,-60;0,0,1,0,0,1",
"xs12_358m93;xs14_69icga6zx1;0;;11,-54;11,-39;;6,-1,-1,0,0,1",
"xs12_358m93;xs14_j5ka52z11;0;12,-58;;;-2,-48;5,0,0,-1,1,0",
"xs12_358m93;xs15_3586p3zx32;0;13,-62;;18,-13;1,-69;0,0,1,0,0,1",
"xs12_358m93;xs15_j5ka53z11;0;12,-73;;14,-12;-2,-86;5,0,0,-1,1,0",
"xs12_358m93;xs16_039m853z311;0;;-10,-16;16,-86,22,-12;;6,0,-1,0,0,1",
"xs12_358m93;xs16_03p6853z321;0;20,-90;;16,-45;-5,-113,9,-79;6,0,-1,0,0,1",
"xs12_358m93;xs16_0j9m853z23;0;13,-62;;14,-21;-1,-73;6,0,-1,0,0,1",
"xs12_358m93;xs16_358m93z311;0;;-16,-12,-10,-86;16,-16;;0,0,1,0,0,1",
"xs12_358m96;xs16_069m853z311;0;;-10,-16;16,-86,22,-12;;6,0,-1,0,0,1",
"xs12_358m96;xs16_358m96z311;0;;-16,-12,-10,-86;16,-16;;0,0,1,0,0,1",
"xs12_358m96;xs16_mkid2koz1;0;13,-82;14,-87,24,-106;-2,-83,18,-37;;6,4,-1,0,0,-1",
"xs12_358m96;xs16_wcid2koz311;0;-5,-32;;;13,-102,19,-28;7,4,-1,0,0,-1",
"xs12_358mic;xs16_358mhar;0;14,-86;13,-83,23,-102;-1,-79,19,-33;;0,0,1,0,0,1",
"xs12_35icz65;xs14_35icz69c;0;11,-102,20,-107;-13,-12;13,-12;;0,0,1,0,0,1",
"xs12_35icz65;xs15_035icz4a9o;0;;-12,-12;13,-13;-11,-91,-8,-101;-1,0,1,0,0,1",
"xs12_35icz65;xs15_25icz69ko;0;11,-166;-13,-76;16,-61,20,-74,20,-12;-13,-152;3,9,-1,0,0,-1",
"xs12_35icz65;xs16_3146248gka6;0;10,-74,14,-66,17,-98;;;-13,-86,-4,-71;-1,10,0,1,-1,0",
"xs12_35icz65;xs16_35iczmdz11;0;6,-145;-12,-76;22,-12;-18,-146,-16,-208,-10,-158;0,0,1,0,0,1",
"xs12_35iczx113;xs16_178k46z6521;0;-4,-78;-8,-45;;-18,-102,-12,-152;0,7,1,0,0,-1",
"xs12_35iczx113;xs16_35iczx1178c;0;17,-78;;;1,-71;0,0,1,0,0,1",
"xs12_39c0ca6;xs16_mkhjz1w346;0;;10,-50;11,-35;3,-62;0,3,0,1,-1,0",
"xs12_39c0f9;xs15_jhkmz1w252;0;;;11,-12;7,-24,8,-38;0,0,0,1,1,0",
"xs12_39c0f9;xs16_c930fpzx32;0;;7,-62,11,-54,14,-86;-2,-74,7,-59;;0,3,1,0,0,-1",
"xs12_39c0f9;xs16_jhkmz1w346;0;;;13,-12;-1,-61;0,0,0,1,1,0",
"xs12_3hu066;xs13_32hu066;0;-6,-28;-1,-36;-4,-51;;-1,0,1,0,0,1",
"xs12_3hu066;xs14_3hu06246;0;13,-77;10,-50,13,-87;14,-65;;0,0,1,0,0,1",
"xs12_3hu066;xs14_3hu06426;0;13,-62,16,-99;10,-65;;11,-77;0,0,1,0,0,1",
"xs12_3hu066;xs14_642hu066;0;-2,-64;-1,-65;-6,-56;-10,-70;-2,0,1,0,0,1",
"xs12_3hu066;xs15_0gbb8oz643;0;-5,-28;1,-58;;;5,-1,0,-1,1,0",
"xs12_3hu066;xs15_6248hf0cc;0;-7,-52,0,-67;-1,-58;-7,-88,-6,-71;9,-28;-3,4,1,0,0,-1",
"xs12_3hu066;xs16_0cp3z643033;0;3,-71,12,-86;;;-12,-98,-9,-66,-5,-74;0,7,1,0,0,-1",
"xs12_3hu066;xs16_0jhu066z32;0;8,-69;-8,-12;;;-1,0,1,0,0,1",
"xs12_3hu066;xs16_69ligozw66;0;-8,-28;2,-54;;;-2,-1,0,1,1,0",
"xs12_3hu066;xs16_gbb8ozdb;0;-16,-28;20,-190;-13,-188,-13,-150;;5,0,0,-1,1,0",
"xs12_3lozx352;xs13_3lozx356;0;18,-82;;;0,-76;0,0,1,0,0,1",
"xs12_3lozx352;xs13_3lozx39c;0;14,-91;-10,-12;13,-30;-10,-106;0,0,1,0,0,1",
"xs12_3lozx352;xs14_3lozx31e8;0;14,-97,22,-98;;;2,-81,3,-93;0,0,1,0,0,1",
"xs12_3lozx352;xs14_3lozx354c;0;;;13,-43,21,-12;-8,-123,-7,-107;0,0,1,0,0,1",
"xs12_3lozx352;xs14_3lozx35a4;0;16,-74;;;-4,-64;0,0,1,0,0,1",
"xs12_3lozx352;xs15_08o652z69k8;0;-6,-104;4,-138;-6,-124;9,-89,13,-102,13,-40;0,7,1,0,0,-1",
"xs12_3lozx352;xs15_256o8zxo9a4;0;-5,-40;;-4,-63,-1,-73;6,-41;5,7,-1,0,0,-1",
"xs12_3lozx352;xs15_3lozx31248c;0;14,-107,17,-100,20,-90;;20,-34;;0,0,1,0,0,1",
"xs12_3lozx352;xs15_3lozx35426;0;23,-111;;16,-12;-4,-99;0,0,1,0,0,1",
"xs12_3lozx352;xs15_3lozx35ac;0;17,-134,32,-138;;25,-16;;0,0,1,0,0,1",
"xs12_3lozx352;xs15_3lozx3pm;0;17,-85;;22,-12;-1,-92;0,0,1,0,0,1",
"xs12_3lozx352;xs15_xg8o64213z321;0;21,-132;;13,-53,16,-34,19,-12;;0,10,0,1,-1,0",
"xs12_3lozx352;xs16_032qk8zol3;0;;-18,-12,-12,-86;20,-16;;0,9,1,0,0,-1",
"xs12_3lozx352;xs16_08o652sgz65;0;21,-98;9,-120,15,-70;;;0,7,1,0,0,-1",
"xs12_3lozx352;xs16_08o652zmdz11;0;-5,-104;-1,-117;-11,-118,-9,-180,-3,-130;15,-40;0,7,1,0,0,-1",
"xs12_3lozx352;xs16_3lozx31248go;0;14,-97,20,-90;8,-53;;5,-72;0,0,1,0,0,1",
"xs12_3lozx352;xs16_3lozx352sg;0;17,-78;;18,-13;-3,-89;0,0,1,0,0,1",
"xs12_3lozx352;xs16_3lozx358gzy223;0;;-11,-23;13,-43,19,-12;-10,-110;0,0,1,0,0,1",
"xs12_3lozx352;xs16_3lozx35a8o;0;19,-103;;16,-12;-2,-95;0,0,1,0,0,1",
"xs12_3lozx352;xs16_w8o652zg6dz11;0;;3,-46,7,-38,10,-70;-6,-58,3,-43;;-1,7,1,0,0,-1",
"xs12_3pcz643;xs14_g853zdjo;0;-5,-40;5,-74;;;2,-2,-1,0,0,1",
"xs12_3pczw1246;xs16_3pczw124628c;0;;;8,-33,17,-12;0,-68,4,-44,7,-64;0,0,1,0,0,1",
"xs12_3pczw1ac;xs14_wg853zg853z11;0;-5,-44;5,-78;;;4,-2,-1,0,0,1",
"xs12_3pczw1ac;xs15_3pczwhik8zw1;0;13,-109,16,-99;-10,-13;17,-12;;0,0,1,0,0,1",
"xs12_3pczw1ac;xs16_xcp3z0cq1z32;0;9,-75,18,-90;;;-14,-102,-11,-70,-7,-78;5,0,-1,0,0,1",
"xs12_4ai3s4zx1;xs16_04s3ia4z6221;0;;;-14,-86,-8,-136;-12,-82;5,-1,0,-1,1,0",
"xs12_4ai3s4zx1;xs16_4ai3s4ozx121;0;;-5,-81,-3,-127;-16,-94,-4,-178,1,-189;13,-128;5,5,0,-1,-1,0",
"xs12_4ai3s4zx1;xs16_4ai3s4z6221;0;;;-8,-66;-18,-102,-12,-152;5,5,0,-1,-1,0",
"xs12_4ai3s4zx1;xs16_8ehik8z643;0;;;4,-41;8,-32;0,0,0,1,1,0",
"xs12_4ai3s4zx1;xs16_8kihe853zx1;0;;2,-75,4,-45,12,-84,14,-66;-9,-100,-4,-106,-4,-52,2,-68;8,-57;0,5,0,1,-1,0",
"xs12_4ai3zx1246;xs16_031e88gzog8421;0;;9,-46;5,-39;;6,-2,-1,0,0,1",
"xs12_4ai3zx1246;xs16_0g8421e8zrm;0;19,-150;15,-70;15,-88,21,-114,23,-44;-3,-147;0,7,0,1,-1,0",
"xs12_4ai3zx1246;xs16_0o4ai3z11x1ac;0;;;-8,-70;-18,-106,-12,-156;-2,0,0,1,1,0",
"xs12_4ai3zx1246;xs16_3pczw1248ge2;0;;;9,-33,18,-12;1,-68,5,-44,8,-64;9,8,0,-1,-1,0",
"xs12_4ai3zx1246;xs16_6413ia4z6421;0;;15,-79;11,-60,13,-88,15,-38;5,-60,8,-40,13,-59;6,0,-1,0,0,1",
"xs12_4ai3zx1246;xs16_x64k871zc8421;0;;;-14,-90,-8,-140;-12,-86;6,-1,-1,0,0,1",
"xs12_4ai3zx1ac;xs15_4ai3zxhik8zx1;0;14,-109,17,-99;-9,-13;18,-12;;0,0,1,0,0,1",
"xs12_4ai3zx1ac;xs16_358gzg0s452z11;0;;9,-46;5,-39;;5,8,-1,0,0,-1",
"xs12_4ai3zx1ac;xs16_358gzwc452sg;0;;;-14,-86,-8,-136;-12,-82;5,8,-1,0,0,-1",
"xs12_4ai3zx1ac;xs16_4ai3146zx1ac;0;;;0,-81,9,-60;4,-68,8,-44,11,-64;0,0,1,0,0,1",
"xs12_4ai3zx1ac;xs16_x3ia4z0cq1z32;0;10,-75,19,-90;;;-13,-102,-10,-70,-6,-78;6,0,-1,0,0,1",
"xs12_4alla4;xs16_0cidicz6221;0;;;-14,-86,-8,-136;-12,-82;5,-1,0,-1,1,0",
"xs12_4alla4;xs16_8k8aliczw23;0;;-7,-22,4,-68;-5,-76,-5,-60,6,-52,13,-12;-9,-78,-2,-72,3,-79;0,-1,1,0,0,1",
"xs12_4alla4;xs16_cidharzw1;0;;-7,-32;16,-33,26,-12;-14,-103,6,-69;5,0,0,-1,1,0",
"xs12_4ap3z65;xs16_3146248c2ko;0;10,-74,14,-66,17,-98;;;-13,-86,-4,-71;-1,10,0,1,-1,0",
"xs12_4s0c93z11;xs15_25a88cz6413;0;-1,-40;-8,-26,-7,-12;;;-2,0,0,1,1,0",
"xs12_4s0c93z11;xs16_31e88cz6413;0;-3,-32;1,-41;;;-2,0,0,1,1,0",
"xs12_4s0c93z11;xs16_4s0c93z39c;0;3,-79,12,-94;;;-14,-106,-11,-74,-7,-82;0,0,1,0,0,1",
"xs12_5b8og4c;xs15_64138n96;0;-9,-28,-6,-72,-2,-56;;-9,-78;;6,4,-1,0,0,-1",
"xs12_5b8og4c;xs16_03pczo8ge3;0;;;10,-36,14,-12,17,-32;0,-73,9,-52;9,0,0,-1,1,0",
"xs12_5b8og4c;xs16_0cp3zc45213;0;;;-8,-70;-18,-106,-12,-156;6,5,0,-1,-1,0",
"xs12_5b8og4c;xs16_cp3z1226413;0;;-2,-63,7,-78;-9,-90,-6,-58,-2,-66;;0,-3,1,0,0,1",
"xs12_5b8ozx123;xs13_5b8ozx1213;0;15,-83;;17,-12;0,-68;0,0,1,0,0,1",
"xs12_5b8ozx123;xs14_0ggs256z56;0;17,-84;;17,-12;;0,7,1,0,0,-1",
"xs12_5b8ozx123;xs14_8ljgzx3426;0;17,-80;9,-46;13,-40;0,-89;7,6,0,-1,-1,0",
"xs12_5b8ozx123;xs15_0ggs2453z56;0;;;16,-12;-2,-90;0,7,1,0,0,-1",
"xs12_5b8ozx123;xs16_032q48cz6511;0;;;-8,-66;-18,-102,-12,-152;-2,6,0,1,-1,0",
"xs12_5b8ozx123;xs16_0ggs2596z56;0;;;19,-12;-3,-86;0,7,1,0,0,-1",
"xs12_628c0f9;xs15_039cz3115a4;0;;;12,-12;8,-24,9,-38;0,0,0,1,1,0",
"xs12_628c0f9;xs15_ghn83146z1;0;;14,-68;3,-53;12,-24;7,3,-1,0,0,-1",
"xs12_628c0f9;xs16_039cz31178c;0;;;14,-12;0,-61;0,0,0,1,1,0",
"xs12_628c0f9;xs16_c88e13z39c;0;;;3,-49;11,-24;8,3,0,-1,-1,0",
"xs12_628c0f9;xs16_pf03146z023;0;;8,-66,12,-58,15,-90;-1,-78,8,-63;;6,3,-1,0,0,-1",
"xs12_641j4czx11;xs14_6413kcz0321;0;4,-56;;;-8,-62;0,0,1,0,0,1",
"xs12_641j4czx11;xs14_6413kczw65;0;-2,-56;;;-8,-62;5,5,0,-1,-1,0",
"xs12_641j4czx11;xs16_0cp3z32c826;0;-7,-52,-4,-32,0,-56;-7,-40,2,-61;;;-3,0,0,1,1,0",
"xs12_641j4czx11;xs16_0drz32c826;0;4,-123;-12,-60,-10,-130,-4,-104;-14,-86;-8,-126;-3,0,0,1,1,0",
"xs12_641j4czx11;xs17_c4j146z011w352;0;1,-55;-5,-38;;-8,-62;5,0,-1,0,0,1",
"xs12_642tic;xs15_17842tic;0;;-5,-33,-2,-55;-5,-51;-8,-62;-2,0,1,0,0,1",
"xs12_642tic;xs16_069n84cz311;0;-6,-32;;;12,-102,18,-28;6,4,-1,0,0,-1",
"xs12_642tic;xs16_5b8bl8zx32;0;18,-103,28,-122;9,-66;;-6,-99,14,-53;6,5,0,-1,-1,0",
"xs12_642tic;xs16_628c48n96;0;-7,-48,-4,-28,0,-52;-7,-36,2,-57;;;-3,4,1,0,0,-1",
"xs12_642tic;xs16_642thar;0;14,-86;13,-83,23,-102;-1,-79,19,-33;;0,0,1,0,0,1",
"xs12_6530f9;xs15_gjlmz1w252;0;;;10,-12,11,-26;8,-24;0,3,0,1,-1,0",
"xs12_6530f9;xs16_6530fpzx32;0;10,-74,14,-66,17,-98;;;-5,-86,4,-71;0,0,1,0,0,1",
"xs12_6530f9;xs16_gjlmz1w346;0;;;2,-49;10,-24;0,3,0,1,-1,0",
"xs12_66069ic;xs14_31246pic;0;-16,-28,-3,-46,6,-68;-7,-47,2,-68;-4,-55;-6,-74;-1,0,1,0,0,1",
"xs12_6960ui;xs15_g8hf0cicz01;0;;;11,-12,12,-26;7,-32;7,4,-1,0,0,-1",
"xs12_6960ui;xs16_0giu0696z32;0;;;14,-12;-2,-69;7,0,-1,0,0,1",
"xs12_6960ui;xs16_g89f0cicz11;0;;;3,-45;9,-28;7,4,-1,0,0,-1",
"xs12_6960ui;xs16_ggm960uiz1;0;15,-116;-17,-12,-11,-86;;-9,-99;-2,0,1,0,0,1",
"xs12_6960ui;xs16_iu0696z146;0;11,-78,15,-70,18,-102;;;-6,-90,3,-75;5,0,-1,0,0,1",
"xs12_6960ui;xs16_wcic0f9z311;0;-14,-28,-8,-102;;;10,-32;-2,4,1,0,0,-1",
"xs12_696z696;xs16_cila8oz065;0;;17,-141,19,-86,24,-153;9,-85,23,-14;-7,-110,2,-82;5,13,0,-1,-1,0",
"xs12_696zw2552;xs18_0g2552z343y48kk8;0;;14,-66;9,-78;;0,7,1,0,0,-1",
"xs12_69iczx113;xs16_03ia4ozc4521;0;-8,-40;;;10,-110,16,-36;5,-2,-1,0,0,1",
"xs12_69iczx113;xs16_32q48gzx1254c;0;-14,-36,-8,-110;;;10,-40;-2,-2,1,0,0,1",
"xs12_69jzx1246;xs16_3pczw1248gkc;0;;;9,-33,18,-12;1,-68,5,-44,8,-64;9,8,0,-1,-1,0",
"xs12_69jzx1ac;xs15_69jzxhik8zx1;0;14,-109,17,-99;-9,-13;18,-12;;0,0,1,0,0,1",
"xs12_69jzx1ac;xs16_69jzx1qczy123;0;10,-75,19,-90;;;-13,-102,-10,-70,-6,-78;0,0,1,0,0,1",
"xs12_8ljgzx252;xs13_8ljgzx652;0;13,-94;-9,-12;;;0,0,1,0,0,1",
"xs12_8ljgzx252;xs14_0358gz8ka221;0;;6,-62,13,-69;;7,-40;5,-2,-1,0,0,1",
"xs12_8ljgzx252;xs14_0gila4z1ac;0;12,-58;;;-8,-68;0,8,1,0,0,-1",
"xs12_8ljgzx252;xs14_25a88gzc8421;0;;;-4,-50,1,-49,7,-48;5,-40;5,7,-1,0,0,-1",
"xs12_8ljgzx252;xs14_358ge1246;0;;-12,-22;14,-32;-12,-78,-9,-88,-3,-90;0,8,0,1,-1,0",
"xs12_8ljgzx252;xs14_8ljgzx25a4;0;16,-74;;;-4,-64;0,0,1,0,0,1",
"xs12_8ljgzx252;xs14_8ljgzx696;0;16,-93;-8,-12;;;0,0,1,0,0,1",
"xs12_8ljgzx252;xs15_0gjl8zrm;0;9,-92;-14,-12;;-9,-85;4,0,-1,0,0,1",
"xs12_8ljgzx252;xs15_0gjla4z1ac;0;;-17,-12;;-24,-134,-9,-130;0,8,1,0,0,-1",
"xs12_8ljgzx252;xs15_3ia4z122ak8;0;-4,-41;3,-73,6,-63;;7,-40;0,-2,1,0,0,1",
"xs12_8ljgzx252;xs15_8ljgzx25426;0;23,-111;;16,-12;-4,-99;0,0,1,0,0,1",
"xs12_8ljgzx252;xs15_8ljgzx25ac;0;17,-134,32,-138;;25,-16;;0,0,1,0,0,1",
"xs12_8ljgzx252;xs15_8ljgzx69a4;0;;;13,-12;;0,0,1,0,0,1",
"xs12_8ljgzx252;xs16_0178k8z2lp1;0;-1,-82;-9,-33;;-19,-106,-13,-156;0,9,1,0,0,-1",
"xs12_8ljgzx252;xs16_032ak8z2lp1;0;;-18,-12,-12,-86;20,-16;;0,9,1,0,0,-1",
"xs12_8ljgzx252;xs16_25a88ge2zx65;0;;;-7,-62;-19,-106,-13,-156;5,7,-1,0,0,-1",
"xs12_8ljgzx252;xs16_69iczx1pl2;0;;;16,-12;-5,-105;6,9,-1,0,0,-1",
"xs12_8ljgzx252;xs16_8kai3zx34213;0;21,-98;9,-120,15,-70;;;7,7,0,-1,-1,0",
"xs12_8ljgzx252;xs16_8ljgzwci96;0;13,-105;-8,-12;;;0,0,1,0,0,1",
"xs12_8ljgzx252;xs16_8ljgzx23ck8;0;;;14,-12;0,-74;0,0,1,0,0,1",
"xs12_8ljgzx252;xs16_8ljgzx252sg;0;21,-168,27,-118;9,-50;;;0,0,1,0,0,1",
"xs12_8ljgzx252;xs16_8ljgzx25a8o;0;19,-103;;16,-12;-2,-95;0,0,1,0,0,1",
"xs12_8o6413z32;xs16_08o6413zoj6;0;9,-70,13,-62,16,-94;;;-12,-82,-3,-67;-1,0,1,0,0,1",
"xs12_8o6413z32;xs16_3pczw23c48c;0;;;7,-36,11,-12,14,-32;1,-57,10,-36;8,-1,0,-1,1,0",
"xs12_8o6413z32;xs16_8o6413zrm;0;5,-137;-11,-76;21,-12;-17,-138,-15,-200,-9,-150;0,0,1,0,0,1",
"xs12_8o6413z32;xs16_g4c3213zdb;0;21,-94;11,-118;3,-115;7,-112,13,-138,15,-68;0,0,0,1,1,0",
"xs12_bdz3146;xs16_31km96zw56;0;2,-97,4,-82;;;-19,-98;3,7,-1,0,0,-1",
"xs12_brz1226;xs13_1784cga6;0;-6,-40;3,-60;-6,-78,1,-53;;3,7,0,-1,-1,0",
"xs12_brz1226;xs13_kq23z1ac;0;;6,-59,19,-93;-6,-76,3,-61;5,-40;0,7,1,0,0,-1",
"xs12_brz1226;xs14_2eg8og853;0;;;-6,-85;3,-86,6,-40;4,7,0,-1,-1,0",
"xs12_brz1226;xs15_1784c0c48go;0;-9,-40;3,-70,11,-85;-5,-66,-4,-85;;3,7,0,-1,-1,0",
"xs12_brz346;xs14_0kq23zc96;0;-4,-132;-6,-139;-21,-147,0,-151;6,-122,6,-40;2,-1,-1,0,0,1",
"xs12_brz346;xs14_358go8gkc;0;;;-6,-85;3,-86,6,-40;4,-1,0,-1,1,0",
"xs12_brz346;xs15_0mp3zga6z11;0;-9,-40;3,-70,11,-85;-5,-66,-4,-85;;-1,7,1,0,0,-1",
"xs12_c93zx2552;xs6_39c;0;;;;-1,-40;2,0,-1,0,0,1",
"xs12_ci52zw1246;xs14_025a4ozc8421;0;;7,-38;1,-28;;5,-1,-1,0,0,1",
"xs12_ci52zw1246;xs15_035a4ozc8421;0;;17,-106;;7,-96,22,-40;5,-1,-1,0,0,1",
"xs12_ci52zw1246;xs15_g84213z12pm;0;;8,-57;4,-64;13,-40;0,7,1,0,0,-1",
"xs12_ci52zw1246;xs16_0g84213zo9a52;0;-13,-40,-7,-114;;;11,-44;-1,7,1,0,0,-1",
"xs12_ci52zw1246;xs16_178k8gzog8421;0;;8,-49;2,-60;9,-40;5,-2,-1,0,0,1",
"xs12_ci52zw1246;xs16_256o8gzog8421;0;;6,-34;0,-40;;5,-2,-1,0,0,1",
"xs12_ci52zw1246;xs16_31248gzo8a521;0;-7,-44;;;11,-114,17,-40;5,7,-1,0,0,-1",
"xs12_ci52zw1246;xs16_3pczw1248a52;0;;;8,-33,17,-12;0,-68,4,-44,7,-64;8,8,0,-1,-1,0",
"xs12_ci52zw1246;xs16_g84215a4zdb;0;18,-146;14,-66;14,-84,20,-110,22,-40;-4,-143;0,7,0,1,-1,0",
"xs12_ck3123z11;xs14_c9jzw1qm;0;;7,-42,14,-66;-4,-54,5,-31;4,-32;4,-4,-1,0,0,1",
"xs12_ck3123z11;xs14_dbgzw1qm;0;;8,-46,15,-70;-3,-58,5,-35;4,-36;4,-4,-1,0,0,1",
"xs12_ck3123z11;xs15_o8624871z23;0;7,-85,10,-75;-10,-13;11,-12;;-1,0,0,1,1,0",
"xs12_ck3146z11;xs14_3213kczw65;0;13,-62;;;7,-56;0,5,0,1,-1,0",
"xs12_ck3146z11;xs14_c9jzwpi6;0;-3,-40,6,-53;-13,-12,-6,-16;;-5,-50;5,0,0,-1,1,0",
"xs12_ck3146z11;xs14_ck312koz11;0;;;12,-12;-2,-62;0,0,1,0,0,1",
"xs12_ck3146z11;xs15_0ck3146z6221;0;7,-84,15,-119,16,-91;-10,-12;;-8,-74;-1,0,1,0,0,1",
"xs12_drz1226;xs15_04ai3zo8b5;0;-5,-41;2,-73,5,-63;;6,-40;3,-2,-1,0,0,1",
"xs12_drz1226;xs16_0drz25aa6;0;2,-101,4,-147;;20,-92;-23,-114,-11,-198,-6,-209;-1,0,1,0,0,1",
"xs12_drz1226;xs16_178k46zwbd;0;-5,-82;-11,-41;;-21,-106,-15,-156;-2,8,1,0,0,-1",
"xs12_drz1226;xs16_drz1226413;0;;;11,-36,15,-12,18,-32;-7,-105,2,-84;0,0,1,0,0,1",
"xs12_drz1226;xs16_drz1226426;0;19,-131;;12,-65,16,-12,19,-61;-10,-127,1,-121;0,0,1,0,0,1",
"xs12_drz1226;xs16_drz122ego;0;16,-74;;;-2,-67;0,0,1,0,0,1",
"xs12_drz346;xs15_3pmz4a9o;0;-5,-41;2,-73,5,-63;;6,-40;2,7,-1,0,0,-1",
"xs12_drz346;xs16_3pczg6rz11;0;;-2,-47,7,-62;-9,-74,-6,-42,-2,-50;;2,-3,-1,0,0,1",
"xs12_drz346;xs16_mp3zdmz11;0;-14,-40;4,-130,10,-180,12,-118;2,-117;6,-104;0,7,1,0,0,-1",
"xs12_g4q453z11;xs12_g4q552z11;0;;11,-54;5,-44;;0,0,1,0,0,1",
"xs12_g4q453z11;xs14_08ka952z321;0;;;-2,-65;10,-32;0,-1,1,0,0,1",
"xs12_g4q453z11;xs16_178k8a6z0321;0;;;-13,-82,-7,-132;-11,-78;-1,-1,1,0,0,1",
"xs12_g4q552z11;xs16_08lb871z321;0;-2,-52;;-9,-91,11,-57;13,-53,23,-32;0,-1,1,0,0,1",
"xs12_g4q552z11;xs16_0g8kk871z643;0;16,-78;14,-140,20,-90;;;0,-2,1,0,0,1",
"xs12_g4q552z11;xs16_178kaa4z0321;0;;;-13,-82,-7,-132;-11,-78;-1,-1,1,0,0,1",
"xs12_g4q552z11;xs16_g4q552sgz11;0;16,-148,22,-98;14,-70;;;0,0,1,0,0,1",
"xs12_g853zdb;xs14_wg853zmdz11;0;;7,-66,14,-73;;8,-44;0,-2,1,0,0,1",
"xs12_g853zdb;xs15_03ia4zmdz11;0;-3,-45;4,-77,7,-67;;8,-44;0,-2,1,0,0,1",
"xs12_g853zdb;xs15_25iczmdz11;0;-10,-106,-10,-44,-6,-93;9,-128;-1,-142;9,-108;0,-2,1,0,0,1",
"xs12_g853zdb;xs15_2eg84c84213;0;;-13,-12;14,-13;-12,-99,-9,-109;3,10,0,-1,-1,0",
"xs12_g853zdb;xs16_0g853z0drz32;0;11,-78,15,-70,18,-102;;;-14,-90,-5,-75;-1,0,1,0,0,1",
"xs12_g853zdb;xs16_rdz01qczx23;0;;0,-43,9,-58;-7,-70,-4,-38,0,-46;;0,8,1,0,0,-1",
"xs12_g853zdb;xs16_wdrzcq1z32;0;-12,-44;6,-134,12,-184,14,-122;4,-121;8,-108;0,-3,1,0,0,1",
"xs12_g88a53z23;xs14_35a88gzwca1;0;11,-82,18,-89;;12,-12;;5,0,-1,0,0,1",
"xs12_g88a53z23;xs16_0178kczad11;0;-2,-61;-8,-54;-12,-78,-6,-128;;0,-2,1,0,0,1",
"xs12_g88a53z23;xs16_032q48cz6521;0;;;-12,-78,-6,-128;-14,-90;-2,0,0,1,1,0",
"xs12_g88a53z23;xs16_cp3z122ako;0;4,-83,13,-98;;;-15,-110,-12,-78,-8,-86;0,9,1,0,0,-1",
"xs12_g88b52z23;xs16_032q48cz3521;0;;;-12,-78,-6,-128;-14,-90;-2,0,0,1,1,0",
"xs12_g88b52z23;xs16_25a8oge123;0;;4,-41;1,-43;6,-36;0,-3,0,1,1,0",
"xs12_g88b52z23;xs16_cp3z122qk8;0;4,-83,13,-98;;;-15,-110,-12,-78,-8,-86;0,9,1,0,0,-1",
"xs12_g88b52z23;xs16_g88b52sgz23;0;16,-148,22,-98;14,-70;;;0,0,1,0,0,1",
"xs12_g88b52z23;xs16_xck871zad11;0;16,-78;14,-140,20,-90;;;0,-2,1,0,0,1",
"xs12_g8o653z11;xs16_08o653z69k8;0;-9,-32;8,-78;-4,-122,-2,-66,2,-129,5,-109;14,-65,20,-65;5,5,-1,0,0,-1",
"xs12_g8o653z11;xs20_33g8o6530oozw11;0;-2,-36;-4,-16;12,-12;2,-40;7,5,-1,0,0,-1",
"xs12_ggdbz65;xs14_03pmzdb;0;-3,-40;;-10,-79,-1,-74;9,-40;0,-1,1,0,0,1",
"xs12_ggdbz65;xs14_358gzw11mq;0;;-12,-12;;-18,-97,-11,-90;-2,9,1,0,0,-1",
"xs12_ggdbz65;xs15_03ia4zqm11;0;;-12,-12;13,-13;-11,-91,-8,-101;3,9,-1,0,0,-1",
"xs12_ggdbz65;xs15_25iczqm11;0;-10,-102,-10,-40,-6,-89;9,-124;-1,-138;9,-104;0,-2,1,0,0,1",
"xs12_ggdbz65;xs15_woka52zdb;0;;8,-42;1,-54,8,-24;;0,-1,1,0,0,1",
"xs12_ggdbz65;xs16_3123c48c4go;0;;0,-43,9,-58;-7,-70,-4,-38,0,-46;;0,7,0,1,-1,0",
"xs12_ggdbz65;xs16_3123ckzy21248c;0;;9,-63;3,-76;12,-40;0,7,0,1,-1,0",
"xs12_ggdbz65;xs16_ggdbzmdz11;0;-12,-40;6,-130,12,-180,14,-118;4,-117;8,-104;3,7,-1,0,0,-1",
"xs12_ghn84cz1;xs16_0o5b8oz39c;0;-1,-68,8,-89;-13,-32,-10,-12,-6,-36;;;5,5,0,-1,-1,0",
"xs12_ghn84cz1;xs16_0o5b8ozbd;0;0,-105,11,-111;-14,-61,-11,-12,-7,-65;;-14,-115;5,5,0,-1,-1,0",
"xs12_ghn84cz1;xs16_ghn84cz1246;0;6,-96,12,-80,17,-128;-13,-38;;-16,-94,-14,-112,-6,-73,-4,-103;0,0,1,0,0,1",
"xs12_ghn84cz1;xs16_wghn84cz643;0;3,-67;;;-11,-74;-2,0,1,0,0,1",
"xs12_kc3213z11;xs15_8o6421e8z32;0;;-10,-12;11,-13;-9,-75,-6,-85;-1,0,0,1,1,0",
"xs12_kc3213z11;xs15_ci52z116246;0;9,-150;-11,-76;14,-61,18,-74,18,-12;-11,-136;0,7,1,0,0,-1",
"xs12_kc3213z11;xs16_0kc3213zc93;0;;;7,-36,11,-12,14,-32;1,-57,10,-36;0,-1,0,1,1,0",
"xs12_kc3213z11;xs16_kc3213zdb;0;4,-129;-10,-76;20,-12;-16,-130,-14,-192,-8,-142;0,0,1,0,0,1",
"xs12_kc3213z11;xs16_xg84c3213zca1;0;;15,-70;4,-70;10,-33;0,-5,0,1,1,0",
"xs12_o4q552z01;xp2_07z8kk8gzx343;1;;12,-58;2,-56;;5,-7,-1,0,0,1",
"xs12_o4q552z01;xs14_0g4q552z321;0;-9,-46;4,-84;3,-116;9,-87,9,-32;0,-1,0,1,1,0",
"xs12_o4q552z01;xs15_0g8gka23z343;0;;-3,-50,3,-91,3,-43,11,-110;-3,-42,0,-58,4,-90;13,-62;0,-2,1,0,0,1",
"xs12_o4q552z01;xs16_0g8kk871z343;0;;-19,-12,-13,-86;15,-16;;-2,0,0,1,1,0",
"xs12_o4q552z01;xs16_c84q552z311;0;-8,-57,12,-103;;-3,-62;-24,-126,-14,-107;-1,0,1,0,0,1",
"xs12_o4q552z01;xs16_o4q552sgz01;0;;-13,-16;15,-86,21,-12;;0,0,0,1,1,0",
"xs12_oo033zy766;xp2_y0oo033zyb66ze;0;9,-140;;;-23,-150;-4,0,1,0,0,1",
"xs12_raar;xs15_0gbaarz121;0;;6,-34,7,-52;-4,-38;;-2,4,1,0,0,-1",
"xs12_raar;xs16_raarzx123;0;;-2,-39;-6,-46;;3,4,-1,0,0,-1",
"xs12_w6996z33;xs11_253039c;0;;-6,-30;-4,-46;1,-78;-9,5,1,0,0,-1",
"xs12_x178cz352;xs16_g8861acz0db;0;-4,-40,10,-111;3,-58,4,-41;;-12,-113;9,0,-1,0,0,1",
"xs12_xdjoz33;xs19_35icga6zw1po;0;0,-54,7,-67,14,-66;-3,-28;;-2,-60;4,0,0,-1,1,0",
"xs12_xg84213zca1;xs14_31248gzy21248go;0;;12,-58;2,-74,8,-51,13,-32;;9,-3,0,-1,1,0",
"xs12_xg84213zca1;xs14_69jzx1248go;0;12,-110,21,-115;-14,-12;14,-12;;0,9,1,0,0,-1",
"xs12_xg84213zca1;xs14_y1g84213zg8421z11;0;;-13,-25;;-19,-118,-12,-111;-2,0,1,0,0,1",
"xs12_xg84213zca1;xs15_358gzy01248ge2;0;;-13,-12;14,-13;-12,-99,-9,-109;8,0,0,-1,1,0",
"xs12_xg84213zca1;xs16_3146248gzy412ko;0;;;10,-44,14,-20,17,-40;4,-65,13,-44;11,-1,-1,0,0,1",
"xs12_xg84213zca1;xs16_xg84213213zca1;0;7,-153;-13,-76;23,-12;-19,-154,-17,-216,-11,-166;0,0,0,1,1,0",
"xs12_xg84213zca1;xs16_y4g853zxg8421zca1;0;-1,-44;11,-75,18,-99;4,-72,12,-61;12,-76;0,-5,1,0,0,1",
"xs13_0354k8z6421;xs14_05b88gzc8421;0;-2,-40;3,-45;-6,-57;;0,-1,1,0,0,1",
"xs13_0354k8z6421;xs15_08ljgzog8421;0;-4,-42;3,-79;-2,-82;10,-40;0,-2,1,0,0,1",
"xs13_0354k8z6421;xs15_25b88gzc8421;0;-4,-40;;-6,-64;;0,-1,1,0,0,1",
"xs13_0354k8z6421;xs15_31248gzca511;0;-3,-40;3,-53;-7,-69;;0,7,1,0,0,-1",
"xs13_0354k8z6421;xs16_31248gzcid11;0;;2,-52;-7,-58,-6,-70;;0,7,1,0,0,-1",
"xs13_0354k8z6421;xs16_31248gzoid11;0;;1,-56;-5,-50;;0,7,1,0,0,-1",
"xs13_035iczca1;xs12_025iczca1;0;;9,-46;3,-36;;0,0,1,0,0,1",
"xs13_035iczca1;xs14_358gzwok96;0;8,-105,19,-113;;;-20,-106,-8,-102;-1,9,1,0,0,-1",
"xs13_035iczca1;xs15_ci53zw1248go;0;3,-84,9,-85,14,-86;-11,-12;;;4,0,-1,0,0,1",
"xs13_035iczca1;xs15_xg84215acz321;0;10,-108;-13,-12;;-12,-98;4,10,0,-1,-1,0",
"xs13_035iczca1;xs16_4a51248gka6;0;12,-174;-14,-76;17,-61,21,-74,21,-12;-14,-160;0,10,0,1,-1,0",
"xs13_035iczca1;xs16_ci53zwhik8zw1;0;;-13,-12;14,-13;-12,-99,-9,-109;4,0,-1,0,0,1",
"xs13_03hik8z252;xs14_03hik8z256;0;15,-70;;;-3,-64;0,0,1,0,0,1",
"xs13_03hik8z252;xs14_03hik8z652;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs13_03hik8z252;xs15_025a88gzog8421;0;-2,-40;0,-58;-5,-54;;-1,7,1,0,0,-1",
"xs13_03hik8z252;xs15_03hik8z25a4;0;13,-68;;;-7,-58;0,0,1,0,0,1",
"xs13_03hik8z252;xs15_03hik8z696;0;13,-93;-11,-12;;;0,0,1,0,0,1",
"xs13_03hik8z252;xs15_358ge12ko;0;8,-90,14,-88,17,-78;-9,-32;17,-22;;1,0,0,1,1,0",
"xs13_03hik8z252;xs15_8kih3zx254c;0;12,-107,13,-123;-16,-12,-8,-43;;;5,0,-1,0,0,1",
"xs13_03hik8z252;xs15_8kih3zx25a4;0;12,-93;-12,-12;;;5,0,-1,0,0,1",
"xs13_03hik8z252;xs16_025a88gz178421;0;-9,-40,-2,-75,4,-77;-15,-35,-8,-27;-7,-58;;-1,7,1,0,0,-1",
"xs13_03hik8z252;xs16_03hik8z25ac;0;13,-97;;15,-12;-7,-110;0,0,1,0,0,1",
"xs13_03hik8z252;xs16_3hik8zrm;0;14,-85;;19,-12;-4,-92;1,0,1,0,0,1",
"xs13_03hik8z252;xs16_8kih3zx25ac;0;9,-110;-13,-12;;-11,-97;5,0,-1,0,0,1",
"xs13_03hik8z252;xs16_8kih3zx69a4;0;;-8,-12;;;5,0,-1,0,0,1",
"xs13_03hik8z252;xs16_g8ge12koz56;0;9,-99;-11,-12;;-18,-111;5,7,0,-1,-1,0",
"xs13_04ap3zca1;xs14_358gzw4ajo;0;8,-105,19,-113;;;-20,-106,-8,-102;-1,9,1,0,0,-1",
"xs13_04ap3zca1;xs15_xg8426853z321;0;10,-108;-13,-12;;-12,-98;4,10,0,-1,-1,0",
"xs13_04ap3zca1;xs16_3pa4zwhik8zw1;0;;-13,-12;14,-13;-12,-99,-9,-109;4,0,-1,0,0,1",
"xs13_08e13zc93;xs15_312kozx2ego;0;4,-76;;;-14,-82;-2,9,1,0,0,-1",
"xs13_08e13zoi6;xs15_g8e13zpi6;0;-4,-52,1,-48;-6,-28;;;0,0,1,0,0,1",
"xs13_08k8a52z321;xs14_08k8a53z321;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs13_08k8a52z321;xs14_0ck8a52z321;0;-2,-36;2,-46;;;0,0,1,0,0,1",
"xs13_08k8a52z321;xs15_0g8gka23z643;0;;;0,-91,1,-75;7,-67,15,-36;0,-1,1,0,0,1",
"xs13_08k8a52z321;xs15_0g8gka52z643;0;;10,-50;4,-40;;0,-1,1,0,0,1",
"xs13_08k8a52z321;xs15_w8ka952z2521;0;0,-67;;;-12,-82;-1,0,0,1,1,0",
"xs13_08k8a52z321;xs16_0g4q453zbc1;0;;17,-79;4,-67;10,-36;0,0,0,1,1,0",
"xs13_08k8a52z321;xs16_0g8gka53z643;0;;11,-110,26,-114;;19,-48;0,-1,1,0,0,1",
"xs13_08k8a52z321;xs16_0j5q453z121;0;-10,-52;;-17,-102,-2,-98;;0,0,0,1,1,0",
"xs13_08ka96z321;xs15_0g8ka96z3421;0;0,-63;;;-12,-78;-1,0,1,0,0,1",
"xs13_08o696z321;xs14_08p78cz321;0;-1,-72;18,-82;-8,-103;11,-64;0,0,1,0,0,1",
"xs13_08o696z321;xs14_0g0si52z343;0;;-17,-12,-8,-43;-2,-49;-12,-89;5,7,-1,0,0,-1",
"xs13_08o696z321;xs15_0g0si96z343;0;0,-63;;;-12,-78;5,7,-1,0,0,-1",
"xs13_08o696z321;xs16_08o696z6ip;0;-1,-52,-1,-36,13,-83;-6,-24;;-15,-95,-8,-71;0,0,1,0,0,1",
"xs13_08o696z321;xs16_08o696zmq1;0;-1,-52,-1,-36,12,-83;-6,-24;;-16,-95,-9,-71;0,0,1,0,0,1",
"xs13_08ob96z32;xs16_032q4goz6413;0;17,-120;;-1,-84,5,-101,5,-53,13,-88;2,-112,6,-64,9,-36;7,6,0,-1,-1,0",
"xs13_08u156z32;xs15_w8u156zca1;0;11,-94;-11,-12;;;-1,0,1,0,0,1",
"xs13_08u156z32;xs16_32q4gozc93;0;-6,-70;3,-98,7,-66,10,-50;-4,-118,4,-99,4,-51,10,-58;;0,-2,1,0,0,1",
"xs13_0bdz6952;xs16_3lkcz1qm;0;4,-56,14,-66,18,-94;;;-11,-82;0,9,1,0,0,-1",
"xs13_0bq23z65;xs16_03loz8ka226;0;;7,-38,8,-56;-3,-42;;-1,7,1,0,0,-1",
"xs13_0brz254c;xs15_0ok213z4a9o;0;;;-5,-89;4,-90,7,-44;0,-1,1,0,0,1",
"xs13_0c84213z253;xs14_wkc0f9z65;0;;-10,-30;;-17,-102;-1,0,0,1,1,0",
"xs13_0c84213z253;xs16_w8o0uh3zca1;0;5,-94;-9,-24;;-14,-90;-2,0,0,1,1,0",
"xs13_0c84213z253;xs16_wkc0f96z65;0;6,-79;-14,-12;;;-1,0,0,1,1,0",
"xs13_0cp3z69c;xs15_31248c48gkc;0;;;-2,-78;8,-44;4,-2,0,-1,1,0",
"xs13_0drz254c;xs16_178426421e8;0;-4,-45;3,-77,6,-67;;7,-44;0,-2,0,1,1,0",
"xs13_0g0s256z321;xs15_wggka53z652;0;;9,-46;3,-52;;7,6,0,-1,-1,0",
"xs13_0g4q552z121;xs15_0g8gka52z343;0;11,-85;-11,-12;;;-1,0,0,1,1,0",
"xs13_0g4q552z121;xs16_0g4q552zbc1;0;5,-85;-16,-13;;-11,-78;0,0,1,0,0,1",
"xs13_0g4q552z121;xs16_0g8gka53z343;0;5,-96;-9,-27;;-13,-86;-1,0,0,1,1,0",
"xs13_0g6p56z121;xs14_0g6p56z321;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs13_0g6p56z121;xs15_1784ozx3453;0;1,-89,2,-77;;;-16,-94,-8,-93;-1,7,1,0,0,-1",
"xs13_0g6p56z121;xs15_25a4ozx3453;0;11,-85;-11,-12;;;-1,7,1,0,0,-1",
"xs13_0g6p56z121;xs16_0g6p56zbc1;0;5,-84;-16,-12;;-11,-77;0,0,1,0,0,1",
"xs13_0g6p56z121;xs16_35a4ozx3453;0;8,-102;-12,-12;;-10,-89;-1,7,1,0,0,-1",
"xs13_0g853z8ld;xs16_358gzwdlkc;0;8,-95;-16,-12;;;4,0,-1,0,0,1",
"xs13_0g853zol3;xs15_xg853z0mdz32;0;;8,-70,15,-77;;9,-48;0,-2,1,0,0,1",
"xs13_0g853zol3;xs16_025icz0mdz32;0;-9,-110,-9,-48,-5,-97;10,-132;0,-146;10,-112;0,-2,1,0,0,1",
"xs13_0g853zol3;xs16_w3ia4z0mdz32;0;-2,-49;5,-81,8,-71;;9,-48;0,-2,1,0,0,1",
"xs13_0g853zrm;xs16_358gzx6bgzw311;0;;-14,-12;15,-13;-13,-107,-10,-117;4,0,-1,0,0,1",
"xs13_0g853zrm;xs16_w3ia4zcq1z32;0;-2,-49;5,-81,8,-71;;9,-48;0,-2,1,0,0,1",
"xs13_0g853zrq;xs14_wg853zgb6z11;0;7,-105,16,-120;-13,-12;;-27,-137,-14,-103;-1,0,1,0,0,1",
"xs13_0g853zrq;xs15_wg8og84213z65;0;16,-129;-14,-12,-11,-58;;;4,10,0,-1,-1,0",
"xs13_0g8gka23z23;xs16_32q4gzx14b8o;0;;14,-66;9,-59;14,-54;9,-1,0,-1,1,0",
"xs13_0g8gka52z23;xs16_32q4gzx12pm;0;;18,-82;5,-70;11,-39;0,6,0,1,-1,0",
"xs13_0g8ka52z321;xs16_0g8ka53zbc1;0;;11,-54;7,-61;16,-37;6,6,-1,0,0,-1",
"xs13_0g8ka53z23;xs12_0g8ka52z23;0;;4,-32;-2,-42;;0,0,1,0,0,1",
"xs13_0g8ka53z23;xs16_32q4gzx125ac;0;9,-89;-12,-12;;-14,-104;-1,8,1,0,0,-1",
"xs13_0g8o6413z23;xs16_xok4871zc93;0;9,-89;-12,-12;;-14,-104;-1,0,0,1,1,0",
"xs13_0g8o652z321;xs15_wggca52z6521;0;;;1,-61;11,-36;0,-1,1,0,0,1",
"xs13_0g8o652z321;xs16_358gzw116ako;0;;8,-83,11,-76,14,-66;;14,-66;9,-1,0,-1,1,0",
"xs13_0g8o652z321;xs16_kq23zw35ac;0;-10,-36,-4,-110;;8,-126;6,-134,14,-40;5,-2,-1,0,0,1",
"xs13_0g8o653z121;xs16_356o8gzy21248c;0;-1,-72;;-4,-61;-14,-90,-5,-92;6,0,-1,0,0,1",
"xs13_0g8o653z23;xs16_xok4871z653;0;9,-89;-12,-12;;-14,-104;-1,0,0,1,1,0",
"xs13_0gba96z121;xs15_0g8ge1daz23;0;11,-99,12,-115;-15,-12,-7,-43;;;5,7,0,-1,-1,0",
"xs13_0gba96z121;xs15_0gba96z1252;0;12,-64;;;-6,-54;0,0,1,0,0,1",
"xs13_0gba96z121;xs15_358ge1da;0;7,-86,13,-84,16,-74;-8,-36;16,-26;;5,7,0,-1,-1,0",
"xs13_0gba96z121;xs15_69abgzx1252;0;11,-85;-11,-12;;;5,0,-1,0,0,1",
"xs13_0gba96z121;xs16_0gba96z1256;0;13,-122,28,-126;;21,-12;;0,0,1,0,0,1",
"xs13_0gba96z121;xs16_g8ge1daz56;0;8,-91;-10,-12;;-17,-103;5,6,0,-1,-1,0",
"xs13_0gbaa4z123;xs14_4aab8ozx32;0;0,-61,0,-36;0,-34;;;5,0,-1,0,0,1",
"xs13_0gbaa4z123;xs15_4aabgzx1256;0;4,-66;-8,-12;;;5,0,-1,0,0,1",
"xs13_0gbaa4z321;xs15_0g6p2sgz321;0;14,-66;;;6,-51;6,6,0,-1,-1,0",
"xs13_0gbaicz121;xs14_0gbaicz321;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs13_0gbaicz121;xs15_0g8id1e8z23;0;11,-99,12,-115;-15,-12,-7,-43;;;5,7,0,-1,-1,0",
"xs13_0gbaicz121;xs15_ciabgzx1252;0;11,-85;-11,-12;;;5,0,-1,0,0,1",
"xs13_0gbaicz121;xs15_g8id1egoz01;0;;11,-62;2,-76;12,-36;5,6,0,-1,-1,0",
"xs13_0gbaicz121;xs16_ciabgzx1256;0;8,-102;-12,-12;;-10,-89;5,0,-1,0,0,1",
"xs13_0gbaicz121;xs16_g8id1e8z56;0;8,-91;-10,-12;;-17,-103;5,6,0,-1,-1,0",
"xs13_0gbb8oz121;xs15_0g8hf0ccz23;0;11,-99,12,-115;-15,-12,-7,-43;;;5,7,0,-1,-1,0",
"xs13_0gbb8oz121;xs15_4aligozw66;0;12,-64;;;-6,-54;0,7,1,0,0,-1",
"xs13_0gbb8oz121;xs16_4aljgozw66;0;12,-89;;14,-12;-6,-102;0,7,1,0,0,-1",
"xs13_0gbb8oz121;xs16_g8hf0ccz56;0;8,-91;-10,-12;;-17,-103;5,6,0,-1,-1,0",
"xs13_0gbq23z121;xs15_25akozx6226;0;11,-85;-11,-12;;;-1,7,1,0,0,-1",
"xs13_0gbq23z121;xs16_0gbq23zbc1;0;5,-84;-16,-12;;-11,-77;0,0,1,0,0,1",
"xs13_0gbq23z121;xs16_25a88cz4a53;0;;8,-42,9,-60;-2,-46;;0,-2,1,0,0,1",
"xs13_0gbq23z121;xs16_25aczw3115a4;0;;9,-46;-2,-60,-1,-42;;0,6,1,0,0,-1",
"xs13_0gbq23z121;xs16_358gzy0560ui;0;-1,-68;;-4,-57;-14,-86,-5,-88;-4,8,0,1,-1,0",
"xs13_0gbq23z121;xs16_g8kc0f9z56;0;8,-91;-10,-12;;-17,-103;5,6,0,-1,-1,0",
"xs13_0gbq23z23;xs16_178cz4a5113;0;;8,-42,9,-60;-2,-46;;0,6,1,0,0,-1",
"xs13_0gbq23z23;xs16_178czw3115a4;0;;9,-46;-2,-60,-1,-42;;0,6,1,0,0,-1",
"xs13_0ggc871z641;xs16_32q4gzx116io;0;;14,-84;3,-69;12,-40;7,-2,-1,0,0,1",
"xs13_0ggca52z641;xs15_xoka52zc93;0;;10,-50;4,-40;;0,-1,1,0,0,1",
"xs13_0ggca52z641;xs16_0g8o6413zbc1;0;;17,-83;4,-71;10,-40;0,0,0,1,1,0",
"xs13_0ggca52z641;xs16_3146o8gzy31248c;0;-3,-51;;-2,-82;4,-78,13,-40;0,7,0,1,-1,0",
"xs13_0ggca52z641;xs16_39cggzx101248go;0;16,-85;5,-68,14,-66;13,-48;;0,7,1,0,0,-1",
"xs13_0ggca52z641;xs16_39cggzx12pm;0;;11,-57;7,-64;16,-40;0,7,1,0,0,-1",
"xs13_0ggca52z641;xs19_08o6413z69cz033;0;;5,-71,16,-74;;5,-77,10,-54;0,1,0,1,1,0",
"xs13_0ggca52z641;xs19_0ggc93zcipz066;0;;6,-79,11,-76;;4,-81,15,-40;5,7,-1,0,0,-1",
"xs13_0ggka23z56;xs15_0ggka23z12ko;0;12,-90,19,-97;;13,-12;;0,0,1,0,0,1",
"xs13_0ggka23z56;xs16_x8k4871zad11;0;;13,-62;8,-55;13,-50;0,-1,1,0,0,1",
"xs13_0ggka52z56;xs15_0ggka52z12ko;0;12,-90,19,-97;;13,-12;;0,0,1,0,0,1",
"xs13_0ggka52z56;xs16_0g8ge123zbc1;0;;17,-83;4,-71;10,-40;0,0,0,1,1,0",
"xs13_0ggka52z56;xs16_5b88gzx12pm;0;;11,-57;7,-64;16,-40;0,7,1,0,0,-1",
"xs13_0ggka53z32;xs16_wggka53zc96;0;6,-88;;;-12,-82;-1,0,1,0,0,1",
"xs13_0ggm952z32;xs16_wggm952zc96;0;6,-88;;;-12,-82;-1,0,1,0,0,1",
"xs13_0ggm96z56;xs15_0ggm96z12ko;0;12,-90,19,-97;;13,-12;;0,0,1,0,0,1",
"xs13_0ggo8b5z32;xs14_0ggo8b5z56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs13_0ggo8b5z32;xs15_0ggo8b52z56;0;;-11,-14;;-13,-86;6,7,-1,0,0,-1",
"xs13_0ggo8b5z32;xs16_wggo8b5zc96;0;6,-88;;;-12,-82;-1,0,1,0,0,1",
"xs13_0ggs252z56;xs14_0ggs253z56;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs13_0ggs252z56;xs15_0ggs2552z56;0;;11,-54;11,-39;;0,0,1,0,0,1",
"xs13_0ggs252z56;xs15_0ggs25a4z56;0;14,-66;;;8,-51;0,0,1,0,0,1",
"xs13_0ggs252z56;xs15_5b8ozx121e8;0;;8,-73,16,-74;10,-57,11,-69;;0,7,1,0,0,-1",
"xs13_0ggs252z56;xs15_5b8ozx125a4;0;;10,-50;4,-40;;0,7,1,0,0,-1",
"xs13_0ggs252z56;xs16_0ggs25acz56;0;15,-70;;11,-43;5,-80;0,0,1,0,0,1",
"xs13_0ggs252z56;xs16_5b8ozx12596;0;;8,-42;;;0,7,1,0,0,-1",
"xs13_0ggs252z56;xs16_5b8ozx125ac;0;;10,-69;4,-82;12,-40;0,7,1,0,0,-1",
"xs13_0ggs252z56;xs16_5b8ozx12pm;0;;11,-57;7,-64;16,-40;0,7,1,0,0,-1",
"xs13_0ggs252z56;xs16_g88e123zdb;0;19,-86;;12,-27;2,-74;0,1,0,1,1,0",
"xs13_0ggs253z32;xs15_wggs253z256;0;;-11,-14;;-13,-86;-1,0,1,0,0,1",
"xs13_0ggs253z32;xs16_wggs253zc96;0;6,-88;;;-12,-82;-1,0,1,0,0,1",
"xs13_0ggs256z32;xs14_178jq23;0;-5,-66;-10,-17,-6,-40,4,-58;-2,-42;-6,-81;2,-2,0,1,1,0",
"xs13_0ggs256z32;xs15_wggs256z256;0;;-11,-14;;-13,-86;-1,0,1,0,0,1",
"xs13_0ggs256z32;xs16_wggs256zc96;0;6,-88;;;-12,-82;-1,0,1,0,0,1",
"xs13_0gila4z56;xs15_025ak8zad11;0;-1,-40;1,-38;;;0,-1,1,0,0,1",
"xs13_0gila4z56;xs15_0gila4z12ko;0;12,-90,19,-97;;13,-12;;0,0,1,0,0,1",
"xs13_0gila4z56;xs16_0g88b5z12pm;0;-8,-40;1,-64;-3,-57;;5,7,-1,0,0,-1",
"xs13_0gila4z56;xs16_0mlla4z56;0;-5,-40;1,-51;;;0,0,1,0,0,1",
"xs13_0gila4z56;xs16_3ihla4z56;0;-2,-40;4,-71;-9,-83;;0,0,1,0,0,1",
"xs13_0gjla4z32;xs16_wgjla4zc96;0;6,-84;;;-12,-78;-1,0,1,0,0,1",
"xs13_0j5ozbc1;xs15_31248a51246;0;13,-98,20,-105;;14,-12;;3,10,0,-1,-1,0",
"xs13_0j5ozbc1;xs16_1784215a84c;0;-4,-44;;-3,-67,0,-77;7,-45;3,-2,0,-1,1,0",
"xs13_0j5ozbc1;xs16_17842akg84c;0;10,-109,13,-99;-13,-13;14,-12;;-1,10,0,1,-1,0",
"xs13_0j5ozbc1;xs16_xj5ozg8jc1z01;0;15,-160;-20,-74,-20,-12,-16,-61;15,-76;-11,-174;-2,0,1,0,0,1",
"xs13_0j9ak8z121;xs14_0j9ak8z321;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs13_0j9ak8z121;xs15_0g8id2koz23;0;11,-99,12,-115;-15,-12,-7,-43;;;5,7,0,-1,-1,0",
"xs13_0j9ak8z121;xs15_25a8ka4z0321;0;15,-70;;;5,-55;0,6,1,0,0,-1",
"xs13_0j9ak8z121;xs15_8ka9jzx1252;0;11,-85;-11,-12;;;5,0,-1,0,0,1",
"xs13_0j9ak8z121;xs16_25a8ka6z0321;0;14,-122,29,-126;;22,-28;;0,6,1,0,0,-1",
"xs13_0j9ak8z121;xs16_25icga6zw56;0;20,-90;;13,-15;-1,-78;0,6,0,1,-1,0",
"xs13_0j9ak8z121;xs16_8ka9jzx1256;0;8,-102;-12,-12;;-10,-89;5,0,-1,0,0,1",
"xs13_0j9ak8z121;xs16_g8id2koz56;0;8,-91;-10,-12;;-17,-103;5,6,0,-1,-1,0",
"xs13_0kc0f9z32;xs16_4a4o0ol3zw23;0;;;11,-24;7,-36,8,-50;7,6,-1,0,0,-1",
"xs13_0kc0f9z32;xs16_w8o0ol3z4a43;0;;;10,-24,11,-38;8,-36;7,6,-1,0,0,-1",
"xs13_0kq23z4a6;xs12_brz1226;0;14,-66;;;;1,7,1,0,0,-1",
"xs13_0kq23z4a6;xs13_1784c871;0;12,-65;;11,-12;0,-45;4,0,0,-1,1,0",
"xs13_0kq23z4a6;xs14_1784c0cic;0;16,-74;;;-4,-68;4,0,0,-1,1,0",
"xs13_0kq23z4a6;xs14_32arzw1226;0;;-11,-18;;-18,-98;-1,7,1,0,0,-1",
"xs13_0kq23z4a6;xs15_0kq23zpi6;0;16,-114;-9,-30;16,-12;-10,-99;0,0,1,0,0,1",
"xs13_0kq23z4a6;xs15_1784cgs26;0;11,-94;-11,-12;;-11,-88;4,0,0,-1,1,0",
"xs13_0kq23z4a6;xs15_31e8zo8b5;0;12,-71;;10,-12;-3,-60;4,9,-1,0,0,-1",
"xs13_0kq23z4a6;xs16_32qkzw622ac;0;6,-90;-10,-12;;-15,-86;4,0,-1,0,0,1",
"xs13_0kq23z4a6;xs16_32qkzw6a96;0;6,-111;;;-23,-118,-14,-115;4,0,-1,0,0,1",
"xs13_0kq23z4a6;xs16_32qkzw6aa6;0;7,-87;-15,-12;;;4,0,-1,0,0,1",
"xs13_0mk453z121;xs14_0c88b5z253;0;;12,-58;3,-46;8,-41;0,-1,1,0,0,1",
"xs13_0mk453z121;xs15_0c88b52z253;0;;12,-60;;10,-36;0,-1,1,0,0,1",
"xs13_0mk453z121;xs15_0ogjl8z4a6;0;-4,-36;8,-78;3,-75;10,-38;0,-2,1,0,0,1",
"xs13_0mk453z121;xs16_04s0f96z321;0;5,-71;-13,-12;;;-1,0,0,1,1,0",
"xs13_0mk453z121;xs16_0mk453zbc1;0;5,-84;-16,-12;;-11,-77;0,0,1,0,0,1",
"xs13_0mk453z121;xs16_0oggm93z4a6;0;;11,-54;5,-60;;0,-2,1,0,0,1",
"xs13_0mk453z121;xs16_g8o0uh3z56;0;8,-91;-10,-12;;-17,-103;5,6,0,-1,-1,0",
"xs13_0ml2zc96;xs12_brz346;0;;;-3,-34;;2,1,-1,0,0,1",
"xs13_0ml2zc96;xs13_178c48a6;0;0,-44;-5,-13;-1,-33;;-1,1,0,1,1,0",
"xs13_0ml2zc96;xs14_2ll2zc96;0;;-1,-36;-5,-42;;0,0,1,0,0,1",
"xs13_0ml2zc96;xs14_354260ui;0;;13,-62;;6,-46;0,8,0,1,-1,0",
"xs13_0ml2zc96;xs15_0c9jzojd;0;-5,-44;5,-67;-5,-82;4,-62;0,-1,1,0,0,1",
"xs13_0ml2zc96;xs15_0ca52zojd;0;;7,-38;1,-28;;0,-1,1,0,0,1",
"xs13_0ml2zc96;xs15_3lkczc96;0;;6,-56;0,-62;6,-44;0,0,1,0,0,1",
"xs13_0ml2zc96;xs15_8e13zdjo;0;1,-44;-2,-28;-1,-39;;2,-1,-1,0,0,1",
"xs13_0ml2zc96;xs16_0mk453zc96;0;;10,-54;5,-58;5,-44;0,0,1,0,0,1",
"xs13_0ml2zc96;xs16_0ml56zc96;0;;;4,-55;10,-44;0,0,1,0,0,1",
"xs13_0ml2zc96;xs16_0ml96zc96;0;;9,-79,18,-82;5,-75;;0,0,1,0,0,1",
"xs13_0o4871z643;xs16_32q4gzx1cjo;0;;13,-84;2,-69;11,-40;6,-2,-1,0,0,1",
"xs13_0o4a52z643;xs15_0g8ka52zc96;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs13_0o4a52z643;xs16_3p6gzw12pm;0;;10,-57;6,-64;15,-40;0,7,1,0,0,-1",
"xs13_0o4a52z643;xs16_g8ka2453z56;0;;16,-83;3,-71;9,-40;0,0,0,1,1,0",
"xs13_0og853z4a6;xs16_354kmzx101ac;0;6,-94;-10,-16;;-15,-90;-2,8,1,0,0,-1",
"xs13_0og853z4a6;xs16_358gozx6aa6;0;7,-87;-15,-12;;;5,0,-1,0,0,1",
"xs13_0ok213z4a6;xs16_312kozx6aa6;0;7,-87;-15,-12;;;5,0,-1,0,0,1",
"xs13_0ok213zca1;xs15_0g88a52zol3;0;;13,-73;9,-54;9,-44;0,-1,1,0,0,1",
"xs13_0ok213zca1;xs15_wg84264213z65;0;;11,-58;6,-62;8,-44;0,-2,0,1,1,0",
"xs13_0ok213zca1;xs16_0g8421e8zol3;0;;13,-62;14,-31,21,-39;2,-81,8,-79,15,-44;0,-1,1,0,0,1",
"xs13_1784c871;xs15_2eg8oge13;0;18,-82;;15,-32;6,-82;0,-1,1,0,0,1",
"xs13_17871ac;xs14_358e1da;0;8,-61;-8,-12,-3,-31;;;6,3,-1,0,0,-1",
"xs13_17871ac;xs15_31ege2ko;0;1,-78;-8,-28;;-11,-78;-1,-1,1,0,0,1",
"xs13_178c0f9;xs16_32acz3115a4;0;;;12,-12;8,-24,9,-38;0,0,0,1,1,0",
"xs13_178c0f9;xs16_c88a52z354c;0;;;11,-12,12,-26;9,-24;8,3,0,-1,-1,0",
"xs13_178c0f9;xs16_ggm930f9z1;0;-6,-24;3,-53;-8,-68;;-1,3,1,0,0,-1",
"xs13_178c0f9;xs16_ghn831e8z1;0;;14,-68;3,-53;12,-24;7,3,-1,0,0,-1",
"xs13_178c48a6;xs15_31ego8gkc;0;1,-82;-8,-32;;-11,-82;-1,-1,1,0,0,1",
"xs13_178f123;xs15_2egu2453;0;14,-66;12,-58;;8,-60,17,-29;0,-1,1,0,0,1",
"xs13_178f123;xs15_31egu246;0;1,-78;-8,-28;;-11,-78;-1,-1,1,0,0,1",
"xs13_178f123;xs16_17842uge2;0;13,-62;12,-59;7,-63,10,-41;;8,-1,-1,0,0,1",
"xs13_178f123;xs16_25iczwd553;0;14,-130;15,-119,19,-148,19,-86;12,-94;8,-124;8,-2,0,-1,1,0",
"xs13_178kc0cc;xs15_32qkgozw66;0;10,-50;;;-5,-61;0,0,0,1,1,0",
"xs13_1no3123;xs16_ra24871z23;0;7,-76,16,-83;-8,-12;;-14,-99,-6,-66;0,0,0,1,1,0",
"xs13_1no3146;xs15_1no312ko;0;;;13,-12;-1,-62;0,0,1,0,0,1",
"xs13_1no3146;xs16_178j146z311;0;7,-76,16,-83;-8,-12;;-14,-99,-6,-66;0,0,1,0,0,1",
"xs13_2530312ko;xs12_330312ko;0;-3,-28;;;;1,0,1,0,0,1",
"xs13_2530312ko;xs14_0ok213z4aa4;0;-5,-28;3,-54;;;8,-1,0,-1,1,0",
"xs13_2530312ko;xs14_358go0ui;0;;-11,-14;;-6,-66;8,4,-1,0,0,-1",
"xs13_2530312ko;xs15_c9jz358go;0;-5,-60;-3,-53;-7,-70;-4,-76;-1,0,0,1,1,0",
"xs13_2530312ko;xs16_358go0uh3;0;5,-76;-8,-20;;-5,-62;8,4,-1,0,0,-1",
"xs13_2530312ko;xs16_358go0uic;0;4,-69;;;-10,-82;8,4,-1,0,0,-1",
"xs13_2530312ko;xs16_358go4qic;0;5,-89;-16,-12,-7,-45;;;8,4,-1,0,0,-1",
"xs13_253032ak8;xs16_25a8o0uic;0;4,-69;;;-10,-82;8,4,-1,0,0,-1",
"xs13_253032qk;xs16_5b8o0uic;0;4,-65;;;-10,-78;7,4,-1,0,0,-1",
"xs13_253032qk;xs16_g8e123zc952;0;-6,-45;0,-69,3,-97;-7,-66;;7,-1,0,-1,1,0",
"xs13_2530358go;xs16_312ko0uh3;0;5,-76;-8,-20;;-5,-62;8,4,-1,0,0,-1",
"xs13_2530358go;xs16_312ko0uic;0;4,-69;;;-10,-82;8,4,-1,0,0,-1",
"xs13_25303pm;xs16_69f03pm;0;4,-61;;;-10,-74;0,0,1,0,0,1",
"xs13_2530f96;xs15_25ac0f96;0;-2,-51;;;-8,-66;-1,3,1,0,0,-1",
"xs13_2530f96;xs15_4a960uic;0;;-5,-39;-5,-54;;-1,-1,1,0,0,1",
"xs13_2530f96;xs16_35ac0f96;0;1,-80;-5,-43;;-9,-70;-1,3,1,0,0,-1",
"xs13_2530f96;xs16_c84213z3553;0;;-9,-12,-6,-34,-3,-53;;-11,-92;-1,0,0,1,1,0",
"xs13_2530f96;xs16_ml56z1cb;0;4,-74;-6,-27;;-13,-86;6,0,0,-1,1,0",
"xs13_2530fho;xs14_2530fh8o;0;14,-67;;16,-12;3,-52;0,0,1,0,0,1",
"xs13_2530fho;xs15_0mk453z1243;0;;-5,-39;-5,-54;;6,-1,0,-1,1,0",
"xs13_2530fho;xs15_2530fh84c;0;16,-74;;7,-60;3,-83,11,-50;0,0,1,0,0,1",
"xs13_2530fho;xs15_3hu0oka4;0;-2,-51;;;-8,-66;6,4,-1,0,0,-1",
"xs13_2530fho;xs15_c88b52z352;0;16,-74;;16,-18;;7,0,0,-1,1,0",
"xs13_2530fho;xs16_3hu0ojd;0;1,-69;-12,-29;;-7,-62;6,4,-1,0,0,-1",
"xs13_2530fho;xs16_3hu0ok48c;0;4,-74;-6,-27;;-13,-86;6,4,-1,0,0,-1",
"xs13_2530fho;xs16_3hu0oka6;0;1,-80;-5,-43;;-9,-70;6,4,-1,0,0,-1",
"xs13_2530fho;xs16_3hu0uic;0;4,-61;;;-10,-74;6,4,-1,0,0,-1",
"xs13_2530fho;xs16_g8530fhoz11;0;;-9,-12,-6,-34,-3,-53;;-11,-92;-1,0,1,0,0,1",
"xs13_2530fho;xs16_mligz1w69c;0;;;15,-12;1,-74;0,0,0,1,1,0",
"xs13_255q8a6;xs17_255q8a6z0321;0;5,-55;;;-7,-62;0,0,1,0,0,1",
"xs13_256069ic;xs14_4s0ci96z11;0;-9,-28;;-4,-64;;1,4,1,0,0,-1",
"xs13_256069ic;xs16_04a952z3553;0;;2,-57;-8,-70;;7,-1,0,-1,1,0",
"xs13_256069ic;xs16_04s0ci96z321;0;-6,-28;3,-68;-3,-54;;0,4,1,0,0,-1",
"xs13_25606ako;xs14_0gbq23z321;0;-9,-28;;-4,-64;;1,4,0,1,-1,0",
"xs13_25606ako;xs16_354kmzx1256;0;-6,-28;3,-68;-3,-54;;0,-2,0,1,1,0",
"xs13_25606ako;xs16_35aczw3553;0;;2,-57;-8,-70;;7,4,0,-1,-1,0",
"xs13_2560uh3;xs14_2560uh23;0;;10,-51;7,-36;12,-28;0,0,1,0,0,1",
"xs13_2560uh3;xs14_4s0fhoz11;0;-9,-28;;-4,-64;;1,4,1,0,0,-1",
"xs13_2560uh3;xs15_03lk46z2521;0;-3,-28;-1,-26;;;6,-1,0,-1,1,0",
"xs13_2560uh3;xs15_2560uh246;0;16,-74;12,-60;7,-69;8,-68;0,0,1,0,0,1",
"xs13_2560uh3;xs15_25b88cz0253;0;;12,-58;;12,-34;7,-1,0,-1,1,0",
"xs13_2560uh3;xs15_35a88cz0253;0;;11,-54;7,-43;13,-35;7,-1,0,-1,1,0",
"xs13_2560uh3;xs16_321560uh3;0;-4,-35;2,-66;-11,-78;;-2,0,1,0,0,1",
"xs13_2560uh3;xs16_39mggoz04a6;0;;;5,-58;11,-28;8,-1,0,-1,1,0",
"xs13_2560uh3;xs16_62s0f96z011;0;;2,-53;-8,-66;;6,-1,-1,0,0,1",
"xs13_2560uh3;xs16_o4c0fhoz23;0;-10,-37;-1,-61;-5,-54;;0,4,1,0,0,-1",
"xs13_2560uic;xs16_0ml56zbc1;0;-4,-35;2,-66;-11,-78;;6,0,0,-1,1,0",
"xs13_2560uic;xs16_ggml56z1221;0;;2,-53;-8,-66;;6,-1,0,-1,1,0",
"xs13_2560uic;xs16_o4c0f96z23;0;-10,-37;-1,-61;-5,-54;;0,4,1,0,0,-1",
"xs13_256o8a52;xs14_255q8a52;0;;8,-59,15,-70;1,-63;;0,0,1,0,0,1",
"xs13_256o8a52;xs15_0252sgz4a53;0;-3,-28;-1,-26;;;7,-1,0,-1,1,0",
"xs13_256o8a52;xs15_0252sgzc453;0;;-5,-73,-4,-61;-10,-78,-2,-77;;7,-1,0,-1,1,0",
"xs13_256o8a52;xs15_0256o8z4a521;0;;11,-54;5,-44;;0,-1,0,1,1,0",
"xs13_256o8a52;xs15_02l2sgz2543;0;-4,-28;6,-53;;;7,-1,0,-1,1,0",
"xs13_256o8a52;xs15_ggka23ck8z1;0;;;1,-83,2,-67;8,-59,16,-28;8,4,-1,0,0,-1",
"xs13_256o8a52;xs16_252sgzmp3;0;-4,-39;2,-70;-11,-82;;7,0,0,-1,1,0",
"xs13_256o8a52;xs16_256o8a5123;0;;18,-82;5,-70;11,-39;0,0,1,0,0,1",
"xs13_256o8a52;xs16_o4c32ak8z23;0;-10,-41;-1,-65;-5,-58;;0,4,1,0,0,-1",
"xs13_256o8b5;xs15_03ihe8z2521;0;-3,-28;-1,-26;;;6,-1,0,-1,1,0",
"xs13_256o8b5;xs15_03ihe8z6221;0;;-5,-69,-4,-57;-10,-74,-2,-73;;6,-1,0,-1,1,0",
"xs13_256o8b5;xs15_354c32qk;0;5,-74;-3,-60;-5,-68,-5,-54;-9,-89;-1,4,1,0,0,-1",
"xs13_256o8b5;xs16_32156o8b5;0;-4,-35;2,-66;-11,-78;;-2,0,1,0,0,1",
"xs13_256o8b5;xs16_o4c32qkz23;0;-10,-37;-1,-61;-5,-54;;0,4,1,0,0,-1",
"xs13_256o8b5;xs16_wkc32qkz65;0;-7,-28,-4,-50,-1,-69;;-9,-92;;-1,4,1,0,0,-1",
"xs13_256o8ge2;xs16_32qkz5b8o;0;;3,-140;-9,-78,-1,-140;-17,-106,-11,-156;7,1,0,-1,1,0",
"xs13_256o8ge2;xs16_8e123ckzx311;0;0,-89;-2,-81,3,-52,9,-46;-4,-55,4,-59;;7,4,-1,0,0,-1",
"xs13_256o8gkc;xs14_356o8gkc;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs13_256o8gkc;xs14_mp3zw39c;0;-1,-57;-7,-48;-2,-64;-9,-74;7,4,0,-1,-1,0",
"xs13_256o8gkc;xs15_mp3zw31e8;0;-9,-28,-1,-59;5,-67,6,-83;;;7,4,0,-1,-1,0",
"xs13_256o8gkc;xs15_mp3zw354c;0;;-5,-73,-4,-61;-10,-78,-2,-77;;7,4,0,-1,-1,0",
"xs13_256o8gkc;xs15_mp3zw35a4;0;-3,-28;-1,-26;;;7,4,0,-1,-1,0",
"xs13_256o8gkc;xs16_32qkzdjo;0;;3,-140;-9,-78,-1,-140;-17,-106,-11,-156;-2,4,0,1,-1,0",
"xs13_256o8gkc;xs16_djozwojd;0;-4,-39;2,-70;-11,-82;;-2,0,0,1,1,0",
"xs13_256o8gkc;xs16_kc321e8z123;0;0,-89;-2,-81,3,-52,9,-46;-4,-55,4,-59;;1,4,0,1,-1,0",
"xs13_256o8gkc;xs16_mp3zw31248c;0;-7,-28,-4,-50,-1,-69;;-9,-92;;7,4,0,-1,-1,0",
"xs13_256o8gkc;xs16_mp3zw35426;0;-10,-41;-1,-65;-5,-58;;7,4,0,-1,-1,0",
"xs13_256o8gkc;xs16_mp3zw35ac;0;-13,-52;;-20,-118,-5,-114;;7,4,0,-1,-1,0",
"xs13_256o8gkc;xs16_x3pmzg853z11;0;-8,-70;;-8,-70,-5,-80,-2,-87;;7,-1,0,-1,1,0",
"xs13_25960ui;xs16_04a96z3115a4;0;;;12,-12,13,-26;8,-32;0,4,0,1,-1,0",
"xs13_25960ui;xs16_0c88a52z6952;0;;;13,-12;7,-32,8,-46;8,0,0,-1,1,0",
"xs13_25960ui;xs16_4al960ui;0;-6,-57,3,-125,5,-84;;;-8,-66;-1,0,1,0,0,1",
"xs13_2596zy32552;xs14_3lozx3lo;0;-3,-52;-7,-52,10,-107;10,-81;16,-61,17,-40;20,-10,0,-1,1,0",
"xs13_259m853;xs16_69bk46z321;0;-7,-28,1,-37,11,-61;-4,-24;;-10,-81,-4,-53;0,0,0,1,1,0",
"xs13_25a842ak8;xs15_0o4871z8k96;0;;;13,-43,21,-12;-2,-99,-1,-83;9,0,0,-1,1,0",
"xs13_25a842ak8;xs15_0o4a52z8k96;0;;-2,-60;-8,-74;;-1,4,0,1,-1,0",
"xs13_25a842ak8;xs16_0o4a53z8k96;0;-13,-56;;-20,-122,-5,-118;;-1,4,0,1,-1,0",
"xs13_25a842ak8;xs16_25a842akg8o;0;-4,-43;2,-74;-11,-86;;8,4,-1,0,0,-1",
"xs13_25a88gzwca1;xs16_0ggka53z12ko;0;-13,-44;;-20,-110,-5,-106;;5,-1,-1,0,0,1",
"xs13_25a88gzwca1;xs16_0ggm952z12ko;0;-1,-44;;;;5,-1,-1,0,0,1",
"xs13_25a88gzwca1;xs16_0gjla4z12ko;0;;16,-110;;6,-100,21,-44;5,-1,-1,0,0,1",
"xs13_25a88gzwca1;xs16_31231eg8426;0;;7,-61;3,-68;12,-44;1,-2,0,1,1,0",
"xs13_25a88gzwca1;xs16_g8ge1248cz56;0;-4,-44;2,-75;-11,-87;;5,0,0,-1,1,0",
"xs13_25a88gzwca1;xs16_g8ge1248ge2z01;0;;-11,-12;16,-13;-10,-99,-7,-109;5,0,0,-1,1,0",
"xs13_25a8og84c;xs15_0o4871z3lo;0;-9,-28,-1,-59;5,-67,6,-83;;;-1,4,0,1,-1,0",
"xs13_25a8og84c;xs15_0o4a52z3lo;0;-3,-28;-1,-26;;;-1,4,0,1,-1,0",
"xs13_25a8og84c;xs15_25a8og84213;0;;12,-58;11,-62;9,-60;0,0,1,0,0,1",
"xs13_25a8og84c;xs15_gs252zpic;0;17,-78;13,-62;13,-56,22,-25;;0,4,0,1,-1,0",
"xs13_25a8og84c;xs15_gs25a4z1ac;0;;6,-52;0,-42;;0,4,0,1,-1,0",
"xs13_25a8og84c;xs16_0gs252zg9icz01;0;20,-139,24,-168,24,-106;13,-126;13,-120;11,-114;0,5,0,1,-1,0",
"xs13_25a8og84c;xs16_17842132ak8;0;17,-79;12,-58;;6,-83,9,-61;10,4,-1,0,0,-1",
"xs13_25a8og84c;xs16_3215a8og84c;0;-4,-43;2,-74;-11,-86;;-2,0,1,0,0,1",
"xs13_25a8og84c;xs16_gs25acz1ac;0;;7,-94,22,-98;;15,-32;0,4,0,1,-1,0",
"xs13_25a8oge2;xs15_8kai31e8zw1;0;;6,-48;0,-38;;0,4,1,0,0,-1",
"xs13_25a8oge2;xs16_032qczmp21;0;-4,-39;2,-70;-11,-82;;7,0,0,-1,1,0",
"xs13_25a8oge2;xs16_gs25acz1226;0;;7,-94,22,-98;;15,-32;0,4,0,1,-1,0",
"xs13_25ac0f9;xs15_25ako0ui;0;-3,-24;-1,-22;;;-1,-1,1,0,0,1",
"xs13_25ac0f9;xs16_25acz3115a4;0;;;12,-12;8,-24,9,-38;0,0,0,1,1,0",
"xs13_25ac0f9;xs16_3iarzbc1;0;-4,-35;2,-66;-11,-78;;6,0,0,-1,1,0",
"xs13_25ac0f9;xs16_c88a52z35a4;0;;;11,-12,12,-26;9,-24;8,3,0,-1,-1,0",
"xs13_25ac0f9;xs16_ci530f9z11;0;-10,-37;-1,-61;-5,-54;;0,3,1,0,0,-1",
"xs13_25akg8426;xs15_g853z125ak8;0;-3,-28;-1,-26;;;8,4,0,-1,-1,0",
"xs13_25akg8426;xs16_25akg8421e8;0;16,-75;13,-62;;7,-79,10,-57;0,0,1,0,0,1",
"xs13_25akg8426;xs16_3215a4ozxca1;0;-10,-45;-1,-69;-5,-62;;0,-2,0,1,1,0",
"xs13_25akg8426;xs16_3215akg8426;0;-4,-43;2,-74;-11,-86;;-2,0,1,0,0,1",
"xs13_25akg853;xs15_031i4oz4a521;0;-3,-28;-1,-26;;;7,-1,0,-1,1,0",
"xs13_25akg853;xs15_0g84213z34ak8;0;;11,-75,18,-82;;12,-53;9,4,0,-1,-1,0",
"xs13_25akg853;xs15_358gz0g8k96zw1;0;;;1,-38,6,-37,12,-36;10,-28;10,-1,0,-1,1,0",
"xs13_25akg853;xs16_31i4ozmp21;0;-4,-39;2,-70;-11,-82;;7,0,0,-1,1,0",
"xs13_25akg853;xs16_g8421e8z125a4;0;;5,-67,11,-89,18,-82;-10,-101,-3,-65;14,-28;8,4,0,-1,-1,0",
"xs13_25akg853;xs16_o4a512koz23;0;-10,-41;-1,-65;-5,-58;;0,4,1,0,0,-1",
"xs13_25b8og8o;xs15_0o4a53zbd;0;-2,-28;-2,-34;;;-1,4,0,1,-1,0",
"xs13_25icz69c;xs16_3215a842156;0;-10,-44;-1,-68;-5,-61;;0,-2,0,1,1,0",
"xs13_25iczw1256;xs14_35iczw1256;0;-5,-40;3,-66;;;0,0,1,0,0,1",
"xs13_25iczw1256;xs15_25a4ozx34ac;0;-3,-40;-1,-38;;;-1,-1,1,0,0,1",
"xs13_25iczw1256;xs16_35a4ozx34ac;0;-13,-44;;-20,-110,-5,-106;;-1,-1,1,0,0,1",
"xs13_25iczw1256;xs16_35iczw12pm;0;-10,-40;-1,-64;-5,-57;;5,7,-1,0,0,-1",
"xs13_25iczx1156;xs14_25iczx11da;0;20,-90;;16,-17;-3,-78;0,0,1,0,0,1",
"xs13_25iczx1156;xs15_25iczx11da4;0;20,-92;;18,-12;;0,0,1,0,0,1",
"xs13_25iczx1156;xs15_25iczx1pl2;0;15,-112;-8,-16;18,-12;-3,-105;0,0,1,0,0,1",
"xs13_25iczx1156;xs16_25iczx11dic;0;20,-106,21,-94;;;-2,-88;0,0,1,0,0,1",
"xs13_25iczx1156;xs16_25iczx11dio;0;19,-86;;;-1,-92;0,0,1,0,0,1",
"xs13_2ege1246;xs15_04aabgzc8421;0;13,-62;;;-1,-78,5,-55,10,-36;0,5,0,1,-1,0",
"xs13_2ege1246;xs15_2ege12453;0;16,-74;12,-58;;8,-68,17,-37;0,0,1,0,0,1",
"xs13_2ege1246;xs15_2ege1248go;0;15,-70;;12,-40,19,-19;;0,0,1,0,0,1",
"xs13_2ege1246;xs16_0gbaa4z8k96;0;16,-138;15,-119,19,-148,19,-86;14,-94;8,-132;0,-1,0,1,1,0",
"xs13_2ege1246;xs16_178421ege2;0;15,-70;12,-59;9,-63,12,-41;;9,0,-1,0,0,1",
"xs13_2ege1e8;xs14_2ege1da;0;;;1,-53;6,-47,11,-28;0,0,1,0,0,1",
"xs13_2ege1e8;xs15_2ege1ego;0;;14,-66;8,-66;11,-40;0,0,1,0,0,1",
"xs13_2ego8b5;xs16_0cq231e8z32;0;;11,-54;8,-58;12,-35;7,4,-1,0,0,-1",
"xs13_2ego8b5;xs16_2ego2tic;0;;15,-78;;8,-56,12,-72,15,-28;0,0,1,0,0,1",
"xs13_2lmge2z01;xs14_178bq23;0;-9,-32;;-4,-68;;1,5,0,1,-1,0",
"xs13_2lmge2z01;xs15_0gbq2sgz121;0;;-4,-39;-6,-54;;-1,5,1,0,0,-1",
"xs13_2lmge2z01;xs16_0bq2sgz643;0;-6,-32;3,-72;-3,-58;;0,5,1,0,0,-1",
"xs13_2lmge2z01;xs16_0gbq2sgz321;0;-19,-32,-4,-88;;-14,-98;;-1,5,1,0,0,-1",
"xs13_2lmge2z01;xs16_65lmge2zw1;0;;2,-49;-8,-62;;0,-1,0,1,1,0",
"xs13_2lmge2z01;xs16_gbq2sgz56;0;-10,-33;-1,-57;-5,-50;;0,5,1,0,0,-1",
"xs13_2lmzc96;xs14_651230f9;0;-3,-44;;-10,-60;;2,8,0,-1,-1,0",
"xs13_2lmzc96;xs16_3hu0o8gkc;0;-2,-44;-2,-58;-7,-54;;-2,0,0,1,1,0",
"xs13_2lmzc96;xs16_3pmz4aip;0;;9,-75;1,-75,4,-91;8,-44;0,8,1,0,0,-1",
"xs13_2lmzc96;xs16_ml56z69c;0;-7,-44;-1,-55;;;2,0,-1,0,0,1",
"xs13_2lmzw3426;xs14_2ll2zw3426;0;;8,-42;4,-36;;0,0,1,0,0,1",
"xs13_2lmzw3426;xs14_32arzx1213;0;-3,-54;;-10,-70;;-1,1,1,0,0,1",
"xs13_2lmzw3426;xs15_25aczw1784c;0;-3,-40;-1,-38;;;-1,-1,1,0,0,1",
"xs13_2lmzw3426;xs15_ckl3zw3426;0;-3,-40;3,-58;-3,-52;;0,0,1,0,0,1",
"xs13_2lmzw3426;xs15_g8e123zc93;0;-1,-58;8,-78;-2,-63;8,-40;0,7,1,0,0,-1",
"xs13_2lmzw3426;xs16_0ggo0uh3z56;0;-2,-48;-2,-62;-7,-58;;-2,7,0,1,-1,0",
"xs13_2lmzw3426;xs16_65lmzx3426;0;-7,-40;-1,-51;;;-1,0,1,0,0,1",
"xs13_2lmzw3426;xs16_69lmzx3426;0;;-2,-83;-15,-90,-6,-87;;-1,0,1,0,0,1",
"xs13_2lmzw34a4;xs14_2ll2zw34a4;0;;8,-42;4,-36;;0,0,1,0,0,1",
"xs13_2lmzw34a4;xs14_32arzx1252;0;-3,-54;;-10,-70;;-1,1,1,0,0,1",
"xs13_2lmzw34a4;xs14_3lmzw34a4;0;-5,-44;3,-70;;;0,0,1,0,0,1",
"xs13_2lmzw34a4;xs15_0gs252zpi6;0;-1,-62;8,-82;-2,-67;8,-44;0,8,1,0,0,-1",
"xs13_2lmzw34a4;xs15_252sgzx6ak8;0;-3,-44;-1,-42;;;5,8,-1,0,0,-1",
"xs13_2lmzw34a4;xs15_ckl3zw34a4;0;-3,-44;3,-62;-3,-56;;0,0,1,0,0,1",
"xs13_2lmzw34a4;xs16_69lmzx34a4;0;;-2,-83;-15,-90,-6,-87;;-1,0,1,0,0,1",
"xs13_31231ego;xs16_0ggm93zrm;0;;;16,-12;2,-74;9,0,0,-1,1,0",
"xs13_31231ego;xs16_0ok453z4a9o;0;-3,-49,0,-71;;-6,-62;-7,-67;7,-1,0,-1,1,0",
"xs13_3123qic;xs16_08u156z254c;0;-3,-45,0,-67;;-6,-58;-7,-63;6,-1,0,-1,1,0",
"xs13_3123qic;xs16_32q4goz0db;0;;14,-96;7,-88,11,-40,14,-12;-4,-92,2,-109,2,-61,10,-96;8,-1,0,-1,1,0",
"xs13_3123qic;xs16_4a5123qic;0;-5,-98;-3,-120;-7,-126;-14,-152,-14,-90,-10,-123;-2,0,1,0,0,1",
"xs13_31246w6413;xs15_3lozj4cz11;0;;8,-54;-4,-70,1,-46;;0,0,0,1,1,0",
"xs13_31248ge13;xs15_0358gz8kq221;0;;14,-66;;14,-42;0,-1,0,1,1,0",
"xs13_31248ge13;xs15_0358gzoka221;0;;13,-62;9,-51;15,-43;0,-1,0,1,1,0",
"xs13_31248ge13;xs15_31248ge1246;0;16,-78;14,-66;9,-75;9,-82;0,0,1,0,0,1",
"xs13_31248ge13;xs16_0358gzo4q221z01;0;;;8,-50;14,-44,15,-28;0,-1,0,1,1,0",
"xs13_31248ge13;xs16_g88ge1248goz11;0;;;7,-58;13,-28;10,4,-1,0,0,-1",
"xs13_3146178c;xs14_j9cz11da;0;14,-66;;16,-19;5,-51;0,0,0,1,1,0",
"xs13_3146178c;xs15_0ckl3zok21;0;;-4,-56;-6,-62;;7,-1,0,-1,1,0",
"xs13_3146178c;xs15_0ok213zca23;0;-5,-24;5,-58;;;-1,3,0,1,-1,0",
"xs13_3146178c;xs15_3146178kc;0;16,-74;;16,-26;;0,0,1,0,0,1",
"xs13_3146178c;xs15_3146178ko;0;15,-70;;17,-27;5,-59;0,0,1,0,0,1",
"xs13_3146178c;xs15_gjl8zpi6;0;16,-74;;7,-68;5,-83,13,-50;9,0,0,-1,1,0",
"xs13_3146178c;xs16_ggm93zpi6;0;;;15,-12;3,-66;9,0,0,-1,1,0",
"xs13_3146o8a6;xs14_0kc32acz32;0;-4,-32;3,-45;-3,-50;;1,4,1,0,0,-1",
"xs13_3146o8a6;xs14_252sgzc93;0;;14,-66;6,-53;11,-46;8,0,0,-1,1,0",
"xs13_3146o8a6;xs14_3146o8b5;0;;13,-62;6,-50;9,-53;0,0,1,0,0,1",
"xs13_3146o8a6;xs15_25b8o6413;0;;13,-62;;11,-46;8,0,-1,0,0,1",
"xs13_3146o8a6;xs15_312kozxc871;0;-5,-28;5,-62;;;-1,-2,0,1,1,0",
"xs13_3146o8a6;xs15_3146o8a53;0;;14,-66;6,-50;10,-45;0,0,1,0,0,1",
"xs13_3146o8a6;xs15_358gzwphe2;0;;-4,-56;-6,-62;;-2,-1,0,1,1,0",
"xs13_3146o8a6;xs16_2552sgz0c93;0;;13,-78,14,-66;7,-60;;8,-1,0,-1,1,0",
"xs13_3146o8a6;xs16_3542sgz0c93;0;;12,-58;8,-64;;8,-1,0,-1,1,0",
"xs13_3146o8a6;xs17_39cggkcz0643;0;6,-55;;;-6,-62;0,0,0,1,1,0",
"xs13_3146o8a6;xs18_39cggka4z0643;0;9,-46;;;-2,-49;0,0,0,1,1,0",
"xs13_3146pic;xs15_04ap56zca1;0;;-4,-52;-6,-58;;6,-1,0,-1,1,0",
"xs13_31e86246;xs14_5b8oz0bd;0;-6,-31;-1,-39;-4,-54;;-1,0,0,1,1,0",
"xs13_31e86246;xs15_gbdz1pl2;0;-2,-72;-1,-73;-6,-64;-10,-78;7,3,0,-1,-1,0",
"xs13_31e86246;xs16_gbdz11dio;0;-5,-24;1,-54;;;7,3,0,-1,-1,0",
"xs13_31eg84ko;xs14_321eg84ko;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs13_31eg84ko;xs14_g88a52zc96;0;-7,-38;-1,-49;-6,-62;;-1,4,0,1,-1,0",
"xs13_31eg84ko;xs15_0gjl8zpic;0;-1,-78;-1,-71;-6,-62;-8,-74;-2,4,0,1,-1,0",
"xs13_31eg84ko;xs15_g88a53zc96;0;-7,-39;-1,-47;-5,-58;;-1,4,0,1,-1,0",
"xs13_31eg84ko;xs15_g88b52zc96;0;-6,-38;;-6,-62;;-1,4,0,1,-1,0",
"xs13_31eg84ko;xs16_0ggm93zpic;0;-5,-28;1,-58;;;-2,4,0,1,-1,0",
"xs13_31eg84ko;xs16_0ggm96zpic;0;-7,-28,-6,-44;0,-50;;;-2,4,0,1,-1,0",
"xs13_31ege13;xs14_03lkk8z252;0;;12,-58;7,-45;13,-34;0,-1,0,1,1,0",
"xs13_31ege13;xs14_31ege123;0;;-4,-56;-6,-58,-4,-68;;6,0,-1,0,0,1",
"xs13_31ege13;xs15_03lkk8z256;0;;12,-58;;12,-34;0,-1,0,1,1,0",
"xs13_31ege13;xs15_03lkk8z652;0;;11,-54;7,-43;13,-35;0,-1,0,1,1,0",
"xs13_31ege13;xs15_31ege1246;0;-2,-68;-1,-69;-6,-60;-10,-74;6,0,-1,0,0,1",
"xs13_31ege13;xs15_3lkia4z32;0;;;13,-12;-5,-69;6,0,0,-1,1,0",
"xs13_31ege13;xs16_03lkk8z696;0;;;6,-50;12,-44,13,-28;0,-1,0,1,1,0",
"xs13_31ege13;xs16_03lkk8zc96;0;;;5,-58;11,-28;0,-1,0,1,1,0",
"xs13_31ege13;xs16_gjlkk8z146;0;;17,-91;2,-87,13,-60;3,-94,14,-28;0,-1,0,1,1,0",
"xs13_31egma4;xs14_0mlicz56;0;-6,-28;-1,-36;-4,-51;;6,0,0,-1,1,0",
"xs13_31egma4;xs14_cilmzx252;0;-7,-34;-1,-45;-6,-58;;6,4,0,-1,-1,0",
"xs13_31egma4;xs15_0mlicz1ac;0;-1,-74;-1,-67;-6,-58;-8,-70;6,0,0,-1,1,0",
"xs13_31egma4;xs15_cilmzx256;0;-7,-35;-1,-43;-5,-54;;6,4,0,-1,-1,0",
"xs13_31egma4;xs15_cilmzx652;0;-6,-34;;-6,-58;;6,4,0,-1,-1,0",
"xs13_31egma4;xs16_cilmzx696;0;-7,-28,-6,-44;0,-50;;;6,4,0,-1,-1,0",
"xs13_31egma4;xs16_cilmzx69c;0;-5,-28;1,-58;;;6,4,0,-1,-1,0",
"xs13_31eozca1;xs14_5b8og8426;0;-6,-44;-1,-52;-4,-67;;-1,0,0,1,1,0",
"xs13_31eozca1;xs15_25b8og8426;0;-6,-44;;-6,-68;;-1,-1,0,1,1,0",
"xs13_31eozca1;xs15_358gzwg0t6zw11;0;10,-108;-13,-12;;-12,-98;-2,10,1,0,0,-1",
"xs13_31eozca1;xs16_2eg842132ac;0;;-13,-12;14,-13;-12,-99,-9,-109;3,10,0,-1,-1,0",
"xs13_31eozx1252;xs14_0ggo8a52z56;0;-6,-40;-1,-48;-4,-63;;6,0,0,-1,1,0",
"xs13_31eozx1252;xs15_31eozx121e8;0;15,-101,23,-102;;;3,-85,4,-97;0,0,1,0,0,1",
"xs13_31eozx1252;xs15_31eozx125a4;0;17,-78;;;-3,-68;0,0,1,0,0,1",
"xs13_31eozx1252;xs15_8kih3zx1156;0;16,-98;10,-64;;-1,-88,5,-62,8,-40;7,6,0,-1,-1,0",
"xs13_31eozx1252;xs15_wgs25a4z643;0;;7,-38;15,-23;;0,7,1,0,0,-1",
"xs13_31eozx1252;xs16_31eozx12596;0;15,-70;;;;0,0,1,0,0,1",
"xs13_31eozx1252;xs16_31eozx12pm;0;18,-85;;23,-12;0,-92;0,0,1,0,0,1",
"xs13_31eozx1252;xs16_wggo8a52zc96;0;-5,-40;1,-70;;;6,-1,0,-1,1,0",
"xs13_31eozx1252;xs16_wgs25acz643;0;;15,-70;;5,-100,20,-44;0,7,1,0,0,-1",
"xs13_31kmiczw1;xs15_31kmicz032;0;16,-78;;17,-12;-3,-92;0,0,1,0,0,1",
"xs13_31kmiczw1;xs15_wgbqicz65;0;-5,-32;5,-66;;;-1,5,1,0,0,-1",
"xs13_31kmiczw1;xs15_wmd1e8z65;0;;-4,-48;-6,-54;;5,-1,0,-1,1,0",
"xs13_31kmiczw1;xs16_04s0cp3z6221;0;18,-116;;0,-72,6,-89,6,-41,14,-76;1,-108,5,-60,8,-32;0,6,0,1,-1,0",
"xs13_321eg8426;xs15_6248ge1248c;0;;-11,-27,-4,-48;;-7,-70;8,0,-1,0,0,1",
"xs13_321eg853;xs15_358ge1248c;0;;-11,-23,-4,-44;;-7,-66;7,0,-1,0,0,1",
"xs13_321egma;xs15_6248ge1da;0;;-11,-19,-4,-40;;-7,-62;-2,4,1,0,0,-1",
"xs13_321fgkc;xs16_2eg88bdzx23;0;8,-118,12,-86,15,-70;-9,-58;;-7,-138,1,-119,1,-71,7,-78;0,6,0,1,-1,0",
"xs13_32ac0f9;xs16_178cz3115a4;0;;;12,-12;8,-24,9,-38;0,0,0,1,1,0",
"xs13_32ac0f9;xs16_c871z3115a4;0;;;11,-12,12,-26;9,-24;0,3,0,1,-1,0",
"xs13_32akg8426;xs15_069jzgs243;0;16,-74;14,-66;12,-60,21,-29;;9,0,0,-1,1,0",
"xs13_32akg8426;xs15_358gzwo496z011;0;;13,-62;10,-66;10,-56;10,-1,0,-1,1,0",
"xs13_32akg8426;xs16_0o48a51248cz11;0;-7,-58;-2,-63;-7,-70;;-2,4,1,0,0,-1",
"xs13_32akg8426;xs16_25a84215a8o;0;19,-135,23,-164,23,-102;14,-130;12,-124;12,-110;10,4,-1,0,0,-1",
"xs13_32akg8426;xs16_2eg84215a8o;0;16,-75;13,-62;;7,-79,10,-57;10,4,-1,0,0,-1",
"xs13_32akg853;xs15_0g84213z342sg;0;;11,-54;5,-64;12,-32;9,4,0,-1,-1,0",
"xs13_32akg853;xs16_031i4ozo8b41;0;-7,-54;-2,-59;-7,-66;;7,-1,0,-1,1,0",
"xs13_32akg853;xs16_g8421e8z121e8;0;;5,-67,11,-89,18,-82;-10,-101,-3,-65;14,-28;8,4,0,-1,-1,0",
"xs13_32arz065;xs14_1no31246;0;-9,-40,2,-76;-12,-21,0,-65;;;3,0,0,-1,1,0",
"xs13_32arz065;xs16_03loz622ak8;0;;7,-38;-4,-52,-3,-34;;0,7,1,0,0,-1",
"xs13_32arz065;xs16_c88a52z3lo;0;;6,-34,7,-52;-4,-38;;3,-2,-1,0,0,1",
"xs13_32arz065;xs16_mk4871z1ac;0;-7,-40;-2,-45;-7,-52;;3,-1,-1,0,0,1",
"xs13_32arzx123;xs14_0ggo3tgz32;0;-9,-36,2,-72;-12,-17,0,-61;;;-1,6,0,1,-1,0",
"xs13_32arzx123;xs15_32arzx1253;0;17,-84;;17,-12;;0,0,1,0,0,1",
"xs13_32arzx123;xs16_25a88czc871;0;;7,-46;-4,-60,-3,-42;;5,-2,-1,0,0,1",
"xs13_32arzx123;xs16_31e8zw3115a4;0;;6,-42,7,-60;-4,-46;;5,6,-1,0,0,-1",
"xs13_32arzx123;xs16_32arzx12156;0;;;16,-12;-2,-90;0,0,1,0,0,1",
"xs13_32arzx123;xs16_wmk4871z643;0;-7,-46;-2,-51;-7,-58;;5,-1,-1,0,0,1",
"xs13_32hjkczw1;xs15_03iaczmq1;0;1,-36;0,-35,8,-58;-10,-70,-3,-46;;1,5,1,0,0,-1",
"xs13_32hjkczw1;xs15_32hjkcz032;0;16,-78;;17,-12;-3,-92;0,0,1,0,0,1",
"xs13_32hjkczw1;xs16_0ck31e8z6221;0;-10,-45,-2,-44;-10,-29,-1,-58;-6,-54;;5,-1,0,-1,1,0",
"xs13_32hu066;xs14_8k9b8oz023;0;;9,-46;2,-55;11,-28;6,-1,0,-1,1,0",
"xs13_32hu066;xs15_0bdzad113;0;14,-66,17,-103;11,-69;;12,-81;8,0,0,-1,1,0",
"xs13_32hu066;xs15_0dbzad113;0;14,-81;11,-54,14,-91;15,-69;;8,0,0,-1,1,0",
"xs13_32hu066;xs16_0gbb8ozc93;0;-4,-37;3,-69;-7,-62;;6,-1,0,-1,1,0",
"xs13_32hu0oo;xs16_0c88b5zol3;0;20,-90;;13,-51,14,-28;4,-72,12,-55;0,5,0,1,-1,0",
"xs13_32hu0oo;xs16_0g88brzc93;0;-4,-37;3,-69;-7,-62;;6,-1,0,-1,1,0",
"xs13_32qb96;xs16_04s0fpz6221;0;17,-112;;-1,-76,5,-93,5,-45,13,-80;2,-104,6,-56,9,-28;0,5,0,1,-1,0",
"xs13_32qbzx113;xs16_25a88czc453;0;;7,-46;-4,-60,-3,-42;;5,-2,-1,0,0,1",
"xs13_32qbzx113;xs16_32aczw3115a4;0;;6,-42,7,-60;-4,-46;;5,6,-1,0,0,-1",
"xs13_32qczx1246;xs15_y0g853zggmdz1;0;17,-78;;;-7,-94,-1,-71,4,-52;0,10,1,0,0,-1",
"xs13_32qczx1ac;xs16_x3ia4zggmdz1;0;14,-109,17,-99;-9,-13;18,-12;;0,10,1,0,0,-1",
"xs13_32qkzx346;xs14_32qkzx3426;0;16,-91;;18,-12;-1,-76;0,0,1,0,0,1",
"xs13_32qkzx346;xs14_32qkzx34a4;0;18,-92;;19,-12;-1,-79;0,0,1,0,0,1",
"xs13_32qkzx346;xs15_31eozw122ac;0;;9,-66;0,-80;10,-40;5,7,-1,0,0,-1",
"xs13_32qkzx346;xs15_32qkzx34213;0;18,-84;8,-42;14,-36;-1,-93;0,0,1,0,0,1",
"xs13_32qkzx346;xs15_32qkzx34a6;0;18,-92;;18,-12;;0,0,1,0,0,1",
"xs13_32qkzx346;xs15_32qkzx34ac;0;17,-87;;19,-12;-1,-76;0,0,1,0,0,1",
"xs13_32qkzx346;xs16_32qkzx342ac;0;;;17,-12;-3,-98;0,0,1,0,0,1",
"xs13_33032ako;xs15_358go8a53;0;-5,-63;;;-7,-66,-4,-100;-1,4,1,0,0,-1",
"xs13_33zy4ck8zw66;xs15_db8oz39c;0;-10,-60;-4,-100,0,-119,15,-231;;-8,-248;-9,-10,-1,0,0,1",
"xs13_354264ko;xs13_3lozc96;0;;;4,-50,15,-24;7,-50,10,-28;8,0,0,-1,1,0",
"xs13_354264ko;xs14_3pmzw3426;0;18,-82;;14,-33;1,-70;0,0,0,1,1,0",
"xs13_354264ko;xs14_3pmzw34a4;0;19,-86;;16,-26;1,-73;0,0,0,1,1,0",
"xs13_354264ko;xs15_3pmzw34213;0;14,-86;-6,-12;16,-14;1,-83;0,0,0,1,1,0",
"xs13_354264ko;xs15_3pmzw34a6;0;18,-82;;16,-26;;0,0,0,1,1,0",
"xs13_354264ko;xs15_3pmzw34ac;0;19,-86;;15,-25;1,-70;0,0,0,1,1,0",
"xs13_354264ko;xs16_3pmzw342ac;0;17,-78;;;3,-84;0,0,0,1,1,0",
"xs13_354264ko;xs16_3pmzw34aa4;0;18,-98,19,-86;;;2,-80;0,0,0,1,1,0",
"xs13_354c0cic;xs15_03lka4z643;0;15,-70;;;-4,-88,5,-66;7,0,0,-1,1,0",
"xs13_354c0f9;xs14_5b8o0ui;0;-3,-45;2,-50;-7,-62;;0,-1,1,0,0,1",
"xs13_354c0f9;xs15_25b8o0ui;0;-5,-38;;-7,-62;;-1,-1,1,0,0,1",
"xs13_354c0f9;xs15_4ai30f9z011;0;-5,-24;2,-61,10,-60;2,-54;;0,3,1,0,0,-1",
"xs13_354c0f9;xs16_31e8z3115a4;0;;;12,-12;8,-24,9,-38;0,0,0,1,1,0",
"xs13_354c0f9;xs16_8e13z3115a4;0;;;11,-12,12,-26;9,-24;0,3,0,1,-1,0",
"xs13_354c0f9;xs16_bq23z012156;0;;0,-64;-6,-58;;6,3,0,-1,-1,0",
"xs13_354c0f9;xs16_bq23z012552;0;;1,-60;-8,-66,-7,-78;;6,3,0,-1,-1,0",
"xs13_354djo;xs15_g5r8b5z11;0;-5,-28,-3,-46;5,-66;-1,-66;7,-46,9,-28;5,-1,-1,0,0,1",
"xs13_354djo;xs16_178jd453;0;;12,-104;7,-96,11,-53,14,-13,19,-12,23,-25;0,-125,5,-62,8,-112,10,-67;7,0,-1,0,0,1",
"xs13_354mp3;xs14_j5s246z11;0;15,-70;;11,-21;-2,-58;5,0,0,-1,1,0",
"xs13_354mp3;xs14_j5s252z11;0;16,-74;;13,-14;-2,-61;5,0,0,-1,1,0",
"xs13_354mp3;xs15_354m93zw32;0;11,-86;-9,-12;13,-14;-2,-83;0,0,1,0,0,1",
"xs13_354mp3;xs15_j5s253z11;0;16,-74;;12,-13;-2,-58;5,0,0,-1,1,0",
"xs13_354mp3;xs15_j5s256z11;0;15,-70;;13,-14;;5,0,0,-1,1,0",
"xs13_354mp3;xs16_178jd4ko;0;16,-120;;4,-109,9,-46,12,-96,14,-51;3,-112,7,-69,10,-29,15,-28,19,-41;7,4,-1,0,0,-1",
"xs13_354mp3;xs16_39m453z321;0;14,-66;;;0,-72;5,0,-1,0,0,1",
"xs13_354mp3;xs16_j5s2552z11;0;15,-86,16,-74;;;-1,-68;5,0,0,-1,1,0",
"xs13_356o8a6;xs13_jhe8z65;0;-8,-28;-12,-32,-1,-68;-5,-73;-7,-69;6,1,0,-1,1,0",
"xs13_356o8a6;xs14_25a8o653;0;;13,-62;5,-49;10,-42;7,0,-1,0,0,1",
"xs13_356o8a6;xs14_356o8b5;0;;12,-58;5,-46;8,-49;0,0,1,0,0,1",
"xs13_356o8a6;xs15_25b8o653;0;;12,-58;;10,-42;7,0,-1,0,0,1",
"xs13_356o8a6;xs15_356o8a53;0;;13,-62;5,-46;9,-41;0,0,1,0,0,1",
"xs13_356o8a6;xs16_2552sgz0653;0;;12,-74,13,-62;6,-56;;7,-1,0,-1,1,0",
"xs13_356o8a6;xs16_3542sgz0653;0;;11,-54;7,-60;;7,-1,0,-1,1,0",
"xs13_358e1246;xs15_0ca9jzok21;0;15,-70;;12,-40,19,-19;;0,4,0,1,-1,0",
"xs13_358e1246;xs15_g84213zc953;0;13,-62;;;-1,-78,5,-55,10,-36;8,0,0,-1,1,0",
"xs13_358e1246;xs16_0ci52z6aip;0;16,-138;15,-119,19,-148,19,-86;14,-94;8,-132;9,3,0,-1,-1,0",
"xs13_358e1246;xs16_3ia4zpia6;0;15,-70;12,-59;9,-63,12,-41;;9,0,0,-1,1,0",
"xs13_358go8a6;xs14_358go8b5;0;;13,-62;6,-50;9,-53;0,0,1,0,0,1",
"xs13_358go8a6;xs15_0g84213z3ego;0;-5,-32;2,-64;-4,-54;;-2,4,0,1,-1,0",
"xs13_358go8a6;xs15_25b8og853;0;;13,-62;;11,-46;8,0,-1,0,0,1",
"xs13_358go8a6;xs16_g8421e8z178c;0;-7,-28;10,-65,17,-101;-11,-82,-4,-89,2,-67;;-1,4,0,1,-1,0",
"xs13_358gzw8k96;xs15_69jzwg9iczx1;0;-6,-48;4,-82,13,-87;;6,-48;0,-1,1,0,0,1",
"xs13_358gzw8k96;xs16_358gzwo496zw23;0;10,-108;-17,-12;;-12,-101;0,0,1,0,0,1",
"xs13_358gzw8k96;xs16_4ai3zx1i4ozx121;0;-5,-48;;-4,-71,-1,-81;6,-49;-1,-2,1,0,0,1",
"xs13_358gzw8k96;xs16_ci52zw1i4ozw121;0;-6,-112;4,-146;-6,-132;9,-97,13,-110,13,-48;0,-2,1,0,0,1",
"xs13_358gzw8k96;xs16_g0g84215akoz11;0;13,-126;-13,-12;;-11,-113;5,0,0,-1,1,0",
"xs13_358gzx6jo;xs15_xg853z0gb6z32;0;;;19,-12;-9,-118;6,0,-1,0,0,1",
"xs13_358gzxo9a4;xs16_ggxg8421e8z03421;0;-5,-48;;-4,-71,-1,-81;6,-49;6,-2,0,-1,1,0",
"xs13_35a8og4c;xs15_35a8og8426;0;;11,-54;13,-48;;0,0,1,0,0,1",
"xs13_35akg84c;xs16_1784215ako;0;16,-75;11,-54;;5,-79,8,-57;9,4,-1,0,0,-1",
"xs13_39cggkczx1;xs14_39cggmazx1;0;;11,-54;6,-42;7,-53;0,0,1,0,0,1",
"xs13_39cggkczx1;xs15_0652sgz6413;0;;11,-54;;9,-46;7,0,0,-1,1,0",
"xs13_39cggkczx1;xs15_358gozxc871;0;;-4,-52;-6,-58;;-2,-1,0,1,1,0",
"xs13_39cggkczx1;xs16_3542sgz6413;0;;10,-50;8,-56;;7,0,0,-1,1,0",
"xs13_39cz6952;xs16_3lkczpi6;0;4,-56,14,-66,18,-94;;;-11,-82;0,9,1,0,0,-1",
"xs13_39e0db;xs14_0gbap3z121;0;2,-50;-7,-26;;-9,-66;5,5,0,-1,-1,0",
"xs13_39e0db;xs16_db079ozx32;0;0,-48;-7,-28,-7,-12,7,-59;-9,-71,-2,-47;;5,3,-1,0,0,-1",
"xs13_39e0db;xs16_o970bdz23;0;0,-48;-7,-28,-7,-12,6,-59;-10,-71,-3,-47;;0,3,1,0,0,-1",
"xs13_39e0mq;xs16_gie0dbz146;0;0,-48;-7,-28,-7,-12,7,-59;-9,-71,-2,-47;;0,4,1,0,0,-1",
"xs13_39e0mq;xs16_gie0dbz56;0;0,-48;-7,-28,-7,-12,6,-59;-10,-71,-3,-47;;0,4,1,0,0,-1",
"xs13_3hu06a4;xs14_32hu06a4;0;-6,-28;-1,-36;-4,-51;;-1,0,1,0,0,1",
"xs13_3hu06a4;xs14_3hu06ac;0;15,-70;;;5,-64;0,0,1,0,0,1",
"xs13_3hu06a4;xs15_25ac0fho;0;13,-62;;;1,-52;7,4,-1,0,0,-1",
"xs13_3hu06a4;xs15_4a60uh246;0;-2,-68;-1,-69;-6,-60;-10,-74;6,0,-1,0,0,1",
"xs13_3hu06a4;xs15_gilmz1w256;0;-7,-35;-1,-43;-5,-54;;6,4,0,-1,-1,0",
"xs13_3hu06a4;xs15_gilmz1w652;0;-6,-34;;-6,-58;;6,4,0,-1,-1,0",
"xs13_3hu06a4;xs16_0ga60uh3z32;0;18,-100;;10,-53,13,-34,16,-12;;7,0,-1,0,0,1",
"xs13_3hu06a4;xs16_35ac0fho;0;14,-122,29,-126;;22,-36;;7,4,-1,0,0,-1",
"xs13_3hu06a4;xs16_3hu06996;0;;;7,-42;9,-28;0,0,1,0,0,1",
"xs13_3hu06a4;xs16_3hu06a84c;0;20,-90;;13,-23;1,-78;0,0,1,0,0,1",
"xs13_3hu06a4;xs16_ci60uh3z11;0;14,-66;;19,-25;4,-73;6,0,-1,0,0,1",
"xs13_3hu06a4;xs16_gilmz1w69c;0;-5,-28;1,-58;;;6,4,0,-1,-1,0",
"xs13_3ia4zw1156;xs16_39mggzx4a9o;0;18,-82;;;-2,-88;6,9,-1,0,0,-1",
"xs13_3lo0ui;xs16_0g2u0ol3z121;0;;;12,-12;6,-32,7,-46;7,0,-1,0,0,1",
"xs13_3lo0ui;xs16_8o03iarz0121;0;-7,-28;10,-65,17,-101;-11,-82,-4,-89,2,-67;;5,-2,0,-1,1,0",
"xs13_3lo0ui;xs16_g8hf03loz01;0;;;11,-12,12,-26;7,-32;7,4,-1,0,0,-1",
"xs13_3lozc96;xs15_31248go8gkc;0;-5,-44;2,-76;-4,-66;;-2,-2,0,1,1,0",
"xs13_3lozx3123;xs15_0kc3213z346;0;-6,-36;4,-70,13,-75;;6,-36;0,6,1,0,0,-1",
"xs13_3lozx3123;xs16_4ai3zw23c48c;0;-5,-36;;-4,-59,-1,-69;6,-37;-1,-2,1,0,0,1",
"xs13_3lozx3146;xs15_3lozx312ko;0;;;18,-12;-6,-102;0,0,1,0,0,1",
"xs13_3lozx3146;xs16_4ai3zw23c4go;0;-5,-40;;-4,-63,-1,-73;6,-41;-1,-2,1,0,0,1",
"xs13_3lozx356;xs16_356o8zxo9a4;0;-5,-40;;-4,-63,-1,-73;6,-41;5,7,-1,0,0,-1",
"xs13_3lozx39c;xs15_3lozx358go;0;19,-86;;;1,-80;0,0,1,0,0,1",
"xs13_3lozx39c;xs16_39cggzxhik8zx1;0;-5,-44;;-4,-67,-1,-77;6,-45;5,8,-1,0,0,-1",
"xs13_3lozxbd;xs16_bdggzwhik8zw1;0;-5,-44;;-4,-67,-1,-77;6,-45;4,8,-1,0,0,-1",
"xs13_3pa4zw1246;xs15_3pa4zw115a4;0;20,-97;;16,-12;2,-78;0,0,1,0,0,1",
"xs13_3pa4zw1246;xs15_3pa4zw1248go;0;18,-103;;15,-33,22,-12;;0,0,1,0,0,1",
"xs13_3pa4zw1246;xs16_3pa4zw124871;0;20,-90;;9,-53,15,-51,22,-16;7,-59,14,-67;0,0,1,0,0,1",
"xs13_3pczw1156;xs14_3pczw11da;0;19,-86;;15,-13;-4,-74;0,0,1,0,0,1",
"xs13_3pczw1156;xs15_354kozx12ko;0;-5,-40;5,-74;;;5,7,-1,0,0,-1",
"xs13_3pczw1156;xs15_3pczw11da4;0;19,-92;;17,-12;;0,0,1,0,0,1",
"xs13_3pczw1156;xs15_3pczw1pl2;0;14,-112;-9,-16;17,-12;-4,-105;0,0,1,0,0,1",
"xs13_3pczw1156;xs15_wg8oge13z65;0;;-4,-48;-6,-54;;5,-1,0,-1,1,0",
"xs13_3pczw1156;xs16_3pczw11dic;0;19,-102,20,-90;;;-3,-84;0,0,1,0,0,1",
"xs13_3pczw1156;xs16_3pczw11dio;0;18,-82;;;-2,-88;0,0,1,0,0,1",
"xs13_3pczw1248c;xs15_wg84c84213z65;0;-5,-44;5,-78;;;-1,8,0,1,-1,0",
"xs13_4a960ui;xs16_04a96z4a5113;0;;;12,-12,13,-26;8,-32;0,-1,0,1,1,0",
"xs13_4a960ui;xs16_0c88a52z2596;0;;;13,-12;7,-32,8,-46;8,0,0,-1,1,0",
"xs13_4a960ui;xs16_0cila4z6226;0;-4,-28;-1,-58,1,-107,10,-75;;;-1,4,0,1,-1,0",
"xs13_4aarzx123;xs14_4aarzx1213;0;15,-83;;17,-12;0,-68;0,0,1,0,0,1",
"xs13_4aarzx123;xs15_4aarzx1253;0;17,-84;;17,-12;;0,0,1,0,0,1",
"xs13_4aarzx123;xs15_g88e1e8z056;0;17,-78;;7,-56;0,-87,6,-56;0,6,0,1,-1,0",
"xs13_4aarzx123;xs16_4aarzx12156;0;;;16,-12;-2,-90;0,0,1,0,0,1",
"xs13_4ai3zx1248c;xs16_4ai3zx1248ge2;0;23,-102;;12,-57,18,-55,25,-20;8,-71,15,-79;0,0,1,0,0,1",
"xs13_4ap3zw1252;xs15_1784ozxc952;0;14,-97,22,-98;;;2,-81,3,-93;6,8,-1,0,0,-1",
"xs13_4ap3zw1252;xs15_25a4ozxc952;0;16,-74;;;-4,-64;6,8,-1,0,0,-1",
"xs13_4ap3zw1252;xs16_4ap3zw12596;0;14,-66;;;;0,0,1,0,0,1",
"xs13_4ap3zw1252;xs16_4ap3zw12pm;0;17,-85;;22,-12;-1,-92;0,0,1,0,0,1",
"xs13_5b8og84c;xs15_0321eozc8421;0;;9,-46;3,-62,9,-39,14,-20;;0,-1,0,1,1,0",
"xs13_5b8og84c;xs15_31248go8b5;0;;11,-54;10,-58;8,-56;9,0,-1,0,0,1",
"xs13_5b8og84c;xs15_3542132qk;0;16,-74;12,-58;12,-52,21,-21;;8,4,-1,0,0,-1",
"xs13_5b8og84c;xs15_354c88gzxca1;0;-2,-48;-1,-68;-7,-66;;-1,-1,0,1,1,0",
"xs13_5b8og84c;xs16_0oe123z8k96;0;19,-135,23,-164,23,-102;12,-122;12,-116;10,-110;0,5,0,1,-1,0",
"xs13_5b8og84c;xs16_17842132qk;0;16,-75;11,-54;;5,-79,8,-57;9,4,-1,0,0,-1",
"xs13_5b8og84c;xs16_642138n96;0;-9,-28,-6,-72,-2,-56;;-9,-78;;7,4,-1,0,0,-1",
"xs13_5b8og84c;xs16_gs26413z1ac;0;-6,-39;-2,-62;-5,-58;;-1,4,0,1,-1,0",
"xs13_6246pic;xs16_2eg84cj96;0;-2,-49,1,-71;;-5,-54;-8,-67;-2,4,1,0,0,-1",
"xs13_6248n96;xs15_065la4zca1;0;-2,-48;-2,-58;-5,-54;;6,-1,0,-1,1,0",
"xs13_6248n96;xs16_25a842tic;0;-4,-102;-4,-116;-6,-122;-15,-156,-15,-94,-11,-127;-2,4,1,0,0,-1",
"xs13_6248n96;xs16_2eg842tic;0;-2,-49,1,-71;;-5,-54;-8,-67;-2,4,1,0,0,-1",
"xs13_6413kczx32;xs15_6413kkozx32;0;;11,-54;12,-57;7,-67;0,0,1,0,0,1",
"xs13_6413kczx32;xs15_ck312koz023;0;7,-62;-7,-12;;;5,0,-1,0,0,1",
"xs13_6413kczx32;xs16_3ia4z32c826;0;;-8,-12;15,-13;-7,-83,-4,-93;5,8,-1,0,0,-1",
"xs13_641vg4c;xs15_0c9b8oz253;0;;8,-42;5,-30;3,-45;0,-1,0,1,1,0",
"xs13_641vg4c;xs21_4s0v1aczwdl8;0;-5,-52,3,-80,10,-92;5,-86,15,-70;7,-60;7,-78;6,-1,-1,0,0,1",
"xs13_6421eozx32;xs15_0312koz31243;0;5,-60;;;-9,-66;0,7,1,0,0,-1",
"xs13_651i4ozw121;xs14_651i4ozw321;0;11,-86;-9,-12;;;0,0,1,0,0,1",
"xs13_651i4ozw121;xs15_01784oz35421;0;3,-81,4,-69;;;-14,-86,-6,-85;0,7,1,0,0,-1",
"xs13_651i4ozw121;xs15_025a4oz35421;0;10,-52;;;-8,-62;0,7,1,0,0,-1",
"xs13_651i4ozw121;xs16_035a4oz35421;0;10,-102;-10,-12;;-8,-89;0,7,1,0,0,-1",
"xs13_651i4ozw121;xs16_651i4ozwbc1;0;7,-84;-14,-12;;-9,-77;0,0,1,0,0,1",
"xs13_652sga6;xs14_2552sga6;0;;-2,-52;-6,-58;;-1,0,1,0,0,1",
"xs13_652sga6;xs15_ca9jzw1256;0;;3,-52;-3,-46;;6,4,0,-1,-1,0",
"xs13_652sga6;xs15_ca9jzw3452;0;;2,-40;-4,-50;;6,4,0,-1,-1,0",
"xs13_6952zy1cic;xs15_699m4k8zx11;0;14,-111,20,-90;-10,-21;;;2,9,0,1,-1,0",
"xs13_696zx8kic;xs20_w33z0c88gkczca23;0;10,-153;20,-90;6,-102,7,-71;2,-155,5,-70;13,-3,0,-1,-1,0",
"xs13_69e0mq;xs13_39e0db;0;0,-28;-2,-22;;;0,4,1,0,0,-1",
"xs13_69e0mq;xs13_39e0mq;0;2,-48;;;-7,-58;0,0,1,0,0,1",
"xs13_69e0mq;xs14_25is0qm;0;-4,-62,2,-66;-16,-73,-13,-12;;;-1,5,1,0,0,-1",
"xs13_69e0mq;xs15_69is0qm;0;-5,-32,4,-44;-6,-12;;;-1,5,1,0,0,-1",
"xs13_69e0mq;xs15_bd0ehr;0;0,-28;-5,-20;;;5,4,-1,0,0,-1",
"xs13_69e0mq;xs15_kc0si96z11;0;3,-57;-9,-12,-4,-38;;;5,-1,-1,0,0,1",
"xs13_69e0mq;xs16_0g8ie0dbz23;0;-5,-88,3,-101,3,-53,9,-84;-7,-12,-4,-40,0,-88;-9,-96;;-2,4,1,0,0,-1",
"xs13_69e0mq;xs16_3pab8oz023;0;;-13,-17,4,-57,11,-78;-3,-66;-8,-62;5,4,0,-1,-1,0",
"xs13_69jzx12ko;xs16_8e1248gzy312453;0;16,-117,19,-107;-9,-13;20,-12;;7,11,0,-1,-1,0",
"xs13_8e13zdb;xs14_31e8gzwbd;0;;-23,-37;-4,-38;;3,0,-1,0,0,1",
"xs13_8e13zdb;xs16_o8bdzw178c;0;-2,-44;-6,-13;;;-2,8,1,0,0,-1",
"xs13_8e13zqm;xs15_g8e13z1qm;0;-5,-52,0,-48;-7,-28;;;-1,0,1,0,0,1",
"xs13_8ljgzx256;xs16_3ia4z122ako;0;-4,-41;3,-73,6,-63;;7,-40;0,-2,1,0,0,1",
"xs13_8ljgzx346;xs15_8ljgzx34213;0;18,-82;;8,-52;-1,-91,5,-60;0,0,1,0,0,1",
"xs13_8ljgzx346;xs15_8ljgzx34a6;0;18,-92;;18,-12;;0,0,1,0,0,1",
"xs13_8ljgzx346;xs16_8ljgzx342ac;0;;;17,-12;-3,-98;0,0,1,0,0,1",
"xs13_bdggkczw1;xs14_amggdbzx1;0;;10,-50;5,-38;6,-49;5,0,-1,0,0,1",
"xs13_bdggkczw1;xs14_bdggka4zw1;0;;11,-54;5,-41;8,-42;0,0,1,0,0,1",
"xs13_bdggkczw1;xs15_bdggka6zw1;0;;11,-54;5,-38;7,-41;0,0,1,0,0,1",
"xs13_bdggkczw1;xs15_bdggma4zw1;0;;10,-50;;8,-42;0,0,1,0,0,1",
"xs13_bdggkczw1;xs16_bdggm93zw1;0;;9,-46;7,-52;;0,0,1,0,0,1",
"xs13_bdggkczw1;xs16_bdggm96zw1;0;;10,-66,11,-54;6,-48;;0,0,1,0,0,1",
"xs13_bdggkczw1;xs18_0bdggkcz4a43;0;8,-47;;;-5,-50;-1,0,1,0,0,1",
"xs13_brz34a4;xs15_25a84c0c4go;0;-16,-51,-11,-44;6,-159,12,-131;;;3,8,0,-1,-1,0",
"xs13_brz34a4;xs15_25iczw5b8o;0;-9,-71,-1,-110;-3,-85;-8,-112,-7,-142,1,-109;8,-44;3,8,-1,0,0,-1",
"xs13_brz34a4;xs15_358go8gka4;0;;;-6,-89;3,-90,6,-44;4,-1,0,-1,1,0",
"xs13_brz34a4;xs15_bdzdj8gzw1;0;-5,-59;;-8,-115;6,-44,9,-69;0,-2,1,0,0,1",
"xs13_c88a52z33;xs15_0c88a52z2552;0;12,-59;;;-6,-54;-1,0,1,0,0,1",
"xs13_c88a52z33;xs15_0c88a52z653;0;6,-95;-18,-12;;-10,-94;-1,0,1,0,0,1",
"xs13_c88a52z33;xs15_0c88a52zc93;0;12,-175,18,-147;-22,-19,-17,-12;;;-1,0,1,0,0,1",
"xs13_c88a52z33;xs15_bdz3115a4;0;;-11,-27;12,-12,15,-37;-14,-131;0,8,1,0,0,-1",
"xs13_c88a52z33;xs15_c88a52z39c;0;;;18,-12,23,-19;-17,-147,-11,-175;0,0,1,0,0,1",
"xs13_c88a52z33;xs15_c88a52zbd;0;15,-131;-14,-37,-11,-12;12,-27;;0,0,1,0,0,1",
"xs13_c88a52z33;xs15_oggka23z66;0;;;-1,-91,0,-75;6,-67,14,-36;0,-1,1,0,0,1",
"xs13_c88a52z33;xs15_oggka52z66;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs13_c88a52z33;xs15_ogila4z66;0;;5,-30;-1,-40;;0,-1,1,0,0,1",
"xs13_c88a52z33;xs16_0c88a52zol3;0;9,-90,17,-105;-15,-12;;-11,-86,-10,-105;-1,0,1,0,0,1",
"xs13_c88a52z33;xs16_g88brzdb;0;-7,-36;2,-60;-2,-53;;4,6,-1,0,0,-1",
"xs13_c88a52z33;xs16_g8hf033z56;0;;16,-79;3,-67;9,-36;0,0,0,1,1,0",
"xs13_c88a52z33;xs16_oggka53z66;0;;10,-106,25,-110;;18,-44;0,-1,1,0,0,1",
"xs13_c88a52z33;xs16_oggm952z66;0;;;;6,-36;0,-1,1,0,0,1",
"xs13_c88a52z33;xs16_ogjla4z66;0;-10,-36;;-17,-102,-2,-98;;0,-1,1,0,0,1",
"xs13_c88a52z33;xs19_033z628czw3115a4;0;6,-112;;18,-12;-15,-133,-9,-104;-2,13,1,0,0,-1",
"xs13_c88a52z33;xs19_033zc826z3115a4;0;10,-104,16,-133;-17,-12;;-5,-112;0,13,1,0,0,-1",
"xs13_c9jzbd;xs16_0c9jzgjl8z1;0;10,-109,13,-99;-13,-13;14,-12;;-1,0,1,0,0,1",
"xs13_c9jzw1156;xs15_0312kozca23;0;;8,-42;6,-36;;5,-1,-1,0,0,1",
"xs13_c9jzw1156;xs15_c9jzw11da4;0;19,-92;;17,-12;;0,0,1,0,0,1",
"xs13_c9jzw1156;xs15_g853z1164ko;0;;;-3,-74;7,-40;0,-2,1,0,0,1",
"xs13_ca168ozx32;xs15_ca168ozwca1;0;14,-94;-8,-12;;;0,0,1,0,0,1",
"xs13_ca168ozx32;xs15_gj12koz1243;0;5,-60;;;-9,-66;0,7,1,0,0,-1",
"xs13_ci52z39c;xs14_ci53z39c;0;;9,-46;5,-40;;0,0,1,0,0,1",
"xs13_ci52z39c;xs15_25a84c84213;0;;;15,-12;-11,-110;3,0,0,-1,1,0",
"xs13_ci52z39c;xs15_cp3z342sg;0;;5,-61,13,-62;7,-45,8,-57;;0,8,1,0,0,-1",
"xs13_ci52z39c;xs15_cp3z34ak8;0;;7,-38;1,-28;;0,8,1,0,0,-1",
"xs13_ci52z39c;xs16_3215a84c826;0;;8,-61;4,-68;13,-44;3,-2,0,-1,1,0",
"xs13_ci52z39c;xs16_cp3z34ako;0;;17,-110;;7,-100,22,-44;0,8,1,0,0,-1",
"xs13_ci52zbd;xs14_ci53zbd;0;;9,-46;5,-40;;0,0,1,0,0,1",
"xs13_ci52zbd;xs15_0ci52zojd;0;;-13,-12;15,-12;-20,-115,-11,-110;-1,0,1,0,0,1",
"xs13_ci52zbd;xs15_drz342sg;0;;5,-61,13,-62;7,-45,8,-57;;0,8,1,0,0,-1",
"xs13_ci52zbd;xs15_drz34ak8;0;;7,-38;1,-28;;0,8,1,0,0,-1",
"xs13_ci52zbd;xs15_ggc48a52z56;0;1,-72,9,-81;-17,-12,-10,-16;;-8,-78;3,7,0,-1,-1,0",
"xs13_ci52zbd;xs16_17842642ak8;0;10,-109,13,-99;-13,-13;14,-12;;-1,10,0,1,-1,0",
"xs13_ci52zbd;xs16_drz34ako;0;;17,-110;;7,-100,22,-44;0,8,1,0,0,-1",
"xs13_ci52zbd;xs16_g8jdzdmz11;0;;8,-61;4,-68;13,-44;0,-2,1,0,0,1",
"xs13_ci52zbd;xs16_wci52zg8jdz01;0;15,-160;-20,-74,-20,-12,-16,-61;15,-76;-11,-174;-2,0,1,0,0,1",
"xs13_ci52zw1248c;xs15_xg84215a4zca1;0;20,-111;;17,-33,24,-12;;0,10,0,1,-1,0",
"xs13_ci52zw1248c;xs16_0g84213z34ako;0;;17,-110;;7,-100,22,-44;0,8,1,0,0,-1",
"xs13_ci52zw1248c;xs16_0g84215a84cz32;0;;8,-61;4,-68;13,-44;0,8,0,1,-1,0",
"xs13_ci52zw1248c;xs16_4ai3zx1248a52;0;22,-98;;11,-53,17,-51,24,-16;7,-67,14,-75;8,9,0,-1,-1,0",
"xs13_ci52zw1248c;xs16_ci52zw1248a52;0;21,-158;8,-91,12,-120,12,-58;19,-66;1,-152;0,0,1,0,0,1",
"xs13_dbgzbd;xs16_0dbgzgjl8z1;0;-5,-45;2,-77,5,-67;;6,-44;-1,8,1,0,0,-1",
"xs13_dbgzw1156;xs15_3pmzx32ac;0;-5,-40;;-12,-79,-3,-74;7,-40;-1,-1,1,0,0,1",
"xs13_dbgzw1156;xs15_wo8b52zbd;0;19,-92;;17,-12;;0,8,1,0,0,-1",
"xs13_dbgzw1156;xs16_0ggc453zo9a4;0;-5,-41;2,-73,5,-63;;6,-40;-1,7,1,0,0,-1",
"xs13_dbgzw1156;xs16_25iczw1164ko;0;-12,-102,-12,-40,-8,-89;7,-124;-3,-138;7,-104;-2,-2,1,0,0,1",
"xs13_dbgzw1156;xs16_dbgzw11dic;0;19,-102,20,-90;;;-3,-84;0,0,1,0,0,1",
"xs13_dbgzw1156;xs16_dbgzw11dio;0;18,-82;;;-2,-88;0,0,1,0,0,1",
"xs13_dj8gzx346;xs15_031i4ozc8701;0;;;-5,-50,0,-49,6,-48;4,-40;5,-1,-1,0,0,1",
"xs13_dj8gzx346;xs15_g853z121ego;0;;5,-62,12,-69;;6,-40;0,-2,1,0,0,1",
"xs13_dj8gzx346;xs16_0g8ge13zo9a4;0;-5,-41;2,-73,5,-63;;6,-40;-1,7,1,0,0,-1",
"xs13_dj8gzx346;xs16_dj8gzx342ac;0;;;17,-12;-3,-98;0,0,1,0,0,1",
"xs13_djozx352;xs14_djozx356;0;18,-82;;;0,-76;0,0,1,0,0,1",
"xs13_djozx352;xs15_djozx31e8;0;14,-97,22,-98;;;2,-81,3,-93;0,0,1,0,0,1",
"xs13_djozx352;xs15_djozx354c;0;;;13,-43,21,-12;-8,-123,-7,-107;0,0,1,0,0,1",
"xs13_djozx352;xs15_djozx35a4;0;16,-74;;;-4,-64;0,0,1,0,0,1",
"xs13_djozx352;xs15_g853z123ck8;0;;5,-62,12,-69;;6,-40;0,-2,1,0,0,1",
"xs13_djozx352;xs16_032qkzmp3;0;;-18,-12,-12,-86;12,-110,20,-16;0,-158;0,9,1,0,0,-1",
"xs13_djozx352;xs16_0g8o652zo9a4;0;-5,-41;2,-73,5,-63;;6,-40;-1,7,1,0,0,-1",
"xs13_djozx352;xs16_djozx31248c;0;14,-107,17,-100,20,-90;;20,-34;;0,0,1,0,0,1",
"xs13_djozx352;xs16_djozx35ac;0;16,-97;;18,-12;-4,-110;0,0,1,0,0,1",
"xs13_djozx352;xs16_djozx3pm;0;17,-85;;22,-12;-1,-92;0,0,1,0,0,1",
"xs13_djozx352;xs16_kq23zw35426;0;13,-160,21,-98;9,-120,15,-70;;-5,-160;7,6,0,-1,-1,0",
"xs13_djozx352;xs16_xg8o65123z321;0;21,-132;;13,-53,16,-34,19,-12;;0,10,0,1,-1,0",
"xs13_g0s2pmz11;xs14_0g0s2pmz121;0;4,-63;-12,-12;;-11,-76;-1,0,1,0,0,1",
"xs13_g0s2pmz11;xs14_gba952z23;0;1,-72;;;-11,-74,-9,-84;5,5,0,-1,-1,0",
"xs13_g0s2pmz11;xs15_0g0s2pmz321;0;4,-60;-12,-12;;-10,-71;-1,0,1,0,0,1",
"xs13_g0s2pmz11;xs15_0gba952z123;0;;-11,-12;;-11,-76;5,6,0,-1,-1,0",
"xs13_g0s2pmz11;xs15_259abgzx65;0;4,-83;-6,-50;-3,-46;-11,-74;5,0,0,-1,1,0",
"xs13_g0s2pmz11;xs16_0gba952z343;0;5,-74;-12,-12,-11,-28;;;5,6,0,-1,-1,0",
"xs13_g0s2pmz11;xs16_0gba952z643;0;6,-82;-10,-12;;;5,6,0,-1,-1,0",
"xs13_g84213zdd;xs14_0g84213zol3;0;6,-102,15,-117;-12,-17;;-26,-134,-13,-100;-1,0,1,0,0,1",
"xs13_g84213zdd;xs14_3pa4zw1248c;0;8,-89,15,-114;;15,-12;-10,-96;-1,8,1,0,0,-1",
"xs13_g84213zdd;xs15_g84213z5b8o;0;9,-187,30,-183;-13,-94,-13,-12;13,-104;-1,-175;0,0,1,0,0,1",
"xs13_g84213zdd;xs15_g84213zdlz11;0;17,-147;-16,-37,-13,-12;14,-27;;0,0,1,0,0,1",
"xs13_g84213zdd;xs15_xg8og853zca1;0;15,-121;-13,-12,-10,-58;;;-3,0,0,1,1,0",
"xs13_g853zdl8;xs14_02ll2zok21;0;7,-76;;;-15,-82;3,9,-1,0,0,-1",
"xs13_g853zdl8;xs14_32arzca1;0;21,-100;;14,-12;;3,8,-1,0,0,-1",
"xs13_g853zdl8;xs16_358gzcild;0;17,-111,26,-114;;;-5,-107;3,0,-1,0,0,1",
"xs13_g853zdl8;xs16_358gzckld;0;;;18,-12;-6,-95;3,0,-1,0,0,1",
"xs13_g853zdl8;xs16_3hu0og8426;0;18,-94;;13,-12;-5,-98;4,9,0,-1,-1,0",
"xs13_g88m96z121;xs15_259m88czx23;0;-1,-41,16,-74;;-8,-72,4,-59,12,-36;7,-65;0,6,0,1,-1,0",
"xs13_g8ge96z121;xs15_0ggci96z343;0;11,-85;-11,-12,-7,-38;-3,-44;;5,7,-1,0,0,-1",
"xs13_g8ka23z56;xs16_0g8k4871zbc1;0;;12,-58;7,-51;12,-46;0,-1,1,0,0,1",
"xs13_g8ka23z56;xs16_0g8ka23zo9a4;0;9,-101,12,-91;-12,-13;13,-12;;-1,0,1,0,0,1",
"xs13_g8ka52z56;xs16_0g8ka52zo9a4;0;9,-101,12,-91;-12,-13;13,-12;;-1,0,1,0,0,1",
"xs13_g8ka52z56;xs16_dj8gzw12pm;0;;10,-57;6,-64;15,-40;5,-2,-1,0,0,1",
"xs13_g8ka52z56;xs16_g8ka5123z56;0;;16,-83;3,-71;9,-40;0,0,1,0,0,1",
"xs13_ggc871z65;xs16_32q4gzx11mq;0;;13,-84;2,-69;11,-40;6,-2,-1,0,0,1",
"xs13_ggca23z65;xs16_wok4871zdb;0;;12,-58;7,-51;12,-46;0,-1,1,0,0,1",
"xs13_ggca52z65;xs16_bdggzw12pm;0;;10,-57;6,-64;15,-40;0,7,1,0,0,-1",
"xs13_ggca52z65;xs16_g8kc3213z56;0;;16,-83;3,-71;9,-40;0,0,0,1,1,0",
"xs13_ggca52z65;xs16_y0g853z8o65z32;0;-4,-51;;-3,-82;3,-78,12,-40;0,-4,1,0,0,1",
"xs13_ghn8426z1;xs16_4ai3z6221e8;0;14,-67;11,-54;;5,-71,8,-49;8,0,0,-1,1,0",
"xs13_gjloz56;xs15_0db8ozok21;0;-4,-40;3,-72;-3,-62;;-1,7,1,0,0,-1",
"xs13_gjloz56;xs15_321fgs26;0;15,-70;;11,-35;4,-73;0,7,0,1,-1,0",
"xs13_gjloz56;xs15_358gz3lp1;0;12,-90,19,-97;;13,-12;;3,9,-1,0,0,-1",
"xs13_gjloz56;xs15_g84213z11db;0;-2,-40;-4,-48,2,-49,7,-50;;;3,-1,-1,0,0,1",
"xs13_gjloz56;xs15_j96z11db;0;-5,-40;5,-74,14,-79;;7,-40;3,-1,-1,0,0,1",
"xs13_gjloz56;xs16_04ai3z3lp1;0;9,-101,12,-91;-12,-13;13,-12;;3,9,-1,0,0,-1",
"xs13_gjloz56;xs16_0ci52zmq23;0;-5,-104;5,-138;-5,-124;10,-89,14,-102,14,-40;0,-2,1,0,0,1",
"xs13_gjloz56;xs16_3ia4z32qm;0;-4,-40;;-3,-63,0,-73;7,-41;3,-2,-1,0,0,1",
"xs13_j5c48cz11;xs14_5bo8goz32;0;-3,-41;2,-46;-7,-58;;0,-1,1,0,0,1",
"xs13_j5c48cz11;xs14_jhke13z1;0;17,-78;9,-53;11,-40;-1,-68;0,5,0,1,-1,0",
"xs13_j5c48cz11;xs15_0j9c84cz123;0;-5,-34;;-7,-58;;-1,5,1,0,0,-1",
"xs13_j5c48cz11;xs15_31ke13z65;0;14,-71;;11,-33,18,-12;;0,5,0,1,-1,0",
"xs13_j5c48cz11;xs15_6iog853z32;0;12,-58;;;-4,-74,2,-51,7,-32;0,6,1,0,0,-1",
"xs13_j5c48cz11;xs15_c48c9jzx65;0;-5,-34;2,-71;-3,-74;9,-32;5,5,-1,0,0,-1",
"xs13_j5c48cz11;xs16_0j9c84cz643;0;;0,-60;-6,-54;;-1,5,1,0,0,-1",
"xs13_j5c48cz11;xs16_25icz643146;0;15,-134;12,-107,16,-136,16,-74;13,-82;5,-128;7,0,0,-1,1,0",
"xs13_j5c48cz11;xs16_j5c48ge2z11;0;14,-66;9,-47;8,-51,11,-29;;0,0,1,0,0,1",
"xs13_j5c4goz11;xs15_628c9jzx65;0;-5,-32;2,-69,10,-68;2,-62;;5,5,-1,0,0,-1",
"xs13_j5c4goz11;xs16_0j9c826z643;0;;0,-60;-6,-54;;-1,5,1,0,0,-1",
"xs13_j96zdb;xs15_3pmzcip;0;12,-110,21,-115;-14,-12;14,-12;;2,9,-1,0,0,-1",
"xs13_j96zdb;xs16_69jzgjl8z1;0;;-13,-12;14,-13;-12,-99,-9,-109;2,0,-1,0,0,1",
"xs13_j96zdd;xs14_0j96zol3;0;6,-97,15,-112;-12,-12;;-26,-129,-13,-95;-1,0,1,0,0,1",
"xs13_j96zdd;xs15_0ok213zcip;0;15,-121;-13,-12,-10,-58;;;2,9,-1,0,0,-1",
"xs13_j96zdd;xs15_dbzj5oz11;0;17,-147;-16,-37,-13,-12;14,-27;;0,10,1,0,0,-1",
"xs13_j96zdd;xs15_j96z5b8o;0;9,-187,30,-183;-13,-94,-13,-12;13,-104;-1,-175;0,0,1,0,0,1",
"xs13_jhe8z65;xs14_5b8o6426;0;-6,-40;-1,-48;-4,-63;;-1,0,0,1,1,0",
"xs13_jhe8z65;xs15_25b8o6426;0;-6,-40;;-6,-64;;-1,-1,0,1,1,0",
"xs13_jhe8z65;xs16_3542sgzwdb;0;-5,-40;1,-70;;;-2,-1,1,0,0,1",
"xs13_kq23z1ac;xs15_2eg8og84213;0;14,-98,21,-105;;15,-12;;4,0,0,-1,1,0",
"xs13_kq23z1ac;xs16_178421321e8;0;11,-109,14,-99;-12,-13;15,-12;;0,10,0,1,-1,0",
"xs13_kq23z6a4;xs14_1784c0f9;0;20,-92;;13,-12;;3,0,0,-1,1,0",
"xs13_kq23z6a4;xs16_04a9jzo8b5;0;6,-123,9,-107;-14,-12;;-15,-107;3,9,-1,0,0,-1",
"xs13_kq23z6a4;xs16_1784c0f96;0;;;17,-12;-5,-87;3,0,0,-1,1,0",
"xs13_kq23z6a4;xs16_2eg8o0uh3;0;17,-86;;12,-12;-4,-90;4,0,0,-1,1,0",
"xs13_o4pb8oz01;xs15_259q4gozw23;0;10,-79;-10,-14,-6,-40;-4,-46;;-1,6,0,1,-1,0",
"xs13_o4pb8oz01;xs15_25t28cz321;0;15,-73;9,-49;11,-43,20,-12;;0,5,0,1,-1,0",
"xs13_o861acz23;xs14_ca168ozx65;0;7,-83,19,-87;;;-16,-94,-5,-86;5,0,-1,0,0,1",
"xs13_o861acz23;xs15_0o861acz643;0;;-11,-15;13,-15;-18,-102,-9,-97;-1,0,1,0,0,1",
"xs13_o861acz23;xs15_4a9jzxpi6;0;-2,-48,7,-61;-14,-12,-7,-16;;-6,-58;5,0,0,-1,1,0",
"xs13_o861acz23;xs16_0o861aczc452;0;8,-104,11,-94,14,-86;-11,-24;18,-12;;-1,0,1,0,0,1",
"xs13_o861acz23;xs16_25iczw116853;0;13,-144;-18,-74,-18,-12,-14,-61;13,-76;-9,-158;-2,8,1,0,0,-1",
"xs13_oe1246z23;xs15_6421eozwca1;0;11,-82,18,-89;;12,-12;;5,0,-1,0,0,1",
"xs13_oe1246z23;xs15_8ljgzx1qm;0;-1,-56,7,-65;-15,-12,-8,-16;;-6,-62;5,0,0,-1,1,0",
"xs13_oe1246z23;xs16_0oe1246zc452;0;8,-93,11,-83;-11,-13;12,-12;;-1,0,1,0,0,1",
"xs13_ol3zw3213;xs15_ckl3zx3213;0;-1,-81;-8,-43;;-12,-78;-1,0,1,0,0,1",
"xs13_ol3zw3213;xs16_3ia4z32c84c;0;-4,-37;3,-69,6,-59;;7,-36;0,-2,1,0,0,1",
"xs13_ol3zw3213;xs16_o8624871z056;0;17,-78;;13,-20,21,-21;0,-82,9,-53;0,7,1,0,0,-1",
"xs13_w8o652zca1;xs16_xog8421e8z253;0;;-13,-12;14,-13;-12,-99,-9,-109;-1,0,0,1,1,0",
"xs13_wg8o652z65;xs15_256o8gzy212ko;0;9,-100;-12,-12;;-11,-90;7,0,-1,0,0,1",
"xs13_wg8o652z65;xs15_312kozy1354c;0;;9,-77,17,-78;11,-61,12,-73;;0,7,0,1,-1,0",
"xs13_wg8o652z65;xs15_312kozy135a4;0;;11,-54;5,-44;;0,7,0,1,-1,0",
"xs13_wg8o652z65;xs15_wg8o652z69c;0;11,-102,20,-107;-13,-12;13,-12;;0,0,1,0,0,1",
"xs13_wg8o652z65;xs16_312kozxo8b5;0;18,-156,24,-106;8,-140,16,-78;4,-140;;0,7,0,1,-1,0",
"xs13_wg8o652z65;xs16_312kozy131248c;0;;16,-104;;8,-81,11,-62,14,-40;0,7,0,1,-1,0",
"xs13_wg8o652z65;xs16_312kozy135ac;0;;11,-69;5,-82;13,-40;0,7,0,1,-1,0",
"xs13_wg8o652z65;xs16_358gozxo8b5;0;-9,-40,-3,-114;;9,-130;7,-138,15,-44;0,7,1,0,0,-1",
"xs13_wg8o652z65;xs16_358gozy131248c;0;;9,-87,12,-80,15,-70;;15,-70;0,7,1,0,0,-1",
"xs13_wg8o652z65;xs16_4ai3zx123ck8;0;;-12,-12;13,-13;-11,-91,-8,-101;-1,9,1,0,0,-1",
"xs13_wg8o652z65;xs16_djozx312ko;0;;12,-58;8,-65;17,-41;7,-2,-1,0,0,1",
"xs13_wggka23z252;xs15_xggka23z4a52;0;12,-93;-12,-12;;;-1,0,1,0,0,1",
"xs13_wggka23z252;xs15_xggka23zc452;0;12,-107,13,-123;-16,-12,-8,-43;;;-1,0,1,0,0,1",
"xs13_wggka23z252;xs16_32q4gzx1078k8;0;;14,-66;9,-59;14,-54;9,-1,0,-1,1,0",
"xs13_wggka23z252;xs16_dj8gzx342sg;0;9,-99;-11,-12;;-18,-111;-2,7,0,1,-1,0",
"xs13_wggka23z252;xs16_xgjla4zc452;0;14,-130,29,-134;;22,-12;;7,8,-1,0,0,-1",
"xs13_wggka52z252;xs15_xggka52z4a52;0;12,-93;-12,-12;;;-1,0,1,0,0,1",
"xs13_wggka52z252;xs16_dj8gzx34ak8;0;9,-99;-11,-12;;-18,-111;-2,7,0,1,-1,0",
"xs13_wggm93z252;xs14_25iczx115a4;0;14,-77;12,-69;;8,-71,17,-40;7,-1,-1,0,0,1",
"xs13_wggm96z252;xs15_wggka52z696;0;12,-93;-12,-12;;;6,8,-1,0,0,-1",
"xs13_wggm96z252;xs15_wggm96z696;0;13,-93;-11,-12;;;0,0,1,0,0,1",
"xs13_wggm96z252;xs15_wgila4z696;0;13,-72;;;-7,-62;6,8,-1,0,0,-1",
"xs13_wggm96z252;xs16_0ggm96zrm;0;14,-85;;19,-12;-4,-92;1,0,1,0,0,1",
"xs13_wggm96z252;xs16_dj8gzx34aa4;0;9,-99;-11,-12;;-18,-111;-2,7,0,1,-1,0",
"xs13_wggm96z252;xs16_wggm952z696;0;;-8,-12;;;6,8,-1,0,0,-1",
"xs13_wggm96z252;xs16_wgjla4z696;0;13,-97;;15,-12;-7,-110;6,8,-1,0,0,-1",
"xs13_wgila4z252;xs14_wgila4z652;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs13_wgila4z252;xs14_wgjla4z252;0;-2,-40;6,-66;;;0,0,1,0,0,1",
"xs13_wgila4z252;xs15_4aligzx4a52;0;13,-72;;;-7,-62;6,0,-1,0,0,1",
"xs13_wgila4z252;xs15_8ka52zw115a4;0;-2,-40;8,-65;;;6,-1,-1,0,0,1",
"xs13_wgila4z252;xs15_xgila4z4a52;0;12,-93;-12,-12;;;-1,0,1,0,0,1",
"xs13_wgila4z252;xs15_xgila4zc452;0;12,-107,13,-123;-16,-12,-8,-43;;;-1,0,1,0,0,1",
"xs13_wgila4z252;xs16_03ihla4z252;0;-1,-40;5,-71;-8,-83;;0,0,1,0,0,1",
"xs13_wgila4z252;xs16_0g88a52z12pm;0;-7,-40;2,-64;-2,-57;;6,7,-1,0,0,-1",
"xs13_wgila4z252;xs16_0gila4zrm;0;14,-85;;19,-12;-4,-92;1,0,1,0,0,1",
"xs13_wgila4z252;xs16_4aligzxca52;0;13,-97;;15,-12;-7,-110;6,0,-1,0,0,1",
"xs13_wgila4z252;xs16_dj8gzx34a52;0;9,-99;-11,-12;;-18,-111;-2,7,0,1,-1,0",
"xs13_wgila4z252;xs16_wmlla4z252;0;-4,-40;2,-51;;;0,0,1,0,0,1",
"xs14_01784ozc8421;xs16_wg84215a8oz65;0;7,-94;-11,-12;;-14,-90;5,10,0,-1,-1,0",
"xs14_0252sgz6413;xs15_0352sgz6413;0;-4,-40;4,-66;;;0,0,1,0,0,1",
"xs14_0252sgz6413;xs15_252sgzol3;0;10,-81;-11,-12;;-10,-86;1,0,1,0,0,1",
"xs14_0252sgz6413;xs15_25a8o64ko;0;2,-54,15,-70;;;-1,-63;1,0,0,1,1,0",
"xs14_0252sgz6413;xs16_1784ozc82611;0;;-4,-61,-3,-49;-9,-66,-1,-65;;0,-1,1,0,0,1",
"xs14_0252sgz6413;xs16_2552sgz6413;0;;-4,-31;-4,-46;;0,0,1,0,0,1",
"xs14_0252sgz6413;xs16_25a4ozc82611;0;-2,-40;0,-38;;;0,-1,1,0,0,1",
"xs14_0252sgz6413;xs16_358gozw8k871;0;12,-102;-12,-12;;;-1,9,1,0,0,-1",
"xs14_0252sgz6413;xs16_wkc32ak8z65;0;3,-76;;;-13,-82;5,8,0,-1,-1,0",
"xs14_025a4ozc8421;xs16_25ak8gzog8421;0;-2,-44;0,-42;;;0,-1,1,0,0,1",
"xs14_025ak8z6511;xs16_25ak8gzca221;0;-2,-40;0,-38;;;0,-1,1,0,0,1",
"xs14_025iczcip;xs16_25akg842156;0;-2,-48;0,-46;;;0,-1,0,1,1,0",
"xs14_025iczcip;xs16_32akg842156;0;;-4,-57,-3,-45;-9,-62,-1,-61;;0,-1,0,1,1,0",
"xs14_02ll2zok21;xs16_31248c2dio;0;-2,-48;-5,-54,4,-68;;;0,9,0,1,-1,0",
"xs14_031eozok21;xs16_25b8og84213;0;-5,-48;;-5,-72;;0,-1,0,1,1,0",
"xs14_031eozok21;xs16_31248go8a53;0;-6,-48;0,-56;-4,-67;;0,9,0,1,-1,0",
"xs14_032ak8z4aa4;xs16_039m4koz311;0;6,-76;-8,-20,8,-54;-4,-61,3,-50,10,-33,13,-12;5,-64;1,6,1,0,0,-1",
"xs14_032qkzc93;xs16_3146o8ge13;0;;10,-70;1,-84;11,-44;0,8,0,1,-1,0",
"xs14_032qkzc93;xs16_358gzwhhmazw1;0;13,-110;-13,-12;;;-1,10,1,0,0,-1",
"xs14_0354k8zok21;xs16_08ljgz0g8421z32;0;-4,-48;3,-85;-1,-92;8,-52;0,-2,1,0,0,1",
"xs14_0354k8zok21;xs16_25b88gzg8421z11;0;-4,-48;;-6,-72;;0,-1,1,0,0,1",
"xs14_0358gz8ka221;xs16_0g8ge1248goz121;0;11,-72;;;-13,-82;5,10,0,-1,-1,0",
"xs14_0358gz8ka221;xs16_0g8ge1248goz23;0;14,-123,15,-139;-18,-12,-10,-43;;;5,10,0,-1,-1,0",
"xs14_0358gz8ka221;xs16_31248ge12ko;0;10,-98,16,-96,19,-86;-11,-24;19,-14;;1,0,0,1,1,0",
"xs14_0358gz8ka221;xs16_358gzwg89a4z0121;0;-4,-48;3,-80;-3,-70;;-1,-2,1,0,0,1",
"xs14_0358gz8ka221;xs16_8k8ge1248gozw1;0;15,-76;;;-9,-66;5,10,0,-1,-1,0",
"xs14_03hik8z643;xs15_8kih3zx3426;0;3,-80;;;-13,-82,-11,-92;5,0,-1,0,0,1",
"xs14_03hik8z643;xs16_8kih3zx34a6;0;;-13,-12;;-13,-92;5,0,-1,0,0,1",
"xs14_03lkk8z252;xs15_25a88gz4a511;0;-4,-40;3,-55;-7,-68;;0,-1,1,0,0,1",
"xs14_03lkk8z252;xs16_03lkia4z252;0;;9,-46;11,-31;;0,0,1,0,0,1",
"xs14_03lkk8z252;xs16_03lkk8z25a4;0;13,-68;;;-7,-58;0,0,1,0,0,1",
"xs14_03lkk8z252;xs16_08ljgz8ka221;0;-4,-42;3,-79;-2,-82;10,-40;0,-2,1,0,0,1",
"xs14_03lkk8z252;xs16_25a84k8z06511;0;15,-70;;;5,-55;0,7,1,0,0,-1",
"xs14_03lkk8z252;xs16_25a88gz4ad11;0;-4,-40;;-6,-64;;0,7,1,0,0,-1",
"xs14_03lkk8z252;xs16_31ege12ko;0;8,-90,14,-88,17,-78;-9,-32;17,-22;;1,0,0,1,1,0",
"xs14_03lkk8z252;xs16_8kkl3zx254c;0;12,-107,13,-123;-16,-12,-8,-43;;;5,0,-1,0,0,1",
"xs14_03lkk8z252;xs16_8kkl3zx25a4;0;12,-93;-12,-12;;;5,0,-1,0,0,1",
"xs14_03pmzdb;xs16_03pmzdjo;0;12,-110,21,-115;-14,-12;14,-12;;0,0,1,0,0,1",
"xs14_04al56z311;xs16_65la4zx1156;0;15,-86;;16,-12;-6,-100;5,0,-1,0,0,1",
"xs14_04al96z311;xs16_69la4zx1156;0;15,-86;;16,-12;-6,-100;5,0,-1,0,0,1",
"xs14_04ap56z311;xs16_65pa4zx1156;0;15,-86;;16,-12;-6,-100;5,0,-1,0,0,1",
"xs14_04s39cz321;xs15_g88bp46z23;0;2,-76;;;-12,-78,-10,-88;5,6,0,-1,-1,0",
"xs14_04s39cz321;xs16_8ljgozx6413;0;5,-89;-8,-40;-4,-46;-12,-80;-2,6,0,1,-1,0",
"xs14_04s39cz321;xs16_c93s4zx1253;0;;-12,-12;;-12,-84;5,0,-1,0,0,1",
"xs14_05b88gzc8421;xs16_g8421eg8426z11;0;;6,-66,13,-73;;7,-44;5,8,0,-1,-1,0",
"xs14_065la4z321;xs16_358gzwckla4;0;1,-44,6,-63,12,-86;;;-10,-70;-1,9,1,0,0,-1",
"xs14_065la4z321;xs16_wg842ticz65;0;5,-82;-9,-16;;-12,-78;5,8,0,-1,-1,0",
"xs14_08k453z4a43;xs15_0g88a52z8k96;0;;13,-72;3,-59;10,-44;0,-1,1,0,0,1",
"xs14_08k453z4a43;xs15_0g88b5z8k96;0;;12,-61;3,-49;8,-44;0,-1,1,0,0,1",
"xs14_08k453z4a43;xs16_0g88a53z8k96;0;;13,-73;3,-57;9,-44;0,-1,1,0,0,1",
"xs14_08k453z4a43;xs16_0g88b52z8k96;0;;12,-68;;10,-44;0,-1,1,0,0,1",
"xs14_08k453z4a43;xs16_wgjl8zg9icz01;0;-2,-48;7,-88;3,-81;10,-44;0,-2,1,0,0,1",
"xs14_08k8a53z321;xs15_0ck8a53z321;0;-2,-36;2,-46;;;0,0,1,0,0,1",
"xs14_08k8a53z321;xs16_w8ka952z6521;0;0,-67;;;-12,-82;-1,0,0,1,1,0",
"xs14_08lb8oz321;xs14_69m88czw23;0;7,-74;-11,-12;;;0,6,1,0,0,-1",
"xs14_08lb8oz321;xs15_25icggozx56;0;-1,-59,4,-88;-18,-12,-3,-45;;-12,-81;-1,7,1,0,0,-1",
"xs14_08lb8oz321;xs16_0c88m93z6421;0;;5,-55;-2,-44,5,-36,12,-32;8,-36;6,6,-1,0,0,-1",
"xs14_08lb8oz321;xs16_39m88a6zw23;0;15,-73;9,-49;11,-43,20,-12;;0,6,1,0,0,-1",
"xs14_08lb8oz321;xs16_39m88cz0643;0;-3,-36;;-10,-75,-1,-70;9,-36;0,6,1,0,0,-1",
"xs14_08lb8oz321;xs16_69icggozx56;0;0,-63;;;-12,-78;-1,7,1,0,0,-1",
"xs14_08lb8oz321;xs16_c88m93zca1;0;;7,-58;1,-68;8,-36;5,6,-1,0,0,-1",
"xs14_08o0e93z321;xs15_025a8cz6513;0;-1,-54;-4,-30;-3,-46;;-1,0,0,1,1,0",
"xs14_08o0e93z321;xs16_xca952z6513;0;;12,-58;12,-43;;7,6,0,-1,-1,0",
"xs14_08o0e96z321;xs15_025a8cz2553;0;-1,-54;-4,-30;-3,-46;;-1,0,0,1,1,0",
"xs14_08o0e96z321;xs15_xc8a52z2553;0;;-17,-12,-8,-43;-2,-49;-12,-89;-1,0,0,1,1,0",
"xs14_08o0e96z321;xs16_0259acz6513;0;;;12,-16;2,-48,11,-36;7,6,0,-1,-1,0",
"xs14_08o0e96z321;xs16_o8bdzx3156;0;14,-66;-1,-47;2,-61,19,-21;;7,0,0,-1,1,0",
"xs14_08o0e96z321;xs16_xca952z2553;0;0,-67;;;-12,-82;-1,0,0,1,1,0",
"xs14_08o0uh3z32;xs15_08o0uh23z32;0;;10,-59;7,-44;12,-36;0,0,1,0,0,1",
"xs14_08o0uh3z32;xs16_8ljgozx628c;0;16,-74;12,-60;7,-69;8,-68;8,0,0,-1,1,0",
"xs14_08o0uh3z32;xs16_w4s0c93z3521;0;;12,-60;;12,-36;7,6,-1,0,0,-1",
"xs14_08o652z254c;xs15_08o653z254c;0;;10,-50;8,-55;;0,0,1,0,0,1",
"xs14_08o652z254c;xs15_0ggc93z4a9o;0;-3,-44;7,-67;-3,-82;6,-62;0,-1,1,0,0,1",
"xs14_08o652z254c;xs16_0354k8z8kc32;0;11,-116;-15,-12;;-14,-102;5,9,-1,0,0,-1",
"xs14_08o652z254c;xs16_0ggca23z4a9o;0;;;-1,-99,0,-83;6,-75,14,-44;0,-1,1,0,0,1",
"xs14_08o652z254c;xs16_0ggca52z4a9o;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs14_08o652z69c;xs16_0ggc871zcip;0;;7,-69,15,-70;9,-53,10,-65;;0,-1,1,0,0,1",
"xs14_08o652z69c;xs16_0ggca23zcip;0;;;-1,-99,0,-83;6,-75,14,-44;0,-1,1,0,0,1",
"xs14_08o652z69c;xs16_0ggca52zcip;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs14_08o652z69c;xs16_0jhe8zcip;0;-3,-63;1,-64;1,-82;9,-58,9,-44;0,-1,1,0,0,1",
"xs14_08o6952z321;xs14_g88m552z121;0;7,-74;-11,-12;;;0,0,0,1,1,0",
"xs14_08o6952z321;xs15_08o69icz321;0;;;-14,-143,9,-125;13,-36;0,0,1,0,0,1",
"xs14_08o6952z321;xs15_w8o6952z2521;0;;-17,-12,-8,-43;-2,-49;-12,-89;-1,0,1,0,0,1",
"xs14_08o6952z321;xs16_wg0si96z2543;0;0,-67;;;-12,-82;6,7,-1,0,0,-1",
"xs14_08objoz32;xs15_0bt066z65;0;4,-59;-8,-16;;-11,-74;5,5,0,-1,-1,0",
"xs14_08objoz32;xs15_3pq32ac;0;-1,-36,12,-72;1,-37;;;5,4,-1,0,0,-1",
"xs14_08objoz32;xs16_0bdz32139c;0;-5,-61,-2,-36;12,-107;;9,-51;5,-2,-1,0,0,1",
"xs14_08objoz32;xs16_0c48c93z6413;0;-8,-36;7,-80,13,-109;-4,-126,4,-88;;6,6,-1,0,0,-1",
"xs14_08objoz32;xs16_0c93z32139c;0;-13,-43,-8,-36;9,-151,15,-123;;;5,-2,-1,0,0,1",
"xs14_08objoz32;xs16_0dbz32139c;0;-2,-51;;-5,-107;9,-36,12,-61;5,-2,-1,0,0,1",
"xs14_08objoz32;xs16_39cz32139c;0;;;-8,-123,-2,-151;15,-36,20,-43;5,-2,-1,0,0,1",
"xs14_08objoz32;xs16_g0bt06ioz11;0;;3,-88,11,-126;-6,-109,0,-80;15,-36;5,6,0,-1,-1,0",
"xs14_08objoz32;xs16_g8objoz56;0;6,-91;-8,-28;;-13,-82;0,0,1,0,0,1",
"xs14_08p78cz321;xs15_08p784cz321;0;13,-78,14,-66;;14,-18;;0,0,1,0,0,1",
"xs14_08p78cz321;xs15_08p78k8z321;0;14,-66;;15,-18;3,-53;0,0,1,0,0,1",
"xs14_08p78cz321;xs16_08p78kcz321;0;14,-66;;14,-18;;0,0,1,0,0,1",
"xs14_08p78cz321;xs16_08p78koz321;0;13,-62;;15,-19;3,-51;0,0,1,0,0,1",
"xs14_08p78cz321;xs16_0jhegoz643;0;-3,-36;;-10,-75,-1,-70;9,-36;0,-1,1,0,0,1",
"xs14_08p78cz321;xs16_c88m453z065;0;14,-66;10,-54;9,-58;3,-75;0,0,0,1,1,0",
"xs14_08u156z65;xs16_08u156z69c;0;11,-102,20,-107;-13,-12;13,-12;;0,0,1,0,0,1",
"xs14_08u156z65;xs16_358gzx2fgkc;0;;-12,-17;;-18,-102,-11,-95;-2,9,1,0,0,-1",
"xs14_08u15a4z32;xs16_08u15a8oz32;0;;;10,-43,18,-12;-3,-91,-2,-75;0,0,1,0,0,1",
"xs14_08u15a4z32;xs16_08u15ak8z32;0;15,-70;;;7,-55;0,0,1,0,0,1",
"xs14_08u15a4z32;xs16_ciligzx101ac;0;2,-76;;;-12,-82;6,0,0,-1,1,0",
"xs14_08u15a4z32;xs16_w8u15a4zca1;0;11,-94;-11,-12;;;-1,0,1,0,0,1",
"xs14_08u1e8z321;xs15_8e1u8zx1252;0;-1,-59,4,-88;-18,-12,-3,-45;;-12,-81;5,0,-1,0,0,1",
"xs14_08u1e8z321;xs16_08u1egoz321;0;;13,-62;7,-62;10,-36;0,0,1,0,0,1",
"xs14_09fg4cz321;xs16_39q4goz643;0;-1,-36;-9,-19,-4,-16;;;0,6,1,0,0,-1",
"xs14_09v04a4z32;xs16_09v04a52z32;0;;11,-54;11,-39;;0,0,1,0,0,1",
"xs14_09v04a4z32;xs16_09v04aa4z32;0;14,-66;;;8,-51;0,0,1,0,0,1",
"xs14_09v04a4z32;xs16_09v04ak8z32;0;15,-70;;;7,-55;0,0,1,0,0,1",
"xs14_09v04a4z32;xs16_3hu08k8z641;0;-1,-36;-9,-19,-4,-16;;;0,-1,1,0,0,1",
"xs14_09v04a4z32;xs16_w9v04a4zca1;0;11,-94;-11,-12;;;-1,0,1,0,0,1",
"xs14_09v04a4z32;xs16_x9v04a4z6421;0;2,-76;;;-12,-82;-2,0,1,0,0,1",
"xs14_0bq2sgz32;xs16_31kmge13zw1;0;;10,-62;1,-76;11,-36;0,6,0,1,-1,0",
"xs14_0bq2sgz32;xs16_31kmge2z032;0;;12,-58;8,-58;9,-40;0,6,0,1,-1,0",
"xs14_0brz69k8;xs15_25iczoja4;0;-5,-48;4,-68;-5,-86,2,-61;;3,9,-1,0,0,-1",
"xs14_0brz69k8;xs16_0ok213zci9gzw1;0;;;-5,-93;4,-94,7,-48;0,-1,1,0,0,1",
"xs14_0brz69k8;xs16_1784c842ak8;0;-8,-75,0,-114;-2,-89;-7,-116,-6,-146,2,-113;9,-48;-1,-1,0,1,1,0",
"xs14_0brzrm;xs16_0ok213zmc1z11;0;;;-5,-93;4,-94,7,-48;0,-1,1,0,0,1",
"xs14_0bt066z32;xs15_0bt0652z32;0;15,-70;;7,-46;5,-55;0,0,1,0,0,1",
"xs14_0bt066z32;xs15_0bt06a4z32;0;;12,-58;8,-43;4,-58;0,0,1,0,0,1",
"xs14_0bt066z32;xs16_0bdz3213146;0;13,-62,16,-99;10,-65;;11,-77;7,0,0,-1,1,0",
"xs14_0bt066z32;xs16_0bt06246z32;0;13,-77;10,-50,13,-87;14,-65;;0,0,1,0,0,1",
"xs14_0bt066z32;xs16_0bt0628cz32;0;19,-86,24,-113;;;8,-133,14,-81;0,0,1,0,0,1",
"xs14_0bt066z32;xs16_0bt06413z32;0;;16,-74,21,-101;11,-121,17,-69;;0,0,1,0,0,1",
"xs14_0bt066z32;xs16_0bt0653z32;0;;17,-78;5,-65;7,-56;0,0,1,0,0,1",
"xs14_0bt066z32;xs16_0bt0696z32;0;;;11,-12;3,-39;0,0,1,0,0,1",
"xs14_0bt066z32;xs16_0bt06acz32;0;20,-90;;10,-44;2,-77;0,0,1,0,0,1",
"xs14_0bt066z32;xs16_0bt06ioz32;0;;16,-74;9,-58,15,-63;2,-94,10,-100;0,0,1,0,0,1",
"xs14_0bt066z32;xs16_0mq0c93z641;0;19,-86;;5,-82,13,-88;6,-70,12,-75;0,-1,1,0,0,1",
"xs14_0bt066z32;xs16_wbt066zca1;0;11,-94;-11,-12;;;-1,0,1,0,0,1",
"xs14_0bt066z32;xs16_wg8objoz65;0;2,-72;;;-12,-78;5,7,0,-1,-1,0",
"xs14_0c88a52z253;xs16_0oggka23z4a6;0;;;0,-95,1,-79;7,-71,15,-40;0,-1,1,0,0,1",
"xs14_0c88a52z253;xs16_0oggka52z4a6;0;;10,-50;4,-40;;0,-1,1,0,0,1",
"xs14_0c88a52z253;xs16_0ogila4z4a6;0;;6,-34;0,-44;;0,-1,1,0,0,1",
"xs14_0c88b5z253;xs15_8o0uh23z23;0;;-10,-26;;-17,-98;5,6,0,-1,-1,0",
"xs14_0c88b5z253;xs16_25aczw311da;0;12,-93;-12,-12;;;-1,8,1,0,0,-1",
"xs14_0ci52z8ld;xs13_brz34a4;0;15,-70;;;;1,8,1,0,0,-1",
"xs14_0ci52z8ld;xs14_178c48a52;0;13,-73;;12,-12;-1,-53;4,8,0,-1,-1,0",
"xs14_0ci52z8ld;xs15_25iczwd54c;0;;-12,-14;;-19,-102;4,0,-1,0,0,1",
"xs14_0ci52z8ld;xs16_03lkcz8k96;0;12,-102;-12,-12;;-12,-96;4,9,-1,0,0,-1",
"xs14_0ck3146z321;xs16_354268ozxca1;0;14,-66;;;8,-60;0,6,0,1,-1,0",
"xs14_0ck3146z321;xs16_3pmxkczx321;0;;;13,-12;-1,-62;0,6,1,0,0,-1",
"xs14_0ck8a52z321;xs16_0o8gka23z643;0;;;0,-91,1,-75;7,-67,15,-36;0,-1,1,0,0,1",
"xs14_0ck8a52z321;xs16_0o8gka52z643;0;;10,-50;4,-40;;0,-1,1,0,0,1",
"xs14_0cp3033z32;xs15_0cp30352z32;0;;14,-66;8,-51;6,-58;0,0,1,0,0,1",
"xs14_0cp3zrm;xs16_314628c48a6;0;13,-118,22,-123;-15,-12;15,-12;;3,0,0,-1,1,0",
"xs14_0cp3zrm;xs16_rdz06bgzx23;0;;;-2,-82;8,-48;0,9,1,0,0,-1",
"xs14_0cp3zrq;xs15_3124628c4go;0;7,-105,16,-120;-13,-12;;-27,-137,-14,-103;-1,10,0,1,-1,0",
"xs14_0cp3zrq;xs16_0g84c826413z32;0;16,-129;-14,-12,-11,-58;;;3,10,0,-1,-1,0",
"xs14_0cp3zrq;xs16_3pczggmbz1;0;9,-149,17,-182,18,-152;-16,-12;11,-78,19,-39;-5,-125;3,0,-1,0,0,1",
"xs14_0cq1e8z321;xs15_0cq1daz321;0;;;0,-61;5,-55,10,-36;0,0,1,0,0,1",
"xs14_0cq1e8z321;xs16_0cq1egoz321;0;;13,-62;7,-62;10,-36;0,0,1,0,0,1",
"xs14_0cq23z69c;xs16_0ok453zcip;0;-6,-44;4,-84;-5,-70;;0,-1,1,0,0,1",
"xs14_0drz69k8;xs15_0drz69ko;0;18,-82;;;-4,-76;0,0,1,0,0,1",
"xs14_0drz69k8;xs15_25a84264213;0;;2,-62,14,-66;-9,-73,2,-65;;3,9,0,-1,-1,0",
"xs14_0drz69k8;xs16_0ck3123z4a43;0;-8,-48,-1,-52;-6,-44,2,-53;1,-50;;3,1,-1,0,0,1",
"xs14_0drz69k8;xs16_25a842642ac;0;-4,-48;;-11,-87,-2,-82;8,-48;3,9,0,-1,-1,0",
"xs14_0drz69k8;xs16_25akg84c84c;0;16,-74;;;-8,-64;4,10,0,-1,-1,0",
"xs14_0drz69k8;xs16_31248c48gka4;0;;6,-70,13,-77;;7,-48;4,-2,0,-1,1,0",
"xs14_0drz69k8;xs16_32akg84c84c;0;14,-97,22,-98;;;-2,-81,-1,-93;4,10,0,-1,-1,0",
"xs14_0g02596z3452;xp2_phhzw65kczy1hhj;1;4,-62,11,-73;11,-54;2,-45,9,-34;-12,-82;10,0,0,-1,1,0",
"xs14_0g0s2pmz121;xs16_0gba952z1252;0;1,-46;-5,-12;;;6,6,0,-1,-1,0",
"xs14_0g0s2pmz121;xs16_6ag0s2pmzx1;0;-3,-36,0,-58,6,-84;;-5,-68;-9,-94;-1,0,1,0,0,1",
"xs14_0g0s2pmz121;xs16_wg0s2pmz2521;0;11,-85;-11,-12;;;-1,0,1,0,0,1",
"xs14_0g0s2pmz121;xs16_wg0s2pmz4701;0;1,-93,2,-81;;;-16,-98,-8,-97;-1,0,1,0,0,1",
"xs14_0g0si52z343;xs15_0g0si53z343;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs14_0g0si52z343;xs15_c87p8zx1252;0;20,-135;-13,-40;13,-48;-20,-114;0,7,1,0,0,-1",
"xs14_0g0si52z343;xs16_1784ozx11696;0;;8,-73,16,-74;10,-57,11,-69;;7,-1,-1,0,0,1",
"xs14_0g0si52z343;xs16_25a4ozx11696;0;;10,-50;4,-40;;7,-1,-1,0,0,1",
"xs14_0g6p2sgz121;xs16_wg6p2sgz2521;0;11,-85;-11,-12;;;-1,0,1,0,0,1",
"xs14_0g6p2sgz121;xs16_wg6p2sgz4701;0;1,-93,2,-81;;;-16,-98,-8,-97;-1,0,1,0,0,1",
"xs14_0g6p3zbc1;xs15_0g6p3z3kp;0;9,-113,22,-124;;18,-12;-7,-115;0,0,1,0,0,1",
"xs14_0g6p3zbc1;xs16_3542akg8426;0;13,-98,20,-105;;14,-12;;4,0,0,-1,1,0",
"xs14_0g6p3zbc1;xs16_3p6gzw1cjo;0;;-13,-12;15,-12;-20,-115,-11,-110;4,0,-1,0,0,1",
"xs14_0g84213z8ld;xs15_32qbzx1248c;0;;-12,-22;;-19,-110;-1,8,1,0,0,-1",
"xs14_0g84213zol3;xs16_xg84213z0mdz32;0;;12,-62;7,-66;9,-48;0,-2,1,0,0,1",
"xs14_0g84213zol3;xs16_xg8og84213zca1;0;11,-116;-14,-12;;-13,-106;-2,0,0,1,1,0",
"xs14_0g84213zrq;xs16_358go8gzy312ko;0;16,-129;-14,-12,-11,-58;;;-3,10,0,1,-1,0",
"xs14_0g8421e8z1226;xs16_8k453zw124871;0;;15,-70;9,-70;12,-44;8,0,0,-1,1,0",
"xs14_0g8421e8z1226;xs18_0o4ai3z11wo9a4;0;;-8,-49,-5,-69;-11,-82,-2,-64;;-2,7,0,1,-1,0",
"xs14_0g8421egoz32;xs15_0g84213z122qk;0;16,-74;;18,-19;5,-59;0,0,0,1,1,0",
"xs14_0g8421egoz32;xs16_025b88gzog8421;0;18,-82;;18,-26;;9,6,0,-1,-1,0",
"xs14_0g8421egoz32;xs16_035a88gzog8421;0;17,-78;;19,-27;5,-67;9,6,0,-1,-1,0",
"xs14_0g8421egoz32;xs16_0g8421eg84cz32;0;18,-82;12,-62;13,-66;5,-91;0,0,1,0,0,1",
"xs14_0g8ehrz121;xs16_0g8jd453z23;0;11,-99,12,-115;-15,-12,-7,-43;;;5,7,0,-1,-1,0",
"xs14_0g8ehrz121;xs16_o8gka52z643;0;11,-85;-11,-12;;;5,7,-1,0,0,-1",
"xs14_0g8ge1e8z23;xs16_x8k453z255d;0;-2,-56;-5,-58;-5,-58;;-1,0,0,1,1,0",
"xs14_0g8jq23z23;xs16_08o0kq23z643;0;-2,-36;10,-60;-2,-70;;0,-1,0,1,1,0",
"xs14_0g8jq23z23;xs16_1784czx3553;0;;10,-50,15,-74;1,-58;;0,6,1,0,0,-1",
"xs14_0g8ob96z23;xs15_g8ob96z56;0;0,-62;-7,-29;-4,-50;;1,0,1,0,0,1",
"xs14_0g8ob96z23;xs16_wg8ob96z643;0;-2,-52;-5,-54;-5,-54;;-1,0,1,0,0,1",
"xs14_0gba96z123;xs15_69ab8ozx32;0;0,-61,0,-36;0,-34;;;5,0,-1,0,0,1",
"xs14_0gba96z123;xs16_69abgzx1256;0;4,-66;-8,-12;;;5,0,-1,0,0,1",
"xs14_0gbaa4z1252;xs16_025ak8z255d;0;14,-66;;;-6,-56;5,8,-1,0,0,-1",
"xs14_0gbaa4z643;xs15_25iczxd552;0;0,-67,5,-96;-19,-12,-4,-45;;-13,-89;-1,8,1,0,0,-1",
"xs14_0gbaicz321;xs16_g8id1egoz11;0;;11,-62;2,-76;12,-36;5,6,0,-1,-1,0",
"xs14_0gbap3z121;xs15_0gbap3z321;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs14_0gbap3z121;xs16_3pabgzx1252;0;11,-85;-11,-12;;;5,0,-1,0,0,1",
"xs14_0gbb8oz123;xs15_0gbb8oz343;0;9,-86;-11,-12;;;0,0,1,0,0,1",
"xs14_0gbb8oz123;xs15_c88b9czw33;0;0,-61,0,-36;0,-34;;;5,6,-1,0,0,-1",
"xs14_0gbb8oz123;xs16_039cz311da4;0;;;-9,-123,-3,-151;14,-36,19,-43;5,-2,-1,0,0,1",
"xs14_0gbb8oz123;xs16_039cz4ad113;0;-14,-43,-9,-36;8,-151,14,-123;;;0,-2,1,0,0,1",
"xs14_0gbb8oz123;xs16_259mggozx66;0;2,-63;;;-12,-78;-1,7,1,0,0,-1",
"xs14_0gbb8oz123;xs16_25b88cz0653;0;-10,-36;2,-71;-2,-70;;0,6,1,0,0,-1",
"xs14_0gbb8oz123;xs16_25b88cz6413;0;;2,-88,10,-126;-7,-109,-1,-80;14,-36;0,6,1,0,0,-1",
"xs14_0gbb8oz123;xs16_25b88czwbd;0;-6,-61,-3,-36;11,-107;;8,-51;0,6,1,0,0,-1",
"xs14_0gbb8oz123;xs16_25b88czwdb;0;-3,-51;;-6,-107;8,-36,11,-61;0,6,1,0,0,-1",
"xs14_0gbb8oz123;xs16_35akggozx66;0;4,-66;-8,-12;;;-1,7,1,0,0,-1",
"xs14_0gbb8oz123;xs16_gill2z1w652;0;-3,-36;;-2,-59;;5,-1,-1,0,0,1",
"xs14_0gbb8oz123;xs16_gjlmz1w652;0;;7,-70;3,-71;15,-36;5,-1,-1,0,0,1",
"xs14_0gbb8oz123;xs16_jhkmz1w652;0;-9,-36;6,-80,12,-109;-5,-126,3,-88;;5,-1,-1,0,0,1",
"xs14_0gbb8oz321;xs16_039cz3115ac;0;;;-9,-123,-3,-151;14,-36,19,-43;5,-2,-1,0,0,1",
"xs14_0gbb8oz321;xs16_039czca5113;0;-14,-43,-9,-36;8,-151,14,-123;;;0,-2,1,0,0,1",
"xs14_0gbb8oz321;xs16_35a88cz0653;0;-10,-36;2,-71;-2,-70;;0,6,1,0,0,-1",
"xs14_0gbb8oz321;xs16_35a88cz6413;0;;2,-88,10,-126;-7,-109,-1,-80;14,-36;0,6,1,0,0,-1",
"xs14_0gbb8oz321;xs16_35a88czwbd;0;-6,-61,-3,-36;11,-107;;8,-51;0,6,1,0,0,-1",
"xs14_0gbb8oz321;xs16_35a88czwdb;0;-3,-51;;-6,-107;8,-36,11,-61;0,6,1,0,0,-1",
"xs14_0gbb8oz321;xs16_g8hf0cicz11;0;-3,-36;;-2,-59;;5,6,0,-1,-1,0",
"xs14_0gbb8oz321;xs16_gjlmz1w256;0;;4,-40,12,-58;0,-41;;5,-1,-1,0,0,1",
"xs14_0gbb8oz321;xs16_jhkmz1w256;0;-9,-36;6,-80,12,-109;-5,-126,3,-88;;5,-1,-1,0,0,1",
"xs14_0gbqicz23;xs16_ggmd1egoz1;0;;11,-62;2,-76;12,-36;5,6,0,-1,-1,0",
"xs14_0ggca53z641;xs16_8kkb96z641;0;-13,-71,-7,-100;-12,-68;-22,-122,5,-120;6,-115;0,0,1,0,0,1",
"xs14_0ggo3tgz32;xs16_31e80ga6zw311;0;-1,-38;-5,-34,2,-38,9,-46;2,-57;;0,6,0,1,-1,0",
"xs14_0ggo3tgz32;xs16_354c0s4zwca1;0;-1,-36;6,-68;0,-58;;0,6,1,0,0,-1",
"xs14_0ggo3tgz32;xs16_wggo3tgz256;0;;-11,-14;;-13,-86;-1,0,1,0,0,1",
"xs14_0ggo8a52z56;xs16_8kih3zx11da;0;-3,-50;;-3,-50,0,-60,6,-62;9,-60;6,-1,-1,0,0,1",
"xs14_0ggo8a52z56;xs16_xggka23zad11;0;;;1,-95,2,-79;8,-71,16,-40;0,-1,1,0,0,1",
"xs14_0ggo8a52z56;xs16_xggka52zad11;0;;11,-54;5,-44;;0,-1,1,0,0,1",
"xs14_0ggo8a52z56;xs16_xgila4zad11;0;0,-40;10,-65;;;0,-1,1,0,0,1",
"xs14_0ggraa4z32;xs15_0ggraa4z56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs14_0ggraa4z32;xs16_8kkl3zx1156;0;;12,-62;3,-76;13,-36;6,-1,-1,0,0,1",
"xs14_0ggraa4z32;xs16_wggraa4z256;0;;-11,-14;;-13,-86;-1,0,1,0,0,1",
"xs14_0ggraa4z32;xs16_wggraa4z652;0;8,-74;-10,-13;;-14,-90;-1,0,1,0,0,1",
"xs14_0ghn84cz32;xs15_0ghn84cz56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs14_0ghn84cz32;xs16_0ghn84cz1ac;0;8,-99;-11,-14;15,-12;-9,-102;0,0,1,0,0,1",
"xs14_0ghn84cz32;xs16_wghn84cz256;0;;-11,-14;;-13,-86;-1,0,1,0,0,1",
"xs14_0gil96z56;xs14_3ia4zw11da;0;;11,-54;1,-39;4,-41;5,-1,-1,0,0,1",
"xs14_0gila4z1ac;xs16_025ak8z2lp1;0;-1,-44;1,-42;;;0,-1,1,0,0,1",
"xs14_0gila4z1ac;xs16_31248gz4al91;0;;;13,-12;-12,-86,-7,-85,-1,-84;5,9,-1,0,0,-1",
"xs14_0gilicz641;xs15_08u15a4z65;0;5,-63;-9,-12;;-12,-78;5,6,0,-1,-1,0",
"xs14_0gilicz641;xs15_0gjlicz641;0;-3,-40;5,-66;;;0,0,1,0,0,1",
"xs14_0gilicz641;xs16_01784ozc9311;0;;-3,-57,-2,-45;-8,-62,0,-61;;0,-1,1,0,0,1",
"xs14_0gilicz641;xs16_025a4ozc9311;0;-1,-40;1,-38;;;0,-1,1,0,0,1",
"xs14_0gilicz641;xs16_0giliczbc1;0;7,-95;-9,-24;;-14,-86;0,0,1,0,0,1",
"xs14_0j5o0ooz121;xs15_0j5o0ok8z121;0;18,-82;;10,-42;4,-67;0,0,1,0,0,1",
"xs14_0j5oz3kp;xs16_0j5ozj4pz11;0;;-13,-12;17,-12;-20,-123,-11,-118;0,0,1,0,0,1",
"xs14_0j5oz8ld;xs15_6421560ui;0;;-12,-12;;-19,-100;3,0,0,-1,1,0",
"xs14_0j5s26z121;xs15_0j5s246z121;0;;8,-51;7,-36;10,-36;0,0,1,0,0,1",
"xs14_0j5s26z121;xs15_0j5s252z121;0;;10,-52;7,-39;11,-36;0,0,1,0,0,1",
"xs14_0j5s26z121;xs15_0j5s26z321;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs14_0j5s26z121;xs16_0j5s253z121;0;;9,-47;7,-36;11,-36;0,0,1,0,0,1",
"xs14_0j5s26z121;xs16_0j5s256z121;0;;10,-52;;10,-36;0,0,1,0,0,1",
"xs14_0j5s26z121;xs16_25a8ci6zx65;0;14,-70;10,-50;7,-59;5,-74;0,6,0,1,-1,0",
"xs14_0j5s26z121;xs16_62s5jzx1074;0;1,-89,2,-77;;;-16,-94,-8,-93;5,0,-1,0,0,1",
"xs14_0j5s26z121;xs16_62s5jzx1252;0;11,-85;-11,-12;;;5,0,-1,0,0,1",
"xs14_0j96066z32;xs15_0j9606a4z32;0;;13,-62;9,-47;5,-62;0,0,1,0,0,1",
"xs14_0j96z8ld;xs15_0bq23z69c;0;;-12,-12;;-19,-100;3,8,-1,0,0,-1",
"xs14_0j96zol3;xs16_651246248a6;0;13,-118,22,-123;-15,-12;15,-12;;3,0,0,-1,1,0",
"xs14_0j96zol3;xs16_wg853zgb6z123;0;11,-116;-14,-12;;-13,-106;3,11,-1,0,0,-1",
"xs14_0j96zrm;xs16_651231248a6;0;13,-118,22,-123;-15,-12;15,-12;;0,10,0,1,-1,0",
"xs14_0j96zrq;xs15_04ap3zcip;0;9,-97,16,-122;;16,-12;-11,-104;3,9,-1,0,0,-1",
"xs14_0j96zrq;xs16_0g84c842156z32;0;16,-129;-14,-12,-11,-58;;;3,10,0,-1,-1,0",
"xs14_0j96zrq;xs16_69jzggmbz1;0;9,-149,17,-182,18,-152;-16,-12;11,-78,19,-39;-5,-125;3,0,-1,0,0,1",
"xs14_0j9ak8z321;xs16_35a8ka4z0321;0;15,-70;;;5,-55;0,6,1,0,0,-1",
"xs14_0j9akoz121;xs16_0g8jd2koz23;0;11,-99,12,-115;-15,-12,-7,-43;;;5,7,0,-1,-1,0",
"xs14_0j9akoz121;xs16_oka9jzx1252;0;11,-85;-11,-12;;;5,0,-1,0,0,1",
"xs14_0j9c826z121;xs15_0j9c826z123;0;14,-66;;;-2,-60;0,0,1,0,0,1",
"xs14_0j9c826z121;xs15_0j9c826z321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs14_0j9c826z121;xs16_0j9c826z1252;0;12,-68;;;-6,-58;0,0,1,0,0,1",
"xs14_0j9c826z121;xs16_0j9c826z343;0;12,-85;-10,-12;;;0,0,1,0,0,1",
"xs14_0j9c826z121;xs16_3h4e12koz011;0;7,-86,13,-84,16,-74;-8,-36;16,-26;;1,0,0,1,1,0",
"xs14_0j9c826z121;xs16_wj9c826z2521;0;11,-85;-11,-12;;;-1,0,1,0,0,1",
"xs14_0j9c826z121;xs16_wj9c826z6221;0;11,-99,12,-115;-15,-12,-7,-43;;;-1,0,1,0,0,1",
"xs14_0j9c84cz121;xs15_0j9c84cz321;0;3,-83;;;-11,-78;0,0,1,0,0,1",
"xs14_0j9c84cz121;xs15_0j9c871z121;0;15,-77;13,-62;5,-52;7,-64;0,0,1,0,0,1",
"xs14_0j9c84cz121;xs15_628s252z065;0;;10,-59,20,-90;5,-67,13,-35;;0,0,0,1,1,0",
"xs14_0j9c84cz121;xs16_06iog853z252;0;;8,-42;2,-58,8,-35,13,-16;;0,-1,1,0,0,1",
"xs14_0j9c84cz121;xs16_0j9c84cz1252;0;12,-68;;;-6,-58;0,0,1,0,0,1",
"xs14_0j9c84cz121;xs16_0j9c84cz343;0;12,-85;-10,-12;;;0,0,1,0,0,1",
"xs14_0j9c84cz121;xs16_0j9c84koz121;0;15,-70;11,-54;11,-48,20,-17;;0,0,1,0,0,1",
"xs14_0j9c84cz121;xs16_628s252zca1;0;;10,-50;9,-54;7,-52;0,0,0,1,1,0",
"xs14_0j9c84cz121;xs16_c4go4871zw65;0;11,-99,12,-115;-15,-12,-7,-43;;;-1,0,0,1,1,0",
"xs14_0j9c84cz121;xs16_c4go4a52zw65;0;11,-85;-11,-12;;;-1,0,0,1,1,0",
"xs14_0j9egoz121;xs15_0j9eg8oz121;0;13,-67;;15,-12;2,-52;0,0,1,0,0,1",
"xs14_0j9egoz121;xs15_0j9egoz321;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs14_0j9egoz121;xs15_25ao4a4z0321;0;15,-70;;16,-14;2,-57;0,6,1,0,0,-1",
"xs14_0j9egoz121;xs16_0g8jd4koz23;0;11,-99,12,-115;-15,-12,-7,-43;;;5,7,0,-1,-1,0",
"xs14_0j9egoz121;xs16_25ao4a6z0321;0;14,-66;;16,-15;2,-55;0,6,1,0,0,-1",
"xs14_0j9egoz121;xs16_25ao4acz0321;0;15,-70;;15,-14;;0,6,1,0,0,-1",
"xs14_0j9egoz121;xs16_25ic8a6zx56;0;15,-70;9,-50;10,-54;2,-79;0,6,0,1,-1,0",
"xs14_0j9egoz121;xs16_oge9jzx1252;0;11,-85;-11,-12;;;5,0,-1,0,0,1",
"xs14_0jhe8zca1;xs15_31246o8b5;0;-5,-44;0,-52;-3,-67;;0,8,0,1,-1,0",
"xs14_0jhe8zca1;xs16_3lozck871;0;-5,-44;;-5,-68;;0,8,1,0,0,-1",
"xs14_0kc32acz32;xs15_0kc32ak8z32;0;17,-78;;14,-26;1,-65;0,0,1,0,0,1",
"xs14_0kc32acz32;xs15_0kc32qkz32;0;16,-74;;12,-33;1,-62;0,0,1,0,0,1",
"xs14_0kc32acz32;xs16_0kc32acz346;0;10,-105,14,-86,19,-110;-12,-23;18,-12;;0,0,1,0,0,1",
"xs14_0kc32acz32;xs16_0kc32akoz32;0;17,-78;;13,-25;1,-62;0,0,1,0,0,1",
"xs14_0kc32acz32;xs16_0kc32qk8z32;0;16,-74;;14,-26;;0,0,1,0,0,1",
"xs14_0kc32acz32;xs16_xkc32aczca1;0;8,-92;-11,-12;;-10,-82;-2,0,1,0,0,1",
"xs14_0m2s53z121;xs15_0m2s53z321;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs14_0m2s53z121;xs16_35s2mzx1074;0;1,-89,2,-77;;;-16,-94,-8,-93;5,0,-1,0,0,1",
"xs14_0m2s53z121;xs16_35s2mzx1252;0;11,-85;-11,-12;;;5,0,-1,0,0,1",
"xs14_0md1e8z32;xs14_0gbqicz23;0;-1,-95,0,-83;;;-14,-86,-6,-104;5,5,0,-1,-1,0",
"xs14_0md1e8z32;xs16_0md1e8z346;0;10,-105,14,-86,19,-110;-12,-23;18,-12;;0,0,1,0,0,1",
"xs14_0md1e8z32;xs16_0md1egoz32;0;;13,-62;7,-62;10,-36;0,0,1,0,0,1",
"xs14_0md1e8z32;xs16_xgbqiczca1;0;1,-68,7,-69,12,-70;-9,-12;;;5,7,0,-1,-1,0",
"xs14_0md1e8z32;xs16_xmd1e8zca1;0;8,-92;-11,-12;;-10,-82;-2,0,1,0,0,1",
"xs14_0mk2156z121;xs15_0kc0f9z346;0;;-9,-34;;-16,-98;-1,0,0,1,1,0",
"xs14_0mk21e8z121;xs15_0kc0f9z1226;0;;-9,-34;;-16,-98;-1,0,0,1,1,0",
"xs14_0mk453z321;xs15_0c88b5z653;0;;12,-58;3,-46;8,-41;0,-1,1,0,0,1",
"xs14_0mk453z321;xs16_0c88b52z653;0;;12,-60;;10,-36;0,-1,1,0,0,1",
"xs14_0mk453z321;xs16_0ogjl8zca6;0;-4,-36;8,-78;3,-75;10,-38;0,-2,1,0,0,1",
"xs14_0mk453z641;xs15_0c88b5zc93;0;;12,-58;3,-46;8,-41;0,-1,1,0,0,1",
"xs14_0mk453z641;xs16_0c88b52zc93;0;;12,-64;;10,-40;0,-1,1,0,0,1",
"xs14_0mk453z641;xs16_0ogjl8zoi6;0;-4,-40;8,-82;3,-79;10,-42;0,-2,1,0,0,1",
"xs14_0mk453z641;xs16_354kmzx12ko;0;12,-102;-12,-12;;;5,0,-1,0,0,1",
"xs14_0mk453z641;xs16_wg8o0uh3z65;0;3,-76;;;-13,-82;5,8,0,-1,-1,0",
"xs14_0ml1246z121;xs15_9f0c4ozx65;0;;-9,-34;;-16,-98;-1,5,0,1,-1,0",
"xs14_0ml9a4z121;xs15_8o6picz23;0;;-9,-30;;-16,-94;5,5,0,-1,-1,0",
"xs14_0mlicz56;xs16_0358gz69ld;0;12,-90,19,-97;;13,-12;;4,9,-1,0,0,-1",
"xs14_0mlicz56;xs16_358ge1da4;0;10,-87;;13,-12;-11,-76,-4,-68,3,-64;4,8,0,-1,-1,0",
"xs14_0o4871z39c;xs16_ggka231248cz1;0;;;15,-12;-11,-110;0,0,0,1,1,0",
"xs14_0o4871zdd;xs16_0312kozgs243;0;;;11,-58,14,-12;-14,-121;5,9,-1,0,0,-1",
"xs14_0o4a52z39c;xs16_0g8ka52z6jo;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs14_0o4a52z39c;xs16_g8ka231248cz01;0;;;15,-12;-11,-110;0,0,0,1,1,0",
"xs14_0o4a52zbd;xs16_0g8ka52zmr;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs14_0o4a52zdd;xs16_0312koz8ka43;0;;;11,-58,14,-12;-14,-121;5,9,-1,0,0,-1",
"xs14_0ok213z4aa4;xs16_04akl3zc8421;0;;;14,-12;-8,-96,1,-82;5,8,-1,0,0,-1",
"xs14_0ok21e8z641;xs16_0ok21egoz641;0;;14,-66;8,-66;11,-40;0,0,1,0,0,1",
"xs14_0ok453zca1;xs15_0g88b5zol3;0;;12,-61;3,-49;8,-44;0,-1,1,0,0,1",
"xs14_0ok453zca1;xs16_0g88a53zol3;0;;13,-73;3,-57;9,-44;0,-1,1,0,0,1",
"xs14_0ok453zca1;xs16_0g88b52zol3;0;;12,-68;;10,-44;0,-1,1,0,0,1",
"xs14_0ok453zca1;xs16_wgjl8zgb6z11;0;-4,-44;8,-86;3,-83;10,-46;0,-2,1,0,0,1",
"xs14_178421ego;xs15_178421eg8o;0;16,-74;;18,-19;5,-59;0,0,1,0,0,1",
"xs14_178421ego;xs16_178421eg84c;0;18,-82;12,-62;13,-66;5,-91;0,0,1,0,0,1",
"xs14_178421ego;xs16_3ia4z122qk8;0;18,-82;;18,-26;;0,0,0,1,1,0",
"xs14_1784264ko;xs15_0gs252zo9a4;0;20,-90;;17,-30;2,-77;9,0,0,-1,1,0",
"xs14_1784264ko;xs15_0oe123zc452;0;19,-86;;15,-37;2,-74;8,0,0,-1,1,0",
"xs14_1784264ko;xs16_0gs253zo9a4;0;20,-90;;16,-29;2,-74;9,0,0,-1,1,0",
"xs14_1784264ko;xs16_0gs256zo9a4;0;19,-86;;17,-30;;9,0,0,-1,1,0",
"xs14_1784c0cic;xs16_03lka4zc452;0;16,-74;;;-3,-92,6,-70;8,0,0,-1,1,0",
"xs14_1784ozx34a4;xs15_1784ozx34ac;0;20,-90;;;0,-84;0,0,1,0,0,1",
"xs14_1784ozx34a4;xs16_1784ozx342sg;0;16,-105,24,-106;;;2,-89,3,-101;0,0,1,0,0,1",
"xs14_1784ozx34a4;xs16_1784ozx34ak8;0;18,-82;;;-4,-72;0,0,1,0,0,1",
"xs14_1784ozx34a4;xs16_25iczw121ego;0;1,-78;-8,-28;;-11,-78;6,8,-1,0,0,-1",
"xs14_178bp46;xs15_c82t52z311;0;19,-86;;12,-45;-3,-94,-1,-69,4,-68,8,-46;6,0,0,-1,1,0",
"xs14_178bp46;xs16_178bp453;0;15,-70;11,-54;;7,-64,16,-33;0,0,1,0,0,1",
"xs14_178c2ego;xs15_178c2eg8o;0;15,-70;;17,-15;4,-55;0,0,1,0,0,1",
"xs14_178c2ego;xs16_0cai3z2lp1;0;17,-80;13,-62;13,-56;4,-89;0,4,0,1,-1,0",
"xs14_178c48a52;xs16_25akg8oge2;0;;12,-58;6,-48;;9,-1,-1,0,0,1",
"xs14_178c48a52;xs16_31ego8gka4;0;1,-86;-8,-36;;-11,-86;-1,-1,1,0,0,1",
"xs14_178f1246;xs16_0caarzok21;0;15,-70;;12,-40,19,-19;;0,4,0,1,-1,0",
"xs14_178f1246;xs16_j96zd553;0;16,-74;12,-58;;8,-68,17,-37;8,0,0,-1,1,0",
"xs14_178f1e8;xs16_178f1ego;0;;14,-66;8,-66;11,-40;0,0,1,0,0,1",
"xs14_178jq23;xs16_09f0kcz6511;0;1,-78;-8,-28;;-11,-78;6,-1,0,-1,1,0",
"xs14_178jq23;xs16_0bq2koz643;0;;9,-46;-5,-61,0,-38;;0,-1,0,1,1,0",
"xs14_178jq23;xs16_gbq2koz123;0;;10,-50,15,-74;1,-58;;0,-1,0,1,1,0",
"xs14_1no31246;xs16_0642arzc8421;0;13,-62;;;-1,-78,5,-55,10,-36;0,5,0,1,-1,0",
"xs14_1no31246;xs16_1no31248go;0;15,-70;;12,-40,19,-19;;0,0,1,0,0,1",
"xs14_1no31e8;xs16_1no31ego;0;;14,-66;8,-66;11,-40;0,0,1,0,0,1",
"xs14_252sgc48c;xs15_25b8ozwbd;0;0,-68;;;-8,-74;0,0,0,1,1,0",
"xs14_252sgc48c;xs15_352sgc48c;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs14_252sgc48c;xs16_0dbgz259ho;0;;-9,-12,-6,-34,0,-60;-3,-70;-11,-92;8,1,0,-1,1,0",
"xs14_252sgc48c;xs16_6413kkozw252;0;;8,-46,15,-70;1,-58,10,-35;5,-52;7,-2,0,-1,1,0",
"xs14_252sgc48c;xs16_gbdz115a8o;0;;-5,-77,-4,-65;-10,-82,-2,-81;;8,4,0,-1,-1,0",
"xs14_252sgc48c;xs16_gbdz115ak8;0;-3,-28;-1,-26;;;8,4,0,-1,-1,0",
"xs14_252sgc48c;xs16_gbdz11dic;0;-3,-55;;;-7,-70;8,4,0,-1,-1,0",
"xs14_252sgc48c;xs16_gbdz19la4;0;-2,-59;;;-8,-74;8,4,0,-1,-1,0",
"xs14_252sgc48c;xs16_o86178k8z23;0;;9,-50,16,-74;2,-62,10,-39;5,-56;7,4,-1,0,0,-1",
"xs14_252sgc4go;xs16_gila4zpi6;0;-2,-59;;;-8,-74;-1,4,0,1,-1,0",
"xs14_252sgz0db;xs15_352sgz0db;0;-5,-44;3,-70;;;0,0,1,0,0,1",
"xs14_252sgz0db;xs16_0o4871z11mq;0;;-5,-61,-4,-49;-10,-66,-2,-65;;4,-1,-1,0,0,1",
"xs14_252sgz0db;xs16_0o4a52z11mq;0;-3,-44;-1,-42;;;4,-1,-1,0,0,1",
"xs14_252sgz0db;xs16_2552sgzwdb;0;;-5,-31;-5,-46;;-1,0,1,0,0,1",
"xs14_252sgzc93;xs16_0252sgzg853z11;0;13,-110;-13,-12;;;-1,0,1,0,0,1",
"xs14_252sgzc93;xs16_039cggz8ka43;0;-3,-44;-1,-42;;;-1,8,1,0,0,-1",
"xs14_252sgzc93;xs16_039cggzgs243;0;;-5,-61,-4,-49;-10,-66,-2,-65;;-1,8,1,0,0,-1",
"xs14_252sgzc93;xs16_312kozw8k871;0;4,-76;;;-14,-82;-2,9,1,0,0,-1",
"xs14_253031248go;xs13_0g853zrq;0;-3,-28;;;;10,0,0,-1,1,0",
"xs14_253031248go;xs14_32qczx12ko;0;-1,-35;7,-47;-2,-58;;1,-2,0,1,1,0",
"xs14_253031248go;xs15_032arzok21;0;;-11,-22;;-6,-74;1,4,0,1,-1,0",
"xs14_253031248go;xs16_wg853zgbacz11;0;0,-68;-4,-46;;-6,-74;10,-1,0,-1,1,0",
"xs14_253031ego;xs15_31ego0ui;0;;-11,-14;;-6,-66;8,4,-1,0,0,-1",
"xs14_253031ego;xs16_0ok453zca23;0;0,-60;-4,-38;;-6,-66;8,-1,0,-1,1,0",
"xs14_2530fh8o;xs16_0c88b5z2596;0;-3,-51;;;-7,-66;7,-1,0,-1,1,0",
"xs14_2530fh8o;xs16_0c88b5z6952;0;-3,-28;-1,-26;;;7,-1,0,-1,1,0",
"xs14_2530fh8o;xs16_32hu0oka4;0;-2,-55;;;-8,-70;7,4,-1,0,0,-1",
"xs14_255q8a52;xs16_0696o8z4a521;0;;11,-54;5,-44;;0,-1,0,1,1,0",
"xs14_2560uh23;xs15_3iab8oz023;0;-9,-28;;-4,-64;;1,-1,0,1,1,0",
"xs14_2560uh23;xs16_05b88cz4a53;0;-3,-28;-1,-26;;;7,-1,0,-1,1,0",
"xs14_256o8a53;xs15_255q8a53;0;0,-30;5,-30;;;0,0,1,0,0,1",
"xs14_256o8a53;xs16_0352sgz4a53;0;-3,-28;-1,-26;;;7,-1,0,-1,1,0",
"xs14_256o8a53;xs16_0352sgzc453;0;;-5,-73,-4,-61;-10,-78,-2,-77;;7,-1,0,-1,1,0",
"xs14_256o8a53;xs16_03l2sgz2543;0;-4,-28;6,-53;;;7,-1,0,-1,1,0",
"xs14_256o8a53;xs16_354c32ako;0;5,-78;-3,-64;-5,-72,-5,-58;-9,-93;-1,4,1,0,0,-1",
"xs14_256o8b52;xs16_0256o8zca521;0;;;9,-34;9,-28;0,-1,0,1,1,0",
"xs14_256o8b52;xs16_0652sgz4a53;0;-3,-28;-1,-26;;;7,-1,0,-1,1,0",
"xs14_256o8b52;xs16_0652sgzc453;0;;-5,-73,-4,-61;-10,-78,-2,-77;;7,-1,0,-1,1,0",
"xs14_256o8b52;xs16_25b8o64ko;0;5,-78;-3,-64;-5,-72,-5,-58;-9,-93;7,0,-1,0,0,1",
"xs14_256o8gka4;xs15_3146o8gka4;0;-1,-61;-7,-52;-2,-68;-9,-78;-1,0,1,0,0,1",
"xs14_256o8gka4;xs15_356o8gka4;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs14_256o8gka4;xs15_8o6413z34a4;0;;-4,-32,5,-49,11,-72;-5,-62,2,-49;;0,4,0,1,-1,0",
"xs14_256o8gka4;xs16_256o8gka52;0;;11,-54;7,-44;;0,0,1,0,0,1",
"xs14_256o8gka4;xs16_25icz2ehp;0;5,-82;-3,-68;-5,-76,-5,-62;-9,-97;8,1,0,-1,1,0",
"xs14_256o8gka4;xs16_ci52z1162sg;0;-9,-28,-1,-59;5,-67,6,-83;;;8,4,0,-1,-1,0",
"xs14_256o8gka4;xs16_ci52z116a8o;0;;-5,-77,-4,-65;-10,-82,-2,-81;;8,4,0,-1,-1,0",
"xs14_256o8gka4;xs16_ci52z116ak8;0;-3,-28;-1,-26;;;8,4,0,-1,-1,0",
"xs14_2596zzzybcik8;xs16_giligoz104a4;0;16,-105,26,-114;-12,-51;11,-38,21,-29;11,-127;5,7,0,1,1,0",
"xs14_259e0mq;xs18_0gj3z1qm1e8;0;;0,-29,8,-42;4,-32,11,-19;9,-33;7,-5,-1,0,0,1",
"xs14_259e0mq;xs18_y633z6ikm93z01;0;;0,-44,8,-57;-4,-63,4,-47,6,-57;13,-28;12,4,0,-1,-1,0",
"xs14_25a4ozok21;xs16_g8ka51248goz01;0;-3,-48;-1,-46;;;4,-1,0,-1,1,0",
"xs14_25a4ozx34a4;xs16_25iczw125ak8;0;-3,-44;-1,-42;;;6,8,-1,0,0,-1",
"xs14_25a842ako;xs13_354215ac;0;0,-28;-2,-20;;;1,1,1,0,0,1",
"xs14_25a842ako;xs16_0o4871zok96;0;-9,-28,-1,-59;5,-67,6,-83;;;-1,4,0,1,-1,0",
"xs14_25a842ako;xs16_0o4a52zok96;0;-3,-28;-1,-26;;;-1,4,0,1,-1,0",
"xs14_25a84cga6;xs16_0o4a52z4ajo;0;-3,-28;-1,-26;;;-1,4,0,1,-1,0",
"xs14_25a88cz0253;xs16_0g8hf0ck8z23;0;-9,-40,-1,-71;5,-79,6,-95;;;5,-1,0,-1,1,0",
"xs14_25a88cz0253;xs16_25akggozw4a6;0;-3,-40;-1,-38;;;-1,-1,1,0,0,1",
"xs14_25a88cz0253;xs16_4aligoz04a6;0;;6,-40;0,-30;;0,-1,1,0,0,1",
"xs14_25a88gzc8421;xs16_031248gz8ka511;0;-3,-44;-1,-42;;;-1,8,1,0,0,-1",
"xs14_25a88gzc8421;xs16_031248gzo8a511;0;-9,-44,-1,-75;5,-83,6,-99;;;-1,8,1,0,0,-1",
"xs14_25a88gzc8421;xs16_3hik8z1248go;0;-2,-60;1,-62,7,-60,10,-50;;10,-50;5,-1,-1,0,0,1",
"xs14_25a8o0ui;xs16_8kai30f9zw1;0;;6,-48;0,-38;;0,4,1,0,0,-1",
"xs14_25a8o653;xs16_0356o8z4a521;0;-3,-28;-1,-26;;;7,-1,0,-1,1,0",
"xs14_25a8o653;xs16_ggka23ckoz1;0;-9,-28,-1,-59;5,-67,6,-83;;;-1,4,1,0,0,-1",
"xs14_25a8og8426;xs16_25a8og842ac;0;17,-78;15,-70;13,-64,22,-33;;0,0,1,0,0,1",
"xs14_25a8og8426;xs16_358gzwg0t6z0121;0;;14,-66;11,-70;11,-60;11,-1,0,-1,1,0",
"xs14_25a8og8426;xs16_g853z178ka4;0;;6,-56;0,-46;;9,4,0,-1,-1,0",
"xs14_25a8og8426;xs16_g853z178kk8;0;-4,-28;6,-53;;;9,4,0,-1,-1,0",
"xs14_25a8og853;xs15_g84213z178k8;0;;8,-83,21,-94;8,-85;17,-46;9,4,0,-1,-1,0",
"xs14_25a8og853;xs16_0312koz25a43;0;;6,-52;0,-42;;8,-1,0,-1,1,0",
"xs14_25a8og853;xs16_0312koz4aa43;0;-4,-28;6,-53;;;8,-1,0,-1,1,0",
"xs14_25a8og853;xs16_0g842132ak8z32;0;;12,-58;6,-68;13,-36;10,4,-1,0,0,-1",
"xs14_25a8og853;xs16_6512koz04a43;0;;9,-81,13,-104,19,-86;-4,-69,4,-73;14,-39;8,-1,0,-1,1,0",
"xs14_25akg84ko;xs16_g8ka52zpic;0;-3,-28;-1,-26;;;-1,4,0,1,-1,0",
"xs14_25b8og84c;xs16_0o4a53z3lo;0;-2,-28;-2,-34;;;-1,4,0,1,-1,0",
"xs14_25b8og84c;xs16_g84213z178kc;0;;10,-50;4,-66,10,-43,15,-24;;9,4,0,-1,-1,0",
"xs14_25b8og84c;xs16_gs256zpic;0;17,-78;13,-62;13,-56,22,-25;;0,4,0,1,-1,0",
"xs14_25b8oge2;xs16_0o4a53z354c;0;-2,-28;-2,-34;;;-1,4,0,1,-1,0",
"xs14_25iczw178c;xs14_25a84cga6;0;11,-98;-9,-12;12,-30;-5,-94;0,0,0,1,1,0",
"xs14_25iczw178c;xs14_ci52z3lo;0;7,-72,18,-90;;;-11,-74,-8,-84;3,0,-1,0,0,1",
"xs14_25iczw178c;xs15_252sgzx69k8;0;19,-100;;20,-12;-2,-87;6,9,-1,0,0,-1",
"xs14_25iczw178c;xs15_25iczw1784c;0;17,-96,19,-86;;;1,-84;0,0,1,0,0,1",
"xs14_25iczw178c;xs15_31eozw34ac;0;-5,-44;3,-70;;;5,8,-1,0,0,-1",
"xs14_25iczw178c;xs16_1784ozx3ego;0;;-5,-65,-4,-53;-10,-70,-2,-69;;-1,-1,1,0,0,1",
"xs14_25iczw178c;xs16_25a4ozx3ego;0;-3,-44;-1,-42;;;-1,-1,1,0,0,1",
"xs14_25iczw178c;xs16_25iczw178426;0;19,-88;7,-38;15,-32;-2,-97;0,0,1,0,0,1",
"xs14_25iczw178c;xs16_25iczw178kc;0;19,-100;;19,-12;;0,0,1,0,0,1",
"xs14_25iczw178c;xs16_25iczw178ko;0;18,-95;;20,-12;-2,-84;0,0,1,0,0,1",
"xs14_25iczx115a4;xs16_25iczwoh952;0;;-11,-18;17,-28;-11,-82,-8,-92,-2,-94;0,0,1,0,0,1",
"xs14_25iczx115a4;xs16_25iczx19la4;0;15,-70;;;-7,-80;0,0,1,0,0,1",
"xs14_25iczx11da;xs16_25iczxh952zx11;0;15,-108;-8,-12;;-7,-98;0,0,1,0,0,1",
"xs14_25is0qm;xs16_ra9jzw1226;0;;-5,-69,-4,-57;-10,-74,-2,-73;;6,4,0,-1,-1,0",
"xs14_25is0qm;xs16_ra9jzw1252;0;-3,-28;-1,-26;;;6,4,0,-1,-1,0",
"xs14_2eg8o653;xs13_256o8ge2;0;;;14,-12;4,-42;7,0,-1,0,0,1",
"xs14_2eg8og853;xs16_0g8421321e8z32;0;;12,-58;6,-68;13,-36;10,4,-1,0,0,-1",
"xs14_2eg8og853;xs16_g88a52z5b8o;0;;13,-62;3,-72;15,-43;9,4,0,-1,-1,0",
"xs14_2eg8og853;xs16_kq23z1248a6;0;;9,-81,13,-104,19,-86;-4,-69,4,-73;14,-39;0,4,0,1,-1,0",
"xs14_2eg8og853;xs16_wg853zmdz0113;0;;;2,-38,7,-37,13,-36;11,-28;11,4,0,-1,-1,0",
"xs14_2ege1248c;xs16_069jz4aaq1;0;18,-82;12,-58;;8,-76,17,-45;9,4,0,-1,-1,0",
"xs14_2ege1248c;xs16_0g84213z1qaa4;0;15,-70;;;-1,-86,5,-63,10,-44;9,0,0,-1,1,0",
"xs14_2ege1248c;xs16_g0g8421ege2z11;0;17,-78;;14,-40,21,-19;;10,0,-1,0,0,1",
"xs14_2ege1da;xs15_2ege1da4;0;16,-74;;;23,-73;0,0,1,0,0,1",
"xs14_2ege1da;xs15_ad1egma;0;9,-69;-9,-12,-4,-31;;;6,0,-1,0,0,1",
"xs14_2ege1da;xs16_31ege1da;0;2,-82;-9,-24;;-12,-82;-1,0,1,0,0,1",
"xs14_2egow31e8;xs16_03iacz6a9o;0;;6,-34;;-1,-50;0,0,0,1,1,0",
"xs14_2ll2zc96;xs16_354268m93;0;;;0,-64,9,-50;6,-44;0,8,0,1,-1,0",
"xs14_2ll2zw3426;xs16_4akl3zx3426;0;-3,-40;-6,-46,3,-60;;;-1,0,1,0,0,1",
"xs14_2ll2zw34a4;xs16_4akl3zx34a4;0;-3,-44;-6,-50,3,-64;;;-1,0,1,0,0,1",
"xs14_2lmz320123;xs15_6ic0f9z32;0;-3,-54;;-10,-70;;-1,6,0,1,-1,0",
"xs14_2lmz3kp;xs15_j5ozd54c;0;-3,-48;;-10,-64;;2,9,-1,0,0,-1",
"xs14_2lmz4a9o;xs13_0brz254c;0;;6,-34;;;0,1,1,0,0,1",
"xs14_2lmz4a9o;xs14_178c48ge2;0;;4,-37;8,-17;3,-48;4,1,0,-1,1,0",
"xs14_2lmz4a9o;xs15_1784260ui;0;-3,-48;;-10,-64;;3,9,0,-1,-1,0",
"xs14_2lmz4a9o;xs16_3ia4zol56;0;-3,-48;3,-66;-3,-60;;3,9,-1,0,0,-1",
"xs14_2lmzcip;xs13_j96zdd;0;;6,-34;;;2,9,-1,0,0,-1",
"xs14_2lmzcip;xs14_0cq23z69c;0;;4,-37;8,-17;3,-48;0,1,1,0,0,1",
"xs14_2lmzcip;xs15_j96zd54c;0;-3,-48;;-10,-64;;2,9,-1,0,0,-1",
"xs14_2lmzcip;xs16_69jz65lo;0;-3,-48;3,-66;-3,-60;;0,9,1,0,0,-1",
"xs14_2lmzo9a4;xs15_2eg84c0f9;0;-3,-48;;-10,-64;;-1,9,0,1,-1,0",
"xs14_2lmzw34213;xs15_g88c0f9z056;0;-3,-58;;-10,-74;;-1,7,0,1,-1,0",
"xs14_2lmzw34213;xs16_ckl3zw34213;0;-3,-40;3,-58;-3,-52;;0,0,1,0,0,1",
"xs14_2lmzw34ac;xs13_33032ako;0;;6,-34;;;1,1,0,1,1,0",
"xs14_2lmzw34ac;xs15_32arzx1256;0;-3,-54;;-10,-70;;-1,1,1,0,0,1",
"xs14_2lmzw34ac;xs15_3lmzw34ac;0;-5,-44;3,-70;;;0,0,1,0,0,1",
"xs14_2lmzw34ac;xs16_ckl3zw34ac;0;-3,-44;3,-62;-3,-56;;0,0,1,0,0,1",
"xs14_31230fho;xs15_bdz311da;0;15,-70;;17,-15;4,-55;0,0,0,1,1,0",
"xs14_31230fho;xs16_bdz311da4;0;17,-78;;17,-22;;0,0,0,1,1,0",
"xs14_31230fho;xs16_bdz31pl2;0;17,-80;13,-62;13,-56;4,-89;0,0,0,1,1,0",
"xs14_3123qp3;xs16_39q3213z32;0;;;20,-12,25,-19;-11,-131,-5,-159;6,0,-1,0,0,1",
"xs14_3123qp3;xs16_bt06246z32;0;;-11,-16;14,-12,17,-37;-8,-115,-7,-74;6,0,0,-1,1,0",
"xs14_3123qp3;xs16_bt0628cz32;0;14,-159,20,-131;-16,-19,-11,-12;;;6,0,0,-1,1,0",
"xs14_3123qp3;xs16_bt06ioz32;0;8,-96,16,-134;;20,-12;-9,-117,-3,-88;6,0,0,-1,1,0",
"xs14_3123qp3;xs16_mq0c93z65;0;12,-88,18,-117;-11,-12;;-7,-134,1,-96;7,0,0,-1,1,0",
"xs14_31246pic;xs16_358gzw4ajkc;0;-10,-28,-3,-49;;-6,-63;;-2,-2,0,1,1,0",
"xs14_31246pic;xs16_4ap56z69c;0;;-12,-29,-3,-60;-7,-66;-7,-66;7,0,0,-1,1,0",
"xs14_31248ge123;xs16_31248ge1248c;0;16,-74;;13,-52,20,-31;;0,0,1,0,0,1",
"xs14_31248ge123;xs16_xg8421eg8oz321;0;-10,-35,-3,-56;;-6,-70;;-2,4,1,0,0,-1",
"xs14_31248gzy212453;xs16_651248gzy312453;0;;-12,-41,-3,-72;-7,-78;-7,-78;-1,0,1,0,0,1",
"xs14_31248n96;xs16_651248n96;0;;-12,-29,-3,-60;-7,-66;-7,-66;-1,0,1,0,0,1",
"xs14_31460uh3;xs15_31460uh23;0;;11,-54;8,-39;13,-31;0,0,1,0,0,1",
"xs14_31460uh3;xs16_03lk46zok21;0;;-4,-56;-6,-62;;7,-1,0,-1,1,0",
"xs14_31460uh3;xs16_0g84c0fhoz32;0;-5,-28;5,-62;;;-1,4,1,0,0,-1",
"xs14_31460uh3;xs16_39cz2lp13;0;17,-78;13,-64;8,-73;9,-72;0,0,0,1,1,0",
"xs14_3146164ko;xs16_0gs253zpi6;0;20,-90;;16,-29;2,-74;9,0,0,-1,1,0",
"xs14_3146164ko;xs16_0gs256zpi6;0;19,-86;;17,-30;;9,0,0,-1,1,0",
"xs14_3146164ko;xs16_312kozw12ego;0;-5,-28;5,-62;;;-1,-2,0,1,1,0",
"xs14_3146o8b5;xs16_03ihe8zok21;0;;-4,-56;-6,-62;;7,-1,0,-1,1,0",
"xs14_3146o8b5;xs16_0g84c32qkz32;0;-5,-28;5,-62;;;-1,4,1,0,0,-1",
"xs14_31e861ac;xs15_321e861ac;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs14_31e861ac;xs16_3586178kc;0;-6,-38;;-6,-62;;7,3,-1,0,0,-1",
"xs14_31e861ac;xs16_4a9jz2lp1;0;-1,-78;-1,-71;-6,-62;-8,-74;7,0,0,-1,1,0",
"xs14_31e88gzwca1;xs15_321e88gzxca1;0;-6,-44;-1,-52;-4,-67;;-1,0,1,0,0,1",
"xs14_31e88gzwca1;xs16_0ggs256z12ko;0;-6,-44;;-6,-68;;5,-1,-1,0,0,1",
"xs14_31e8gzwbd;xs16_0gs253z1qm;0;-7,-44;-1,-52;-5,-63;;4,-1,-1,0,0,1",
"xs14_31e8gzwbd;xs16_0gs256z1qm;0;-6,-44;;-6,-68;;4,-1,-1,0,0,1",
"xs14_31e8gzwbd;xs16_6413kk8zw643;0;2,-64,11,-77;-14,-12,-7,-16;;-6,-74;-2,7,1,0,0,-1",
"xs14_31e8gzwbd;xs16_o86164koz23;0;3,-72,11,-81;-15,-12,-8,-16;;-6,-78;4,7,0,-1,-1,0",
"xs14_31e8zoge2;xs16_354cggc453;0;;;10,-28;3,-48,8,-52;0,0,0,1,1,0",
"xs14_31eg842ac;xs15_069jzkq221;0;-6,-35;-1,-43;-4,-58;;8,0,0,-1,1,0",
"xs14_31eg842ac;xs15_0j96z122ak8;0;-7,-42;-1,-53;-6,-66;;8,4,0,-1,-1,0",
"xs14_31eg842ac;xs16_0j96z122ako;0;-7,-43;-1,-51;-5,-62;;8,4,0,-1,-1,0",
"xs14_31eg842ac;xs16_0j96z122qk8;0;-6,-42;;-6,-66;;8,4,0,-1,-1,0",
"xs14_31eg842ac;xs16_6421eg842ac;0;-1,-82;-1,-75;-6,-66;-8,-78;-2,0,1,0,0,1",
"xs14_31ege123;xs15_321ege123;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs14_31ege123;xs16_05b88gz4ad11;0;-6,-38;;-6,-62;;7,-1,0,-1,1,0",
"xs14_31ege123;xs16_05b88gzca511;0;-7,-39;-1,-47;-5,-58;;7,-1,0,-1,1,0",
"xs14_31ege123;xs16_31ege1248c;0;14,-66;;11,-44,18,-23;;0,0,1,0,0,1",
"xs14_31ege123;xs16_321ege1246;0;-2,-72;-1,-73;-6,-64;-10,-78;7,0,-1,0,0,1",
"xs14_31ege123;xs16_3lkia4z56;0;11,-69;-7,-12;;;0,0,0,1,1,0",
"xs14_31egm93;xs15_03lkicz252;0;-7,-34;-1,-45;-6,-58;;6,-1,0,-1,1,0",
"xs14_31egm93;xs15_321egm93;0;-6,-28;-1,-36;-4,-51;;-1,0,1,0,0,1",
"xs14_31egm93;xs16_03lkicz256;0;-6,-34;;-6,-58;;6,-1,0,-1,1,0",
"xs14_31egm93;xs16_03lkicz652;0;-7,-35;-1,-43;-5,-54;;6,-1,0,-1,1,0",
"xs14_31egm93;xs16_39mge1246;0;-1,-74;-1,-67;-6,-58;-8,-70;6,0,-1,0,0,1",
"xs14_31egm93;xs16_o4id1egoz01;0;;12,-58;12,-43;;7,4,-1,0,0,-1",
"xs14_31egm96;xs15_02llicz252;0;-7,-34;-1,-45;-6,-58;;6,-1,0,-1,1,0",
"xs14_31egm96;xs15_2llicz56;0;-6,-28;-1,-36;-4,-51;;6,0,0,-1,1,0",
"xs14_31egm96;xs16_02llicz256;0;-6,-34;;-6,-58;;6,-1,0,-1,1,0",
"xs14_31egm96;xs16_02llicz652;0;-7,-35;-1,-43;-5,-54;;6,-1,0,-1,1,0",
"xs14_31egm96;xs16_2llicz1ac;0;-1,-74;-1,-67;-6,-58;-8,-70;6,0,0,-1,1,0",
"xs14_31ego8a6;xs14_0ok453zca1;0;;;12,-34,15,-12;-1,-74,10,-48;0,5,0,1,-1,0",
"xs14_31ego8a6;xs15_31ego8b5;0;;13,-62;6,-50;9,-53;0,0,1,0,0,1",
"xs14_31ego8a6;xs15_321ego8a6;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs14_31ego8a6;xs15_g88a52z178c;0;-7,-38;-1,-49;-6,-62;;-1,4,0,1,-1,0",
"xs14_31ego8a6;xs16_031eoz2lp1;0;-1,-78;-1,-71;-6,-62;-8,-74;7,0,0,-1,1,0",
"xs14_31ego8a6;xs16_25b8oge13;0;;13,-62;;11,-46;8,0,-1,0,0,1",
"xs14_31ego8a6;xs16_31ego8a53;0;;14,-66;6,-50;10,-45;0,0,1,0,0,1",
"xs14_31ego8a6;xs16_g88a53z178c;0;-7,-39;-1,-47;-5,-58;;-1,4,0,1,-1,0",
"xs14_31ego8a6;xs16_g88b52z178c;0;-6,-38;;-6,-62;;-1,4,0,1,-1,0",
"xs14_31ek13zx23;xs15_j9c8426z23;0;-6,-36;-1,-44;-4,-59;;5,0,0,-1,1,0",
"xs14_31ek13zx23;xs16_031ke13zca1;0;14,-82;;15,-12;-4,-92;6,0,-1,0,0,1",
"xs14_31ek13zx23;xs16_069jz641346;0;;-8,-12;16,-12;-15,-99,-6,-94;5,7,-1,0,0,-1",
"xs14_31ek13zx23;xs16_628s253z065;0;-7,-36;-1,-44;-5,-55;;5,-1,-1,0,0,1",
"xs14_31ek13zx23;xs16_628s256z065;0;-6,-36;;-6,-60;;5,-1,-1,0,0,1",
"xs14_31ek13zx23;xs16_j9c8426z056;0;-2,-64;-1,-65;-6,-56;-10,-70;5,0,0,-1,1,0",
"xs14_31ek13zx23;xs16_w31ke13z6421;0;;;13,-12;-8,-70,-3,-69,3,-68;7,0,-1,0,0,1",
"xs14_31eozx1253;xs16_31eozx125ac;0;16,-74;;;-4,-80;0,0,1,0,0,1",
"xs14_31eozx1253;xs16_xgs256z6a43;0;-6,-40;;-6,-64;;6,-1,-1,0,0,1",
"xs14_31eozx1256;xs15_0ggo8a53z56;0;-6,-40;-1,-48;-4,-63;;6,0,0,-1,1,0",
"xs14_31eozx1256;xs16_xgs253z6a43;0;-6,-40;;-6,-64;;-1,7,1,0,0,-1",
"xs14_32130fho;xs15_c88b5zbd;0;15,-70;;17,-15;4,-55;8,0,0,-1,1,0",
"xs14_32130fho;xs16_c88b52zbd;0;17,-78;;17,-22;;8,0,0,-1,1,0",
"xs14_32130fho;xs16_dbz31pl2;0;17,-80;13,-62;13,-56;4,-89;0,0,0,1,1,0",
"xs14_3213213zy566;xs10_drz32;0;17,-78;;;;0,0,0,1,1,0",
"xs14_32132qr;xs16_0drz643033;0;;9,-46;-5,-61,0,-38;;0,-1,0,1,1,0",
"xs14_32132qr;xs16_0pf033z643;0;-11,-29,-2,-60;;-6,-58;-8,-66;6,-1,0,-1,1,0",
"xs14_32132qr;xs16_4s0c93zbd;0;13,-88,19,-117;-10,-12;;-6,-134,2,-96;8,0,0,-1,1,0",
"xs14_32132qr;xs16_4s39czbd;0;;;4,-67,16,-45;8,-60,13,-28;8,0,0,-1,1,0",
"xs14_32132qr;xs16_bdz3113213;0;18,-126;-10,-12,-7,-48;15,-38;-6,-94;6,6,-1,0,0,-1",
"xs14_32132qr;xs16_dbz3113213;0;;-10,-16;15,-12,18,-37;-7,-115,-6,-74;6,6,-1,0,0,-1",
"xs14_32132qr;xs16_drz2303146;0;;;21,-12,26,-19;-10,-131,-4,-159;0,0,0,1,1,0",
"xs14_32132qr;xs16_drz230356;0;11,-68,19,-86;;;-1,-69;0,0,0,1,1,0",
"xs14_32132qr;xs16_iu0696z56;0;10,-50;;;-4,-55;7,0,0,-1,1,0",
"xs14_32132qr;xs16_pf03146z23;0;15,-159,21,-131;-15,-19,-10,-12;;;6,0,0,-1,1,0",
"xs14_32132qr;xs16_pf0356z23;0;12,-58;;;-8,-75,0,-57;6,0,0,-1,1,0",
"xs14_32132qr;xs16_pf039cz23;0;9,-96,17,-134;;21,-12;-8,-117,-2,-88;6,0,0,-1,1,0",
"xs14_3213kczw65;xs16_321344og8426;0;1,-40;0,-39,8,-62;-10,-74,-3,-50;;1,-4,0,1,1,0",
"xs14_3213kczw65;xs16_3213kczok21;0;11,-100;-10,-12;;-9,-90;0,0,1,0,0,1",
"xs14_3213kczw65;xs16_6248go443146;0;1,-40;0,-39,9,-62;-9,-74,-2,-50;;1,7,0,1,-1,0",
"xs14_321eg84ko;xs16_35421eg8426;0;0,-74;-4,-48;;-7,-70;8,4,-1,0,0,-1",
"xs14_321eg84ko;xs16_3hik8zpic;0;-3,-38,4,-58,11,-82;-2,-53;;-7,-70;-1,4,0,1,-1,0",
"xs14_321f84ko;xs16_0ggmp3zc96;0;-11,-33,-2,-64;;-6,-62;-8,-70;7,-1,0,-1,1,0",
"xs14_321fgka4;xs15_321fgka6;0;;12,-58;10,-52;;0,0,1,0,0,1",
"xs14_321fgka4;xs16_0giliczc96;0;-11,-33,-2,-64;;-6,-62;-8,-70;7,-1,0,-1,1,0",
"xs14_321fgka4;xs16_25akgf123;0;;10,-50;6,-40;;8,0,-1,0,0,1",
"xs14_321fgka4;xs16_321fgka23;0;;;2,-75,3,-59;7,-59,15,-28;0,0,1,0,0,1",
"xs14_321fgka4;xs16_358gu15a4;0;-3,-34,4,-54,11,-78;-2,-49;;-7,-66;-1,4,1,0,0,-1",
"xs14_321fgka4;xs16_4a51ug8426;0;0,-70;-4,-44;;-7,-66;7,4,-1,0,0,-1",
"xs14_32arzca1;xs15_1no31248c;0;-9,-44,2,-80;-12,-25,0,-69;;;3,0,0,-1,1,0",
"xs14_32arzw1226;xs15_0g8go3tgz23;0;-9,-40,2,-76;-12,-21,0,-65;;;-1,7,0,1,-1,0",
"xs14_32arzx1213;xs15_0ggo3tgz56;0;-9,-36,2,-72;-12,-17,0,-61;;;-1,6,0,1,-1,0",
"xs14_32arzx1252;xs15_wggo3tgz252;0;-9,-40,2,-76;-12,-21,0,-65;;;-1,7,0,1,-1,0",
"xs14_32hu06a4;xs15_32hu06ac;0;16,-74;;;6,-68;0,0,1,0,0,1",
"xs14_32hu06a4;xs16_25ac0fh8o;0;14,-66;;;2,-56;8,4,-1,0,0,-1",
"xs14_32hv04a4;xs16_25a40vh23;0;;10,-50;6,-40;;8,0,-1,0,0,1",
"xs14_32hv04a4;xs16_25a40vh8o;0;14,-66;;;2,-56;8,4,-1,0,0,-1",
"xs14_32hv04a4;xs16_32hv04aa4;0;15,-70;;;9,-55;0,0,1,0,0,1",
"xs14_32hv04a4;xs16_3pmggozw4a4;0;-11,-33,-2,-64;;-6,-62;-8,-70;-1,-1,0,1,1,0",
"xs14_32hv04a4;xs16_6a88bdzw252;0;-1,-65,14,-88;-16,-12,-9,-19;;0,-82;0,5,0,1,-1,0",
"xs14_32qczx1156;xs16_32qczx11da4;0;20,-92;;18,-12;;0,0,1,0,0,1",
"xs14_32qczx1156;xs16_32qczx1pl2;0;15,-112;-8,-16;18,-12;-3,-105;0,0,1,0,0,1",
"xs14_32qczx1156;xs16_354kozx122ac;0;;9,-66;0,-80;10,-40;-1,-1,1,0,0,1",
"xs14_32qczx1248c;xs16_xg8oge13zca1;0;;9,-70;0,-84;10,-44;-1,8,0,1,-1,0",
"xs14_32qczx12ko;xs16_31ego8gzy31246;0;;9,-74;0,-88;10,-48;-1,-1,0,1,1,0",
"xs14_32qj4ko;xs16_c4gf96z321;0;;5,-58;-9,-74,-4,-50;;0,4,0,1,-1,0",
"xs14_32qk0f9;xs16_32qk0f96;0;;;10,-32;9,-28,14,-32;0,0,1,0,0,1",
"xs14_32qk0f9;xs16_g2u05b8oz11;0;15,-70;;13,-40;9,-46;7,4,-1,0,0,-1",
"xs14_32qkzw254c;xs16_32qkzw254ko;0;;9,-70;0,-84;10,-44;5,8,-1,0,0,-1",
"xs14_32qkzx3426;xs16_0ggo8ge13z56;0;;9,-66;0,-80;10,-40;-1,7,0,1,-1,0",
"xs14_32qkzx34a4;xs16_252sgzx254ko;0;;9,-70;0,-84;10,-44;6,8,-1,0,0,-1",
"xs14_32qkzx34a4;xs16_32qkzx342sg;0;16,-105,24,-106;;;2,-89,3,-101;0,0,1,0,0,1",
"xs14_32qkzx34a4;xs16_32qkzx34a52;0;;;13,-12;3,-62;0,0,1,0,0,1",
"xs14_32qkzx34a4;xs16_32qkzx34ak8;0;18,-82;;;-4,-72;0,0,1,0,0,1",
"xs14_33032qr;xs15_642132qr;0;-5,-50,4,-71;-18,-15,-5,-33;;-6,-58;-1,0,1,0,0,1",
"xs14_33032qr;xs15_ck0o8brzw1;0;-5,-52,2,-55;-2,-46;-7,-62;;0,4,1,0,0,-1",
"xs14_33032qr;xs16_0g8go8brz23;0;-7,-74,-6,-108,2,-107;4,-91;-10,-101,-2,-108;-9,-70;-1,4,1,0,0,-1",
"xs14_330fh84c;xs16_0rb88gzc8421;0;;11,-54;-1,-66,6,-42,13,-22;6,-61;0,-1,0,1,1,0",
"xs14_330fh84c;xs16_31248hf033;0;;11,-54;10,-58;8,-56;9,0,-1,0,0,1",
"xs14_330fh84c;xs16_330fh84ko;0;16,-74;12,-58;12,-52,21,-21;;0,0,1,0,0,1",
"xs14_33gv146;xs16_08o1vg4cz32;0;-8,-75,-2,-70;-7,-96,1,-90;;-13,-86;-1,4,1,0,0,-1",
"xs14_33gv146;xs16_0c9b8oz2552;0;-4,-28;0,-39;;;6,-1,0,-1,1,0",
"xs14_33gv146;xs16_0c9b8oz653;0;-3,-56;1,-73;-13,-86;;6,-1,0,-1,1,0",
"xs14_33gv146;xs16_0c9b8ozc93;0;;-11,-77,-5,-129;-17,-109,-12,-82;;6,-1,0,-1,1,0",
"xs14_33gv146;xs16_6413gv146;0;-10,-81,-4,-133;;;-18,-113,-13,-86;-2,0,1,0,0,1",
"xs14_33gv146;xs16_641vg39c;0;-5,-98,2,-94;-9,-71,-3,-66;-12,-82;;6,0,-1,0,0,1",
"xs14_33gv146;xs16_64pb88czx23;0;;7,-70,12,-58;-7,-87,5,-61;;0,-2,0,1,1,0",
"xs14_33gv146;xs16_c9b8ozbd;0;;-8,-73,-7,-36;-9,-95,-6,-58;-13,-90;6,0,0,-1,1,0",
"xs14_33gv146;xs16_c9b8ozdb;0;-7,-88;-7,-56;-6,-84;-13,-86,-10,-110;6,0,0,-1,1,0",
"xs14_354260ui;xs15_0ra246z643;0;10,-86,21,-94;;;-10,-87,2,-83;7,0,0,-1,1,0",
"xs14_3542sga6;xs15_25iczwc953;0;-5,-39;3,-78,8,-69;-13,-90,2,-63;;-1,-1,0,1,1,0",
"xs14_354cgs26;xs14_31e861ac;0;3,-72;-1,-52;0,-56;-7,-66;7,1,-1,0,0,1",
"xs14_354cgs26;xs15_354cgs246;0;;10,-50;9,-35;12,-35;0,0,1,0,0,1",
"xs14_354cgs26;xs16_354cgs248c;0;16,-78;12,-58;9,-67;7,-82;0,0,1,0,0,1",
"xs14_354cgs26;xs16_354cgs256;0;;12,-58;;12,-42;0,0,1,0,0,1",
"xs14_354cgs26;xs16_ckl3zw34a6;0;-5,-42;;-7,-66;;7,4,0,-1,-1,0",
"xs14_354cj96;xs15_8k46picz11;0;-3,-45;2,-50;-7,-62;;0,4,1,0,0,-1",
"xs14_354cj96;xs16_065pa4z3521;0;-5,-38;;-7,-62;;6,-1,0,-1,1,0",
"xs14_354cj96;xs16_065pa4z6521;0;-4,-37;2,-50;-8,-66;;6,-1,0,-1,1,0",
"xs14_354qa4zx23;xs16_0mp3z122156;0;;-8,-12;16,-12;-15,-99,-6,-94;5,7,-1,0,0,-1",
"xs14_3560uh3;xs15_32hu0653;0;;10,-51;7,-36;12,-28;7,0,-1,0,0,1",
"xs14_3560uh3;xs16_3560uh246;0;16,-74;12,-60;7,-69;8,-68;0,0,1,0,0,1",
"xs14_358e12ko;xs16_0g84213zpia6;0;15,-70;;16,-16;1,-80;9,0,0,-1,1,0",
"xs14_358e1da;xs15_25b871ac;0;16,-74;;;23,-73;7,3,-1,0,0,-1",
"xs14_358e1da;xs16_358e1dio;0;15,-70;;12,-36;4,-74;0,0,1,0,0,1",
"xs14_358gka246;xs15_0j5oz349go;0;20,-90;;9,-75,22,-34;5,-93;9,4,0,-1,-1,0",
"xs14_358gka246;xs16_0o4i13zog943;0;14,-66;;;0,-82,6,-59,11,-40;9,0,0,-1,1,0",
"xs14_358gka246;xs16_31248a512ko;0;16,-74;;13,-44,20,-23;;10,4,-1,0,0,-1",
"xs14_358gka246;xs16_31i4ozojc1;0;17,-78;13,-62;;9,-72,18,-41;0,0,0,1,1,0",
"xs14_358go8b5;xs16_0g842132qkz32;0;-5,-32;2,-64;-4,-54;;-2,4,1,0,0,-1",
"xs14_358go8b5;xs16_31eowga6zx121;0;;14,-66;8,-68;9,-48;8,-1,-1,0,0,1",
"xs14_358go8gkc;xs15_g84213zdjo;0;-9,-46;0,-85;-13,-94,0,-83;;-1,4,0,1,-1,0",
"xs14_358go8gkc;xs16_0g842132156z32;0;-5,-36;2,-68;-4,-58;;-2,4,1,0,0,-1",
"xs14_358go8gkc;xs16_g88a52zdjo;0;-7,-43;5,-72;-5,-62;;-1,4,0,1,-1,0",
"xs14_358gzmp21;xs16_31248a51248c;0;14,-106,21,-113;;15,-12;;0,0,0,1,1,0",
"xs14_358gzw116io;xs16_358gzw116agzy223;0;;;20,-12;-8,-118;0,0,1,0,0,1",
"xs14_358gzw116io;xs16_y0j96zg4c32z11;0;-6,-48;4,-82,13,-87;;6,-48;6,-1,-1,0,0,1",
"xs14_358gzw11mq;xs16_xj96zkc32z11;0;-6,-48;4,-82,13,-87;;6,-48;5,-1,-1,0,0,1",
"xs14_358gzwok96;xs16_69jzwg9iczw11;0;-6,-48;4,-82,13,-87;;6,-48;0,-1,1,0,0,1",
"xs14_35a8og84c;xs16_g84213z178ko;0;;10,-50;4,-66,10,-43,15,-24;;9,4,0,-1,-1,0",
"xs14_35a8og84c;xs16_gs253zpic;0;17,-78;13,-62;13,-56,22,-25;;0,4,0,1,-1,0",
"xs14_35iczx1156;xs15_35iczx11da;0;20,-90;;16,-17;-3,-78;0,0,1,0,0,1",
"xs14_35iczx1156;xs16_35iczx11da4;0;20,-92;;18,-12;;0,0,1,0,0,1",
"xs14_35iczx1156;xs16_35iczx1pl2;0;15,-112;-8,-16;18,-12;-3,-105;0,0,1,0,0,1",
"xs14_39c0fho;xs15_32hu06io;0;14,-67;;16,-12;3,-52;7,4,-1,0,0,-1",
"xs14_39c0fho;xs16_39c0fh84c;0;16,-76;12,-58;12,-52;3,-85;0,0,1,0,0,1",
"xs14_39c88czw252;xs15_09v04a4z65;0;-2,-40;-2,-35;-5,-50;;5,1,0,-1,1,0",
"xs14_39c88czw252;xs15_39c88czw256;0;17,-78;;;-1,-72;0,0,1,0,0,1",
"xs14_39c88czw252;xs15_39c88czw652;0;12,-94;-10,-12;;;0,0,1,0,0,1",
"xs14_39c88czw252;xs16_025a4zc93113;0;11,-56;;;-9,-66;0,8,1,0,0,-1",
"xs14_39c88czw252;xs16_0696z31139c;0;15,-93;-9,-12;;;5,8,-1,0,0,-1",
"xs14_39c88czw252;xs16_25a4z31139c;0;15,-70;;;-5,-60;5,8,-1,0,0,-1",
"xs14_39c88czw252;xs16_39c88a6zw252;0;;11,-61,18,-82;-1,-75,14,-38;0,-88;0,0,1,0,0,1",
"xs14_39c88czw252;xs16_djoggozw4a4;0;-2,-52;0,-67;-7,-58;;0,-1,1,0,0,1",
"xs14_39cggmazx1;xs16_xkc32qkz321;0;;-4,-52;-6,-58;;-2,5,1,0,0,-1",
"xs14_39czy06996;xs14_0bq2sgz32;0;8,-58;;7,-24;-9,-74,6,-44;0,6,1,0,0,-1",
"xs14_39e0e93;xs15_0c8a52z6513;0;2,-54;-7,-30;;-9,-70;-1,0,0,1,1,0",
"xs14_39m86246;xs15_3pm86246;0;3,-68;;;-9,-74;0,0,1,0,0,1",
"xs14_39m86246;xs16_ggc2dioz146;0;;8,-46,15,-70;-1,-58,8,-35;5,-44;6,4,-1,0,0,-1",
"xs14_39m86246;xs16_ggc2dioz56;0;;9,-50,16,-74;0,-62,8,-39;5,-48;6,4,-1,0,0,-1",
"xs14_39m86246;xs17_3lka246z056;0;4,-77;-13,-21;;-8,-70;0,0,0,1,1,0",
"xs14_39m8628c;xs17_0c9jz6512213;0;4,-77;-13,-21;;-8,-70;7,0,0,-1,1,0",
"xs14_3hu06246;xs16_0dbz2lp13;0;-2,-72;-1,-73;-6,-64;-10,-78;7,0,0,-1,1,0",
"xs14_3hu0628c;xs15_32hu0628c;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs14_3hu0628c;xs16_039cz31pl2;0;-2,-72;-1,-73;-6,-64;-10,-78;7,4,0,-1,-1,0",
"xs14_3hu06426;xs16_0bdz2lp13;0;-2,-72;-1,-73;-6,-64;-10,-78;7,0,0,-1,1,0",
"xs14_3hu0696;xs15_32hu0696;0;-6,-28;-1,-36;-4,-51;;-1,0,1,0,0,1",
"xs14_3hu0696;xs16_642hu0696;0;-2,-68;-1,-69;-6,-60;-10,-74;-2,0,1,0,0,1",
"xs14_3hu06ac;xs16_642hu06ac;0;-2,-68;-1,-69;-6,-60;-10,-74;-2,0,1,0,0,1",
"xs14_3hu0og4c;xs15_32hu0og4c;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs14_3hu0og4c;xs16_c88b52z39c;0;-6,-38;;-6,-62;;-1,4,0,1,-1,0",
"xs14_3hu0og4c;xs16_c93z31pl2;0;-2,-72;-1,-73;-6,-64;-10,-78;7,4,0,-1,-1,0",
"xs14_3hu0oi6;xs15_32hu0oi6;0;-6,-28;-1,-36;-4,-51;;-1,0,1,0,0,1",
"xs14_3hu0oi6;xs16_642hu0oi6;0;-2,-68;-1,-69;-6,-60;-10,-74;-2,0,1,0,0,1",
"xs14_3hu0oi6;xs16_mkhjz1w652;0;-6,-34;;-6,-58;;6,4,0,-1,-1,0",
"xs14_3hu0okc;xs15_32hu0okc;0;-6,-28;-1,-36;-4,-51;;-1,0,1,0,0,1",
"xs14_3hu0okc;xs15_c88a52z356;0;-7,-34;-1,-45;-6,-58;;-1,4,0,1,-1,0",
"xs14_3hu0okc;xs16_642hu0okc;0;-2,-68;-1,-69;-6,-60;-10,-74;-2,0,1,0,0,1",
"xs14_3hu0okc;xs16_c88a53z356;0;-7,-35;-1,-43;-5,-54;;-1,4,0,1,-1,0",
"xs14_3hu0okc;xs16_c88b52z356;0;-6,-34;;-6,-58;;-1,4,0,1,-1,0",
"xs14_3hu0ui;xs15_32hu0ui;0;-6,-28;-1,-36;-4,-51;;-1,0,1,0,0,1",
"xs14_3hu0ui;xs16_0gbaarz123;0;-6,-30;;-6,-54;;5,-1,0,-1,1,0",
"xs14_3hu0ui;xs16_642hu0ui;0;-2,-64;-1,-65;-6,-56;-10,-70;-2,0,1,0,0,1",
"xs14_3ia4zrm;xs15_2eg84264213;0;7,-113,15,-113;-24,-12,-14,-21;;;-1,0,0,1,1,0",
"xs14_3ia4zrm;xs16_mp3zhik8z1;0;13,-118,22,-123;-15,-12;15,-12;;0,10,1,0,0,-1",
"xs14_3ia4zrq;xs15_03ia4zoja4;0;9,-97,16,-122;;16,-12;-11,-104;-1,0,1,0,0,1",
"xs14_3ia4zrq;xs16_0g84c8421e8z32;0;16,-129;-14,-12,-11,-58;;;3,10,0,-1,-1,0",
"xs14_3ia4zw115a4;xs16_3ia4zw115ak8;0;18,-82;;;-4,-72;0,0,1,0,0,1",
"xs14_3ia4zw115a4;xs16_3ia4zw11dic;0;18,-101;-8,-12;;;0,0,1,0,0,1",
"xs14_3ia4zw115a4;xs16_3ia4zw19la4;0;14,-66;;;-8,-76;0,0,1,0,0,1",
"xs14_3ia4zw11da;xs16_w358gzgil91z1;0;14,-108;-9,-12;;-8,-98;0,10,1,0,0,-1",
"xs14_3lmge2z01;xs16_3lmge2z32;0;15,-78;;16,-12;-4,-92;0,0,1,0,0,1",
"xs14_3lmzw34a4;xs15_0o48a52zbd;0;-6,-44;4,-77;-14,-94;;5,2,0,-1,1,0",
"xs14_3loz32ac;xs15_3loz32qk;0;18,-100;;15,-28,16,-12;;0,0,1,0,0,1",
"xs14_3loz32ac;xs16_31246178426;0;14,-118;-14,-12;16,-14;-7,-115;0,0,0,1,1,0",
"xs14_3lozpi6;xs16_31248go4og4c;0;-5,-48;2,-80;-4,-70;;-2,-2,0,1,1,0",
"xs14_3lozpi6;xs16_358go4og84c;0;5,-72;;;-15,-78;-2,10,0,1,-1,0",
"xs14_3lozpi6;xs16_69jzi5dz11;0;-6,-48;4,-82,13,-87;;6,-48;0,-1,1,0,0,1",
"xs14_3lozpi6;xs16_g8421343146z11;0;-3,-48;-5,-56,1,-57,6,-58;;;2,-1,0,-1,1,0",
"xs14_3lozx31246;xs16_3lozx312453;0;-6,-40;4,-74,13,-79;;6,-40;7,7,0,-1,-1,0",
"xs14_3lozx35a4;xs13_3lozxbd;0;;-8,-12;12,-35;-15,-107;0,0,1,0,0,1",
"xs14_3lozx35a4;xs16_3lozx35ak8;0;18,-82;;;-4,-72;0,0,1,0,0,1",
"xs14_3pa4zw1156;xs16_3pa4zw11da4;0;19,-92;;17,-12;;0,0,1,0,0,1",
"xs14_3pa4zw1156;xs16_3pa4zw1pl2;0;14,-112;-9,-16;17,-12;-4,-105;0,0,1,0,0,1",
"xs14_3pczw115a4;xs16_03hik8zoj6;0;;-12,-18;16,-28;-12,-82,-9,-92,-3,-94;0,9,1,0,0,-1",
"xs14_3pczw115a4;xs16_3pczw115ak8;0;18,-82;;;-4,-72;0,0,1,0,0,1",
"xs14_3pczw115a4;xs16_3pczw19la4;0;14,-66;;;-8,-76;0,0,1,0,0,1",
"xs14_3pczw115a4;xs16_xo4c84213z2521;0;-5,-44;5,-78;;;-1,8,0,1,-1,0",
"xs14_3pczw11da;xs16_3pczwh952zw11;0;14,-108;-9,-12;;-8,-98;0,0,1,0,0,1",
"xs14_3pczw11da;xs16_xg8oge123z321;0;-5,-44;5,-78;;;5,-2,0,-1,1,0",
"xs14_3pczw12453;xs16_358gzw358gkc;0;-5,-40;5,-74;;;-1,-2,1,0,0,1",
"xs14_3pczw12453;xs16_wg8og853z69c;0;;-4,-52;-6,-58;;-2,7,0,1,-1,0",
"xs14_3pczw1248go;xs16_xg84c84213zca1;0;-5,-48;5,-82;;;-1,9,0,1,-1,0",
"xs14_3pczw6jo;xs16_xcp3z0gb6z32;0;;;18,-12;-10,-118;5,0,-1,0,0,1",
"xs14_3pczwpic;xs16_xj96z0gb6z32;0;-5,-48;5,-82;;;-1,9,1,0,0,-1",
"xs14_3pmzw34a4;xs16_3pmzw342sg;0;15,-101,23,-102;;;1,-85,2,-97;0,0,1,0,0,1",
"xs14_3pmzw34a4;xs16_3pmzw34a52;0;;;12,-12;2,-62;0,0,1,0,0,1",
"xs14_3pmzw34a4;xs16_3pmzw34ak8;0;17,-78;;;-5,-68;0,0,1,0,0,1",
"xs14_3pmzx3213;xs15_ol3zw32156;0;;11,-54;10,-57;0,-95,13,-54;7,6,0,-1,-1,0",
"xs14_3pmzx3213;xs16_3pmzx32156;0;18,-89;8,-49;14,-43,23,-12;;0,0,1,0,0,1",
"xs14_3pmzx3213;xs16_3pmzxj4czx11;0;14,-70,21,-94;;11,-12;-9,-82,0,-59;0,0,1,0,0,1",
"xs14_3pmzx3213;xs16_xmp3zck3z11;0;15,-74,22,-98;;11,-16;-8,-86,0,-63;5,0,-1,0,0,1",
"xs14_4a51i4ozx121;xs16_4a51i4ozw2521;0;-1,-55;;;-9,-70;6,6,0,-1,-1,0",
"xs14_4a51i4ozx121;xs17_4a51i4ozxbc1;0;5,-78;-7,-23;;-14,-90;6,6,0,-1,-1,0",
"xs14_4a52sga6;xs16_25ak871ac;0;-1,-59;;;-9,-74;-1,4,1,0,0,-1",
"xs14_4a9jz0bd;xs16_8kk3146z6421;0;1,-64,10,-77;-15,-12,-8,-16;;-7,-74;3,7,-1,0,0,-1",
"xs14_4a9jz0bd;xs16_o8616853z23;0;2,-72,10,-81;-16,-12,-9,-16;;-7,-78;3,7,0,-1,-1,0",
"xs14_4a9jzx1156;xs15_4a9jzx115a4;0;21,-96;;18,-12;-3,-83;0,0,1,0,0,1",
"xs14_4a9jzx1156;xs15_4a9jzx11da;0;20,-90;;16,-17;-3,-78;0,0,1,0,0,1",
"xs14_4a9jzx1156;xs16_4a9jzx115ac;0;21,-97;;17,-12;-3,-81;0,0,1,0,0,1",
"xs14_4a9jzx1156;xs16_4a9jzx11da4;0;20,-92;;18,-12;;0,0,1,0,0,1",
"xs14_4a9jzx1156;xs16_4a9jzx1pl2;0;15,-112;-8,-16;18,-12;-3,-105;0,0,1,0,0,1",
"xs14_4a9m88gzx121;xs22_653g8k48gzw349611;0;;;4,-63;8,-57,11,-36;8,-2,-1,0,0,1",
"xs14_4a9raa4;xs15_4a9r2qk;0;;15,-129;5,-119,12,-105,17,-12;-18,-151,5,-144;0,0,1,0,0,1",
"xs14_4a9raa4;xs15_4a9r8b5;0;13,-135;;-14,-135,9,-128;-5,-145,8,-121,13,-28;0,0,1,0,0,1",
"xs14_4a9raa4;xs15_4aar9ic;0;0,-59;;17,-22;-10,-74,-5,-73,1,-69,6,-78;6,0,-1,0,0,1",
"xs14_4aaraa4;xs18_08u1u8zc4521;0;;-5,-57,-2,-77;-14,-90,-5,-72;;6,-1,0,-1,1,0",
"xs14_4aarzx1252;xs15_4aarzx1256;0;19,-86;;;1,-80;0,0,1,0,0,1",
"xs14_4aarzx1252;xs16_0g88e1e8z1252;0;;;12,-12;4,-54;0,7,0,1,-1,0",
"xs14_4aarzx1252;xs16_4aarzx121e8;0;15,-101,23,-102;;;3,-85,4,-97;0,0,1,0,0,1",
"xs14_4aarzx1252;xs16_4aarzx12552;0;18,-82;;;4,-67;0,0,1,0,0,1",
"xs14_4aarzx1252;xs16_4aarzx125a4;0;17,-78;;;-3,-68;0,0,1,0,0,1",
"xs14_4ai3146zw23;xs16_4ai312kozw23;0;;;13,-12;-1,-62;0,0,1,0,0,1",
"xs14_4ai31e8z011;xs15_4ai31e8zw23;0;7,-82,19,-86;;;-14,-93,-3,-85;0,0,1,0,0,1",
"xs14_4ai31e8z011;xs16_0354koz31243;0;;14,-66;8,-66;11,-40;7,5,0,-1,-1,0",
"xs14_4ai31e8z011;xs16_4ai31e8z321;0;15,-78;-9,-23;19,-12;-16,-102,-7,-97;0,0,1,0,0,1",
"xs14_4aq453z32;xs16_04aq453zca1;0;11,-94;-11,-12;;;-1,0,1,0,0,1",
"xs14_4aq453z32;xs16_0o4og853z643;0;2,-72;;;-12,-78;-2,0,0,1,1,0",
"xs14_4s0f96z11;xs16_32qb9czw23;0;-4,-44;2,-62;2,-62,13,-29,20,-12;2,-77;0,5,0,1,-1,0",
"xs14_4s0fhoz11;xs16_3iab8oz123;0;15,-70;;15,-14;;0,5,0,1,-1,0",
"xs14_4s0fhoz11;xs16_3iab8oz321;0;14,-66;;16,-15;2,-55;0,5,0,1,-1,0",
"xs14_4s0fhoz11;xs16_3iab8ozw56;0;15,-72;11,-54;11,-48;2,-81;0,5,0,1,-1,0",
"xs14_5b8og8426;xs16_0g853z12264ko;0;-2,-52;-1,-72;-7,-70;;8,5,0,-1,-1,0",
"xs14_5b8og8426;xs16_g0g842132qkz11;0;;13,-62;10,-66;10,-56;10,4,-1,0,0,-1",
"xs14_5b8ozxc93;xs16_0312kozkq23;0;7,-68;;;-11,-74;0,9,1,0,0,-1",
"xs14_5b8ozxc93;xs16_5b8ozwg853zw11;0;16,-110;-10,-12;;;0,0,1,0,0,1",
"xs14_5bo8goz32;xs15_j9c871z23;0;18,-82;8,-49;12,-36;-2,-72;0,6,1,0,0,-1",
"xs14_5bo8goz32;xs16_31ke123z65;0;15,-70;;12,-24;2,-74;0,6,0,1,-1,0",
"xs14_5bo8goz32;xs16_6iog853z56;0;13,-62;;;-5,-78,1,-55,6,-36;0,7,1,0,0,-1",
"xs14_628c2dic;xs16_04all2zc8421;0;-4,-28;4,-54;;;7,-1,0,-1,1,0",
"xs14_628c2dic;xs16_31248c2dic;0;;-5,-52;-5,-58;;-2,0,1,0,0,1",
"xs14_64132qr;xs16_358go8br;0;7,-62;-7,-12;;;-1,4,1,0,0,-1",
"xs14_64132qr;xs16_6248go8br;0;-2,-60;;;-8,-66;-2,4,1,0,0,-1",
"xs14_6413kcz0321;xs16_06413kczc8421;0;6,-78;-8,-12;;-11,-74;-1,0,1,0,0,1",
"xs14_6413kcz0321;xs16_ck312kozw56;0;1,-40;-8,-25,-6,-12;;;5,0,0,-1,1,0",
"xs14_6413kczw65;xs13_6413kczx32;0;10,-72,18,-82;;;-4,-69;0,0,1,0,0,1",
"xs14_6413kczw65;xs15_6413kcz0ca1;0;7,-97,15,-97;-20,-12,-10,-21;;;0,0,1,0,0,1",
"xs14_6413kczw65;xs16_0j96z32c826;0;13,-102,22,-107;-11,-12;15,-12;;5,8,-1,0,0,-1",
"xs14_6413kczw65;xs16_358gzc4go56;0;11,-100;-10,-12;;-9,-90;0,9,1,0,0,-1",
"xs14_6413kczw65;xs16_ck31248czw56;0;1,-40;-8,-25,-6,-12;;;5,0,-1,0,0,1",
"xs14_6421egma;xs16_069abgzc8421;0;-3,-36,2,-55,8,-78;;;-6,-62;7,5,0,-1,-1,0",
"xs14_6421egma;xs16_31248ge1da;0;1,-74;-5,-40;;-8,-70;-2,4,1,0,0,-1",
"xs14_6421egma;xs16_35421egma;0;-10,-37,-1,-68;;-5,-58;-9,-74;-1,0,1,0,0,1",
"xs14_6421eozx65;xs16_0358gzc48ge3;0;12,-100;-9,-12;;-8,-90;0,9,1,0,0,-1",
"xs14_6421eozx65;xs16_6421eozc8421;0;5,-76,11,-77,16,-78;-7,-12;;;0,0,1,0,0,1",
"xs14_6421eozx65;xs16_j96z178426;0;14,-102,23,-107;-10,-12;16,-12;;5,8,-1,0,0,-1",
"xs14_64268m96;xs16_ggc2dicz146;0;2,-44;-1,-35,8,-58;-8,-70,-1,-46;;1,4,1,0,0,-1",
"xs14_64268m96;xs16_ggc2dicz56;0;2,-48;-1,-39,7,-62;-9,-74,-2,-50;;1,4,1,0,0,-1",
"xs14_642hjkczx1;xs16_642hjkczw32;0;17,-78;;18,-12;-2,-92;0,0,1,0,0,1",
"xs14_642hjkczx1;xs16_8e13kcz6421;0;-2,-34,5,-54,12,-78;-3,-41;;-8,-66;6,5,0,-1,-1,0",
"xs14_642hjkczx1;xs16_8e13kkozx32;0;-5,-46;-11,-59,-4,-42;-8,-66;;6,5,0,-1,-1,0",
"xs14_642hjkczx1;xs16_ck31e8z643;0;-10,-33,-1,-64;;-5,-54;-9,-70;6,0,0,-1,1,0",
"xs14_642hu066;xs15_8k9b8ozw56;0;;10,-50;3,-59;12,-32;7,-1,0,-1,1,0",
"xs14_642hu066;xs16_0o8bbgzc8421;0;-2,-38,5,-58,12,-82;-3,-45;;-8,-70;7,5,0,-1,-1,0",
"xs14_642hu066;xs16_31248hf0cc;0;1,-74;-5,-40;;-8,-70;-2,4,1,0,0,-1",
"xs14_642hu066;xs16_3542hu066;0;-10,-37,-1,-68;;-5,-58;-9,-74;-1,0,1,0,0,1",
"xs14_64kb9czw11;xs15_4a4o79ozx11;0;9,-67;-8,-12;;-11,-80;0,6,0,1,-1,0",
"xs14_64kb9czw11;xs15_64kb9czw23;0;;-8,-12,-7,-28;;-10,-76;0,0,1,0,0,1",
"xs14_64kb9czw11;xs16_64kb9cz0123;0;;-8,-12;;-10,-76;0,0,1,0,0,1",
"xs14_64kb9czw11;xs16_64kb9cz0321;0;9,-65;-7,-12;;-11,-81;0,0,1,0,0,1",
"xs14_64kb9czw11;xs16_64kb9czx56;0;9,-89;-8,-12;14,-16;-5,-96;0,0,1,0,0,1",
"xs14_64kb9czw11;xs16_64p78cz321;0;-10,-32,-1,-63;;-5,-53;-9,-69;5,0,0,-1,1,0",
"xs14_64kb9czw11;xs16_cahdioz023;0;;;12,-12;2,-47;6,0,0,-1,1,0",
"xs14_64lb8ozw11;xs14_64lb8ozx11;0;;9,-46;3,-36;;5,5,-1,0,0,-1",
"xs14_64lb8ozw11;xs15_4a4o79czw11;0;;-8,-12;14,-12;-15,-91,-6,-86;0,6,0,1,-1,0",
"xs14_64lb8ozx11;xs15_4a4o796zw11;0;-4,-32;6,-66,15,-71;;8,-32;5,-1,0,-1,1,0",
"xs14_65la4ozx11;xs14_04al56z311;0;16,-74;;9,-21;-4,-59;5,0,-1,0,0,1",
"xs14_65la4ozx11;xs15_65la4ozw121;0;-7,-99,-3,-86,16,-126;-18,-76;;-12,-78,0,-120;0,0,1,0,0,1",
"xs14_65la4ozx11;xs15_69la8czw23;0;6,-78;-8,-28,0,-57,8,-66;-3,-75;10,-32;5,5,-1,0,0,-1",
"xs14_65la8czw11;xs15_4a4o796zx11;0;9,-67;-8,-12;;-11,-80;0,6,0,1,-1,0",
"xs14_65la8czw11;xs15_65la8czw23;0;;-8,-12,-7,-28;;-10,-76;0,0,1,0,0,1",
"xs14_65la8czw11;xs16_65la8cz0123;0;;-8,-12;;-10,-76;0,0,1,0,0,1",
"xs14_65la8czw11;xs16_65la8cz0321;0;9,-65;-7,-12;;-11,-81;0,0,1,0,0,1",
"xs14_65la8czw11;xs16_65la8czx56;0;9,-91;-8,-14;16,-12;-6,-94;0,0,1,0,0,1",
"xs14_65la8czw11;xs16_gbhegoz123;0;15,-70;9,-46;;5,-64,14,-33;6,0,0,-1,1,0",
"xs14_65pa4ozx11;xs14_04ap56z311;0;16,-74;;9,-21;-4,-59;5,0,-1,0,0,1",
"xs14_6970si6;xs15_25a8czx2553;0;16,-74;;14,-26;3,-58;7,6,0,-1,-1,0",
"xs14_6996zzw6426;xs15_69b88czw252;0;14,-96;;9,-12;-16,-103;0,14,1,0,0,-1",
"xs14_69a4y04aic;xs26_652y2o8zy23p69czy211y24a6;0;-10,-28;11,-96,19,-126;25,-12;-12,-142,-4,-112;-1,-6,0,1,1,0",
"xs14_69ak8zx1252;xs16_1784ozx12596;0;15,-101,23,-102;;;3,-85,4,-97;7,8,-1,0,0,-1",
"xs14_69ak8zx1252;xs16_25a4ozx12596;0;17,-78;;;-3,-68;7,8,-1,0,0,-1",
"xs14_69arzx123;xs15_69arzx1213;0;15,-83;;17,-12;0,-68;0,0,1,0,0,1",
"xs14_69arzx123;xs16_69arzx1253;0;17,-84;;17,-12;;0,0,1,0,0,1",
"xs14_69arzx123;xs16_g88e1daz056;0;17,-80;9,-46;13,-40;0,-89;0,6,0,1,-1,0",
"xs14_69bo8a6;xs14_08u156z65;0;;;11,-34,14,-12;-2,-74,9,-48;0,5,0,1,-1,0",
"xs14_69bo8a6;xs15_5b8ob96;0;;12,-58;5,-46;8,-49;6,0,-1,0,0,1",
"xs14_69bo8a6;xs16_25b8ob96;0;;12,-58;;10,-42;7,0,-1,0,0,1",
"xs14_69bo8a6;xs16_35a8ob96;0;;13,-62;5,-46;9,-41;7,0,-1,0,0,1",
"xs14_69bqic;xs16_8o6hdaz1221;0;1,-41,14,-66;1,-45;-5,-50,8,-25;0,-61;0,-1,1,0,0,1",
"xs14_69eg8ozw23;xs15_255m88czx23;0;;7,-54,8,-42;;8,-42;0,0,0,1,1,0",
"xs14_69eg8ozw23;xs15_69eg8k8zw23;0;;8,-42;9,-29;9,-42;0,0,1,0,0,1",
"xs14_69eg8ozw23;xs16_0g8p78cz3421;0;3,-57;-9,-12,-4,-38;;;-1,6,1,0,0,-1",
"xs14_69eg8ozw23;xs16_0jhegoz343;0;;-9,-12;15,-12;-16,-99,-7,-94;0,7,1,0,0,-1",
"xs14_69eg8ozw23;xs16_69eg8kczw23;0;;7,-38;9,-27;9,-43;0,0,1,0,0,1",
"xs14_69eg8ozw23;xs16_69eg8kozw23;0;;8,-42;;8,-42;0,0,1,0,0,1",
"xs14_69eg8ozw23;xs16_c45r88czx23;0;-2,-65;-7,-36,1,-59,8,-59,15,-70;3,-63;-11,-74;5,6,0,-1,-1,0",
"xs14_69eg8ozw23;xs16_c88m552z065;0;16,-78;8,-42;9,-51;3,-82;0,6,0,1,-1,0",
"xs14_69f0f9;xs14_3hu0ui;0;0,-24;-2,-18;;;0,4,1,0,0,-1",
"xs14_69jzw23033;xs15_c842156z352;0;20,-90;;12,-34;2,-75;0,6,0,1,-1,0",
"xs14_69la4ozx11;xs14_04al96z311;0;-5,-32;-3,-25;0,-39;;5,0,0,-1,1,0",
"xs14_69m88czw23;xs16_0c88m96z6421;0;11,-79;;14,-12;-8,-68,-1,-60,6,-56;6,0,-1,0,0,1",
"xs14_69m88czw23;xs16_69m88a6zw23;0;15,-73;9,-49;;5,-67,14,-36;0,0,1,0,0,1",
"xs14_69m88czw23;xs16_69m88cz0643;0;;-9,-12;15,-12;-16,-99,-7,-94;0,0,1,0,0,1",
"xs14_69m88czw23;xs16_c88m96zca1;0;13,-83,20,-90;;14,-13;;5,0,-1,0,0,1",
"xs14_69q4goz023;xs16_69q4goz643;0;;-10,-12;14,-12;-17,-99,-8,-94;0,0,1,0,0,1",
"xs14_6ikm93z01;xs16_6ikm93z32;0;15,-78;;16,-12;-4,-92;0,0,1,0,0,1",
"xs14_6ikm96z01;xs16_6ikm96z32;0;15,-78;;16,-12;-4,-92;0,0,1,0,0,1",
"xs14_6is079c;xs15_25a8czx6513;0;;12,-58;7,-42;10,-42;7,-2,0,-1,1,0",
"xs14_6is079c;xs15_25is079c;0;-10,-33,-1,-64;;-5,-54;-9,-70;-1,0,1,0,0,1",
"xs14_8e1248cz33;xs15_8k461aczw56;0;9,-80;-12,-12;;-12,-98,-5,-73;-1,0,0,1,1,0",
"xs14_8e1248cz33;xs16_g853z011321e8;0;3,-101;-15,-39,-7,-78;14,-12;-14,-128,-13,-158,-5,-125;6,0,0,-1,1,0",
"xs14_8e1248gzy31246;xs16_31248gzy21248ge2;0;23,-102;;20,-32;4,-106;12,9,-1,0,0,-1",
"xs14_8ehjzw1074;xs15_0252sgz8e13;0;;9,-64;4,-51;10,-40;5,-1,-1,0,0,1",
"xs14_8ehjzw1074;xs15_ggkc32qkz1;0;;7,-56,9,-46;7,-44;;0,7,0,1,-1,0",
"xs14_8ehjzw1074;xs16_0352sgz8e13;0;;8,-59;4,-48;10,-40;5,-1,-1,0,0,1",
"xs14_8ehjzw1074;xs16_0652sgz8e13;0;;9,-64;;9,-40;5,-1,-1,0,0,1",
"xs14_8ehjzw1074;xs16_31egozxc871;0;;9,-46;11,-46;6,-52;6,8,-1,0,0,-1",
"xs14_8ehjzw1252;xs14_0jhe8zca1;0;16,-74,21,-98;;10,-20;-7,-82;4,0,-1,0,0,1",
"xs14_8ehjzw1252;xs15_0gbhe8z3421;0;;;13,-12;-7,-69;5,0,-1,0,0,1",
"xs14_8ehjzw1252;xs16_25akozxc871;0;16,-74;;;-4,-64;6,8,-1,0,0,-1",
"xs14_8k453zbd;xs15_8k453z3lo;0;9,-113,22,-124;;18,-12;-7,-115;0,0,1,0,0,1",
"xs14_8k453zbd;xs15_drz122qk;0;;11,-61;2,-49;7,-44;0,8,1,0,0,-1",
"xs14_8k453zbd;xs16_08k453zojd;0;;-13,-12;15,-12;-20,-115,-11,-110;-1,0,1,0,0,1",
"xs14_8k453zbd;xs16_0gjl8zdmz11;0;-3,-48;6,-88;2,-81;9,-44;0,-2,1,0,0,1",
"xs14_8k453zbd;xs16_31eg8og8426;0;13,-98,20,-105;;14,-12;;4,0,0,-1,1,0",
"xs14_8k453zdd;xs15_08k453z259c;0;11,-96;-14,-12;;-14,-114,-7,-89;-1,0,1,0,0,1",
"xs14_8k453zdd;xs16_31eg8og853;0;;;11,-58,14,-12;-14,-121;4,0,0,-1,1,0",
"xs14_8ljgzx25a4;xs16_8ljgzx25ak8;0;18,-82;;;-4,-72;0,0,1,0,0,1",
"xs14_8ljgzx34a4;xs15_8ljgzx34ac;0;20,-90;;;0,-84;0,0,1,0,0,1",
"xs14_8ljgzx34a4;xs16_8ljgzx342sg;0;16,-105,24,-106;;;2,-89,3,-101;0,0,1,0,0,1",
"xs14_8ljgzx34a4;xs16_8ljgzx34a52;0;;;13,-12;3,-62;0,0,1,0,0,1",
"xs14_8ljgzx34a4;xs16_8ljgzx34aa4;0;19,-86;;;3,-71;0,0,1,0,0,1",
"xs14_8ljgzx34a4;xs16_8ljgzx34ak8;0;18,-82;;;-4,-72;0,0,1,0,0,1",
"xs14_8o0uh3z23;xs16_8ljgozx6226;0;15,-70;11,-56;6,-65;7,-64;7,0,0,-1,1,0",
"xs14_8o0uh3z23;xs16_9f0s4zx1253;0;;11,-60;;11,-36;0,6,1,0,0,-1",
"xs14_8u15a4z32;xs15_8u15acz32;0;14,-66;;;4,-60;0,0,1,0,0,1",
"xs14_8u15a4z32;xs15_ciligzx1074;0;4,-74;-14,-12;12,-19;-10,-94;5,0,0,-1,1,0",
"xs14_8u15a4z32;xs16_8u15a4z346;0;10,-94,19,-99;-12,-12;12,-12;;0,0,1,0,0,1",
"xs14_8u15a4z32;xs16_8u15a8oz32;0;;;9,-43,17,-12;-4,-91,-3,-75;0,0,1,0,0,1",
"xs14_8u15a4z32;xs16_8u15ak8z32;0;14,-66;;;6,-51;0,0,1,0,0,1",
"xs14_9f03pm;xs16_g6p30f9z11;0;12,-97,17,-78,22,-100;;17,-30;1,-77;6,0,-1,0,0,1",
"xs14_9v04a4z32;xs15_9v04a6z32;0;;10,-50;8,-44;;0,0,1,0,0,1",
"xs14_9v04a4z32;xs15_9v04acz32;0;13,-62;;;5,-67;0,0,1,0,0,1",
"xs14_9v04a4z32;xs16_3hu08k8z065;0;-2,-36;-10,-19,-5,-16;;;-1,-1,1,0,0,1",
"xs14_9v04a4z32;xs16_9v04a4z346;0;10,-94,19,-99;-12,-12;12,-12;;0,0,1,0,0,1",
"xs14_9v04a4z32;xs16_9v04a52z32;0;;10,-50;10,-35;;0,0,1,0,0,1",
"xs14_9v04a4z32;xs16_9v04aa4z32;0;13,-62;;;7,-47;0,0,1,0,0,1",
"xs14_9v04a4z32;xs16_9v04ak8z32;0;14,-66;;;6,-51;0,0,1,0,0,1",
"xs14_9v04a4z32;xs18_bt0uh3z23;0;13,-62;;;-9,-74,-2,-50;0,6,1,0,0,-1",
"xs14_bdggka4zw1;xs16_31i3s4z2521;0;;11,-54;11,-39;;0,0,0,1,1,0",
"xs14_bdggka4zw1;xs16_31i3s4z4701;0;;;1,-79,2,-63;6,-63,14,-32;0,0,0,1,1,0",
"xs14_bdggka4zw1;xs16_kc32ak8z123;0;;4,-67,9,-48,14,-70;1,-47;9,-32;0,5,1,0,0,-1",
"xs14_brz34ac;xs15_35a84cga6;0;-6,-44;3,-64;-6,-82,1,-57;;3,8,0,-1,-1,0",
"xs14_brz34ac;xs15_ci53z3lo;0;;6,-63,19,-97;-6,-80,3,-65;5,-44;0,8,1,0,0,-1",
"xs14_brz34ac;xs16_32qkzw69ko;0;-9,-71,-1,-110;-3,-85;-8,-112,-7,-142,1,-109;8,-44;-2,-1,1,0,0,1",
"xs14_brz34ac;xs16_358go8gka6;0;;;-6,-89;3,-90,6,-44;4,-1,0,-1,1,0",
"xs14_brzrm;xs16_312312312ko;0;;;-6,-93;3,-94,6,-48;0,9,0,1,-1,0",
"xs14_brzrm;xs16_drzbmggzx1;0;-9,-75,-1,-114;-3,-89;-8,-116,-7,-146,1,-113;8,-48;1,9,-1,0,0,-1",
"xs14_c842arzx32;xs15_178j146zx23;0;-7,-47,4,-83;-14,-12,-2,-56;;;5,0,0,-1,1,0",
"xs14_c842arzx32;xs16_0c93g8oz6511;0;-5,-36;5,-76;-4,-62;;6,6,-1,0,0,-1",
"xs14_c842arzx32;xs16_178j12kozw11;0;5,-60;;;-9,-66;5,0,0,-1,1,0",
"xs14_c842arzx32;xs16_641j871z065;0;2,-70;-6,-28;;-9,-66;5,6,0,-1,-1,0",
"xs14_c842arzx32;xs16_641j871z321;0;-1,-36,6,-56,13,-80;-4,-35;;-9,-68;5,6,0,-1,-1,0",
"xs14_c842arzx32;xs16_c842arzwca1;0;14,-94;-8,-12;;;0,0,1,0,0,1",
"xs14_c842arzx32;xs16_ra248a6z023;0;-9,-36,0,-67;;-4,-49;-10,-73;5,0,-1,0,0,1",
"xs14_c88a52z352;xs16_mligz1w254c;0;;;-1,-95,0,-79;6,-71,14,-40;0,7,1,0,0,-1",
"xs14_c88a52z352;xs16_mligz1w25a4;0;;11,-54;9,-39;;0,7,1,0,0,-1",
"xs14_c88a52z352;xs16_ogila4z6a4;0;;5,-30;-1,-40;;0,-1,1,0,0,1",
"xs14_c88a53z33;xs15_0c88a53z253;0;7,-64,15,-83;;;-9,-66;-1,0,1,0,0,1",
"xs14_c88a53z33;xs16_0c88a53z2552;0;12,-59;;;-6,-54;-1,0,1,0,0,1",
"xs14_c88a53z33;xs16_0c88a53z653;0;6,-95;-18,-12;;-10,-94;-1,0,1,0,0,1",
"xs14_c88a53z33;xs16_0c88a53zc93;0;12,-175,18,-147;-22,-19,-17,-12;;;-1,0,1,0,0,1",
"xs14_c88a53z33;xs16_bdz3115ac;0;;-11,-27;12,-12,15,-37;-14,-131;0,8,1,0,0,-1",
"xs14_c88a53z33;xs16_c88a53z39c;0;;;18,-12,23,-19;-17,-147,-11,-175;0,0,1,0,0,1",
"xs14_c88a53z33;xs16_c88a53zbd;0;15,-131;-14,-37,-11,-12;12,-27;;0,0,1,0,0,1",
"xs14_c88a53z33;xs16_c93s4zx1256;0;-5,-36,0,-68;-12,-37,0,-59;;;-2,6,0,1,-1,0",
"xs14_c88a53z33;xs16_mkhjz1w256;0;10,-104,16,-133;-17,-12;;-13,-150,-5,-112;0,7,1,0,0,-1",
"xs14_c88a53z33;xs16_w4s0c93z6521;0;6,-112,14,-150;;18,-12;-15,-133,-9,-104;-2,0,0,1,1,0",
"xs14_c88e13z33;xs15_c88e123z33;0;;10,-72,11,-60;;11,-36;0,0,1,0,0,1",
"xs14_c88e13z33;xs16_8ljgzw47066;0;13,-66;11,-54;6,-63;6,-70;7,0,0,-1,1,0",
"xs14_c88e13z33;xs16_oggs256z66;0;;11,-60;;11,-36;0,-1,1,0,0,1",
"xs14_c9jz354c;xs16_2ego4og853;0;;8,-42;6,-36;;4,8,0,-1,-1,0",
"xs14_c9jz354c;xs16_c9jz354ko;0;11,-116;-15,-12;;-14,-102;0,0,1,0,0,1",
"xs14_c9jz6ip;xs16_358go44og4c;0;;8,-42;6,-36;;4,-1,0,-1,1,0",
"xs14_c9jzmq1;xs16_j9cz122c826;0;1,-72,10,-85;-17,-12,-10,-16;;-9,-82;2,0,-1,0,0,1",
"xs14_c9jzmq1;xs16_j9cz122c84c;0;2,-80,10,-89;-18,-12,-11,-16;;-9,-86;2,0,-1,0,0,1",
"xs14_c9jzw115a4;xs16_25a8ozwog853;0;;8,-42;6,-36;;6,8,-1,0,0,-1",
"xs14_c9jzw115a4;xs16_o8gxgs252zx123;0;;;-3,-78;7,-44;6,-2,0,-1,1,0",
"xs14_c9jzw1qm;xs16_321344og853;0;;8,-42;6,-36;;4,9,0,-1,-1,0",
"xs14_c9jzwpi6;xs16_358go443146;0;;8,-42;6,-36;;4,-1,0,-1,1,0",
"xs14_ca168ozx65;xs16_j96z116853;0;14,-102,23,-107;-10,-12;16,-12;;5,8,-1,0,0,-1",
"xs14_ca9jzca1;xs16_69jz6aip;0;12,-110,21,-115;-14,-12;14,-12;;0,9,1,0,0,-1",
"xs14_ca9jzca1;xs16_wg853zi5kcz11;0;10,-108;-13,-12;;-12,-98;3,10,-1,0,0,-1",
"xs14_ca9jzw1226;xs16_354k8zxc953;0;12,-108;-12,-12;;-11,-94;6,8,-1,0,0,-1",
"xs14_ca9jzw1252;xs16_25ak8zxc953;0;16,-74;;;-4,-64;6,8,-1,0,0,-1",
"xs14_cai3zbd;xs16_3iaczw116413;0;0,-64,9,-77;-16,-12,-9,-16;;-8,-74;3,0,-1,0,0,1",
"xs14_cai3zbd;xs16_dbgz354ko;0;-7,-44;3,-84;-6,-70;;0,8,1,0,0,-1",
"xs14_cai3zbd;xs16_ggc2c871z56;0;1,-72,9,-81;-17,-12,-10,-16;;-8,-78;3,7,0,-1,-1,0",
"xs14_cai3zw1156;xs15_5b8ozwc453;0;19,-86;;15,-13;-4,-74;5,8,-1,0,0,-1",
"xs14_cai3zw1156;xs16_0354kozca23;0;-7,-40;3,-80;-6,-66;;5,-1,-1,0,0,1",
"xs14_cai3zw1156;xs16_25b8ozxc453;0;19,-92;;17,-12;;6,8,-1,0,0,-1",
"xs14_ci52z3lo;xs16_25a84c842ac;0;;-13,-12;17,-12;-20,-123,-11,-118;3,0,0,-1,1,0",
"xs14_ci52z3lo;xs16_25akg8og84c;0;;7,-38;1,-28;;4,-1,0,-1,1,0",
"xs14_ci52z3lo;xs16_31248go8gka4;0;15,-106,22,-113;;16,-12;;4,11,0,-1,-1,0",
"xs14_ci52z3lo;xs16_32akg8og84c;0;;5,-61,13,-62;7,-45,8,-57;;4,-1,0,-1,1,0",
"xs14_ci52zdl8;xs15_25a84c0f9;0;21,-100;;14,-12;;3,0,0,-1,1,0",
"xs14_ci52zw12453;xs16_g842156z125a4;0;;7,-40;1,-30;;0,7,1,0,0,-1",
"xs14_ci53z39c;xs16_31248c48a53;0;;;15,-12;-11,-110;3,10,0,-1,-1,0",
"xs14_ci53zbd;xs16_0ci53zojd;0;;-13,-12;15,-12;-20,-115,-11,-110;-1,0,1,0,0,1",
"xs14_ci53zw1248c;xs16_xg84215aczca1;0;20,-111;;17,-33,24,-12;;0,10,0,1,-1,0",
"xs14_cilmzx252;xs16_cilmzw4a52;0;12,-58;;;-8,-68;0,0,1,0,0,1",
"xs14_cilmzx252;xs16_cilmzx254c;0;;;13,-43,21,-12;-8,-123,-7,-107;0,0,1,0,0,1",
"xs14_cilmzx252;xs16_cilmzx25a4;0;16,-74;;;-4,-64;0,0,1,0,0,1",
"xs14_ck31246z023;xs13_ol3zw3213;0;;;6,-47;4,-58,12,-36;0,6,1,0,0,-1",
"xs14_ck31246z023;xs15_64213kczx65;0;8,-97,21,-108;;17,-12;-4,-99;6,0,-1,0,0,1",
"xs14_ck31246z023;xs16_64213kczwca1;0;12,-82,19,-89;;13,-12;;6,0,-1,0,0,1",
"xs14_ck31246z023;xs16_6agw3lozx123;0;10,-81;;13,-14;-9,-70,-2,-62,5,-58;6,7,0,-1,-1,0",
"xs14_ck31246z023;xs16_ck31246z643;0;;-10,-15;14,-15;-17,-102,-8,-97;0,0,1,0,0,1",
"xs14_ck31246z023;xs16_o86178cz056;0;;14,-66;10,-42,17,-59;11,-46;0,-1,1,0,0,1",
"xs14_cp3033z32;xs15_cp30352z32;0;;13,-62;7,-47;5,-54;0,0,1,0,0,1",
"xs14_cp3z012156;xs15_0o48a52z39c;0;15,-102,24,-107;-9,-12;17,-12;;0,8,1,0,0,-1",
"xs14_cp3z012156;xs16_0312kozca243;0;;8,-42;6,-36;;5,-1,-1,0,0,1",
"xs14_cp3z012156;xs16_g853z1784ko;0;;;-3,-74;7,-40;0,-2,1,0,0,1",
"xs14_cp3zrm;xs16_g853zdrz32;0;;;-3,-82;7,-48;0,-2,1,0,0,1",
"xs14_cp3zrq;xs15_3pcz4ajo;0;9,-97,16,-122;;16,-12;-11,-104;2,0,-1,0,0,1",
"xs14_cp3zrq;xs16_03pczggmbz1;0;9,-149,17,-182,18,-152;-16,-12;11,-78,19,-39;-5,-125;3,0,-1,0,0,1",
"xs14_cp3zrq;xs16_0ok213zg6dz11;0;16,-129;-14,-12,-11,-58;;;2,10,-1,0,0,-1",
"xs14_db8ozca1;xs16_0g84213z32qm;0;3,-84,9,-85,14,-86;-11,-12;;;3,9,-1,0,0,-1",
"xs14_db8ozca1;xs16_31248f1248c;0;;5,-66,12,-73;;6,-44;3,-2,0,-1,1,0",
"xs14_db8ozca1;xs16_69jzmq23;0;12,-110,21,-115;-14,-12;14,-12;;0,9,1,0,0,-1",
"xs14_dbgzmq1;xs14_c9jzmq1;0;;-2,-68;-13,-73,-7,-70,-1,-74;7,-48;0,0,1,0,0,1",
"xs14_dbgzmq1;xs15_cai3zmq1;0;-5,-55;5,-82;3,-62;9,-48;0,0,1,0,0,1",
"xs14_dbgzmq1;xs15_gbdzha6z11;0;;1,-58,13,-62;-10,-69,1,-61;;2,9,-1,0,0,-1",
"xs14_dbgzmq1;xs16_321344312ko;0;;;-5,-58,0,-57,6,-56;4,-48;0,9,0,1,-1,0",
"xs14_dbgzmq1;xs16_35426886246;0;;-14,-12;16,-12;-21,-123,-12,-118;-1,10,0,1,-1,0",
"xs14_dbgzmq1;xs16_dbgz6ahzw23;0;;5,-70,12,-77;;6,-48;0,9,1,0,0,-1",
"xs14_dbgzmq1;xs16_gbdz122c826;0;-8,-48,-1,-52;-8,-36,1,-49;0,-46;;2,9,-1,0,0,-1",
"xs14_dbgzmq1;xs16_gbdz122c84c;0;-9,-48,-2,-52;-7,-44,1,-53;0,-50;;2,9,-1,0,0,-1",
"xs14_dbz3553;xs15_db8ozbd;0;13,-111;-14,-12;4,-58;-12,-102,-4,-93,4,-64;0,8,1,0,0,-1",
"xs14_dj8gzx3426;xs15_g8ge123z1ac;0;;1,-63,13,-67;-10,-74,1,-66;;0,7,1,0,0,-1",
"xs14_dj8gzx3426;xs16_g853z121eg8o;0;;5,-62,12,-69;;6,-40;0,-2,1,0,0,1",
"xs14_dj8gzx3426;xs16_g88a512koz23;0;;3,-61;-4,-50,3,-42,10,-38;6,-42;0,7,0,1,-1,0",
"xs14_dj8gzx34a4;xs15_0g0s252z3kp;0;;1,-63,13,-67;-10,-74,1,-66;;0,8,1,0,0,-1",
"xs14_dj8gzx34a4;xs16_0g0s252z349go;0;;;-5,-54,0,-53,6,-52;4,-44;0,8,1,0,0,-1",
"xs14_dj8gzx34a4;xs16_0g88a51248cz121;0;;5,-66,12,-73;;6,-44;0,8,0,1,-1,0",
"xs14_djozx3123;xs15_8o651246z32;0;;1,-63,13,-67;-10,-74,1,-66;;0,6,0,1,-1,0",
"xs14_djozx3123;xs16_3123c4ozxca1;0;;5,-58,12,-65;;6,-36;6,6,-1,0,0,-1",
"xs14_djozx3146;xs15_g8o6413z1ac;0;;1,-63,13,-67;-10,-74,1,-66;;0,7,1,0,0,-1",
"xs14_djozx3146;xs16_g853z123c4go;0;;5,-62,12,-69;;6,-40;0,-2,1,0,0,1",
"xs14_djozx356;xs15_g8o653z1ac;0;;1,-59,13,-63;-10,-70,1,-62;;0,7,1,0,0,-1",
"xs14_djozx356;xs16_g853z123cko;0;;5,-62,12,-69;;6,-40;0,-2,1,0,0,1",
"xs14_djozx39c;xs15_0ggc93z3kp;0;;1,-59,13,-63;-10,-70,1,-62;;0,8,1,0,0,-1",
"xs14_djozx39c;xs16_g08o651248cz11;0;;5,-66,12,-73;;6,-44;0,8,0,1,-1,0",
"xs14_djozxbd;xs15_0ggdbz3kp;0;;1,-58,13,-62;-10,-69,1,-61;;0,8,1,0,0,-1",
"xs14_djozxbd;xs16_3123ckg8426;0;;5,-66,12,-73;;6,-44;4,8,0,-1,-1,0",
"xs14_drz012156;xs14_drz012552;0;18,-82;;;-2,-72;0,0,1,0,0,1",
"xs14_g2u0696z11;xs15_0c88b5z2552;0;1,-76;;;-11,-78,-9,-88;-1,0,0,1,1,0",
"xs14_g2u0696z11;xs16_0c88b52z2552;0;;-11,-14;;-11,-78;-1,0,0,1,1,0",
"xs14_g2u0696z11;xs16_0ogjl8z4aa4;0;4,-89;-7,-48;-5,-54;-11,-80;-2,0,0,1,1,0",
"xs14_g4c0fhoz11;xs15_05b88cz6413;0;14,-67;;16,-12;3,-52;7,5,0,-1,-1,0",
"xs14_g4c0fhoz11;xs16_08ljgozc826;0;16,-76;12,-58;12,-52;3,-85;8,5,0,-1,-1,0",
"xs14_g4s079cz11;xs15_xc8a52z6513;0;;12,-58;7,-42;10,-42;7,5,0,-1,-1,0",
"xs14_g84213zdl8;xs13_g84213zdd;0;;;;-13,-82;0,0,1,0,0,1",
"xs14_g84213zdl8;xs14_32qczx1248c;0;3,-54;-10,-13;;-11,-74;-2,8,1,0,0,-1",
"xs14_g84213zdl8;xs15_g84213zd54c;0;21,-100;;14,-12;;0,0,1,0,0,1",
"xs14_g84213zdl8;xs16_0g84213zol56;0;14,-96;;14,-12;-10,-102;-1,0,1,0,0,1",
"xs14_g84213zdl8;xs16_wg84c0c453z65;0;6,-68;-9,-12;;-11,-79;-2,0,0,1,1,0",
"xs14_g8421e8z1252;xs16_g8421egoz1252;0;;14,-66;8,-66;11,-40;0,0,1,0,0,1",
"xs14_g853zdjo;xs16_wg853zmdz123;0;;7,-70,14,-77;;8,-48;0,-2,1,0,0,1",
"xs14_g88a52zc96;xs16_0ggka23zpic;0;;;-1,-99,0,-83;6,-75,14,-44;0,-1,1,0,0,1",
"xs14_g88a52zc96;xs16_0ggka52zpic;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs14_g88a52zc96;xs16_0gila4zpic;0;-2,-44;8,-69;;;0,-1,1,0,0,1",
"xs14_g88a52zdd;xs16_312kozx122ak8;0;15,-121;-13,-12,-10,-58;;;-3,9,1,0,0,-1",
"xs14_g88b5zdb;xs16_g88b5zdjo;0;12,-110,21,-115;-14,-12;14,-12;;0,0,1,0,0,1",
"xs14_g88b5zdd;xs15_3pa4zw11da;0;8,-89,15,-114;;15,-12;-10,-96;-1,8,1,0,0,-1",
"xs14_g88b5zdd;xs16_312kozx122qk;0;15,-121;-13,-12,-10,-58;;;-3,9,1,0,0,-1",
"xs14_g88m552z121;xs16_69akggozx56;0;-4,-36;9,-79;-2,-70,6,-61,13,-33,20,-16;2,-81;0,6,1,0,0,-1",
"xs14_g88m952z121;xs15_62461tic;0;-1,-99,18,-101;11,-72,12,-58;18,-51;;5,0,0,-1,1,0",
"xs14_g88q552z121;xs15_259eg8ozx23;0;13,-102;13,-94;18,-57;18,-36;0,6,0,1,-1,0",
"xs14_g88q552z121;xs16_wggci96z2543;0;-2,-36;8,-70,12,-60;10,-45;;7,6,0,-1,-1,0",
"xs14_g8ge13z1ac;xs16_0g0s253z3kp;0;;10,-63;6,-52;12,-44;0,-1,1,0,0,1",
"xs14_g8ge13z1ac;xs16_31248gzoge121;0;;;13,-12;-12,-86,-7,-85,-1,-84;5,9,-1,0,0,-1",
"xs14_g8ge13z1ac;xs16_g88a51248goz11;0;14,-98,21,-105;;15,-12;;0,0,0,1,1,0",
"xs14_g8ge13z1ac;xs16_g8ge13zpic;0;;-12,-12;16,-12;-19,-115,-10,-110;0,0,1,0,0,1",
"xs14_g8id96z121;xs16_0g8id96z3421;0;11,-85;-11,-12,-7,-38;-3,-44;;-1,0,1,0,0,1",
"xs14_g8ka53z56;xs16_g853z125ako;0;12,-90,19,-97;;13,-12;;0,9,1,0,0,-1",
"xs14_g8o652z1ac;xs16_0ggc871z3kp;0;;7,-69,15,-70;9,-53,10,-65;;0,-1,1,0,0,1",
"xs14_g8o652z1ac;xs16_0ggca23z3kp;0;;;-1,-99,0,-83;6,-75,14,-44;0,-1,1,0,0,1",
"xs14_g8o652z1ac;xs16_0ggca52z3kp;0;;11,-54;9,-39;;0,-1,1,0,0,1",
"xs14_g8o69a4z121;xs16_4a9mggozx56;0;-1,-64,7,-87,14,-87,21,-98;-8,-45;-5,-54;-3,-91;6,0,0,-1,1,0",
"xs14_gba952z23;xs16_259abgzwca1;0;11,-82,18,-89;;12,-12;;5,0,-1,0,0,1",
"xs14_ggc4871z146;xs16_ckxkq23zw123;0;15,-70;;;-1,-64;6,8,0,-1,-1,0",
"xs14_ggc4871z146;xs16_g853z11642sg;0;;;14,-12;-10,-102;0,9,1,0,0,-1",
"xs14_ggc4871z56;xs16_xkq23zc4jz011;0;-1,-56,8,-69;-15,-12,-8,-16;;-7,-66;6,6,0,-1,-1,0",
"xs14_ggc4871z56;xs16_xkq23zck3z11;0;0,-64,8,-73;-16,-12,-9,-16;;-7,-70;6,6,0,-1,-1,0",
"xs14_ggca53z65;xs16_69bkk8zx56;0;-14,-71,-8,-100;-13,-68;-23,-122,4,-120;5,-115;4,0,-1,0,0,1",
"xs14_ggkq23z56;xs16_03hikozc452;0;10,-87;;13,-12;-11,-76,-4,-68,3,-64;5,8,-1,0,0,-1",
"xs14_ggkq23z56;xs16_0ggkq23zc96;0;;-12,-12;14,-12;-19,-107,-10,-102;-1,0,1,0,0,1",
"xs14_ggkq23z56;xs16_354k8zx11db;0;-5,-40;5,-80;-4,-66;;6,-1,-1,0,0,1",
"xs14_ggw3loz1252;xs15_oe1248cz056;0;9,-80,19,-114,20,-90;;;-2,-73;7,6,0,-1,-1,0",
"xs14_gilmz1w252;xs16_4aligozw6a4;0;12,-58;;;-8,-68;5,8,-1,0,0,-1",
"xs14_gilmz1w252;xs16_gilmz1w254c;0;;;13,-43,21,-12;-8,-123,-7,-107;0,0,1,0,0,1",
"xs14_gilmz1w252;xs16_gilmz1w25a4;0;16,-74;;;-4,-64;0,0,1,0,0,1",
"xs14_gjloz1ac;xs16_31248gu248c;0;-4,-44;3,-76;-3,-66;;-1,-2,0,1,1,0",
"xs14_gjloz1ac;xs16_62sgf1246;0;;9,-76;-9,-113,-2,-68;10,-44;0,0,0,1,1,0",
"xs14_gs25a4z146;xs16_gs25ak8z146;0;;;11,-18;3,-40;0,0,1,0,0,1",
"xs14_gs25a4z56;xs16_gs25ak8z56;0;14,-66;;;6,-51;0,0,1,0,0,1",
"xs14_i5d2koz11;xs16_02ld2koz65;0;10,-86;-10,-12;;;-1,0,1,0,0,1",
"xs14_i5d2koz11;xs16_o4q9jz01x56;0;1,-68;;;-11,-74;5,0,0,-1,1,0",
"xs14_i5q453z11;xs15_4al9a4z321;0;-8,-32;5,-57;-7,-67,4,-65;;0,-1,1,0,0,1",
"xs14_i5q453z11;xs15_j5q453z11;0;;-2,-48;-6,-54;;0,0,1,0,0,1",
"xs14_i5q453z11;xs16_25ak8a6z0321;0;;-4,-39;-6,-54;;-1,-1,1,0,0,1",
"xs14_i5q8a6z11;xs16_0j9m4koz121;0;-3,-32;-1,-30;;;-1,5,1,0,0,-1",
"xs14_i5t246z11;xs16_354m96z065;0;13,-63;;10,-33,17,-12;;0,5,0,1,-1,0",
"xs14_j1u066z11;xs16_0bdz651156;0;13,-62,16,-99;10,-65;;11,-77;7,0,0,-1,1,0",
"xs14_j1u066z11;xs16_0c93z651156;0;19,-86,24,-113;;;8,-133,14,-81;7,0,0,-1,1,0",
"xs14_j1u066z11;xs16_0dbz651156;0;13,-77;10,-50,13,-87;14,-65;;7,0,0,-1,1,0",
"xs14_j1u066z11;xs16_0j1u0ooz321;0;-7,-32;-1,-40;-5,-51;;-1,5,1,0,0,-1",
"xs14_j1u066z11;xs16_25b88a6zw33;0;-6,-32;;-6,-56;;-1,-1,0,1,1,0",
"xs14_j1u066z11;xs16_39cz651156;0;;16,-74,21,-101;11,-121,17,-69;;7,0,0,-1,1,0",
"xs14_j1u066z11;xs16_62s0c93z321;0;19,-86;;5,-82,13,-88;6,-70,12,-75;0,-1,1,0,0,1",
"xs14_j1u066z11;xs16_6a88b52z033;0;;-11,-12;;-11,-76;-1,0,0,1,1,0",
"xs14_j1u066z11;xs26_c4g0696z69pz32w696;0;4,-70;-1,-50;-5,-50,6,-41;-10,-70;1,-4,-1,0,0,1",
"xs14_j1u413z11;xs14_31ek13zx23;0;10,-72,13,-62;;;-10,-78,1,-60;0,0,1,0,0,1",
"xs14_j1u413z11;xs15_25ao8a6z032;0;-7,-32;-1,-43;-6,-56;;-1,-1,0,1,1,0",
"xs14_j1u413z11;xs15_5bo8a6z32;0;-6,-32;-1,-40;-4,-55;;-1,0,0,1,1,0",
"xs14_j1u413z11;xs15_6ao8a52z32;0;4,-63;-12,-12;;-11,-76;-1,0,0,1,1,0",
"xs14_j1u413z11;xs15_6ao8b5z32;0;1,-72;;;-11,-74,-9,-84;-1,0,0,1,1,0",
"xs14_j1u413z11;xs16_25bo8a6z032;0;-6,-32;;-6,-56;;-1,-1,0,1,1,0",
"xs14_j1u413z11;xs16_35ao8a6z032;0;-7,-32;-1,-40;-5,-51;;-1,-1,0,1,1,0",
"xs14_j1u413z11;xs16_6ao8a53z32;0;4,-60;-12,-12;;-10,-71;-1,0,0,1,1,0",
"xs14_j1u413z11;xs16_6ao8b52z32;0;;-11,-12;;-11,-76;-1,0,0,1,1,0",
"xs14_j5c2koz11;xs14_i5d2koz11;0;;0,-44;-6,-54;;0,0,1,0,0,1",
"xs14_j5c2koz11;xs16_03lc2koz65;0;10,-86;-10,-12;;;-1,0,1,0,0,1",
"xs14_j5c2koz11;xs16_0j9cga6z1221;0;-5,-32;7,-65;;;-1,5,1,0,0,-1",
"xs14_j5c2koz11;xs16_g4q9jz11x56;0;1,-68;;;-11,-74;5,0,0,-1,1,0",
"xs14_j5ka52z11;xs15_4a9la4z321;0;;1,-65,12,-67;0,-57;13,-32;0,-1,1,0,0,1",
"xs14_j5ka52z11;xs16_0j9m853z121;0;;11,-54;9,-39;;0,-1,0,1,1,0",
"xs14_j5o0ok8z11;xs15_j5o0uiz11;0;;8,-52;;13,-32;0,0,1,0,0,1",
"xs14_j5o652z11;xs16_09fgkcz253;0;-2,-32;-1,-40;;;-2,0,0,1,1,0",
"xs14_j5o652z11;xs16_0j9q453z23;0;;;-1,-87,0,-71;6,-63,14,-32;0,-1,0,1,1,0",
"xs14_j5s246z11;xs14_i5t246z11;0;;0,-44;-6,-54;;0,0,1,0,0,1",
"xs14_j5s246z11;xs16_354m93z065;0;13,-62;;10,-32;4,-66;0,5,0,1,-1,0",
"xs14_j5s246z11;xs16_354m93z321;0;13,-64;;8,-39;-7,-76,0,-52,7,-32;0,5,0,1,-1,0",
"xs14_j5s246z11;xs16_69ic8a6zw23;0;-5,-32;7,-65;;;-1,-1,0,1,1,0",
"xs14_j5s252z11;xs16_0j9m453z121;0;;11,-54;9,-39;;0,-1,0,1,1,0",
"xs14_j5s252z11;xs16_j5s25a4z11;0;13,-62;;;7,-47;0,0,1,0,0,1",
"xs14_j5s252z11;xs17_ckg8jdz643;0;;10,-50;6,-57;15,-33;0,-2,1,0,0,1",
"xs14_j9a4zc93;xs16_0ok213z4aip;0;4,-72;;;-14,-78;3,9,-1,0,0,-1",
"xs14_j9a4zc93;xs16_31248c2cga6;0;13,-110;-13,-12;;;-1,10,0,1,-1,0",
"xs14_j9c826z23;xs16_628c9jzwca1;0;11,-82,18,-89;;12,-12;;5,0,-1,0,0,1",
"xs14_j9cz11da;xs16_0ok213zkq23;0;;-4,-40;-6,-46;;3,-1,-1,0,0,1",
"xs14_j9cz11da;xs16_31248c2eg8o;0;-5,-44;5,-78;;;-1,-2,0,1,1,0",
"xs14_jhke13z1;xs16_0j9c871z123;0;;11,-56;;11,-32;0,-1,0,1,1,0",
"xs14_jhke13z1;xs16_0jhke13z32;0;14,-78;;15,-12;-5,-92;-1,0,1,0,0,1",
"xs14_jhke13z1;xs16_178c9jzx65;0;13,-66;11,-54;6,-63;6,-70;0,5,0,1,-1,0",
"xs14_kc321e8z11;xs16_kc321egoz11;0;;14,-66;8,-66;11,-40;0,0,1,0,0,1",
"xs14_kq23zw3146;xs16_8k453z11628c;0;-7,-40;3,-80;-6,-66;;0,-1,1,0,0,1",
"xs14_kq23zw3146;xs16_wkc321e8z65;0;18,-82;;;2,-76;0,8,0,1,-1,0",
"xs14_mmge13z1;xs15_gbb871z23;0;;10,-68,11,-56;;11,-32;0,0,0,1,1,0",
"xs14_mmge13z1;xs16_0c93s4z6511;0;-5,-69,7,-91;-12,-12,-7,-44;;;-2,0,0,1,1,0",
"xs14_mmge13z1;xs16_0g0s2qrz321;0;;10,-51;6,-40;12,-32;6,5,-1,0,0,-1",
"xs14_mmge13z1;xs16_0gbb871z123;0;;11,-56;;11,-32;0,-1,0,1,1,0",
"xs14_mmge13z1;xs16_0mmge13z32;0;14,-78;;15,-12;-5,-92;-1,0,1,0,0,1",
"xs14_mmge13z1;xs16_178bbgzx65;0;13,-66;11,-54;6,-63;6,-70;0,5,0,1,-1,0",
"xs14_mp3zw39c;xs16_mp3zw358go;0;18,-82;;;0,-76;0,0,1,0,0,1",
"xs14_o8brzx123;xs15_g89f0ccz23;0;15,-83;;17,-12;0,-68;0,6,0,1,-1,0",
"xs14_o8brzx123;xs16_g89f0ccz056;0;17,-80;9,-46;13,-40;0,-89;0,6,0,1,-1,0",
"xs14_o8brzx123;xs16_o8brzx1253;0;17,-84;;17,-12;;0,0,1,0,0,1",
"xs14_oe12koz23;xs16_0oe12koz643;0;15,-86;-11,-23;19,-12;-18,-110,-9,-105;-1,0,1,0,0,1",
"xs14_ok2156z65;xs16_mp3z1248a6;0;11,-102,20,-107;-13,-12;13,-12;;0,8,1,0,0,-1",
"xs14_ok2156z66;xs15_3pa4zw12453;0;7,-81,14,-106;;14,-12;-9,-88;-1,7,1,0,0,-1",
"xs14_ok21e8z65;xs15_0ok21e8zca1;0;5,-97,13,-97;-22,-12,-12,-21;;;-1,0,1,0,0,1",
"xs14_ok21e8z65;xs16_358gzw358ge2;0;9,-100;-12,-12;;-11,-90;-2,9,1,0,0,-1",
"xs14_ok21e8z65;xs16_mp3z124871;0;11,-102,20,-107;-13,-12;13,-12;;0,8,1,0,0,-1",
"xs14_ok21e8z65;xs16_ok21egoz65;0;;13,-66;7,-66;10,-40;0,0,1,0,0,1",
"xs14_ok21e8z66;xs15_0ok21e8z6421;0;7,-81,14,-106;;14,-12;-9,-88;-1,0,1,0,0,1",
"xs14_ok21e8z66;xs16_312kozx124871;0;14,-113;-12,-12,-9,-58;;;-3,8,1,0,0,-1",
"xs14_ol3zw32ac;xs15_5b8ozxol3;0;20,-100;;17,-28,18,-12;;5,9,-1,0,0,-1",
"xs14_ol3zw32ac;xs15_ol3zw32ak8;0;21,-104;;18,-12;-5,-91;0,0,1,0,0,1",
"xs14_ol3zw32ac;xs16_8ljgzxha6zx11;0;15,-120;-10,-16;18,-12;-5,-113;5,10,-1,0,0,-1",
"xs14_ol3zw32ac;xs16_ckl3zx32ac;0;-7,-44;5,-68,12,-113;-6,-76;;-1,0,1,0,0,1",
"xs14_ol3zw32ac;xs16_g0s431248goz11;0;;6,-66,13,-73;;7,-44;0,8,0,1,-1,0",
"xs14_ol3zw32ac;xs16_ggc453zpic;0;-4,-44;;-11,-83,-2,-78;8,-44;0,8,1,0,0,-1",
"xs14_ol3zw32ac;xs16_ol3zw32ako;0;21,-105;;17,-12;-5,-89;0,0,1,0,0,1",
"xs14_ol3zw32ac;xs16_ol3zw32qk8;0;20,-100;;18,-12;;0,0,1,0,0,1",
"xs14_ra248cz23;xs16_0ra248cz643;0;;-11,-15;13,-15;-18,-102,-9,-97;-1,0,1,0,0,1",
"xs14_ra248cz23;xs16_321j871z065;0;14,-66;;11,-28;3,-70;0,6,0,1,-1,0",
"xs14_ra248cz23;xs16_321j871z321;0;14,-68;;9,-35;-8,-80,-1,-56,6,-36;0,6,0,1,-1,0",
"xs14_ra248cz23;xs16_3lk48goz056;0;;9,-62;0,-76;10,-36;-1,-1,1,0,0,1",
"xs14_ra248cz23;xs16_ra248a6z23;0;15,-73;9,-49;;5,-67,14,-36;0,0,1,0,0,1",
"xs14_rai3zx123;xs16_rai3zx1248c;0;17,-78;;14,-16;0,-82;0,0,1,0,0,1",
"xs14_w8k8a52z2521;xs15_w8k8a52z6521;0;;13,-62;9,-56;;0,0,0,1,1,0",
"xs14_w8k8a52z2521;xs15_wck8a52z2521;0;;-2,-40;-2,-46;;0,0,1,0,0,1",
"xs14_w8k8a52z2521;xs16_1784ozx1215a4;0;;;1,-95,2,-79;8,-71,16,-40;8,-1,0,-1,1,0",
"xs14_w8k8a52z2521;xs16_25a4ozx1215a4;0;;11,-54;5,-44;;8,-1,0,-1,1,0",
"xs14_w8o6413zca1;xs16_358gzw116248go;0;;13,-62;11,-56;;0,8,1,0,0,-1",
"xs14_w8o6413zca1;xs16_69jzw23c4go;0;12,-110,21,-115;-14,-12;14,-12;;0,9,1,0,0,-1",
"xs14_w8o653zca1;xs16_69jzw23cko;0;12,-110,21,-115;-14,-12;14,-12;;0,9,1,0,0,-1",
"xs14_wg853zgb6z11;xs16_358gzx6bgzy256;0;12,-124;-15,-12;;-14,-114;5,0,-1,0,0,1",
"xs14_wg853zgbqz01;xs15_32qbzx12ko;0;;-13,-14;;-20,-110;-1,9,1,0,0,-1",
"xs14_wg853zmdz11;xs16_xj96zcq1z32;0;-1,-52;;-8,-91,1,-86;11,-52;0,-1,1,0,0,1",
"xs14_wg853zmlz11;xs16_y1g853zxmdz321;0;17,-137;-15,-12,-12,-58;;;-3,0,1,0,0,1",
"xs14_wg8ge13z643;xs15_x8k453zad11;0;;-13,-12;;-13,-92,-12,-104;7,7,0,-1,-1,0",
"xs14_wg8ge13z643;xs15_xg8ge13z4a43;0;;13,-64;8,-51;14,-40;8,7,-1,0,0,-1",
"xs14_wg8ge13z643;xs16_8ljgzx254ko;0;6,-101;-9,-44;-3,-50;-13,-92;-2,7,0,1,-1,0",
"xs14_wg8ge13z643;xs16_xg8ge13z6a43;0;;-13,-12;;-13,-92;-1,0,1,0,0,1",
"xs14_wg8ge13z643;xs16_xg8ge13zca43;0;;12,-59;8,-48;14,-40;8,7,-1,0,0,-1",
"xs14_wg8ka52z2521;xs16_xg8ka52z4a521;0;;;2,-65;12,-40;0,-1,1,0,0,1",
"xs14_wg8ka52z643;xs16_xg8ge13z4a521;0;;11,-54;5,-44;;8,7,-1,0,0,-1",
"xs14_wg8o653z65;xs16_wg8o653z69c;0;11,-102,20,-107;-13,-12;13,-12;;0,0,1,0,0,1",
"xs14_wg8o653z65;xs16_xg8o653z4a43;0;12,-97;-14,-12;;-12,-87;-1,0,1,0,0,1",
"xs14_wggc453z643;xs14_4a9jzx1156;0;9,-86;-6,-30;13,-12;-5,-90;1,7,1,0,0,-1",
"xs14_wggc453z643;xs14_ol3zw32ac;0;;;11,-34,14,-12;0,-66,11,-40;8,2,0,-1,1,0",
"xs14_wggc453z643;xs15_252sgzy132ac;0;;15,-70;5,-57;12,-42;8,-1,0,-1,1,0",
"xs14_wggc453z643;xs15_5b8ozy0178c;0;;-13,-12;;-13,-92,-12,-104;-1,7,0,1,-1,0",
"xs14_wggc453z643;xs16_25b8ozy1178c;0;;-13,-12;;-13,-92;-1,8,0,1,-1,0",
"xs14_wggc453z643;xs16_352sgzy132ac;0;;15,-70;5,-54;11,-41;8,-1,0,-1,1,0",
"xs14_wggc453z643;xs16_8ljgzx12ego;0;-2,-40;10,-82;5,-79;12,-42;7,-2,-1,0,0,1",
"xs14_wggc871z2521;xs16_25akozy131e8;0;12,-93;-12,-12;;;-1,8,1,0,0,-1",
"xs14_wggc871z6221;xs16_31egozy1354c;0;16,-94;;17,-12;-7,-108;-1,8,0,1,-1,0",
"xs14_wggca52z2521;xs16_25akozy135a4;0;;;2,-65;12,-40;8,-1,-1,0,0,1",
"xs14_wggka23z256;xs16_xggka23zca52;0;5,-74;-9,-12;;;-1,0,1,0,0,1",
"xs14_wggka23z643;xs16_xggka23z6a43;0;;-13,-12;;-13,-92;-1,0,1,0,0,1",
"xs14_wggka52z256;xs16_xggka52zca52;0;5,-74;-9,-12;;;-1,0,1,0,0,1",
"xs14_wggka52z643;xs16_xggka52z6a43;0;;-13,-12;;-13,-92;-1,0,1,0,0,1",
"xs14_wggka53z252;xs16_wggka53z696;0;13,-93;-11,-12;;;0,0,1,0,0,1",
"xs14_wggka53z252;xs16_xgila4zca52;0;13,-76;;;-7,-66;7,8,-1,0,0,-1",
"xs14_wggm93z652;xs15_25iczx115ac;0;14,-77;12,-69;;8,-71,17,-40;7,-1,-1,0,0,1",
"xs14_wggm952z252;xs14_g88a52zdb;0;0,-40;;-7,-79;5,-67;5,7,-1,0,0,-1",
"xs14_wggm952z252;xs15_wggm952z652;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs14_wggm952z252;xs16_xggka23z4a96;0;12,-107,13,-123;-16,-12,-8,-43;;;7,8,-1,0,0,-1",
"xs14_wggm952z252;xs16_xggka52z4a96;0;12,-93;-12,-12;;;7,8,-1,0,0,-1",
"xs14_wggm952z252;xs16_xgila4z4a96;0;13,-76;;;-7,-66;7,8,-1,0,0,-1",
"xs14_wggm96z643;xs16_wggs256z696;0;;-13,-12;;-13,-92;6,8,-1,0,0,-1",
"xs14_wggs252z256;xs16_xgila4z6a43;0;15,-70;;;9,-55;8,7,0,-1,-1,0",
"xs14_wggs252z652;xs15_wggs253z652;0;;13,-62;9,-56;;0,0,1,0,0,1",
"xs14_wggs252z652;xs16_wggs253z696;0;14,-66;;;10,-51;0,0,0,1,1,0",
"xs14_wggs252z652;xs16_xggka23zca43;0;;9,-77,17,-78;11,-61,12,-73;;8,7,0,-1,-1,0",
"xs14_wggs252z652;xs16_xggka52zca43;0;;11,-54;5,-44;;8,7,0,-1,-1,0",
"xs14_wggs252z652;xs16_xgila4zca43;0;15,-70;;;9,-55;8,7,0,-1,-1,0",
"xs14_wgila4z256;xs16_8ka52zw11da4;0;-2,-40;8,-65;;;6,-1,-1,0,0,1",
"xs14_wgila4z652;xs16_8ka52zw115ac;0;-2,-40;8,-65;;;6,-1,-1,0,0,1",
"xs14_wgjla4z252;xs16_xgjla4z4a52;0;12,-93;-12,-12;;;-1,0,1,0,0,1",
"xs14_wkc3213z65;xs16_3123ckzy212ko;0;9,-100;-12,-12;;-11,-90;7,0,-1,0,0,1",
"xs14_wkc3213z65;xs16_69jzw23c48c;0;11,-102,20,-107;-13,-12;13,-12;;0,8,1,0,0,-1",
"xs14_wo8a52zbd;xs16_3pmzx32ak8;0;;-13,-12;15,-12;-20,-115,-11,-110;-1,9,1,0,0,-1",
"xs14_wo8a52zbd;xs16_dbgzw19la4;0;-1,-44;9,-69;;;0,8,1,0,0,-1",
"xs14_wo8b5zbd;xs16_3pmzx32qk;0;;-13,-12;15,-12;-20,-115,-11,-110;-1,9,1,0,0,-1",
"xs14_wog853zdb;xs16_69j0gzx11mq;0;0,-44;;-7,-83,2,-78;12,-44;6,-1,-1,0,0,1",
"xs14_wog853zdb;xs16_bdggzw1078k8;0;;11,-63;1,-73;13,-44;0,8,1,0,0,-1",
"xs14_wok213zdb;xs16_wok2156zdb;0;16,-74;;9,-57,14,-18,19,-20;4,-57;0,0,1,0,0,1",
"xs14_xg84215a4z321;xs16_31248gzy21248a52;0;5,-102;-9,-36;;-12,-98;-2,8,1,0,0,-1",
"xs14_xg84215a4z321;xs16_358gzxg9iczw23;0;;;14,-43,22,-12;1,-91,2,-75;0,6,0,1,-1,0",
"xs14_xg84215a4z321;xs16_358gzy01248gka4;0;1,-64,6,-83,12,-106;;;-10,-90;-1,9,1,0,0,-1",
"xs14_xg84215a4z321;xs16_69jzx1i4ozx121;0;-6,-65,3,-96;;-1,-54;-13,-102;-1,6,0,1,-1,0",
"xs14_xg84215a4z321;xs16_xg84215ak8z321;0;17,-78;;;5,-68;0,0,1,0,0,1",
"xs14_xg853zg6dz11;xs16_y0g853zwmdz65;0;15,-126;-15,-12;;;-1,0,1,0,0,1",
"xs14_xg8o652zca1;xs15_39cggzx1012ko;0;0,-44;10,-67;0,-82;9,-62;8,-1,-1,0,0,1",
"xs14_xg8o652zca1;xs15_xg8o6413zca1;0;17,-78;10,-68;15,-52;9,-61;0,0,1,0,0,1",
"xs14_xg8o652zca1;xs15_xg8o653zca1;0;;14,-66;10,-60;;0,0,1,0,0,1",
"xs14_xg8o652zca1;xs16_178cggzy01012ko;0;;10,-81,18,-82;12,-65,13,-77;;9,-1,-1,0,0,1",
"xs14_xg8o652zca1;xs16_178cggzy01248go;0;;;2,-99,3,-83;9,-75,17,-44;9,-1,0,-1,1,0",
"xs14_xg8o652zca1;xs16_256o8gzy21248go;0;3,-84,9,-85,14,-86;-11,-12;;;8,0,-1,0,0,1",
"xs14_xg8o652zca1;xs16_25acggzy01012ko;0;;12,-58;6,-48;;9,-1,-1,0,0,1",
"xs14_xg8o652zca1;xs16_69jzx123ck8;0;12,-110,21,-115;-14,-12;14,-12;;0,9,1,0,0,-1",
"xs14_xg8o652zca1;xs16_y1g84213zg8o65z01;0;10,-108;-13,-12;;-12,-98;-2,0,0,1,1,0",
"xs14_xgs252z4a43;xs15_wggraa4z252;0;;;6,-41,13,-23;3,-50,11,-44;7,8,0,-1,-1,0",
"xs14_xgs252z4a43;xs15_xgs252z6a43;0;;-8,-32;0,-38;;0,0,1,0,0,1",
"xs14_xgs252z4a43;xs15_xgs252zca43;0;;13,-62;9,-56;;7,8,-1,0,0,-1",
"xs14_xgs252z4a43;xs16_1784ozy0178k8;0;;9,-77,17,-78;11,-61,12,-73;;8,-1,-1,0,0,1",
"xs14_xgs252z4a43;xs16_252sgzy034ak8;0;;11,-54;5,-44;;0,8,1,0,0,-1",
"xs14_xgs252z4a43;xs16_8kih3zx115a4;0;-1,-44,2,-66,8,-92;;-3,-60;-11,-102;-1,7,0,1,-1,0",
"xs14_xgs252z4a43;xs16_wggo8a52z696;0;;12,-58;12,-43;;0,0,0,1,1,0",
"xs14_xgs252z4a43;xs16_xgs25a4z4a43;0;;-10,-23;0,-38;;7,8,-1,0,0,-1",
"xs14_xog853zc93;xs16_312kozy1312ko;0;4,-88;;;-14,-94;-2,9,1,0,0,-1",
"xs14_xog853zc93;xs16_39cggzx1078k8;0;;12,-63;2,-73;14,-44;0,8,1,0,0,-1",
"xs14_xog853zc93;xs16_39cggzx10pic;0;1,-44;;-6,-83,3,-78;13,-44;0,8,1,0,0,-1",
"xs14_xoge13z253;xs15_xoge13z653;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs14_xoge13z253;xs16_31egozy131e8;0;2,-101,3,-89;;;-17,-106,-9,-105;7,0,-1,0,0,1",
"xs14_xoge13z253;xs16_31egozy135a4;0;12,-93;-12,-12;;;7,0,-1,0,0,1",
"xs14_xok213zc93;xs16_312kozy1358go;0;4,-88;;;-14,-94;7,0,-1,0,0,1",
"xs14_xok213zc93;xs16_3146o8gzy312ko;0;;13,-62;8,-66;10,-48;0,8,0,1,-1,0",
"xs14_xok213zc93;xs16_39cggzx122ak8;0;;15,-73;11,-54;11,-44;0,8,1,0,0,-1",
"xs14_xok213zc93;xs16_xok2156zc93;0;17,-78;;10,-61,15,-22,20,-24;5,-61;0,0,1,0,0,1",
"xs15_025a8cz2553;xs16_035a8cz2553;0;-4,-40;4,-66;;;0,0,1,0,0,1",
"xs15_025a8cz6513;xs16_035a8cz6513;0;-4,-40;4,-66;;;0,0,1,0,0,1",
"xs15_02lla4z643;xs15_69m861ac;0;9,-86;-6,-30;13,-12;-5,-90;1,0,0,1,1,0",
"xs15_02lla4z643;xs16_069ak8zc871;0;-14,-100;-13,-83,-9,-70,10,-110;-8,-62,4,-104;;0,-1,1,0,0,1",
"xs15_02lla4z643;xs16_4all2zx3426;0;3,-80;;;-13,-82,-11,-92;5,0,-1,0,0,1",
"xs15_02lla4z643;xs16_4all2zx34a4;0;6,-79;-14,-12;;-13,-92;5,0,-1,0,0,1",
"xs15_02lmz2520123;xs16_25ic0f9z032;0;-2,-54;;-9,-70;;0,7,0,1,-1,0",
"xs15_02lmzog943;xs16_358gkc0f9;0;-2,-48;;-9,-64;;0,9,0,1,-1,0",
"xs15_0312kozca23;xs16_31248gzok4611;0;-10,-44,2,-88;-9,-55,2,-91;;;0,-1,1,0,0,1",
"xs15_031i4oz4a611;xs16_031i4ozca611;0;11,-102;-13,-12;;;0,0,1,0,0,1",
"xs15_031i4oz4a611;xs16_031i4ozoi611;0;16,-114;-9,-30;16,-12;-10,-99;0,0,1,0,0,1",
"xs15_031i4oz4a611;xs16_08o6512koz32;0;-5,-44,4,-75,13,-94;-20,-33,-11,-29;;;5,8,0,-1,-1,0",
"xs15_031i4oz4a611;xs17_0ggca52z349go;0;13,-101;-13,-12;;;5,9,-1,0,0,-1",
"xs15_032qk8zc93;xs14_032qkzc93;0;;;9,-20;3,-44;0,0,1,0,0,1",
"xs15_0352sgz6413;xs16_352sgzol3;0;10,-81;-11,-12;;-10,-86;1,0,1,0,0,1",
"xs15_0358gzoge221;xs16_0g853z122eg8o;0;5,-88;;;-15,-90,-13,-100;5,0,-1,0,0,1",
"xs15_035iczcip;xs14_025iczcip;0;;9,-46;3,-36;;0,0,1,0,0,1",
"xs15_03iacz6ip;xs17_2ego4431248c;0;;;16,-12;-12,-118;0,0,0,1,1,0",
"xs15_03lk46z6221;xs16_05b88czc453;0;-2,-40;3,-45;-6,-57;;0,-1,1,0,0,1",
"xs15_03lk46z643;xs16_05b88czc871;0;-2,-40;3,-45;-6,-57;;0,-1,1,0,0,1",
"xs15_03lk46z643;xs16_64kl3zx3426;0;3,-80;;;-13,-82,-11,-92;5,0,-1,0,0,1",
"xs15_03lk46z643;xs16_64kl3zx34a4;0;6,-79;-14,-12;;-13,-92;5,0,-1,0,0,1",
"xs15_03lka4z643;xs15_39m861ac;0;9,-86;-6,-30;13,-12;-5,-90;1,0,0,1,1,0",
"xs15_03lkicz252;xs16_25a84oz4a511;0;-4,-40;;-11,-79,-2,-74;8,-40;0,-1,1,0,0,1",
"xs15_03lkk8z643;xs16_8kkl3zx3426;0;3,-80;;;-13,-82,-11,-92;5,0,-1,0,0,1",
"xs15_03pczok452;xs16_321eg84c826;0;11,-89;-12,-12;;-16,-101;0,10,0,1,-1,0",
"xs15_03pczok452;xs16_g8ge124628cz01;0;11,-99;-14,-12;;-17,-112;4,10,0,-1,-1,0",
"xs15_04al56z2521;xs14_3542tic;0;10,-62;;;-8,-62;1,6,0,1,-1,0",
"xs15_04al56z2521;xs16_04al56z6521;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs15_069jz8ka43;xs16_069jzoka43;0;12,-110;-14,-12;;;0,0,1,0,0,1",
"xs15_06t1acz321;xs16_ca1t6zx1252;0;5,-71;-13,-12;;-12,-84;5,0,-1,0,0,1",
"xs15_06t1acz321;xs16_g88bpicz23;0;5,-68;-12,-12;;-10,-83;5,6,0,-1,-1,0",
"xs15_06t1e8z321;xs16_8e1t6zx1252;0;5,-71;-13,-12;;-12,-84;5,0,-1,0,0,1",
"xs15_06t1e8z321;xs16_g88bqicz23;0;2,-76;;;-12,-78,-10,-88;5,6,0,-1,-1,0",
"xs15_08e1248cz253;xs14_8e1248cz33;0;13,-62;;;;1,0,1,0,0,1",
"xs15_08e1248cz253;xs16_9f0c88gzxca1;0;;-10,-34;;-17,-106;-1,6,0,1,-1,0",
"xs15_08e12koz253;xs16_32arwkczx121;0;;-10,-30;;-17,-102;-1,6,1,0,0,-1",
"xs15_08k453z259c;xs16_0g88b5z4ajo;0;;12,-61;3,-49;8,-44;0,-1,1,0,0,1",
"xs15_08k453z8ld;xs14_8k453zdd;0;15,-70;;;;1,0,1,0,0,1",
"xs15_08k453z8ld;xs15_2ego8ge13;0;13,-73;;12,-12;-1,-53;5,8,0,-1,-1,0",
"xs15_08k453z8ld;xs16_32arzw122ac;0;;-12,-18;;-19,-106;-1,8,1,0,0,-1",
"xs15_08k453zca43;xs16_0g88a52zok96;0;;13,-72;3,-59;10,-44;0,-1,1,0,0,1",
"xs15_08k453zca43;xs16_0g88b5zok96;0;;12,-61;3,-49;8,-44;0,-1,1,0,0,1",
"xs15_08kaarz321;xs16_raak8zx1252;0;;-17,-12,-8,-43;-2,-49;-12,-89;5,0,-1,0,0,1",
"xs15_08o0uh3z65;xs16_08o0uh23z65;0;;10,-63;7,-48;12,-40;0,0,1,0,0,1",
"xs15_08o6413z254c;xs16_03ia4z2ehp;0;;0,-35;-2,-42,11,-26;;4,8,-1,0,0,-1",
"xs15_08o6413z254c;xs16_0ggc871z4a9o;0;;11,-54;7,-49;7,-48;0,-1,1,0,0,1",
"xs15_08o6413z254c;xs16_3lozwgjl8zw1;0;;9,-62;3,-57;10,-44;5,-2,-1,0,0,1",
"xs15_08o652sgz32;xs14_kq23zw3146;0;;6,-34;2,-34;;7,1,0,-1,1,0",
"xs15_08o652zrm;xs16_08o653zrm;0;;11,-54;7,-48;;0,0,1,0,0,1",
"xs15_08o6996z321;xs16_w8o6996z2521;0;;-17,-12,-8,-43;-2,-49;-12,-89;-1,0,1,0,0,1",
"xs15_08o69icz321;xs16_w8o69icz2521;0;;-17,-12,-8,-43;-2,-49;-12,-89;-1,0,1,0,0,1",
"xs15_08o6picz32;xs15_0ml9a4z321;0;6,-79;;;-13,-86;6,5,0,-1,-1,0",
"xs15_08o6picz32;xs16_0ml9a4zca1;0;4,-63;-8,-20;;-11,-78;6,5,0,-1,-1,0",
"xs15_08o6picz32;xs16_4a9lmzx1074;0;8,-79;-10,-12;;-8,-78;6,0,0,-1,1,0",
"xs15_08o6picz32;xs16_4a9lmzx1252;0;8,-86;;;-12,-82;6,0,0,-1,1,0",
"xs15_08o6picz32;xs16_69jc32ac;0;-1,-36,12,-72;1,-37;;;6,4,-1,0,0,-1",
"xs15_08o6picz32;xs17_w8o6piczca1;0;11,-94;-11,-12;;;-1,0,1,0,0,1",
"xs15_08u15a4z65;xs16_08u15acz65;0;15,-70;;;5,-64;0,0,1,0,0,1",
"xs15_08u16413z32;xs16_0gs2d96z641;0;;8,-50;-6,-66,-1,-42,6,-40;;0,-1,1,0,0,1",
"xs15_08u16413z32;xs17_w8u16413zca1;0;11,-94;-11,-12;;;-1,0,1,0,0,1",
"xs15_08u16426z32;xs16_0gs2c871z641;0;15,-77;15,-70;5,-60;9,-64;0,-1,1,0,0,1",
"xs15_08u178cz32;xs16_08u1784cz32;0;13,-62;;15,-15;4,-47;0,0,1,0,0,1",
"xs15_08u178cz32;xs16_08u178k8z32;0;15,-70;;16,-22;4,-57;0,0,1,0,0,1",
"xs15_08u1daz321;xs16_08u1da4z321;0;15,-70;;;22,-69;0,0,1,0,0,1",
"xs15_08u1daz321;xs16_0gs2pmz643;0;;2,-108,14,-66;-4,-114,15,-74,19,-87;20,-104;0,-1,1,0,0,1",
"xs15_08u1daz321;xs16_ad1u8zx1252;0;-1,-59,4,-88;-18,-12,-3,-45;;-12,-81;5,0,-1,0,0,1",
"xs15_09f033z253;xs14_33032qr;0;13,-62;;;;1,6,0,1,-1,0",
"xs15_09f033z253;xs15_2ego8br;0;11,-60;;10,-15;1,-40;5,6,0,-1,-1,0",
"xs15_09f033z253;xs16_8o0o8brz23;0;;-10,-26;;-17,-98;5,6,0,-1,-1,0",
"xs15_09v04a4z65;xs16_09v04a6z65;0;;11,-54;9,-48;;0,0,1,0,0,1",
"xs15_09v04a4z65;xs16_09v04acz65;0;15,-70;;;5,-64;0,0,1,0,0,1",
"xs15_09v0ccz321;xs16_09v0ck8z321;0;;11,-54;9,-39;3,-62;0,0,1,0,0,1",
"xs15_09v0ccz321;xs16_cc0v9zx1252;0;-1,-59,4,-88;-18,-12,-3,-45;;-12,-81;5,0,-1,0,0,1",
"xs15_0at1acz321;xs16_ca1tazx1252;0;-1,-59,4,-88;-18,-12,-3,-45;;-12,-81;5,0,-1,0,0,1",
"xs15_0at1e8z321;xs16_8e1tazx1252;0;-1,-59,4,-88;-18,-12,-3,-45;;-12,-81;5,0,-1,0,0,1",
"xs15_0bdz25b8o;xs15_0kq23z1qm;0;4,-65;-8,-25;;-14,-82;0,9,1,0,0,-1",
"xs15_0bq1e8z321;xs15_255mgmazx1;0;7,-74;-11,-12;;;0,6,0,1,-1,0",
"xs15_0bq1e8z321;xs16_0bq1daz321;0;;;0,-61;5,-55,10,-36;0,0,1,0,0,1",
"xs15_0bq1e8z321;xs16_0ml2sgz643;0;-5,-36;22,-143;;;0,-1,1,0,0,1",
"xs15_0bq1e8z321;xs16_8e1qbzx1252;0;-1,-59,4,-88;-18,-12,-3,-45;;-12,-81;5,0,-1,0,0,1",
"xs15_0brz69ko;xs16_35iczoja4;0;-5,-48;4,-68;-5,-86,2,-61;;3,9,-1,0,0,-1",
"xs15_0brzmdz11;xs16_4ap3zmdz11;0;-5,-52;4,-72;-5,-90,2,-65;;0,0,1,0,0,1",
"xs15_0bt06a4z32;xs16_0bt0uiz32;0;13,-72;;18,-12;;0,0,1,0,0,1",
"xs15_0c4gf9z2521;xs16_0c4gf9z6521;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs15_0c4oa52z2521;xs16_0c4oa52z6521;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs15_0c4oa52z2521;xs16_0c4oa53z2521;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs15_0c8421e8z253;xs16_4ai3zw230f9;0;;-10,-34;;-17,-106;7,0,0,-1,1,0",
"xs15_0c88a53z253;xs16_9f0s4zx1256;0;;-10,-30;;-17,-102;-1,6,0,1,-1,0",
"xs15_0c88e13z253;xs16_0giu0652z56;0;;10,-63;7,-48;12,-40;0,0,0,1,1,0",
"xs15_0c9b8oz253;xs16_8o1vg4cz23;0;;-10,-26;;-17,-98;5,6,0,-1,-1,0",
"xs15_0ca2453z253;xs16_0o4c0f9z643;0;;-10,-30;;-17,-102;-1,0,0,1,1,0",
"xs15_0ca52zojd;xs15_0dbgzojd;0;-2,-48;;-9,-79,8,-55;1,-73;0,0,1,0,0,1",
"xs15_0ci53z8ld;xs14_brz34ac;0;15,-70;;;;1,8,1,0,0,-1",
"xs15_0ci53z8ld;xs15_178c48a53;0;13,-73;;12,-12;-1,-53;4,8,0,-1,-1,0",
"xs15_0ci53z8ld;xs16_32arzw34ac;0;;-12,-14;;-19,-102;-1,8,1,0,0,-1",
"xs15_0cid96z321;xs15_04aq453z311;0;;5,-43;8,-29;10,-36;0,0,0,1,1,0",
"xs15_0cilicz321;xs16_ciliczx1252;0;-1,-59,4,-88;-18,-12,-3,-45;;-12,-81;5,0,-1,0,0,1",
"xs15_0ck31e8z321;xs16_wck31e8z2521;0;-1,-60,4,-89;-18,-13,-3,-46;;-12,-82;-1,0,1,0,0,1",
"xs15_0cp30352z32;xs16_0cp30f9z32;0;13,-64;;18,-12;;0,0,1,0,0,1",
"xs15_0cp3zgbqz01;xs16_0bq23zoj6;0;;-13,-12;;-20,-108;3,9,-1,0,0,-1",
"xs15_0cp3zragz01;xs14_0cp3zrq;0;;;;-14,-78;0,0,1,0,0,1",
"xs15_0cp3zragz01;xs15_32qczx6jo;0;4,-61;-11,-12;;-12,-81;-2,9,1,0,0,-1",
"xs15_0cp3zragz01;xs16_32arzoj6;0;22,-108;;15,-12;;3,9,-1,0,0,-1",
"xs15_0cq1daz321;xs16_0cq1da4z321;0;14,-66;;;8,-51;0,0,1,0,0,1",
"xs15_0cq23zrm;xs16_wcq23zgb6z11;0;9,-109,20,-117;;;-21,-110,-9,-106;-1,0,1,0,0,1",
"xs15_0drz254ko;xs16_321eg84c84c;0;20,-101;;16,-12;-7,-89;4,10,0,-1,-1,0",
"xs15_0drz254ko;xs16_xrdzg8k452z01;0;21,-112;;18,-12;-7,-99;5,0,-1,0,0,1",
"xs15_0drz3ego;xs16_3124628c453;0;;2,-62,14,-66;-9,-73,2,-65;;3,-1,0,-1,1,0",
"xs15_0drz69ko;xs16_31246248a53;0;;2,-62,14,-66;-9,-73,2,-65;;3,-1,0,-1,1,0",
"xs15_0drzmdz11;xs16_rdz0dmzw23;0;;2,-62,14,-66;-9,-73,2,-65;;0,10,1,0,0,-1",
"xs15_0g0j96z8ld;xs16_wgbq23z69c;0;;-12,-18;;-19,-106;5,8,-1,0,0,-1",
"xs15_0g0s252z8ld;xs16_xgbq23z4a43;0;;-12,-22;;-19,-110;6,8,-1,0,0,-1",
"xs15_0g0s2qrz121;xs16_mmge1e8z1;0;0,-39,7,-57;-10,-12,-2,-18;;;6,5,-1,0,0,-1",
"xs15_0g0si53z343;xs16_c87p8zx1256;0;20,-135;-13,-40;13,-48;-20,-114;0,7,1,0,0,-1",
"xs15_0g3ia4z8ld;xs16_32qbgzxc452;0;;-12,-18;;-19,-106;-1,8,1,0,0,-1",
"xs15_0g4q23z8ld;xs16_32q4gzxd54c;0;;-12,-18;;-19,-106;5,0,-1,0,0,1",
"xs15_0g4qajoz121;xs16_0g4qajoz321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0g6p3z8ld;xs16_0gbq23zc96;0;;-12,-14;;-19,-102;4,8,-1,0,0,-1",
"xs15_0g6pb8oz121;xs14_g6pb8oz11;0;9,-62;;;-7,-62;1,0,1,0,0,1",
"xs15_0g6pb8oz121;xs16_0g6pb8oz321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0g6picz343;xs16_cip6gzx3452;0;-1,-116,18,-152,22,-181;-15,-12,-3,-102;;-23,-202;5,0,-1,0,0,1",
"xs15_0g842130352z32;xs14_0g84213zrq;0;;;;13,-36;0,0,0,1,1,0",
"xs15_0g842130352z32;xs15_32qczx1248go;0;;12,-59;3,-48;11,-36;9,-2,0,-1,1,0",
"xs15_0g842130352z32;xs16_0g84213zra8o;0;16,-74;;21,-22;;0,0,0,1,1,0",
"xs15_0g84cj96z32;xs16_wg84cj96z65;0;6,-105;-15,-18;;-19,-114,-6,-103;-1,0,1,0,0,1",
"xs15_0g88a52z8ld;xs16_32qbzx115a4;0;;-12,-22;;-19,-110;-1,8,1,0,0,-1",
"xs15_0g88b5z8ld;xs16_32qbzx11da;0;;-12,-18;;-19,-106;-1,8,1,0,0,-1",
"xs15_0g8ehrz321;xs14_0g8ehrz121;0;-1,-36;-3,-18;;;0,0,1,0,0,1",
"xs15_0g8ge13zc96;xs16_0g8ge123zc96;0;;10,-67;7,-52;12,-44;0,0,1,0,0,1",
"xs15_0g8ge13zc96;xs16_3p6gzw1078k8;0;;12,-68;7,-55;13,-44;0,8,1,0,0,-1",
"xs15_0g8go3tgz23;xs16_4s0c4871zw56;0;-4,-36;5,-75;-8,-84,5,-73;;7,6,-1,0,0,-1",
"xs15_0g8hf0ccz23;xs16_08k9b8oz6221;0;14,-66;;16,-16;-1,-75;7,6,0,-1,-1,0",
"xs15_0g8it246z23;xs16_0g8jt246z23;0;-2,-36;6,-62;;;0,0,1,0,0,1",
"xs15_0g8jdz3kp;xs16_64215akg84c;0;-6,-48;3,-87;-10,-96,3,-85;;4,-1,0,-1,1,0",
"xs15_0g8jdz6jo;xs16_64132akg84c;0;-6,-48;3,-87;-10,-96,3,-85;;0,9,0,1,-1,0",
"xs15_0g8k453zoo11;xs11_g0s256z11;0;9,-48;;;;1,0,0,1,1,0",
"xs15_0g8o0uh3z23;xs16_32aczw311da;0;;11,-59;8,-44;13,-36;0,6,0,1,-1,0",
"xs15_0g8o652zc96;xs16_0g8o6413zc96;0;15,-70;8,-60;13,-44;7,-53;0,0,1,0,0,1",
"xs15_0g8o652zc96;xs16_0g8o653zc96;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs15_0g8o652zc96;xs16_39cggzx1cjo;0;-2,-44;8,-67;-2,-82;7,-62;6,-1,-1,0,0,1",
"xs15_0g8o652zc96;xs17_3p6gzw116ak8;0;;12,-58;10,-43;;0,8,1,0,0,-1",
"xs15_0g8objoz23;xs16_c48c871z253;0;-3,-36;7,-61;3,-60;;6,6,-1,0,0,-1",
"xs15_0g8objoz23;xs16_wbt06a4z311;0;;5,-43,13,-62;1,-45;;6,6,0,-1,-1,0",
"xs15_0gba952z123;xs16_kc0v146z121;0;0,-61,0,-36;0,-34;;;0,0,0,1,1,0",
"xs15_0gba96z643;xs16_25iczxd596;0;0,-67,5,-96;-19,-12,-4,-45;;-13,-89;-1,8,1,0,0,-1",
"xs15_0gbb8oz643;xs16_8k9b8oz643;0;-1,-40;-2,-45;-5,-54;;0,0,1,0,0,1",
"xs15_0gbb8oz643;xs16_gwci52z11dd;0;0,-67,5,-96;-19,-12,-4,-45;;-13,-89;5,8,-1,0,0,-1",
"xs15_0ggca96z3421;xs16_0gil9a4z3421;0;-12,-93,11,-167;;;-15,-94;6,7,-1,0,0,-1",
"xs15_0ggci96z643;xs16_wg0si52z6943;0;;-18,-12,-9,-43;-1,-49;-13,-97;6,8,-1,0,0,-1",
"xs15_0ggdjoz643;xs15_0ggdjoz343;0;8,-82;-12,-12;;;0,0,1,0,0,1",
"xs15_0ggdjoz643;xs16_39eg8k8zx56;0;15,-70;;6,-50,21,-17;3,-77,8,-48;0,7,1,0,0,-1",
"xs15_0ggdjoz643;xs16_gg0si52z1cb;0;0,-67,5,-96;-19,-12,-4,-45;;-13,-89;5,8,-1,0,0,-1",
"xs15_0ggdjoz643;xs16_j5oz11079c;0;;4,-70,16,-74;-7,-81,4,-73;;5,-1,-1,0,0,1",
"xs15_0ggo8brz32;xs16_0ggo8brz56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs15_0ggra96z32;xs16_0ggra96z56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs15_0ggraicz32;xs16_0ggraicz56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs15_0ggrb8oz32;xs16_0ggrb8oz56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs15_0ggrb8oz32;xs16_wpf0ck8z321;0;;4,-39,12,-58;0,-41;;6,6,0,-1,-1,0",
"xs15_0ggs252z12ko;xs16_0ggs253z12ko;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs15_0ggs252z12ko;xs16_8e1e88gzxca1;0;;;5,-45,12,-27;2,-54,10,-48;6,1,-1,0,0,1",
"xs15_0ggs2pmz32;xs16_0ggs2pmz56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs15_0ghn8426z32;xs16_0ghn8426z56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs15_0ghn871z32;xs16_0ghn871z56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs15_0gilicz346;xs16_0gilicz34a4;0;16,-152;;16,-86,17,-12,21,-35,21,-16;-7,-132,-7,-107,-6,-152,1,-138;0,0,1,0,0,1",
"xs15_0gjlkcz641;xs16_025a8ozc9311;0;-3,-40;4,-55;-6,-68;;0,-1,1,0,0,1",
"xs15_0gjlkcz641;xs16_g88c93z11da;0;-1,-40;4,-45;-5,-57;;5,7,-1,0,0,-1",
"xs15_0gs25a4z1246;xs16_0gs25acz1246;0;;;14,-12;0,-62;0,0,1,0,0,1",
"xs15_0gs25a4z1246;xs17_0gs25ak8z1246;0;;;12,-18;4,-40;0,0,1,0,0,1",
"xs15_0i5q453z121;xs16_04ak8a52z2521;0;;9,-85,14,-66,19,-88;6,-65;14,-50;0,-1,1,0,0,1",
"xs15_0i5q453z121;xs16_04al9a4z2521;0;-7,-36;6,-61;-6,-71,5,-69;;0,-1,1,0,0,1",
"xs15_0i5q453z121;xs16_0i5q453z321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0i5q8a6z121;xs14_i5q8a6z11;0;9,-62;;;-7,-62;1,0,1,0,0,1",
"xs15_0i5q8a6z121;xs16_0i5q8a6z321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0i5q8a6z121;xs16_0j5q8a6z121;0;-4,-36;4,-62;;;0,0,1,0,0,1",
"xs15_0i5t246z121;xs16_0i5t246z321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0j1u066z121;xs15_39u066z032;0;4,-121,20,-90;-6,-81;;-2,-120,5,-99;1,0,1,0,0,1",
"xs15_0j1u066z121;xs16_0j1u066z321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0j1u066z121;xs16_0j1u06a4z121;0;;13,-62;9,-47;5,-62;0,0,1,0,0,1",
"xs15_0j1u066z121;xs16_252s0ccz2521;0;-6,-36;0,-47;-5,-60;;0,-1,1,0,0,1",
"xs15_0j1u066z121;xs16_3i1u066z121;0;-5,-36;0,-44;-3,-59;;0,0,1,0,0,1",
"xs15_0j1u066z121;xs16_6a88a52z253;0;16,-74;;8,-50;6,-59;0,0,0,1,1,0",
"xs15_0j1u0ooz121;xs16_25a88b5zw33;0;-5,-36;0,-44;-3,-59;;0,6,0,1,-1,0",
"xs15_0j5o0ok8z121;xs16_0j5o0uiz121;0;;9,-56;;14,-36;0,0,1,0,0,1",
"xs15_0j5o652z121;xs16_0j5o652z321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0j5oz349go;xs16_g84215a8426z11;0;23,-124;;12,-53,25,-12;-6,-127;0,10,0,1,-1,0",
"xs15_0j5s246z121;xs16_0j5s246z321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0j5s252z121;xs16_04ap5a4z2521;0;;2,-69,13,-71;1,-61;14,-36;0,-1,1,0,0,1",
"xs15_0j5s252z121;xs16_0j5s252z321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0j960652z32;xs16_06ic0f9z65;0;;11,-72;;16,-36;0,-1,1,0,0,1",
"xs15_0j9606a4z32;xs16_0j960uiz32;0;14,-72;;19,-12;;0,0,1,0,0,1",
"xs15_0j96zragz01;xs14_0j96zrq;0;;;;-14,-78;0,0,1,0,0,1",
"xs15_0j96zragz01;xs15_32qczxpic;0;4,-61;-11,-12;;-12,-81;-2,9,1,0,0,-1",
"xs15_0j96zragz01;xs16_32arzcip;0;22,-108;;15,-12;;3,9,-1,0,0,-1",
"xs15_0j9c84cz321;xs16_0j9c871z321;0;15,-77;13,-62;5,-52;7,-64;0,0,1,0,0,1",
"xs15_0j9c871z121;xs16_jhke1e8z1;0;6,-55,13,-65;;;-11,-78,-3,-52;1,0,0,1,1,0",
"xs15_0j9cga6z121;xs16_0j9cga6z321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0j9cz1215a4;xs14_39m8628c;0;;;13,-12;-1,-68;4,7,0,-1,-1,0",
"xs15_0j9cz1215a4;xs16_0j9cz1215ac;0;19,-86;;;-1,-80;0,0,1,0,0,1",
"xs15_0j9cz1215a4;xs16_0j9cz3215a4;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs15_0j9eg8oz121;xs16_0j9eg8oz321;0;4,-76;;;-12,-82;0,0,1,0,0,1",
"xs15_0j9egoz321;xs16_35ao4a4z0321;0;15,-70;;16,-14;2,-57;0,6,1,0,0,-1",
"xs15_0jhe8zbc1;xs16_0jhe8z3kp;0;9,-113,22,-124;;18,-12;-7,-115;0,0,1,0,0,1",
"xs15_0kc0fhoz32;xs16_0kc0fh8oz32;0;14,-67;;16,-12;3,-52;0,0,1,0,0,1",
"xs15_0mk215a4z121;xs16_0kc0f9z34a4;0;;-9,-38;;-16,-102;-1,0,0,1,1,0",
"xs15_0ml12koz121;xs16_32qb0ga6zx11;0;;-9,-34;;-16,-98;-1,5,1,0,0,-1",
"xs15_0mp3zga6z11;xs16_0mp3zha6z11;0;-3,-52;-13,-24,-7,-19;;;0,0,1,0,0,1",
"xs15_0o4871zdl8;xs16_0o4871zd54c;0;21,-100;;14,-12;;0,0,1,0,0,1",
"xs15_0o48a52z39c;xs16_0o48a53z39c;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs15_0o4a52zdl8;xs16_0o4a52zd54c;0;21,-100;;14,-12;;0,0,1,0,0,1",
"xs15_0o4a53zdd;xs16_35a4ozxc952;0;11,-96;-14,-12;;-14,-114,-7,-89;5,0,-1,0,0,1",
"xs15_0o8a52zc453;xs16_0o8a53zc453;0;;11,-54;7,-48;;0,0,1,0,0,1",
"xs15_0o8a52zc453;xs16_0o8b52zc453;0;-2,-44;6,-70;;;0,0,1,0,0,1",
"xs15_0o8a52zc453;xs16_178c2ege2;0;;2,-25,10,-51;-2,-38,5,-28;;0,8,0,1,-1,0",
"xs15_0oge123z4a6;xs16_0ggkc0f9z56;0;;-11,-26;;-18,-106;-1,0,0,1,1,0",
"xs15_0ogjl8z4a6;xs16_0g358gz8ld11;0;-6,-44;3,-83;-10,-92,3,-81;;0,-1,1,0,0,1",
"xs15_0ok213z4a9o;xs16_0g8426421e8z32;0;;15,-88;4,-91;4,-89,17,-48;0,-1,0,1,1,0",
"xs15_0ok213zcip;xs16_0g842642156z32;0;;15,-88;4,-91;4,-89,17,-48;0,-1,0,1,1,0",
"xs15_0ok2156z4a6;xs16_32qbzx12453;0;;-11,-26;;-18,-106;-1,7,1,0,0,-1",
"xs15_0ok215a4z641;xs16_0ok215acz641;0;16,-74;;;6,-68;0,0,1,0,0,1",
"xs15_0ok215a4z641;xs17_358gzw358gka4;0;12,-102;-12,-12;;;-1,9,1,0,0,-1",
"xs15_0ok21e8z4a6;xs16_wok21e8z6226;0;;-11,-26;;-18,-106;-1,0,1,0,0,1",
"xs15_0ok4871z4a6;xs16_wo4c0f9z6221;0;;-11,-26;;-18,-106;-1,0,0,1,1,0",
"xs15_0rq23z4a6;xs16_32qrzw6226;0;;-11,-18;;-18,-98;4,0,-1,0,0,1",
"xs15_1784260ui;xs16_0ra246zc452;0;11,-90,22,-98;;;-9,-91,3,-87;8,0,0,-1,1,0",
"xs15_1784c0c48go;xs16_1784cgc48go;0;12,-65,18,-94;;;-8,-82;0,0,1,0,0,1",
"xs15_1784c32ac;xs16_1784c32ak8;0;19,-86;;16,-34;3,-73;0,0,1,0,0,1",
"xs15_1784c32ac;xs16_1784c32qk;0;18,-82;;14,-41;3,-70;0,0,1,0,0,1",
"xs15_1784cgs26;xs16_05b8ozo8b5;0;;11,-54;10,-39;13,-39;9,0,0,-1,1,0",
"xs15_1784ozx122ac;xs16_1784ozx122ak8;0;23,-104;;20,-12;-3,-91;0,0,1,0,0,1",
"xs15_1784ozx122ac;xs16_1784ozx122qk;0;22,-100;;19,-28,20,-12;;0,0,1,0,0,1",
"xs15_178c0f96;xs15_178c0fho;0;;;9,-18;7,-24;0,0,1,0,0,1",
"xs15_178c0fho;xs16_178c0fh8o;0;15,-70;;17,-15;4,-55;0,0,1,0,0,1",
"xs15_178c2dic;xs16_178c2dik8;0;27,-178;;7,-102,19,-12;-12,-157,-8,-128,11,-92;0,0,1,0,0,1",
"xs15_178c2dio;xs15_178c2dic;0;;;16,-12;2,-58;0,0,1,0,0,1",
"xs15_178c2dio;xs16_178c2djo;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs15_178czw31156;xs16_178czw311da;0;20,-90;;16,-17;-3,-78;0,0,1,0,0,1",
"xs15_178czw3553;xs15_178czw31156;0;12,-58;;;-6,-56;0,0,1,0,0,1",
"xs15_178czy16996;xs15_0gbq2sgz23;0;9,-58;;8,-24;-8,-74,7,-44;0,6,1,0,0,-1",
"xs15_252sgc2ko;xs16_178716853;0;-4,-33,4,-39;-6,-12,1,-30;;;0,4,1,0,0,-1",
"xs15_252sgc2ko;xs16_352sgc2ko;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs15_252sgc453;xs15_252sgc2ko;0;15,-70;8,-60;9,-56;5,-76;0,0,1,0,0,1",
"xs15_252sgc453;xs16_1787164ko;0;-4,-33,4,-39;-6,-12,1,-30;;;0,4,1,0,0,-1",
"xs15_252sgc453;xs16_352sgc453;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs15_252sgzx69k8;xs16_252sgzx69ko;0;21,-94;;;-1,-88;0,0,1,0,0,1",
"xs15_252sgzx6ak8;xs15_0gs252z1qm;0;;-9,-12;12,-37;-16,-115,1,-91;5,0,-1,0,0,1",
"xs15_252sgzy132ac;xs16_252sgzy132ak8;0;24,-106;;21,-14;-2,-93;0,0,1,0,0,1",
"xs15_252sgzy132ac;xs16_252sgzy132qk;0;23,-102;;19,-21;-2,-90;0,0,1,0,0,1",
"xs15_2530fh84c;xs16_2530fh8426;0;;16,-74;9,-77;5,-91,18,-50;0,0,1,0,0,1",
"xs15_255mgmazx1;xs16_0ml2sgz343;0;;12,-58;27,-57;;7,0,0,-1,1,0",
"xs15_255mgmazx1;xs16_gbq1daz121;0;12,-77,17,-78;;;5,-63;6,0,0,-1,1,0",
"xs15_255q826zx23;xs16_628q552z065;0;10,-94,22,-98;;;-13,-105,-2,-97;6,0,-1,0,0,1",
"xs15_255q826zx23;xs16_628q552z311;0;14,-94;-8,-19;18,-12;0,-74;6,0,-1,0,0,1",
"xs15_255q88czx23;xs16_c88q552z065;0;10,-94,22,-98;;;-13,-105,-2,-97;6,0,-1,0,0,1",
"xs15_25606248a52;xs16_025iczo8bq;0;-9,-30;;-4,-66;;10,-1,0,-1,1,0",
"xs15_25606248ge2;xs16_32qbzwo9a4;0;-9,-30;;-4,-66;;1,-1,0,1,1,0",
"xs15_25606248gkc;xs16_32qbzxpic;0;-9,-30;;-4,-66;;1,-1,0,1,1,0",
"xs15_2560628c4go;xs16_32qbzx6jo;0;-9,-30;;-4,-66;;1,-1,0,1,1,0",
"xs15_256064215a4;xs14_0brz69k8;0;;-5,-12;;;1,0,0,1,1,0",
"xs15_256064215a4;xs15_025iczo8b6;0;9,-55;-3,-27;;-4,-66;10,4,0,-1,-1,0",
"xs15_256064215a4;xs16_0ci52zo8ar;0;-9,-30;;-4,-66;;10,-1,0,-1,1,0",
"xs15_2560651248c;xs16_0g853zo9ar;0;-9,-30;;-4,-66;;10,-1,0,-1,1,0",
"xs15_256069ar;xs16_mkic0f9z1;0;-9,-28;;-4,-64;;7,-1,-1,0,0,1",
"xs15_25606a84213;xs16_6248gkc0f9;0;-9,-30;;-4,-66;;10,-1,-1,0,0,1",
"xs15_25606agzy31246;xs16_32qbgzy112ko;0;-9,-40;;-4,-76;;1,-1,0,1,1,0",
"xs15_25606iczx65;xs16_9f0c4ozwca1;0;-9,-40;;-4,-76;;1,-1,1,0,0,1",
"xs15_2560uh246;xs16_2560uh248c;0;20,-90;;9,-75,22,-34;5,-93;0,0,1,0,0,1",
"xs15_256o8br;xs16_2560uiz0253;0;;9,-46;-3,-63,5,-44;;7,-1,0,-1,1,0",
"xs15_256o8ge13;xs16_256o8ge123;0;;12,-58;9,-43;14,-35;0,0,1,0,0,1",
"xs15_256o8gka6;xs16_3146o8gka6;0;-1,-61;-7,-52;-2,-68;-9,-78;-1,0,1,0,0,1",
"xs15_256o8gka6;xs16_356o8gka6;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs15_256o8gka6;xs16_8o6413z34ac;0;;-4,-44,5,-61,14,-66;-13,-115,-4,-75;;0,4,0,1,-1,0",
"xs15_25960uh3;xs16_25960uh23;0;;11,-54;8,-39;13,-31;0,0,1,0,0,1",
"xs15_25960uh3;xs16_3hu069ic;0;-7,-28;-3,-117,20,-135;;;7,0,-1,0,0,1",
"xs15_25960uh3;xs16_wkc0fhoz65;0;-7,-28,2,-63;5,-63;-3,-67;;0,4,1,0,0,-1",
"xs15_259e0e93;xs16_0c8a52z6953;0;16,-74;;14,-34;5,-58;8,0,0,-1,1,0",
"xs15_259e0eio;xs16_25is0sia4;0;;12,-58;9,-42;10,-50;8,-1,-1,0,0,1",
"xs15_259eg8ozx23;xs16_0gila8oz3421;0;;9,-46;10,-33;10,-46;7,0,0,-1,1,0",
"xs15_259eg8ozx23;xs16_69acggozx56;0;;8,-58,9,-46;;9,-46;0,0,0,1,1,0",
"xs15_259eg8ozx23;xs16_o8ge952z065;0;10,-94,22,-98;;;-13,-105,-2,-97;6,0,-1,0,0,1",
"xs15_259m8628c;xs17_259m86248go;0;17,-78;;;9,-72;0,0,1,0,0,1",
"xs15_259m88czx23;xs16_c88m952z065;0;10,-94,22,-98;;;-13,-105,-2,-97;6,0,-1,0,0,1",
"xs15_259mge13;xs16_069a4oz4a511;0;;13,-62;8,-49;14,-38;0,-1,0,1,1,0",
"xs15_259mge13;xs16_259mge123;0;;11,-54;8,-39;13,-31;0,0,1,0,0,1",
"xs15_25a4ozx122ac;xs16_25a4ozx122ak8;0;23,-104;;20,-12;-3,-91;0,0,1,0,0,1",
"xs15_25a4ozx122ac;xs16_25a4ozx122qk;0;22,-100;;19,-28,20,-12;;0,0,1,0,0,1",
"xs15_25a8421ego;xs16_25a8421eg8o;0;17,-78;;19,-23;6,-63;0,0,1,0,0,1",
"xs15_25a8421ego;xs16_g88a52zg9icz01;0;19,-86;;20,-30;6,-73;10,0,0,-1,1,0",
"xs15_25a84c0c4go;xs16_25a84cgc4go;0;13,-62,19,-91;;;-7,-79;0,0,1,0,0,1",
"xs15_25a88czwbd;xs16_g88a52z11db;0;;;12,-49,12,-32;10,-44;5,0,-1,0,0,1",
"xs15_25a8czx2553;xs16_35a8czx2553;0;-5,-40;3,-66;;;0,0,1,0,0,1",
"xs15_25a8czx6513;xs16_25a8czw4a513;0;;-9,-12;17,-12;-16,-107,-7,-102;0,0,1,0,0,1",
"xs15_25a8czx6513;xs16_35a8czx6513;0;-5,-40;3,-66;;;0,0,1,0,0,1",
"xs15_25a8k8zwbd;xs14_39m86246;0;0,-44;-2,-36;;;1,1,0,1,1,0",
"xs15_25a8k8zwbd;xs16_25a8kczwbd;0;;9,-46;9,-40;;0,0,1,0,0,1",
"xs15_25a8k8zwbd;xs16_35a8k8zwbd;0;-5,-44;3,-70;;;0,0,1,0,0,1",
"xs15_25a8o64ko;xs16_08ehi3z4a43;0;19,-86;;15,-37;2,-74;8,0,0,-1,1,0",
"xs15_25a8o64ko;xs16_0gs252z8k871;0;20,-90;;17,-30;2,-77;9,0,0,-1,1,0",
"xs15_25a8ozxc453;xs16_35a8ozxc453;0;-5,-44;3,-70;;;0,0,1,0,0,1",
"xs15_25aczw1784c;xs15_321e8gzxbd;0;3,-69;-4,-51,13,-75;;6,-44;6,8,-1,0,0,-1",
"xs15_25ao4cz2521;xs14_0j9egoz121;0;10,-62;;;-8,-62;0,6,1,0,0,-1",
"xs15_25ao4cz2521;xs16_25ao48cz2521;0;;7,-47;8,-32;9,-40;0,0,1,0,0,1",
"xs15_25ao4cz2521;xs16_25ao4a4z2521;0;;9,-48;8,-35;10,-40;0,0,1,0,0,1",
"xs15_25ao4cz2521;xs16_25ao4cz6521;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs15_25ao4cz2521;xs16_35ao4cz2521;0;-5,-40;3,-66;;;0,0,1,0,0,1",
"xs15_25ao8a6z032;xs16_252s826z2521;0;;13,-62;5,-49;10,-42;0,0,0,1,1,0",
"xs15_25ao8a6z032;xs16_25ao8b5z032;0;;12,-58;5,-46;8,-49;0,0,1,0,0,1",
"xs15_25b871ac;xs16_358e1dic;0;-5,-24;3,-50;;;7,3,-1,0,0,-1",
"xs15_25b8ozwbd;xs16_62461vg4c;0;6,-58;-6,-37,-6,-12;;;4,8,0,-1,-1,0",
"xs15_25icga6z023;xs16_35icga6z023;0;-5,-36;3,-62;;;0,0,1,0,0,1",
"xs15_25icggozx56;xs16_35icggozx56;0;-5,-40;3,-66;;;0,0,1,0,0,1",
"xs15_25icz69ko;xs16_35icz69ko;0;-5,-48;3,-74;;;0,0,1,0,0,1",
"xs15_25iczmlz11;xs16_3586248gka4;0;10,-105,17,-130;;17,-12;-12,-112;-1,10,0,1,-1,0",
"xs15_25iczqm11;xs16_35iczqm11;0;-5,-48;3,-74;;;0,0,1,0,0,1",
"xs15_25iczw116413;xs17_g853z11642ak8;0;;8,-42;16,-36;;9,7,0,-1,-1,0",
"xs15_25iczw11db;xs16_35iczw11db;0;-5,-44;3,-70;;;0,0,1,0,0,1",
"xs15_25iczw1784c;xs16_321eozx34ac;0;-5,-44;3,-70;;;6,8,-1,0,0,-1",
"xs15_25iczwc953;xs16_35iczwc953;0;-5,-44;3,-70;;;0,0,1,0,0,1",
"xs15_25iczwd54c;xs16_25iczwd5426;0;;;11,-48,22,-12;-3,-101,9,-57;0,0,1,0,0,1",
"xs15_25iczx1178c;xs16_25iczx11784c;0;19,-104,21,-94;;;3,-92;0,0,1,0,0,1",
"xs15_25is0796;xs16_35is0796;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs15_25is079c;xs16_35is079c;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs15_25is0sic;xs16_35is0sic;0;-5,-28;3,-54;;;0,0,1,0,0,1",
"xs15_25t28cz321;xs16_5b88ciczx32;0;5,-68;-12,-12;;-10,-83;-1,6,0,1,-1,0",
"xs15_2eg8421ego;xs16_2eg8421eg8o;0;17,-78;;19,-23;6,-63;0,0,1,0,0,1",
"xs15_2eg8oge13;xs16_2eg8oge123;0;;12,-58;9,-43;14,-35;0,0,1,0,0,1",
"xs15_2ege1da4;xs16_4ad1egma;0;9,-69;-9,-12,-4,-31;;;7,0,-1,0,0,1",
"xs15_2ege1ego;xs16_04aabgz4a511;0;17,-78;;18,-22;4,-65;0,5,0,1,-1,0",
"xs15_2ege1ego;xs16_2ege1eg8o;0;15,-70;;17,-15;4,-55;0,0,1,0,0,1",
"xs15_2ego0uh3;xs16_2ego0uh23;0;;11,-54;8,-39;13,-31;0,0,1,0,0,1",
"xs15_2ego8br;xs16_cq23z230352;0;;9,-46;-3,-63,5,-44;;0,4,0,1,-1,0",
"xs15_2ego8br;xs16_rai31e8z01;0;;6,-47,14,-66;2,-49;;6,4,-1,0,0,-1",
"xs15_2ego8ge13;xs16_2ego8ge123;0;;12,-58;9,-43;14,-35;0,0,1,0,0,1",
"xs15_2egu15a4;xs16_2egu15ac;0;16,-74;;;6,-68;0,0,1,0,0,1",
"xs15_2l2s53z121;xs16_0i5q8a52z121;0;;8,-81,13,-62,18,-84;5,-61;13,-46;0,-1,0,1,1,0",
"xs15_2l2s53z121;xs16_2l2s53z321;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs15_2l2s53z121;xs16_3l2s53z121;0;-5,-36;3,-62;;;0,0,1,0,0,1",
"xs15_2l2s53z121;xs16_4a5pa4z2521;0;-8,-36;5,-61;-7,-71,4,-69;;0,-1,1,0,0,1",
"xs15_2lla8oz121;xs16_256o696zx23;0;;12,-58;7,-61;1,-83,14,-42;0,6,0,1,-1,0",
"xs15_2lla8oz121;xs16_2lla8cz1221;0;14,-66;;;-2,-60;0,6,1,0,0,-1",
"xs15_2lla8oz121;xs16_2lla8oz321;0;4,-72;;;-12,-78;0,0,1,0,0,1",
"xs15_2lla8oz121;xs16_2lm88cz1243;0;;0,-100,12,-58;-6,-106,13,-66,17,-79;18,-96;0,6,1,0,0,-1",
"xs15_2lla8oz121;xs16_2lm88cz3421;0;-15,-104;-14,-87,-10,-74,9,-114;-9,-66,3,-108;;0,6,1,0,0,-1",
"xs15_2lla8oz121;xs16_8ehdioz023;0;0,-61;-3,-57;-7,-58;;-1,5,0,1,-1,0",
"xs15_2lla8oz121;xs16_9fgcicz023;0;;-9,-30;;-16,-94;-1,5,0,1,-1,0",
"xs15_2lmge2z32;xs16_02lmge2z252;0;8,-75;-11,-12;;-14,-88;-1,0,1,0,0,1",
"xs15_2lmge2z32;xs16_09f0s4z6511;0;-9,-36;;-4,-72;;0,-1,1,0,0,1",
"xs15_2lmge2z32;xs16_2lmge2z56;0;11,-98;-11,-12,-9,-30;;;0,0,1,0,0,1",
"xs15_2lmge2z32;xs16_9f0s26z311;0;-3,-54;;-10,-70;;-1,1,0,1,1,0",
"xs15_2lmz056zz33;xs11_bdz352;0;15,-76;;;;2,7,-1,0,0,-1",
"xs15_2lmzg6dz11;xs14_cp3zrq;0;;6,-34;;;2,10,-1,0,0,-1",
"xs15_2lmzg6dz11;xs15_0cq23zoj6;0;;4,-41;8,-21;3,-52;0,1,1,0,0,1",
"xs15_2lmzg6dz11;xs16_cp3zra8o;0;-3,-52;;-10,-68;;2,10,-1,0,0,-1",
"xs15_2lmzw342ac;xp2_gilmgmaz1w10s;1;-2,-60,4,-87;-3,-66;8,-52,20,-12;-4,-98;6,1,0,-1,1,0",
"xs15_2lmzw342sg;xs14_0o4871zdd;0;;6,-34;;;1,9,1,0,0,-1",
"xs15_2lmzw342sg;xs15_0o4871z354c;0;;4,-37;8,-17;3,-48;1,9,1,0,0,-1",
"xs15_2lmzw342sg;xs16_32arzx121e8;0;-3,-58;;-10,-74;;-1,1,1,0,0,1",
"xs15_2lmzw34a52;xs16_wgs25a4z6226;0;-3,-58;;-10,-74;;-1,8,1,0,0,-1",
"xs15_2lmzw34aa4;xs16_32arzx12552;0;-3,-58;;-10,-74;;-1,1,1,0,0,1",
"xs15_2lmzw34ak8;xs14_0o4a52zdd;0;;6,-34;;;1,9,1,0,0,-1",
"xs15_2lmzw34ak8;xs15_0o4a52z354c;0;;4,-37;8,-17;3,-48;1,9,1,0,0,-1",
"xs15_2lmzw34ak8;xs16_32arzx125a4;0;-3,-58;;-10,-74;;-1,1,1,0,0,1",
"xs15_3123cj96;xs16_0g8o6picz23;0;-3,-60;3,-64;-9,-74;-7,-73;0,4,1,0,0,-1",
"xs15_312460uh3;xs16_3lozkq226;0;;12,-58;9,-43;14,-35;0,0,0,1,1,0",
"xs15_31248c2c84c;xs16_0g853zra4z23;0;-11,-24,1,-68;-10,-35,1,-71;;;-1,3,0,1,-1,0",
"xs15_31248gka246;xs16_31248gka248c;0;22,-98;;11,-83,24,-42;7,-101;0,0,1,0,0,1",
"xs15_31248gzc8711;xs16_5b8owga6zx121;0;4,-84;;;-14,-86,-12,-96;-1,8,0,1,-1,0",
"xs15_312kozx2ego;xs15_178f12ko;0;6,-66,13,-89;-8,-25;;-17,-102,-9,-90;4,7,0,-1,-1,0",
"xs15_312kozxc871;xs16_354kozxc871;0;;0,-38,5,-61;-3,-46;;0,0,1,0,0,1",
"xs15_312kozxc871;xs16_8ehjzw1248go;0;-11,-44,1,-88;-10,-55,1,-91;;;6,8,-1,0,0,-1",
"xs15_312kozy135a4;xs14_wok213zdb;0;;-6,-12;14,-35;-13,-107;6,0,-1,0,0,1",
"xs15_3146178kc;xs16_31461vg4c;0;7,-52;;;-3,-79,-3,-54;0,0,1,0,0,1",
"xs15_31461ug8o;xs16_0gjlozpi6;0;;15,-70;10,-73;4,-95,17,-54;9,0,0,-1,1,0",
"xs15_31461ug8o;xs16_g88b96zc93;0;22,-98;;;-6,-110,0,-81;8,0,0,-1,1,0",
"xs15_3146pb8o;xs16_3iajc4gozw1;0;14,-88,17,-78;10,-77;6,-66;9,-76,14,-51;7,4,-1,0,0,-1",
"xs15_31e88cz0253;xs16_g89f0ck8z23;0;-6,-40;-1,-48;-4,-63;;5,0,0,-1,1,0",
"xs15_31e8zo8b5;xs16_1784cgc453;0;;;10,-23,16,-28;8,-48;0,9,0,1,-1,0",
"xs15_31ege2ko;xs16_321ege2ko;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs15_31ege2ko;xs16_g88a52zc953;0;-7,-38;-1,-49;-6,-62;;-1,4,0,1,-1,0",
"xs15_31ego8b5;xs16_0321eoz4a511;0;-7,-38;-1,-49;-6,-62;;7,-1,0,-1,1,0",
"xs15_31ego8b5;xs16_321ego8b5;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs15_31egu246;xs16_321egu246;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs15_31ek13z311;xs16_25ao8ge2z032;0;-7,-36;-1,-47;-6,-60;;-1,-1,0,1,1,0",
"xs15_31ek13z311;xs16_5bo8ge2z32;0;-6,-36;-1,-44;-4,-59;;-1,0,0,1,1,0",
"xs15_31eozcip;xs16_069jzo8ge3;0;-6,-48;-1,-56;-4,-71;;-1,9,1,0,0,-1",
"xs15_31eozw122ac;xs16_31eozw122qk;0;21,-100;;18,-28,19,-12;;0,0,1,0,0,1",
"xs15_31eozx12156;xs16_25iczx1132ac;0;17,-109,26,-114;-7,-19;19,-19;;8,8,0,-1,-1,0",
"xs15_31kmicz032;xs16_31kmicz056;0;12,-98;-10,-12,-8,-30;;;0,0,1,0,0,1",
"xs15_31kmicz032;xs16_31kmicz252;0;9,-75;-10,-12;;-13,-88;0,0,1,0,0,1",
"xs15_31kmicz032;xs16_31kmp3z032;0;14,-111,20,-90;;;5,-89;0,0,1,0,0,1",
"xs15_32138n96;xs16_3213on96;0;6,-56;;;-6,-62;0,0,1,0,0,1",
"xs15_3213ia4zw65;xs16_4ai31246zx56;0;-9,-40,2,-76;-12,-21,0,-65;;;6,0,-1,0,0,1",
"xs15_3213ob96;xs15_6413ob96;0;-12,-28,-6,-49,0,-77;3,-83;;-8,-83;0,0,1,0,0,1",
"xs15_3213ob96;xs16_64213ob96;0;-9,-31,2,-67;-12,-12,0,-56;;;-1,0,1,0,0,1",
"xs15_321e88gzxca1;xs16_g853z01178426;0;-9,-44,2,-80;-12,-25,0,-69;;;6,8,-1,0,0,-1",
"xs15_321egm93;xs16_25a84oz0ad11;0;15,-70;13,-62;;9,-64,18,-33;8,-1,0,-1,1,0",
"xs15_321fgc48c;xs16_0gjloz1qm;0;-9,-31,2,-67;-12,-12,0,-56;;;-1,4,0,1,-1,0",
"xs15_321fgc48c;xs16_3iaczw11db;0;20,-90;12,-65;14,-52;2,-80;8,5,0,-1,-1,0",
"xs15_321fgc48c;xs16_3loz122qm;0;21,-94;;10,-71,23,-30;4,-97;9,4,0,-1,-1,0",
"xs15_321fgc48c;xs16_69b88gzxbd;0;;4,-65,10,-94;-10,-82;;0,-1,0,1,1,0",
"xs15_321fgs26;xs16_252sgf123;0;;12,-58;9,-45;13,-42;8,0,-1,0,0,1",
"xs15_321fgs26;xs16_321fgs246;0;;10,-50;9,-35;12,-35;0,0,1,0,0,1",
"xs15_32ac0fho;xs16_32ac0fh8o;0;15,-70;;17,-15;4,-55;0,0,1,0,0,1",
"xs15_32ako0ui;xs16_woe12koz6221;0;16,-76;;14,-12;-4,-63;0,7,1,0,0,-1",
"xs15_32arzx1256;xs16_wggo3tgz652;0;-9,-40,2,-76;-12,-21,0,-65;;;-1,7,0,1,-1,0",
"xs15_32hjkcz032;xs16_32hjkcz056;0;12,-98;-10,-12,-8,-30;;;0,0,1,0,0,1",
"xs15_32hu0og4c;xs16_32hu0ol3;0;;9,-46;7,-41;10,-44;0,0,1,0,0,1",
"xs15_32qjc48c;xs16_0ckgf9z6221;0;19,-86;11,-61;13,-48;1,-76;0,5,0,1,-1,0",
"xs15_32qjc48c;xs16_31246pb8o;0;20,-90;;9,-67,22,-26;3,-93;8,4,-1,0,0,-1",
"xs15_32qjc48c;xs16_4akgf9zw65;0;5,-82;-11,-35,-6,-60;-6,-62,-3,-72;-7,-93;0,5,0,1,-1,0",
"xs15_32qk8zdb;xs14_32qkzdb;0;;;8,-20;2,-44;0,0,1,0,0,1",
"xs15_32qkgozw66;xs16_32qkgoz04a6;0;10,-63,18,-82;;;-8,-65;0,0,1,0,0,1",
"xs15_32qkzy032ac;xs15_ggwkq23z1243;0;;10,-50;13,-58;-7,-117,-1,-113,8,-95,11,-65;7,0,-1,0,0,1",
"xs15_3303ia4zw65;xs16_8k461aczw1ac;0;-5,-52,2,-55;-2,-46;-7,-62;;6,-1,-1,0,0,1",
"xs15_33gv1oo;xs16_0c88brz253;0;;11,-54;11,-39;3,-70;0,5,0,1,-1,0",
"xs15_33gv1oo;xs16_253gv1oo;0;0,-58;-2,-51;-8,-66;;-1,0,1,0,0,1",
"xs15_3542arzx32;xs16_mk48a52z146;0;-8,-46;0,-61;-13,-84,-8,-62,-3,-81;;5,-1,-1,0,0,1",
"xs15_3542sgz0253;xs16_0g4q23ck8z121;0;-5,-40;;-12,-79,-3,-74;7,-40;5,-1,0,-1,1,0",
"xs15_354c0fho;xs16_064kl3z4a43;0;-5,-42;2,-57;-8,-70;;7,-1,0,-1,1,0",
"xs15_354c0fho;xs16_064kl3z6243;0;-3,-49;2,-54;-7,-66;;7,-1,0,-1,1,0",
"xs15_354c0fho;xs16_32hu064ko;0;15,-70;;17,-15;4,-55;8,4,-1,0,0,-1",
"xs15_354c0s4zx65;xs16_0o5jz11011da;0;-3,-45;2,-50;-7,-62;;6,7,-1,0,0,-1",
"xs15_354c0s4zx65;xs16_xra248cz2521;0;-5,-40;2,-55;-8,-68;;6,-1,0,-1,1,0",
"xs15_354c32qk;xs16_08ehi3z6243;0;-3,-49;2,-54;-7,-66;;7,-1,0,-1,1,0",
"xs15_354cgc2ko;xs15_358616853;0;3,-76;-1,-56;0,-60;-7,-70;0,4,1,0,0,-1",
"xs15_354cgc453;xs15_3loz12ego;0;;;12,-34,15,-12;1,-66,12,-40;9,4,0,-1,-1,0",
"xs15_354cgc453;xs16_031e8gzc4871;0;;15,-70;6,-58;11,-53;0,-1,0,1,1,0",
"xs15_354cgs246;xs16_0gs252z32qk;0;-5,-46;2,-61;-8,-74;;-1,4,0,1,-1,0",
"xs15_354cgs246;xs16_g8e123z11da;0;-3,-53;2,-58;-7,-70;;0,4,0,1,-1,0",
"xs15_354k8zcip;xs16_069jzg8k452z01;0;-5,-48;2,-63;-8,-76;;-1,9,1,0,0,-1",
"xs15_354k8zcip;xs16_321eg842156;0;-3,-48;2,-53;-7,-65;;0,-1,0,1,1,0",
"xs15_354m93zw32;xs15_354m96zw32;0;;;4,-50;10,-36;0,0,1,0,0,1",
"xs15_354miozw32;xs16_0g6s178cz121;0;-5,-36;3,-75,8,-66;-13,-87,2,-60;;5,-1,0,-1,1,0",
"xs15_354miozw32;xs16_354mioz0252;0;10,-75;-9,-12;;-12,-88;0,0,1,0,0,1",
"xs15_354miozw32;xs16_354miozw56;0;10,-65;-7,-12;;-11,-77;0,0,1,0,0,1",
"xs15_354q96zx23;xs16_069q453z311;0;14,-94;-8,-19;18,-12;0,-74;6,0,-1,0,0,1",
"xs15_354q96zx23;xs16_4a9liczx56;0;;1,-69,12,-71;0,-61;13,-36;0,-1,1,0,0,1",
"xs15_354q96zx23;xs16_69q453z65;0;10,-94,22,-98;;;-13,-105,-2,-97;5,0,-1,0,0,1",
"xs15_354q96zx23;xs16_cik8a52z065;0;-8,-46;0,-61;-13,-84,-8,-62,-3,-81;;5,-1,-1,0,0,1",
"xs15_3586p3zx32;xs16_3586p3zw65;0;9,-89,20,-97;;;-15,-90,-3,-86;0,0,1,0,0,1",
"xs15_358go8gka4;xs16_g84213215a4z11;0;-9,-50;0,-89;-13,-98,0,-87;;-1,4,1,0,0,-1",
"xs15_358gzg8k452z01;xs16_358gzg8k452z11;0;13,-118;-15,-12;;;0,0,1,0,0,1",
"xs15_35a842ako;xs14_25a842ako;0;;;9,-26;11,-28;8,4,-1,0,0,-1",
"xs15_35iczx115a4;xs16_35iczx115ac;0;21,-94;;;1,-88;0,0,1,0,0,1",
"xs15_35iczx115a4;xs16_35iczxd552;0;12,-64,20,-90;;;-8,-77,-1,-67;0,0,1,0,0,1",
"xs15_39c84czw253;xs14_08objoz32;0;15,-70;;;;0,6,1,0,0,-1",
"xs15_39c84czw253;xs16_0bqajoz32;0;;-8,-18;;-15,-90;0,6,1,0,0,-1",
"xs15_39c84czw253;xs16_0bt06a4z65;0;-2,-40;-2,-35;-5,-50;;5,1,0,-1,1,0",
"xs15_39c84czw253;xs16_39c84czw653;0;12,-94;-10,-12;;;0,0,1,0,0,1",
"xs15_39c8a6z033;xs16_39c8a6z0352;0;10,-85;-12,-12;;-6,-84;0,0,1,0,0,1",
"xs15_39c8a6z033;xs16_39u0ooz65;0;-2,-40;-2,-35;-5,-50;;5,1,0,-1,1,0",
"xs15_39c8a6zx33;xs16_39c8a6zw253;0;10,-63,18,-82;;;-6,-65;0,0,1,0,0,1",
"xs15_39c8a6zx33;xs16_6a8c93z253;0;12,-85;-10,-12;;-4,-84;5,0,-1,0,0,1",
"xs15_39c8a6zx33;xs17_0bdz65139c;0;18,-131;-11,-37,-8,-12;15,-27;;5,8,-1,0,0,-1",
"xs15_39c8a6zx33;xs17_39cz65139c;0;;;21,-12,26,-18;-14,-146,-8,-174;5,8,-1,0,0,-1",
"xs15_39cga6z321;xs15_j5m853z11;0;;0,-51;-7,-58;;0,1,1,0,0,1",
"xs15_39cga6z321;xs15_j9cga6z121;0;2,-76;-18,-12,-11,-39,-10,-22;;;0,0,1,0,0,1",
"xs15_39cga6z321;xs16_178cga6z0321;0;-4,-36;2,-55;-2,-54;;-1,0,0,1,1,0",
"xs15_39cga6z321;xs16_25acga6z0321;0;;2,-58;-6,-54;;-1,0,1,0,0,1",
"xs15_39cga6z321;xs16_3lo0kcz6421;0;-2,-40;-2,-35;-5,-50;;-2,1,0,1,1,0",
"xs15_39e0djo;xs16_g8ie0djoz01;0;2,-54;-7,-30;;-9,-70;-1,0,1,0,0,1",
"xs15_39e0mp3;xs16_g6q0si52z11;0;2,-54;-7,-30;;-9,-70;6,5,-1,0,0,-1",
"xs15_39eg8oz321;xs16_354m853zw32;0;;12,-58;7,-61;1,-83,14,-42;0,0,0,1,1,0",
"xs15_39m86248c;xs15_6248c2dic;0;-5,-28;1,-42;;;8,4,-1,0,0,-1",
"xs15_39m86248c;xs16_3pm86248c;0;3,-72;;;-9,-78;0,0,1,0,0,1",
"xs15_39m88czx56;xs15_69m88czx56;0;-5,-40;1,-54;;;0,0,1,0,0,1",
"xs15_39m88czx56;xs16_25icggozx1ac;0;-12,-40,3,-73;-7,-39,-2,-68;-6,-61;;-1,-1,1,0,0,1",
"xs15_39q453z32;xs15_354q93zx23;0;7,-73,17,-78,21,-101;;;-7,-69;5,0,-1,0,0,1",
"xs15_39q453z32;xs15_6agc93z321;0;-8,-36,-1,-53,5,-80;-4,-45;;-10,-84;-1,0,0,1,1,0",
"xs15_39q453z32;xs15_j5o653z11;0;6,-75;;;-13,-82;0,0,0,1,1,0",
"xs15_39q453z32;xs16_039q453z311;0;8,-79;-10,-12;;-8,-78;-1,0,1,0,0,1",
"xs15_39q453z32;xs16_0j9q453z121;0;8,-82;;;-12,-78;-1,0,1,0,0,1",
"xs15_39q453z32;xs16_6ik8a52z641;0;;8,-81,13,-62,18,-84;5,-61;13,-46;0,-1,1,0,0,1",
"xs15_39q453z32;xs16_ck0ol3z643;0;4,-59;-8,-16;;-11,-74;-2,0,0,1,1,0",
"xs15_39u066z032;xs16_039u066z311;0;5,-74;-13,-12;13,-19;-9,-94;-1,0,1,0,0,1",
"xs15_39u066z032;xs16_39u0652z032;0;15,-70;;7,-46;5,-55;0,0,1,0,0,1",
"xs15_39u066z032;xs16_39u06a4z032;0;;12,-58;8,-43;4,-58;0,0,1,0,0,1",
"xs15_39u066z32;xs16_25a8c826zw33;0;-12,-38,-7,-36,-2,-75;1,-67;-9,-84;;-1,-1,0,1,1,0",
"xs15_39u066z32;xs16_39u0652z32;0;15,-70;;7,-46;5,-55;0,0,1,0,0,1",
"xs15_39u066z32;xs16_39u06a4z32;0;;12,-58;8,-43;4,-58;0,0,1,0,0,1",
"xs15_39u0ooz32;xs16_039s0ccz2521;0;-12,-38,-7,-36,-2,-75;1,-67;-9,-84;;-1,6,1,0,0,-1",
"xs15_39u0ooz32;xs16_39u0ok8z32;0;17,-78;;9,-38;3,-63;0,0,1,0,0,1",
"xs15_3h4e1e8z011;xs16_3h4e1daz011;0;;;1,-57;6,-51,11,-32;0,0,1,0,0,1",
"xs15_3hu06248c;xs16_03loz622qk;0;-6,-35;-1,-43;-4,-58;;8,4,0,-1,-1,0",
"xs15_3hu069a4;xs16_32hu069a4;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs15_3hu0o8a6;xs16_25a8o0uh3;0;;14,-66;6,-53;11,-46;8,0,-1,0,0,1",
"xs15_3hu0o8a6;xs16_32hu0o8a6;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs15_3hu0o8a6;xs16_3hu0o8b5;0;;13,-62;6,-50;9,-53;0,0,1,0,0,1",
"xs15_3hu0og84c;xs16_c88b5z3lo;0;-6,-35;-1,-43;-4,-58;;-1,4,0,1,-1,0",
"xs15_3hu0ok46;xs16_32hu0ok46;0;-6,-31;-1,-39;-4,-54;;-1,0,1,0,0,1",
"xs15_3iaczw178c;xs16_252sgzx6a9o;0;19,-100;;20,-12;-2,-87;6,9,-1,0,0,-1",
"xs15_3iaczw178c;xs16_3iaczw1784c;0;17,-96,19,-86;;;1,-84;0,0,1,0,0,1",
"xs15_3iaj2aczw1;xs16_3iaj2acz011;0;4,-68;;;-10,-74;0,0,1,0,0,1",
"xs15_3iakgozw56;xs16_3iakgozw1ac;0;10,-105,23,-116;;19,-12;-4,-107;0,0,1,0,0,1",
"xs15_3iarzw1226;xs15_caarzw1226;0;-2,-60,3,-51;-11,-12,-3,-32;;;0,0,1,0,0,1",
"xs15_3lc2koz32;xs15_2ld2koz32;0;;0,-44;-6,-54;;0,0,1,0,0,1",
"xs15_3lc2koz32;xs16_03lo0kcz25201;0;-5,-39;;-12,-78,-3,-73;7,-39;-1,6,1,0,0,-1",
"xs15_3lk453z121;xs16_5b88a6z253;0;-3,-41;2,-46;-7,-58;;0,-1,1,0,0,1",
"xs15_3lk453z121;xs16_62s0f9z321;0;;-9,-30;;-16,-94;-1,0,0,1,1,0",
"xs15_3lk453z121;xs16_6a88b5z253;0;;12,-58;3,-46;8,-41;0,-1,1,0,0,1",
"xs15_3lk48cz0146;xs16_25a88gozw39c;0;-5,-40;2,-55;-8,-68;;-1,-1,1,0,0,1",
"xs15_3lk48cz0146;xs16_5b88goz039c;0;-3,-41;2,-46;-7,-58;;0,-1,1,0,0,1",
"xs15_3lk48cz056;xs16_25a88gozwbd;0;-5,-40;2,-55;-8,-68;;-1,-1,1,0,0,1",
"xs15_3lk48cz056;xs16_5b88goz0bd;0;-3,-41;2,-46;-7,-58;;0,-1,1,0,0,1",
"xs15_3lkaa4z121;xs16_25a8kk8z0253;0;-5,-36;3,-75,8,-66;-13,-87,2,-60;;-1,-1,1,0,0,1",
"xs15_3lkaa4z121;xs16_3iabkk8z011;0;;-9,-30;;-16,-94;-1,5,1,0,0,-1",
"xs15_3lkczc96;xs16_3pmzkq23;0;-3,-44;2,-49;-7,-61;;0,8,1,0,0,-1",
"xs15_3lkm93z01;xs16_0j5s2sgz121;0;-8,-46;0,-61;-13,-84,-8,-62,-3,-81;;5,-1,0,-1,1,0",
"xs15_3lkm93z01;xs16_0j9ege2z121;0;13,-69;11,-61;;7,-63,16,-32;0,-1,0,1,1,0",
"xs15_3lkm93z01;xs16_j5s2qkz11;0;10,-69,15,-70;;;3,-55;5,0,0,-1,1,0",
"xs15_3lkm96z01;xs15_3lkm93z01;0;;;13,-28,13,-12;4,-56;0,0,1,0,0,1",
"xs15_3lkm96z01;xs16_0i5t2sgz121;0;-8,-46;0,-61;-13,-84,-8,-62,-3,-81;;5,-1,0,-1,1,0",
"xs15_3lkm96z01;xs16_3lkm952z01;0;;21,-166;-10,-145,-6,-116,13,-80;1,-122,13,-32;0,0,1,0,0,1",
"xs15_3lkm96z01;xs16_ci5t2sgzw1;0;;1,-65,12,-67;0,-57;13,-32;5,-1,0,-1,1,0",
"xs15_3lmzw34ac;xs16_0o48a53zbd;0;-6,-44;4,-77;-14,-94;;5,2,0,-1,1,0",
"xs15_3loz12ego;xs16_3loz12eg8o;0;17,-107;;19,-12;-4,-92;0,0,1,0,0,1",
"xs15_3loz32ak8;xs16_3loz32ako;0;19,-86;;;-3,-80;0,0,1,0,0,1",
"xs15_3loz32ak8;xs16_3loz32qk8;0;14,-110;-12,-12;;;0,0,1,0,0,1",
"xs15_3loz32ak8;xs16_3lozraa4;0;10,-61,18,-87;;;-12,-74,-5,-64;0,0,1,0,0,1",
"xs15_3lozx35426;xs16_3lozx354213;0;;11,-54;12,-57;0,-103,13,-62;0,0,1,0,0,1",
"xs15_3lozx3pm;xs16_3lozxj96zx11;0;13,-123;-14,-12;;-18,-132,-5,-121;0,0,1,0,0,1",
"xs15_3lozy0ciic;xs15_0bq2sgz65;0;9,-62;;8,-20;-10,-78,5,-48;0,7,1,0,0,-1",
"xs15_3p6o8a6zw1;xs15_4aq453z65;0;;;11,-34,14,-12;-2,-74,9,-48;0,5,0,1,-1,0",
"xs15_3p6o8a6zw1;xs16_0g6p64koz121;0;-12,-34,-7,-32,-2,-71;1,-63;-9,-80;;-1,5,1,0,0,-1",
"xs15_3p6o8a6zw1;xs16_354qa4z2521;0;;13,-62;5,-49;10,-42;0,0,0,1,1,0",
"xs15_3p6o8a6zw1;xs16_3p6o8b5zw1;0;;12,-58;5,-46;8,-49;0,0,1,0,0,1",
"xs15_3pczw1178c;xs16_3pczw11784c;0;18,-100,20,-90;;;2,-88;0,0,1,0,0,1",
"xs15_3pczw230352;xs16_3pczw230f9;0;18,-104;;23,-12;;0,0,1,0,0,1",
"xs15_3pm0e96;xs16_259e0djo;0;;;12,-12,16,-19;5,-69,10,-34;7,4,-1,0,0,-1",
"xs15_3pm0e96;xs16_g8jd0eicz01;0;-12,-30,-7,-28,-2,-67;1,-59;-9,-76;;-1,4,1,0,0,-1",
"xs15_3pm0eic;xs16_259e0mp3;0;;;9,-53,14,-18;8,-28,12,-35;7,0,-1,0,0,1",
"xs15_3pmzw34213;xs16_0oe1248cz643;0;;11,-54;10,-57;0,-95,13,-54;0,7,1,0,0,-1",
"xs15_3pq32ac;xs16_25a8objo;0;17,-78;;14,-26;1,-65;7,4,-1,0,0,-1",
"xs15_3pq32ac;xs16_3paj2aczw1;0;8,-69;-10,-12;;-4,-68;0,0,1,0,0,1",
"xs15_3pq32ac;xs16_3pq32qk;0;16,-74;;12,-33;1,-62;0,0,1,0,0,1",
"xs15_4a40vh246;xs16_4a40vh248c;0;20,-90;;9,-75,22,-34;5,-93;0,0,1,0,0,1",
"xs15_4a40vh246;xs16_642hv04a6;0;-4,-28;2,-46;;;8,0,-1,0,0,1",
"xs15_4a40vh246;xs16_642hv04ac;0;1,-72;;;-9,-78;8,0,-1,0,0,1",
"xs15_4a4o796zw11;xs16_65la8oz0321;0;-4,-32;2,-50;;;6,0,0,-1,1,0",
"xs15_4a4o79czw11;xs16_4a4o79k8zw11;0;15,-70;11,-54;11,-48,20,-17;;0,0,1,0,0,1",
"xs15_4a4o79czw11;xs16_64lb8oz0321;0;-4,-32;2,-50;;;6,0,0,-1,1,0",
"xs15_4a4o79ozx11;xs16_c9bk46z311;0;-3,-41,5,-47;-7,-12,0,-30;;;6,5,0,-1,-1,0",
"xs15_4a51ug84c;xs16_6421fgka6;0;1,-72;;;-9,-78;8,4,-1,0,0,-1",
"xs15_4a6069ar;xs16_9f0ciar;0;;-12,-12;;-7,-72;1,4,1,0,0,-1",
"xs15_4a60uh246;xs16_4a60uh248c;0;20,-90;;9,-75,22,-34;5,-93;0,0,1,0,0,1",
"xs15_4a970si6;xs16_25a8czx6953;0;17,-78;;15,-30;4,-62;8,6,0,-1,-1,0",
"xs15_4a9b88gzx311;xs16_4a9b88czx33;0;;;7,-61;1,-81,8,-53,15,-36;0,0,1,0,0,1",
"xs15_4a9b88gzx311;xs16_69ab88gzx321;0;13,-81,18,-82;;;4,-67;6,6,-1,0,0,-1",
"xs15_4a9b8oz033;xs16_0mligoz1246;0;10,-85;-12,-12;;-6,-84;0,7,1,0,0,-1",
"xs15_4a9b8oz033;xs16_4a9b8oz253;0;8,-60,16,-79;;;-8,-62;0,0,1,0,0,1",
"xs15_4a9b8oz033;xs16_8ka9b8ozw23;0;3,-69;-8,-16;;-12,-78;-1,0,1,0,0,1",
"xs15_4a9diczx32;xs16_4a9diczw65;0;9,-89,20,-97;;;-15,-90,-3,-86;0,0,1,0,0,1",
"xs15_4a9mgmazx1;xs16_0ml2sgz1243;0;;11,-54;13,-39;;7,0,0,-1,1,0",
"xs15_4a9r2qk;xs16_25b8ria4;0;17,-78;;;22,-77;7,4,-1,0,0,-1",
"xs15_4a9r8b5;xs16_25b8r9a4;0;;13,-62;26,-61;;7,0,-1,0,0,1",
"xs15_4a9ra96;xs16_259ar9a4;0;;22,-162;-9,-141,-5,-112,14,-76;2,-118,14,-28;7,0,-1,0,0,1",
"xs15_4a9ra96;xs16_69ar9ic;0;0,-59;;17,-22;-10,-74,-5,-73,1,-69,6,-78;6,0,-1,0,0,1",
"xs15_4a9raic;xs16_259aria4;0;26,-178;;6,-102,18,-12;-13,-157,-9,-128,10,-92;7,4,-1,0,0,-1",
"xs15_4aab88gzx311;xs16_4aab88czx33;0;;;7,-61;1,-81,8,-53,15,-36;0,0,1,0,0,1",
"xs15_4aab88gzx311;xs16_69ab88gzx311;0;;-4,-43;-6,-58,-1,-57;;0,0,1,0,0,1",
"xs15_4aab8oz033;xs16_0mligoz1226;0;10,-85;-12,-12;;-6,-84;0,7,1,0,0,-1",
"xs15_4aab8oz033;xs16_4aab8oz253;0;8,-60,16,-79;;;-8,-62;0,0,1,0,0,1",
"xs15_4aab8oz033;xs16_69ab8oz033;0;;-4,-39;-6,-54,-1,-53;;0,0,1,0,0,1",
"xs15_4aab8oz033;xs16_8kaab8ozw23;0;3,-69;-8,-16;;-12,-78;-1,0,1,0,0,1",
"xs15_4aara96;xs16_259araa4;0;;22,-162;-9,-141,-5,-112,14,-76;2,-118,14,-28;7,0,-1,0,0,1",
"xs15_4ai30f9z011;xs16_4ai30f9zw23;0;7,-82,19,-86;;;-14,-93,-3,-85;0,0,1,0,0,1",
"xs15_4ai30o4czx121;xs16_8e1248gzwad11;0;;10,-66,11,-54;;11,-46;0,0,0,1,1,0",
"xs15_4ai3146zx123;xs17_4ai31248czx123;0;;;12,-12,14,-25;5,-40;0,0,1,0,0,1",
"xs15_4al9aczw23;xs16_4al9aczx56;0;9,-90,21,-94;;;-14,-101,-3,-93;0,0,1,0,0,1",
"xs15_4ap3zrm;xs16_3124628c2ko;0;9,-105,20,-113;;;-21,-106,-9,-102;-1,10,0,1,-1,0",
"xs15_4ap3zrq;xs16_04ap3zoja4;0;9,-97,16,-122;;16,-12;-11,-104;-1,0,1,0,0,1",
"xs15_4ap3zw12156;xs15_4ap3zw12552;0;19,-86;;;-1,-76;0,0,1,0,0,1",
"xs15_4ap3zw12156;xs16_4ap3zw1215a4;0;16,-105,25,-110;-8,-15;18,-15;;0,0,1,0,0,1",
"xs15_4ap5a4z321;xs16_4a5pa4ozx121;0;-5,-45,6,-87;-5,-35;-8,-62;;5,0,-1,0,0,1",
"xs15_4ap6413z32;xs16_69p6413z32;0;-14,-112;-15,-87,-11,-74;-8,-66;;0,0,1,0,0,1",
"xs15_4ap6426z032;xs15_4ap6426z32;0;;12,-67;8,-61,14,-33,20,-12;1,-83;0,0,0,1,1,0",
"xs15_4ap6426z032;xs16_4ap6426z65;0;;15,-70;6,-73;4,-79,17,-38;0,0,0,1,1,0",
"xs15_4ap6426z032;xs16_8kic871z065;0;5,-74;-13,-12;13,-19;-9,-94;-1,0,0,1,1,0",
"xs15_4ap6426z32;xs16_4ap6413z65;0;;15,-70;6,-73;4,-79,17,-38;0,0,0,1,1,0",
"xs15_4aq3213z32;xs16_g88c871zc93;0;13,-69;15,-70;3,-60;9,-56;0,-2,1,0,0,1",
"xs15_4aqb8oz32;xs16_69qb8oz32;0;;-4,-39;-6,-54,-1,-53;;0,0,1,0,0,1",
"xs15_4s0s2pmzw1;xs16_q6ge1daz01;0;10,-77;-10,-12,-5,-31;;;6,5,-1,0,0,-1",
"xs15_5b88a6z033;xs16_6a88bl8zx32;0;3,-69;-8,-16;;-12,-78;5,0,-1,0,0,1",
"xs15_5b8r54c;xs16_25b8r54c;0;;-20,-61;-7,-62;;-1,0,1,0,0,1",
"xs15_5bo8a6z32;xs16_5bo8a52z32;0;;12,-58;4,-45;9,-38;0,0,1,0,0,1",
"xs15_5bo8a6z32;xs16_5bo8b5z32;0;;11,-54;4,-42;7,-45;0,0,1,0,0,1",
"xs15_62461tic;xs15_31461tic;0;5,-83;-14,-12,-8,-33,-2,-61;-6,-67;;0,0,1,0,0,1",
"xs15_62461tic;xs16_0cil56z6221;0;-2,-64;2,-60;-8,-70;-8,-77;7,-1,0,-1,1,0",
"xs15_62461tic;xs16_312461tic;0;-10,-28,2,-72;-11,-31,0,-67;;;-1,0,1,0,0,1",
"xs15_6248hf0cc;xs16_8k9b8ozw1ac;0;15,-70;;17,-20;0,-79;8,5,0,-1,-1,0",
"xs15_628s252z065;xs16_31ke1e8z032;0;;;5,-37,12,-19;2,-46,10,-40;0,1,1,0,0,1",
"xs15_64138n96;xs16_6413on96;0;6,-56;;;-6,-62;0,0,1,0,0,1",
"xs15_6413kkozx32;xs16_6413kkozx56;0;;-8,-12,-7,-28;;-10,-84;0,0,1,0,0,1",
"xs15_642132qr;xs16_2530fpzx65;0;11,-67,19,-86;;;-1,-69;7,5,0,-1,-1,0",
"xs15_642132qr;xs16_iu0652z1ac;0;14,-66;;;-6,-83,2,-64;8,0,0,-1,1,0",
"xs15_6421eozwca1;xs16_c8421eozxca1;0;-8,-44,3,-80;-13,-17,-1,-61;;;-1,0,1,0,0,1",
"xs15_64kb9czw23;xs16_64p784czw23;0;-8,-39,3,-75;-13,-12,-1,-56;;;5,0,0,-1,1,0",
"xs15_64lb8ozw121;xs15_65la8ozw121;0;;9,-46;3,-36;;0,0,1,0,0,1",
"xs15_64lb8ozw121;xs16_gila8cz1243;0;-4,-36;6,-70,15,-75;;8,-36;5,-1,-1,0,0,1",
"xs15_6512kozw643;xs16_0321eoz35421;0;5,-72;;;-11,-74,-9,-84;0,7,1,0,0,-1",
"xs15_66xrdzx321;xs11_32132ac;0;;1,-14;;;6,0,0,-1,1,0",
"xs15_6952sga6;xs15_17842sga6;0;-5,-31;-3,-24;0,-38;;-1,0,1,0,0,1",
"xs15_6996zwo8a6;xs19_cky06952zwhik8zw1;0;;;-1,-50,9,-37;4,-48;0,-1,1,0,0,1",
"xs15_6996zzx4aic;xs16_39u08k8z321;0;13,-122;-12,-12;9,-31;;0,13,0,1,-1,0",
"xs15_69aczw6513;xs16_025a8cz6953;0;;-10,-12;16,-12;-17,-107,-8,-102;0,8,1,0,0,-1",
"xs15_69aczw6513;xs16_69aczx315a4;0;17,-92;;17,-12;-4,-80;0,0,1,0,0,1",
"xs15_69ajkk8zx1;xs16_4aajk4ozx121;0;;;-18,-139;9,-32;6,5,-1,0,0,-1",
"xs15_69arzx1252;xs16_69arzx1256;0;19,-86;;;1,-80;0,0,1,0,0,1",
"xs15_69b88czw252;xs16_69b88czw256;0;17,-78;;;-1,-72;0,0,1,0,0,1",
"xs15_69eg8k8zw23;xs16_69eg8k8zx56;0;9,-90,21,-94;;;-14,-101,-3,-93;0,0,1,0,0,1",
"xs15_69eg8oz321;xs16_255m853zw32;0;;12,-58;7,-61;1,-83,14,-42;0,0,0,1,1,0",
"xs15_69jc48a6;xs16_25a84cj96;0;;9,-85,14,-66,19,-88;8,-65;14,-58;8,0,-1,0,0,1",
"xs15_69jwo4czx121;xs16_651248gzwad11;0;;10,-66,11,-54;;11,-46;0,0,0,1,1,0",
"xs15_69jzw230352;xs16_69jzw230f9;0;18,-104;;23,-12;;0,0,1,0,0,1",
"xs15_69la8czw23;xs16_69la8czx56;0;9,-90,21,-94;;;-14,-101,-3,-93;0,0,1,0,0,1",
"xs15_69lmzx346;xs15_69d2cga6;0;10,-90;-8,-12;11,-30;-4,-86;0,0,0,1,1,0",
"xs15_69q453z32;xs16_cik8a52z641;0;;8,-81,13,-62,18,-84;5,-61;13,-46;0,-1,1,0,0,1",
"xs15_69q453z32;xs16_cil9a4z641;0;-8,-36;5,-61;-7,-71,4,-69;;0,-1,1,0,0,1",
"xs15_69q48cz321;xs16_259m453zx23;0;18,-82;;7,-59,20,-18;1,-85;0,0,0,1,1,0",
"xs15_6ikm952z01;xs16_g84qajoz121;0;;3,-112,15,-70;-3,-118,16,-78,20,-91;21,-108;6,5,-1,0,0,-1",
"xs15_6t1egoz11;xs16_3iab96z023;0;13,-67;;15,-12;2,-52;0,5,0,1,-1,0",
"xs15_6t1egoz11;xs16_3iab96z121;0;15,-70;;16,-14;2,-57;0,5,0,1,-1,0",
"xs15_6t1egoz11;xs16_3pmk46zx23;0;;;-2,-91;7,-77,13,-32;-1,0,0,1,1,0",
"xs15_8e12453z33;xs16_8k461acz643;0;9,-80;-12,-12;;-12,-98,-5,-73;-1,0,0,1,1,0",
"xs15_8e12kozw643;xs16_8e12koz04a43;0;8,-79;-12,-12;;-11,-92;0,0,1,0,0,1",
"xs15_8e12kozw643;xs16_8kih32qkzx1;0;5,-72;;;-11,-74,-9,-84;5,0,0,-1,1,0",
"xs15_8e13zdjo;xs16_03pmzoge21;0;-5,-48;-13,-28,-7,-23;;;3,9,-1,0,0,-1",
"xs15_8e13zx31248c;xs13_69jzx1248c;0;5,-71;-13,-15;;-9,-78;1,0,1,0,0,1",
"xs15_8e1qczx1252;xs16_8e1qczx1256;0;19,-86;;;1,-80;0,0,1,0,0,1",
"xs15_8e1qczx1252;xs16_ad1qczx1252;0;-5,-40,0,-59;5,-65;;;0,0,1,0,0,1",
"xs15_8e1u8zx1252;xs16_8e1u8zx1256;0;19,-86;;;1,-80;0,0,1,0,0,1",
"xs15_8ehegoz023;xs16_4a4o7p8zx121;0;15,-70;;16,-14;2,-57;6,6,-1,0,0,-1",
"xs15_8ehegoz023;xs16_4aabk46zx32;0;14,-82,15,-70;;15,-14;;0,0,0,1,1,0",
"xs15_8ehjzw1256;xs16_0252sgzca53;0;;9,-64;4,-51;10,-40;5,-1,-1,0,0,1",
"xs15_8ehjzw1256;xs16_03ihe8z6521;0;;7,-56,9,-46;7,-44;;5,0,-1,0,0,1",
"xs15_8k453z3lo;xs16_321eg8og84c;0;;11,-65;2,-53;7,-48;4,-1,0,-1,1,0",
"xs15_8k453zdl8;xs16_31eg8o0ui;0;21,-100;;14,-12;;4,0,0,-1,1,0",
"xs15_8k4r9iczw1;xs16_699m4iczx11;0;-10,-107,-6,-94;-19,-92;;-13,-86;0,5,1,0,0,-1",
"xs15_8k4ra96zw1;xs16_0gs2pmz1243;0;;22,-166;-9,-145,-5,-116,14,-80;2,-122,14,-32;7,5,0,-1,-1,0",
"xs15_8k4ra96zw1;xs16_4a9mk4ozx121;0;-3,-32;24,-139;;;0,5,1,0,0,-1",
"xs15_8kai31e8zw1;xs20_8e13iak8zw6521;0;13,-77;;;-14,-94,-4,-78,-3,-98;7,0,-1,0,0,1",
"xs15_8kih3zx3426;xs16_8kih3zx34213;0;;;11,-48,22,-12;-1,-93,11,-49;0,0,1,0,0,1",
"xs15_8kih3zx34a4;xs16_4aarwkczx121;0;;;10,-18,18,-12;-3,-73,4,-55;6,7,0,-1,-1,0",
"xs15_8kih3zx34a4;xs16_8kih3zx34ac;0;20,-90;;;0,-84;0,0,1,0,0,1",
"xs15_8kk3123z641;xs15_8kk3123z065;0;8,-77,18,-82,22,-105;;;-8,-73;0,0,1,0,0,1",
"xs15_8kk3123z641;xs16_ggc2d96z56;0;-5,-44,0,-40,7,-66;-7,-20;;;-1,0,0,1,1,0",
"xs15_8kk3123z641;xs17_08kk3123zok21;0;12,-102;-12,-12;;;-1,0,1,0,0,1",
"xs15_8kk3146z641;xs15_8kk3146z065;0;8,-77,18,-82,22,-105;;;-8,-73;0,0,1,0,0,1",
"xs15_8kk3146z641;xs16_ggc2d96z146;0;-5,-44,0,-40,7,-66;-7,-20;;;-1,0,0,1,1,0",
"xs15_8kk3146z641;xs17_08kk3146zok21;0;12,-102;-12,-12;;;-1,0,1,0,0,1",
"xs15_8kk8a52z065;xs14_354qa4zx23;0;;;8,-32;6,-40;5,1,-1,0,0,1",
"xs15_8kk8a52z065;xs16_3loz12215a4;0;8,-105,19,-113;;;-18,-106,-6,-102;0,8,1,0,0,-1",
"xs15_8kk8a52z065;xs16_8kk8a53z065;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs15_8kk8a52z065;xs16_wcic871z2521;0;6,-82;-14,-12;14,-19;-10,-102;-1,0,0,1,1,0",
"xs15_8kk8a52z641;xs14_4aq453z32;0;;;8,-32;6,-40;0,1,1,0,0,1",
"xs15_8kk8a52z641;xs16_8kk8a53z641;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs15_8ljgzx115a4;xs14_8ljgzx1156;0;19,-86;;;-5,-98;0,0,1,0,0,1",
"xs15_8ljgzx115a4;xs16_0ggo8a52z12ko;0;;2,-63,14,-67;-9,-74,2,-66;;0,8,1,0,0,-1",
"xs15_8ljgzx115a4;xs16_8ljgzx115ac;0;21,-94;;;1,-88;0,0,1,0,0,1",
"xs15_8ljgzx115a4;xs16_8ljgzx11da4;0;11,-68;;;-9,-74;0,0,1,0,0,1",
"xs15_8ljgzx11da;xs16_0ggo8b5z12ko;0;;2,-62,14,-66;-9,-73,2,-65;;0,8,1,0,0,-1",
"xs15_8ljgzx25426;xs16_8ljgzx254213;0;;11,-54;12,-57;0,-103,13,-62;0,0,1,0,0,1",
"xs15_8o032acz346;xs13_g842156z123;0;-2,-41;2,-50;-8,-66;;0,1,1,0,0,1",
"xs15_8o652sgz32;xs14_kc321e8z11;0;;5,-30;1,-30;;0,1,1,0,0,1",
"xs15_8u16426z32;xs15_08u16426z32;0;8,-91,14,-87,20,-90;-12,-17;;-3,-85;-1,0,1,0,0,1",
"xs15_8u16426z32;xs15_4aq3213z32;0;;12,-67;8,-61,14,-33,20,-12;1,-83;0,0,0,1,1,0",
"xs15_8u16426z32;xs15_8u178cz32;0;;5,-63;-9,-70,-2,-59,7,-48;;0,0,1,0,0,1",
"xs15_8u16426z32;xs16_08u16426z65;0;6,-101;-15,-14;;-19,-110,-6,-99;-1,0,1,0,0,1",
"xs15_8u16426z32;xs16_4aq3213z65;0;;15,-70;6,-73;4,-79,17,-38;0,0,0,1,1,0",
"xs15_8u16426z32;xs16_g88c871z0db;0;-5,-92,10,-121;-9,-76;15,-36;-16,-98;-2,0,0,1,1,0",
"xs15_8u16426z32;xs16_gs2c871z65;0;14,-73;14,-66;4,-56;8,-60;0,-1,1,0,0,1",
"xs15_8u16426z32;xs16_gs2d96z65;0;;13,-62;-3,-80,1,-45,4,-52,11,-25;6,-56;0,-1,1,0,0,1",
"xs15_8u178cz32;xs16_08u178cz65;0;6,-101,17,-109;;;-18,-102,-6,-98;-1,0,1,0,0,1",
"xs15_8u178cz32;xs16_8u1784cz32;0;13,-78,14,-66;;14,-18;;0,0,1,0,0,1",
"xs15_8u178cz32;xs16_8u178k8z32;0;14,-66;;15,-18;3,-53;0,0,1,0,0,1",
"xs15_8u178cz32;xs16_ckljgzx1074;0;-5,-88,10,-117;-9,-72;15,-32;-16,-94;5,0,0,-1,1,0",
"xs15_9f0352z33;xs16_mk461acz121;0;9,-80;-12,-12;;-12,-98,-5,-73;-1,0,0,1,1,0",
"xs15_bd0ehr;xs16_gbhe0dbz01;0;16,-95;12,-58,16,-114;6,-101,15,-76,17,-45;2,-117,13,-40;6,0,-1,0,0,1",
"xs15_bd0ehr;xs16_gbhe0mqz01;0;16,-74,20,-130;12,-79;6,-101,17,-24;2,-117,11,-92,13,-61;6,4,-1,0,0,-1",
"xs15_bdzdj8gzw1;xs16_25a84cgc48c;0;-5,-52;-13,-32,-7,-27;;;3,10,0,-1,-1,0",
"xs15_brz0123146;xs16_0ok461acz641;0;-6,-40;3,-60;-6,-78,1,-53;;-1,7,0,1,-1,0",
"xs15_brz122ak8;xs16_0g88a52z4ajo;0;-6,-48;3,-68;-6,-86,1,-61;;-1,9,1,0,0,-1",
"xs15_brz230352;xs16_0iu0652z1246;0;-6,-40;3,-60;-6,-78,1,-53;;-1,7,1,0,0,-1",
"xs15_brz342sg;xs16_0o4871z4ajo;0;-6,-48;3,-68;-6,-86,1,-61;;-1,9,1,0,0,-1",
"xs15_bt0652z32;xs16_bt0653z32;0;;11,-54;7,-48;;0,0,1,0,0,1",
"xs15_bt06a4z32;xs16_bt06acz32;0;14,-66;;;4,-60;0,0,1,0,0,1",
"xs15_c48c93z253;xs16_0bt0652z65;0;;10,-50;7,-35;7,-40;0,1,0,1,1,0",
"xs15_c48c93z253;xs16_c48c93z653;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs15_c48c93z253;xs16_j9q32acz01;0;;;-1,-48,12,-12;-2,-61;0,2,1,0,0,1",
"xs15_c48c9jzx65;xs16_c48c9jzwca1;0;10,-107;-13,-12;;-17,-116,-4,-105;0,0,1,0,0,1",
"xs15_c842156z352;xs16_g8530f9z123;0;13,-68;;;-12,-82,-4,-57;0,0,0,1,1,0",
"xs15_c87p8zx1252;xs16_oggc8a52zw65;0;;-9,-22;;-9,-70,-8,-82;6,0,0,-1,1,0",
"xs15_c87p8zx1252;xs16_w8p78k8z2521;0;2,-57;-10,-22;;-9,-70;6,0,-1,0,0,1",
"xs15_c88a53z352;xs16_0gbaarz321;0;19,-86;;12,-14;;5,6,-1,0,0,-1",
"xs15_c88b9czw33;xs16_c88b9czw352;0;11,-85;-11,-12;;-5,-84;0,0,1,0,0,1",
"xs15_c88e13z352;xs16_c88e123z352;0;;10,-76,11,-64;;11,-40;0,0,1,0,0,1",
"xs15_c88m96z311;xs16_c88m952z311;0;;21,-170;-10,-149,-6,-120,13,-84;1,-126,13,-36;0,0,1,0,0,1",
"xs15_c8idicz023;xs16_c8idiczw56;0;8,-86,20,-90;;;-15,-97,-4,-89;0,0,1,0,0,1",
"xs15_c8idioz023;xs15_c8idicz023;0;;;14,-12;0,-58;0,0,1,0,0,1",
"xs15_c8idioz023;xs16_4a4o79ozw121;0;15,-73;9,-49;11,-43,20,-12;;6,6,-1,0,0,-1",
"xs15_c8idioz023;xs16_c8idjoz023;0;;10,-50;6,-44;;0,0,1,0,0,1",
"xs15_c93s4zx1252;xs16_025t28cz2521;0;;7,-75;-3,-60,1,-66,6,-47,8,-64;12,-40;6,0,-1,0,0,1",
"xs15_c9jzw12ego;xs15_641344og84c;0;9,-76,20,-94;;;-11,-78,-8,-88;0,0,0,1,1,0",
"xs15_c9jzw12ego;xs16_25a8ozy1116413;0;21,-108;;22,-12;-2,-95;7,10,0,-1,-1,0",
"xs15_c9jzw12ego;xs16_c9jzw12eg8o;0;19,-104,21,-94;;;1,-92;0,0,1,0,0,1",
"xs15_ca1u8zx1252;xs16_ca1u8zx1256;0;19,-86;;;1,-80;0,0,1,0,0,1",
"xs15_ca23123z33;xs16_gs26853z56;0;6,-73,13,-98;;13,-12;-8,-80;-1,0,0,1,1,0",
"xs15_ca23146z33;xs16_gs26853z146;0;6,-73,13,-98;;13,-12;-8,-80;-1,0,0,1,1,0",
"xs15_ca96zw3156;xs16_25is079a4;0;11,-80;-10,-12;;-10,-92;0,8,0,1,-1,0",
"xs15_cahegoz023;xs16_4a4o79ozx121;0;15,-70;;16,-14;2,-57;6,6,-1,0,0,-1",
"xs15_cahegoz023;xs16_4a9bk46zx32;0;14,-82,15,-70;;15,-14;;0,0,0,1,1,0",
"xs15_cai3zmq1;xs16_3iaczo9a6;0;14,-118;-14,-19;18,-12;-6,-98;3,0,-1,0,0,1",
"xs15_ci52z116246;xs16_ci53z116246;0;;9,-46;5,-40;;0,0,1,0,0,1",
"xs15_ci52zw124871;xs16_ci53zw124871;0;;9,-46;5,-40;;0,0,1,0,0,1",
"xs15_ci53zdl8;xs16_32qbzca43;0;21,-100;;14,-12;;3,8,-1,0,0,-1",
"xs15_ci9b8oz023;xs16_ci9b8ozw56;0;8,-86,20,-90;;;-15,-97,-4,-89;0,0,1,0,0,1",
"xs15_ciab8oz023;xs16_ciab8ozw56;0;8,-86,20,-90;;;-15,-97,-4,-89;0,0,1,0,0,1",
"xs15_cila8ozx32;xs16_cilb8ozx32;0;;9,-46;5,-40;;0,0,1,0,0,1",
"xs15_ciligzx1074;xs16_ciljgzx1074;0;;9,-46;5,-40;;0,0,1,0,0,1",
"xs15_cilmzx346;xs16_cilmzx3426;0;16,-91;;18,-12;-1,-76;0,0,1,0,0,1",
"xs15_cilmzx652;xs16_ggmlicz146;0;;;6,-30;4,-65,4,-40;5,0,-1,0,0,1",
"xs15_ckl3zx3213;xs16_3213kkozx56;0;;10,-53;1,-41;6,-36;6,6,-1,0,0,-1",
"xs15_cky233z3lo;xs11_0drz65;0;;;10,-12;;2,2,-1,0,0,1",
"xs15_cp30352z32;xs16_cp30f9z32;0;18,-82;;12,-12,17,-17;;0,0,1,0,0,1",
"xs15_cp3z3ego;xs16_cp3z3eg8o;0;16,-107;;18,-12;-5,-92;0,0,1,0,0,1",
"xs15_cq23146z32;xs16_0cq23146z65;0;6,-101;-15,-14;;-19,-110,-6,-99;-1,0,1,0,0,1",
"xs15_cq23z012156;xs16_0o48a52z354c;0;15,-102,24,-107;-9,-12;17,-12;;0,8,1,0,0,-1",
"xs15_db8oz39c;xs16_c93gz3lp1;0;;1,-58,13,-62;-10,-69,1,-61;;0,8,1,0,0,-1",
"xs15_dbgzw12ego;xs15_321344og84c;0;9,-76,20,-94;;;-11,-78,-8,-88;0,0,0,1,1,0",
"xs15_dbgzw12ego;xs16_31e8gzxo9a6;0;-5,-55;5,-82;3,-62;9,-48;6,9,-1,0,0,-1",
"xs15_dbgzw12ego;xs16_dbgzw12eg8o;0;19,-104,21,-94;;;1,-92;0,0,1,0,0,1",
"xs15_dbgzw12ego;xs16_xgs252zck3z11;0;21,-108;;22,-12;-2,-95;0,10,1,0,0,-1",
"xs15_dbzj5oz11;xs16_dbgzj5oz11;0;;;14,-13;0,-52,6,-57;0,0,1,0,0,1",
"xs15_dj8gzx34a6;xs16_0g0s256z3kp;0;;1,-63,13,-67;-10,-74,1,-66;;0,8,1,0,0,-1",
"xs15_drz122ak8;xs16_drz122ako;0;20,-90;;;-2,-84;0,0,1,0,0,1",
"xs15_drz122ak8;xs16_drz122qk8;0;10,-72;;;-12,-78;0,0,1,0,0,1",
"xs15_drz122ak8;xs16_drz1qaa4;0;11,-61,19,-87;;;-11,-74,-4,-64;0,0,1,0,0,1",
"xs15_drz122ak8;xs16_g88a52z6bgz011;0;;1,-59,13,-63;-10,-70,1,-62;;0,9,1,0,0,-1",
"xs15_drz230352;xs16_4s0f9zbd;0;16,-104;;21,-12;;0,8,1,0,0,-1",
"xs15_drz3ego;xs16_drz3eg8o;0;16,-107;;18,-12;-5,-92;0,0,1,0,0,1",
"xs15_drzragz01;xs14_brzrm;0;;;;-14,-74;1,9,-1,0,0,-1",
"xs15_drzragz01;xs15_cq23zrm;0;4,-61;-11,-12;;-12,-81;1,9,-1,0,0,-1",
"xs15_drzragz01;xs16_drzra8o;0;22,-108;;15,-12;;0,0,1,0,0,1",
"xs15_g0j96zdl8;xs16_03iarz69c;0;21,-100;;14,-12;;4,8,-1,0,0,-1",
"xs15_g0s252zdl8;xs16_rai3zw34a4;0;21,-100;;14,-12;;0,8,1,0,0,-1",
"xs15_g2u0ol3z11;xs16_0mkih3z56w1;0;1,-76;;;-11,-78,-9,-88;6,5,0,-1,-1,0",
"xs15_g3ia4zdl8;xs16_2eg8530f9;0;21,-100;;14,-12;;0,0,0,1,1,0",
"xs15_g4q23zdl8;xs16_1784ko0ui;0;21,-100;;14,-12;;4,0,0,-1,1,0",
"xs15_g4s3pmz11;xs16_0g4s3pmz121;0;;-16,-12,-7,-43;-3,-49;-11,-81;-1,0,1,0,0,1",
"xs15_g5r8b5z11;xs16_g5r8b52z11;0;;12,-58;25,-57;;0,0,1,0,0,1",
"xs15_g5r8b5z11;xs16_i5r8b5z11;0;;-19,-53;-6,-54;;0,0,1,0,0,1",
"xs15_g6p3zdl8;xs16_3iarzc96;0;21,-100;;14,-12;;3,8,-1,0,0,-1",
"xs15_g6pajoz11;xs16_0g6pajoz121;0;-2,-52,3,-81;-17,-13,-2,-46;;-11,-74;-1,0,1,0,0,1",
"xs15_g6pajoz11;xs16_gbdgma4z11;0;;;-17,-139;10,-32;5,5,0,-1,-1,0",
"xs15_g84213zdlz11;xs16_g84213zdl2z11;0;;;16,-12;-2,-67,4,-72;0,0,1,0,0,1",
"xs15_g84215a4z1252;xs16_g84215a4z1256;0;;;15,-12;-7,-94;0,0,1,0,0,1",
"xs15_g88a52zdl8;xs14_g88a52zdd;0;;;;-13,-82;0,0,1,0,0,1",
"xs15_g88a52zdl8;xs15_32qczx115a4;0;3,-54;-10,-13;;-11,-74;-2,8,1,0,0,-1",
"xs15_g88a52zdl8;xs16_g88a52zd54c;0;21,-100;;14,-12;;0,0,1,0,0,1",
"xs15_g88a53zdd;xs16_3pa4zw115ac;0;8,-89,15,-114;;15,-12;-10,-96;-1,8,1,0,0,-1",
"xs15_g88b5zdl8;xs14_g88b5zdd;0;;;;-13,-78;0,0,1,0,0,1",
"xs15_g88b5zdl8;xs15_32qczx11da;0;3,-53;-10,-12;;-11,-73;-2,8,1,0,0,-1",
"xs15_g88b5zdl8;xs16_321ego0ui;0;21,-100;;14,-12;;4,0,0,-1,1,0",
"xs15_g88c0f9z056;xs16_0ggo3tgz1ac;0;-4,-40;5,-79;-8,-88,5,-77;;0,-1,1,0,0,1",
"xs15_g88e13zc96;xs16_g88e123zc96;0;;10,-80,11,-68;;11,-44;0,0,1,0,0,1",
"xs15_g8e123zc93;xs16_g8e1246zc93;0;16,-74;;5,-67,18,-26;3,-77;0,0,1,0,0,1",
"xs15_g8e13z1qm;xs15_gbdzpia4;0;-2,-48;2,-70;2,-66;3,-66;0,9,1,0,0,-1",
"xs15_g8e13z1qm;xs16_0gs252z3kcz011;0;;10,-72;5,-59;11,-48;0,-1,1,0,0,1",
"xs15_g8e13z1qm;xs16_g8e123z1qm;0;;8,-60,10,-50;8,-48;;0,0,1,0,0,1",
"xs15_g8e13zpi6;xs15_j9a4zpi6;0;-2,-48;2,-70;2,-66;3,-66;0,0,1,0,0,1",
"xs15_g8ge1e8z56;xs16_g8ge1e8z1ac;0;8,-105,21,-116;;17,-12;-6,-107;0,0,1,0,0,1",
"xs15_g8idioz123;xs16_g8idjoz123;0;;10,-50;6,-44;;0,0,1,0,0,1",
"xs15_g8ob96z56;xs16_g8ob96z1ac;0;8,-105,21,-116;;17,-12;-6,-107;0,0,1,0,0,1",
"xs15_g9fgka4z11;xs16_g9fgka6z11;0;;11,-54;9,-48;;0,0,1,0,0,1",
"xs15_gbaa4zdb;xs16_0gbaa4zol3;0;8,-105,19,-113;;;-20,-106,-8,-102;-1,0,1,0,0,1",
"xs15_gbaa4zdd;xs16_3pa4zwd552;0;8,-89,15,-114;;15,-12;-10,-96;-1,8,1,0,0,-1",
"xs15_gbb871z23;xs16_8k9b871z023;0;-2,-40;-3,-45;-6,-54;;-1,0,1,0,0,1",
"xs15_gbdzha6z11;xs16_3loz3kcz32;0;-14,-52,-4,-61;-1,-81,7,-81;;;0,-1,1,0,0,1",
"xs15_ggka23ck8z1;xs16_ggka2bkk8z1;0;;;13,-12;1,-51;0,0,1,0,0,1",
"xs15_ggkc0fhoz1;xs16_05b88cz8e13;0;15,-70;;17,-15;4,-55;8,5,0,-1,-1,0",
"xs15_gilmz1w346;xs16_g89f0ca4z23;0;16,-91;;18,-12;-1,-76;0,7,0,1,-1,0",
"xs15_gilmz1w652;xs16_c88b9cz0253;0;;;6,-30;4,-65,4,-40;0,7,1,0,0,-1",
"xs15_gjl8628cz1;xs17_0358gzgs259c;0;16,-74;;;8,-68;9,5,0,-1,-1,0",
"xs15_gjlc2koz1;xs15_gild2koz1;0;;1,-44;-5,-54;;0,0,1,0,0,1",
"xs15_gjlc2koz1;xs16_3iacga6z121;0;-4,-39;;-11,-78,-2,-73;8,-39;0,5,1,0,0,-1",
"xs15_gs2453z1ac;xs16_0o48a52z3lo;0;-2,-44;8,-78,17,-83;;10,-44;0,-1,1,0,0,1",
"xs15_gs2596z146;xs15_gs24871z146;0;;5,-47;8,-33;10,-40;0,0,1,0,0,1",
"xs15_j1u06a4z11;xs16_0gilmz32w252;0;-7,-34;-1,-45;-6,-58;;6,5,0,-1,-1,0",
"xs15_j1u06a4z11;xs16_0gilmz32w65;0;-6,-32;-1,-40;-4,-55;;6,5,0,-1,-1,0",
"xs15_j1u06a4z11;xs16_0gilmz56w23;0;1,-76;;;-11,-78,-9,-88;6,5,0,-1,-1,0",
"xs15_j1u06a4z11;xs16_j1u06acz11;0;15,-70;;;5,-64;0,0,1,0,0,1",
"xs15_j5c48a6z11;xs16_5bo8gkcz32;0;-3,-45;2,-50;-7,-62;;0,-1,1,0,0,1",
"xs15_j5s256z11;xs16_4ap5acz321;0;;1,-65,12,-67;0,-57;13,-32;0,-1,1,0,0,1",
"xs15_j96zd54c;xs16_1no312453;0;;;9,-48,20,-12;-5,-101,7,-57;0,8,0,1,-1,0",
"xs15_j9aczdb;xs16_0j9aczol3;0;8,-101,19,-109;;;-20,-102,-8,-98;-1,0,1,0,0,1",
"xs15_j9aczdd;xs16_35862sga6;0;8,-89,15,-114;;15,-12;-10,-96;-1,8,0,1,-1,0",
"xs15_jhe8z69c;xs16_03pmz178k8;0;-7,-44;-1,-55;-6,-68;;3,8,-1,0,0,-1",
"xs15_jhe8z69c;xs16_5b8o642ac;0;-6,-44;-1,-52;-4,-67;;-1,0,0,1,1,0",
"xs15_ml2z10784c;xs16_rai3zw3426;0;;12,-60;;5,-44;0,1,1,0,0,1",
"xs15_ml2z124871;xs14_ok21e8z66;0;;;-4,-46;;0,8,1,0,0,-1",
"xs15_ml2z124871;xs15_wok21e8z6221;0;-1,-49;-6,-18;-2,-38;;-2,8,1,0,0,-1",
"xs15_ml2z124871;xs16_8kih30f9zx1;0;;12,-60;;5,-44;0,8,0,1,-1,0",
"xs15_ml2z1248a6;xs14_ok2156z66;0;;;-4,-46;;0,8,1,0,0,-1",
"xs15_ml2z1248a6;xs15_32qczx12453;0;-1,-49;-6,-18;-2,-38;;-2,1,1,0,0,1",
"xs15_ml2z1248a6;xs16_ok2156z6226;0;;12,-60;;5,-44;0,8,1,0,0,-1",
"xs15_ml2zd54c;xs16_9f0330f9;0;;12,-60;;5,-44;0,1,0,1,1,0",
"xs15_ml2zhik8z1;xs14_3ia4zrq;0;;;-4,-38;;0,10,1,0,0,-1",
"xs15_ml2zhik8z1;xs15_32qczwo9a4;0;-1,-52;-6,-21;-2,-41;;-2,1,1,0,0,1",
"xs15_ml2zhik8z1;xs16_32arz4a9o;0;;12,-68;;5,-52;3,1,-1,0,0,1",
"xs15_ml2zmdz11;xs16_bq23zrm;0;;12,-68;;5,-52;0,1,1,0,0,1",
"xs15_ml56z1ac;xs15_3hu06248c;0;;4,-26;0,-28;;-1,0,0,1,1,0",
"xs15_mlic0ccz1;xs16_mkhf0ccz1;0;;7,-63,7,-38;5,-36;;0,0,1,0,0,1",
"xs15_mp3zw35a4;xs15_3lozwojd;0;17,-78,22,-102;;11,-16;-8,-86;4,9,-1,0,0,-1",
"xs15_mp3zw35a4;xs15_mp3zw31246;0;12,-86;;16,-12,21,-16;1,-80;0,0,1,0,0,1",
"xs15_mp3zw35a4;xs16_mp3zw312ko;0;12,-149,27,-142;;17,-68,32,-12;;0,0,1,0,0,1",
"xs15_o4871acz23;xs16_o4871acz056;0;7,-87,19,-91;;;-16,-98,-5,-90;0,0,1,0,0,1",
"xs15_o4a5123z056;xs16_o4a51246z056;0;17,-78;;6,-71,19,-30;4,-81;0,0,1,0,0,1",
"xs15_o4c32acz23;xs16_o4c32acz056;0;7,-87,19,-91;;;-16,-98,-5,-90;0,0,1,0,0,1",
"xs15_o4s3pmz01;xs15_g4s3pmz11;0;-3,-48,-3,-32;-4,-36;;;0,0,1,0,0,1",
"xs15_o4s3pmz01;xs16_gbap56z121;0;-3,-100,16,-136,20,-165;-13,-12,-1,-102;;-21,-186;5,5,0,-1,-1,0",
"xs15_o5r8b5z01;xs16_mk2t52z121;0;;12,-58;25,-57;;0,0,0,1,1,0",
"xs15_o8brzx1252;xs16_o8brzx1256;0;19,-86;;;1,-80;0,0,1,0,0,1",
"xs15_oe12453z23;xs16_oe12453z056;0;7,-87,19,-91;;;-16,-98,-5,-90;0,0,1,0,0,1",
"xs15_oe12koz056;xs16_oe12koz01ac;0;9,-105,22,-116;;18,-12;-5,-107;0,0,1,0,0,1",
"xs15_oggm93z66;xs16_gwci52zdd11;0;;11,-61;7,-68,12,-39;2,-73,17,-40;0,-1,1,0,0,1",
"xs15_oggs252z66;xs16_c88e1e8z33;0;;;5,-37,12,-19;2,-46,10,-40;0,1,1,0,0,1",
"xs15_oggs252z66;xs16_oggs253z66;0;;12,-58;8,-52;;0,0,1,0,0,1",
"xs15_ogkq23z66;xs16_0ogkq23z4a6;0;8,-68,16,-87;;;-10,-70;-1,0,1,0,0,1",
"xs15_ogkq23z66;xs16_ogkq23z6a4;0;10,-93;-14,-12;;-8,-92;0,0,1,0,0,1",
"xs15_oi60652z65;xs16_g4c0f9zdb;0;;10,-76;;15,-40;0,-1,1,0,0,1",
"xs15_ok215a4z66;xs16_0ok215a4z6421;0;7,-81,14,-106;;14,-12;-9,-88;-1,0,1,0,0,1",
"xs15_ol3zmdz11;xs16_0ol3z0mdz32;0;10,-105,21,-113;;;-22,-106,-10,-102;-1,0,1,0,0,1",
"xs15_ol3zmlz11;xs16_312462461ac;0;10,-105,17,-130;;17,-12;-12,-112;2,0,0,-1,1,0",
"xs15_ra2453z23;xs16_mk48a52z56;0;;8,-81,13,-62,18,-84;5,-61;13,-46;0,-1,1,0,0,1",
"xs15_ra248goz23;xs16_ra248goz056;0;7,-87,19,-91;;;-16,-98,-5,-90;0,0,1,0,0,1",
"xs15_rdz0qbgzw1;xs16_0bq23zrm;0;23,-108;;16,-12;;0,9,1,0,0,-1",
"xs15_rdzgarz01;xs14_0brzrm;0;16,-74;;;;0,9,1,0,0,-1",
"xs15_rdzgarz01;xs15_0cq23zrm;0;14,-81;;13,-12;-2,-61;0,9,1,0,0,-1",
"xs15_rdzgarz01;xs16_0drzra8o;0;;-13,-12;;-20,-108;2,0,-1,0,0,1",
"xs15_w8k8a52z6521;xs16_wck8a52z6521;0;-1,-40;3,-50;;;0,0,1,0,0,1",
"xs15_w8o6952z2521;xs16_w8o6952z6521;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs15_w9v04a4z311;xs16_w9v04a6z311;0;;12,-58;10,-52;;0,0,1,0,0,1",
"xs15_w9v04a4z311;xs16_w9v04acz311;0;16,-74;;;6,-68;0,0,1,0,0,1",
"xs15_wdrzgb6z11;xs16_3124628c48go;0;;3,-66,15,-70;-8,-77,3,-69;;4,-1,0,-1,1,0",
"xs15_wg84213033z65;xs16_xg8426853zca1;0;18,-82;;9,-67,16,-64;11,-66;0,-1,1,0,0,1",
"xs15_wg8421egoz65;xs16_8k8gxg853zx3421;0;19,-86;;20,-30;6,-73;10,7,-1,0,0,-1",
"xs15_wg8421egoz65;xs16_wg8421eg8oz65;0;17,-78;;19,-23;6,-63;0,0,1,0,0,1",
"xs15_wg84260652z65;xs16_32qbzx1248go;0;;14,-76;;19,-40;9,-1,0,-1,1,0",
"xs15_wg853zmlz121;xs14_wg853zmlz11;0;;;;-15,-90;0,0,1,0,0,1",
"xs15_wg853zmlz121;xs16_g0g842130f9z11;0;23,-116;;16,-12;;0,0,0,1,1,0",
"xs15_wg8ob96z65;xs16_xg8ob96zca1;0;7,-109;-16,-14;;-20,-118,-7,-107;-1,0,1,0,0,1",
"xs15_wgbqicz65;xs16_wgbqicz643;0;3,-75,8,-72;-9,-12;;;0,0,1,0,0,1",
"xs15_wggka23zc96;xs16_25iczx115a8o;0;;-19,-12,-10,-43;0,-49;-14,-105;-1,9,1,0,0,-1",
"xs15_wggka52zc96;xs16_25iczx115ak8;0;;-19,-12,-10,-43;0,-49;-14,-105;-1,9,1,0,0,-1",
"xs15_wghn84cz252;xs16_0ghn84cz1226;0;7,-63,14,-73;;;-12,-86,-4,-60;1,0,1,0,0,1",
"xs15_wghn84cz252;xs16_wghn84cz652;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs15_wgil96z256;xs15_3ia4zw11da4;0;;12,-58;2,-43;5,-45;6,-1,-1,0,0,1",
"xs15_wgil96z652;xs15_3ia4zw115ac;0;;12,-58;2,-43;5,-45;6,-1,-1,0,0,1",
"xs15_wj96zmlz11;xs16_xj96zg6l8z11;0;10,-105,17,-130;;17,-12;-12,-112;-1,0,1,0,0,1",
"xs15_wmk453z643;xs16_31e8zw311da;0;;13,-62;4,-50;9,-45;0,7,1,0,0,-1",
"xs15_woge13zdb;xs16_woge123zdb;0;;10,-67;7,-52;12,-44;0,0,1,0,0,1",
"xs15_x8k453zad11;xs16_5b88gzx122ak8;0;;15,-72;5,-59;12,-44;0,8,1,0,0,-1",
"xs15_x8k453zad11;xs16_5b88gzx122qk;0;;14,-66;5,-54;10,-49;7,-1,-1,0,0,1",
"xs15_x8o652zad11;xs16_39cggzx122qk;0;-1,-44;9,-67;-1,-82;8,-62;7,-1,-1,0,0,1",
"xs15_x8o652zad11;xs16_x8o653zad11;0;;13,-62;9,-56;;0,0,1,0,0,1",
"xs15_x8o652zad11;xs16_xoge123zc93;0;16,-74;9,-64;14,-48;8,-57;0,0,0,1,1,0",
"xs15_x8o652zad11;xs17_321egozy235a4;0;;13,-62;11,-47;;0,8,0,1,-1,0",
"xs15_xc8a52z2553;xs16_xc8a53z2553;0;;13,-62;9,-56;;0,0,1,0,0,1",
"xs15_xc8a52z6513;xs16_xc8a53z6513;0;;13,-62;9,-56;;0,0,1,0,0,1",
"xs15_xg853z0mlz121;xs16_9f0c48gzy31246;0;;-14,-14;;-21,-118;-1,10,0,1,-1,0",
"xs15_xg853zca1z33;xs16_3586248gzy41246;0;11,-113,18,-138;;18,-12;-13,-120;-1,11,0,1,-1,0",
"xs15_xg853zrahz01;xs16_358gzxo9ar;0;22,-108;;15,-12;;6,0,-1,0,0,1",
"xs15_xg8ka52z4a43;xs16_xg8ka52z6a43;0;1,-44;-3,-22;;;0,0,1,0,0,1",
"xs15_xg8ka52z4a43;xs16_xg8ka52zca43;0;11,-102;-13,-12;;;0,0,1,0,0,1",
"xs15_xg8o652z4a43;xs17_252s0gzy0116ak8;0;;14,-66;12,-51;;0,8,1,0,0,-1",
"xs15_xg8og853zca1;xs16_358g0ggzy011012ko;0;;9,-87,22,-98;9,-89;18,-50;10,-1,-1,0,0,1",
"xs15_xgs252zca43;xs16_xgs253zca43;0;;13,-62;9,-56;;0,0,1,0,0,1",
"xs15_xok21e8z253;xs16_39cggzx1o9a4;0;0,-80;-8,-33;-2,-50;-9,-96;-1,7,0,1,-1,0",
"xs15_xok21e8z253;xs16_xok21e8z653;0;10,-94;-12,-12;;;0,0,1,0,0,1",
"xs15_xok21e8z253;xs16_xok21e8zc93;0;3,-72,12,-89,21,-94;;;-20,-143,-11,-103;0,0,1,0,0,1",
"xs15_xok21e8z253;xs17_4ai3gzx116ak8;0;12,-93;-12,-12;;;8,0,0,-1,1,0",
"xs16_0252sgzca53;xs16_02l2sgz6943;0;3,-83;-11,-12;;;0,0,1,0,0,1",
"xs16_02lmzggmdz1;xs16_32qczw6b8o;0;;5,-41;9,-21;4,-52;5,1,-1,0,0,1",
"xs16_031e8gz8k871;xs16_0gs252zha6z11;0;;6,-56,9,-46;-4,-62,7,-44;;5,9,-1,0,0,-1",
"xs16_031e8gz8k871;xs16_0gs252zpia4;0;2,-66;3,-66;3,-70;7,-48;5,9,-1,0,0,-1",
"xs16_031e8gzc9311;xs16_3loz1226io;0;;6,-56,9,-46;-4,-62,7,-44;;5,-1,-1,0,0,1",
"xs16_031e8gzc9311;xs16_g88c93zc952;0;-2,-49;-4,-56,3,-62;3,-66;7,-44;5,8,-1,0,0,-1",
"xs16_032qk8zol3;xs15_032qkzol3;0;;;9,-24;3,-48;0,0,1,0,0,1",
"xs16_039q48cz2521;xs16_069q48cz2521;0;-11,-40,-4,-67,-3,-50;-3,-56;;;0,0,1,0,0,1",
"xs16_03hik8z69a4;xs16_03hik8zo9a4;0;12,-74;-7,-12;;-14,-89;0,0,1,0,0,1",
"xs16_03iacz6a9o;xs16_4a9jzwo9a6;0;-6,-105;8,-146,10,-74;1,-144,1,-88;9,-118,11,-48;5,0,-1,0,0,1",
"xs16_03l2sgz2543;xs16_4a5p6o8zx121;0;-9,-54;-9,-57;-6,-54;;-1,7,1,0,0,-1",
"xs16_03lka4zc452;xs16_02lla4zc452;0;;1,-40;-5,-50;;0,0,1,0,0,1",
"xs16_03lka6z643;xs16_3pm861ac;0;9,-86;-6,-30;13,-12;-5,-90;1,0,0,1,1,0",
"xs16_03loz252ak8;xs15_39m86248c;0;;;14,-12;-2,-76;4,8,0,-1,-1,0",
"xs16_06413kczc8421;xs15_6413kcz6421;0;0,-49,8,-71;-6,-12;;;1,0,1,0,0,1",
"xs16_08e1248goz253;xs15_3303ia4zw65;0;13,-62;;;;1,6,0,1,-1,0",
"xs16_08eharz321;xs16_g8eharz121;0;2,-76;-18,-12,-11,-39,-10,-22;;;0,0,1,0,0,1",
"xs16_08kkm93z321;xs16_08kkm96z321;0;;;5,-50;11,-36;0,0,1,0,0,1",
"xs16_08o032acz254c;xs14_4ai3zx12453;0;-6,-44;0,-52;-2,-59;;0,8,1,0,0,-1",
"xs16_08o032acz69c;xs14_69jzx12453;0;-1,-44;3,-53;-7,-69;;0,8,1,0,0,-1",
"xs16_08o0ehrz321;xs15_354miozw32;0;-9,-36,-2,-53;-1,-61,8,-68;1,-79;;0,6,0,1,-1,0",
"xs16_08o652sgz65;xs15_0kc321e8z32;0;;6,-34;2,-34;;0,1,1,0,0,1",
"xs16_08o652zragz01;xs16_32qczx23ck8;0;4,-61;-11,-12;;-12,-81;-2,9,1,0,0,-1",
"xs16_08u164koz32;xs16_3loz122628c;0;;;4,-58,15,-32;7,-58,10,-36;8,0,0,-1,1,0",
"xs16_08u164koz32;xs21_ok461u8z6a4x23;0;13,-62;;;;7,0,-1,0,0,1",
"xs16_09f0352z253;xs15_9f0352z33;0;13,-62;;;;1,0,1,0,0,1",
"xs16_0bdz3213146;xs16_0at16426z32;0;2,-76;-18,-12,-11,-39,-10,-22;;;0,7,0,1,-1,0",
"xs16_0bdz32139c;xs16_39c84ozxbd;0;2,-76;-18,-12,-11,-39,-10,-22;;;5,8,-1,0,0,-1",
"xs16_0bt06413z32;xs16_0at16413z32;0;;6,-70;-12,-86,-5,-85,-4,-64;;0,0,1,0,0,1",
"xs16_0bt06a4z65;xs15_bt06a4z32;0;8,-64,16,-74;;;-6,-61;1,0,1,0,0,1",
"xs16_0c8a53z2553;xs15_0c8a52z2553;0;;;12,-12;2,-42;0,0,1,0,0,1",
"xs16_0c8a53z2553;xs16_0c8a53z6513;0;;;13,-12;-6,-78;0,0,1,0,0,1",
"xs16_0c8a53z2553;xs16_35is0si6;0;10,-64;;;-8,-62;5,0,0,-1,1,0",
"xs16_0c9jz253056;xs16_2lm853z056;0;;4,-53;-12,-85,-8,-62,2,-57;;0,7,1,0,0,-1",
"xs16_0c9jzi5dz11;xs16_0dbgzi5dz11;0;;4,-45;-12,-77,-8,-54,2,-49;;0,0,1,0,0,1",
"xs16_0ca952z2553;xs20_259acx33zw3552;0;-4,-40;-4,-28;;;5,0,-1,0,0,1",
"xs16_0co2dicz321;xs16_0co2dioz321;0;15,-70;17,-92;8,-78;;0,0,1,0,0,1",
"xs16_0cp3zmlz121;xs16_xcp3zggmdz1;0;5,-69;-12,-12;;-13,-89;-2,0,1,0,0,1",
"xs16_0drzmlz121;xs15_0brzmdz11;0;;;;-15,-78;2,10,-1,0,0,-1",
"xs16_0drzmlz121;xs16_xdrzggmdz1;0;5,-69;-12,-12;;-13,-89;-2,0,1,0,0,1",
"xs16_0g84c842156z32;xs15_31246248gkc;0;-6,-57,12,-96;;-1,-54;;0,4,1,0,0,-1",
"xs16_0g88a52zgarz01;xs15_brz122ak8;0;16,-74;;;;1,9,1,0,0,-1",
"xs16_0g88a52zgarz01;xs16_cq23z122ak8;0;14,-81;;13,-12;-2,-61;1,9,1,0,0,-1",
"xs16_0g8e13zo9a6;xs16_03lozgjkcz1;0;;-1,-40,10,-58;-3,-42,0,-52;;0,-1,1,0,0,1",
"xs16_0g8e13zo9a6;xs16_0cai3z4aip;0;-1,-48;3,-70;3,-66;4,-66;4,9,-1,0,0,-1",
"xs16_0g8it248cz23;xs15_0g8it246z23;0;;;9,-39;5,-58,13,-36;0,0,1,0,0,1",
"xs16_0g8it248cz23;xs16_0g8it2sgz23;0;;;10,-62,18,-12;-3,-105,-2,-89;0,0,1,0,0,1",
"xs16_0gba96z3452;xs16_3ia4zwd596;0;11,-67;-6,-13;;-13,-82;0,8,1,0,0,-1",
"xs16_0ggc453zpi6;xs16_0ggc453z1qm;0;10,-85,20,-90,24,-113;;;-10,-81;0,0,1,0,0,1",
"xs16_0ggca52zcip;xs15_0ggdbzcip;0;0,-48;;-7,-79;4,-71;0,0,1,0,0,1",
"xs16_0ggca52zcip;xs16_3lozxj5ozx11;0;;10,-50,15,-74;1,-58;4,-52;5,-1,-1,0,0,1",
"xs16_0ggml96z641;xs16_3iaczw1139c;0;;12,-58;2,-43;5,-45;6,-1,-1,0,0,1",
"xs16_0ggs2596z56;xs16_0ggs24871z56;0;;7,-47;10,-33;12,-40;0,0,1,0,0,1",
"xs16_0gilmz32w252;xs16_0co2dicz321;0;;10,-50;8,-44,17,-19;2,-67;6,6,0,-1,-1,0",
"xs16_0gjlka4z641;xs16_0gilla4z641;0;;2,-40;-4,-50;;0,0,1,0,0,1",
"xs16_0gs2596z1246;xs16_08k461acz6221;0;;6,-47;9,-33;11,-40;0,0,0,1,1,0",
"xs16_0gs2arz3421;xs16_0gs2arz6421;0;-10,-149,-5,-144;-11,-90,5,-130;;-18,-185,10,-40;0,0,1,0,0,1",
"xs16_0gs2dioz641;xs16_0gs2dicz641;0;;;15,-12;1,-58;0,0,1,0,0,1",
"xs16_0iu0652z4a6;xs15_brz230352;0;14,-66;;;;1,7,1,0,0,-1",
"xs16_0iu0dbz641;xs16_08obap3z32;0;-7,-40,0,-57,6,-84;-5,-41;;-11,-88;5,6,0,-1,-1,0",
"xs16_0iu0dbz641;xs16_3123qajo;0;8,-77,18,-82,22,-105;;;-8,-73;1,7,0,1,-1,0",
"xs16_0j5o653z121;xs16_06agc93z2521;0;;12,-97,13,-80;3,-89;8,-80,23,-36;0,-1,1,0,0,1",
"xs16_0j5o653z121;xs16_6ik8a52z065;0;13,-77;11,-81;7,-76,18,-40;14,-36;0,0,0,1,1,0",
"xs16_0j9c84cz1252;xs16_31ke12kozw11;0;11,-97;-12,-12;16,-13;-6,-91,-3,-139,1,-64;1,0,0,1,1,0",
"xs16_0j9cz343113;xs16_0j9cz643113;0;-1,-56,-1,-40;-6,-28;;;0,0,1,0,0,1",
"xs16_0j9cz343146;xs16_0j9cz643146;0;-1,-56,-1,-40;-6,-28;;;0,0,1,0,0,1",
"xs16_0kc32acz1226;xs16_08o6421e8z65;0;;;2,-70,13,-44;7,-62,10,-40;0,-1,0,1,1,0",
"xs16_0mk453z3443;xs14_0mk453z321;0;;;;-4,-46;0,0,1,0,0,1",
"xs16_0ml56zc96;xs16_354260uh3;0;;5,-30;1,-32;;0,8,0,1,-1,0",
"xs16_0ml96zc96;xs16_0cai3zojd;0;;10,-57;0,-42;3,-44;0,-1,1,0,0,1",
"xs16_0o4871zgarz01;xs15_brz342sg;0;16,-74;;;;1,9,1,0,0,-1",
"xs16_0o4871zgarz01;xs16_2ego8gka23;0;14,-81;;13,-12;-2,-61;5,9,0,-1,-1,0",
"xs16_0ok213zg6dz11;xs15_0cp3zgb6z11;0;-1,-52;;-8,-83,10,-50;;3,10,-1,0,0,-1",
"xs16_178c4go0ok8;xs16_32qczx6b8o;0;16,-74;;15,-19;-1,-63;0,0,0,1,1,0",
"xs16_178cga6z0321;xs14_i5m853z11;0;;;-5,-54;;1,1,1,0,0,1",
"xs16_178kc32ac;xs15_1784c32ac;0;9,-54;;;-3,-54;0,0,1,0,0,1",
"xs16_252s0ccz2521;xs16_25is0cczw65;0;5,-125,21,-94;-7,-77;;-3,-124,4,-103;0,0,1,0,0,1",
"xs16_25303123ck8;xs16_256o8zx6b8o;0;-1,-35;7,-47;-2,-58;;10,4,0,-1,-1,0",
"xs16_253031461ac;xs15_4ap3zrq;0;-3,-24;;;;10,0,0,-1,1,0",
"xs16_253031461ac;xs16_32qczw4ajo;0;-1,-35;7,-47;-2,-58;;1,-2,0,1,1,0",
"xs16_25308e12453;xs15_j96zc953;0;-4,-52,7,-64;-7,-24,3,-55;;-8,-82;10,0,0,-1,1,0",
"xs16_256064132ac;xs16_031eozo8b6;0;9,-55;-3,-27;;-4,-66;10,4,0,-1,-1,0",
"xs16_256064215ac;xs15_0brz69ko;0;;-5,-12;;;1,0,0,1,1,0",
"xs16_256064215ac;xs16_035iczo8b6;0;9,-55;-3,-27;;-4,-66;10,4,0,-1,-1,0",
"xs16_256064264ko;xs16_31eozo8b6;0;9,-55;-3,-27;;-4,-66;10,4,0,-1,-1,0",
"xs16_25606426853;xs16_04ap3zo8b6;0;9,-55;-3,-27;;-4,-66;10,4,0,-1,-1,0",
"xs16_256o8gzca221;xs15_256o8ge13;0;;;10,-12;2,-44;0,0,0,1,1,0",
"xs16_259aczx6513;xs16_259aczx2553;0;10,-64;;;-10,-74;0,0,1,0,0,1",
"xs16_259q453z032;xs16_259q453zw32;0;8,-77,18,-82,22,-105;;;-6,-73;0,0,1,0,0,1",
"xs16_25a88a6z0253;xs16_0co2d96z321;0;-8,-40,4,-167;-14,-111,-9,-107,-3,-133,9,-109;;;0,1,0,1,1,0",
"xs16_25a88czc871;xs16_25a8k8zc871;0;;;5,-54;9,-44;0,0,1,0,0,1",
"xs16_25a8ci6zx65;xs16_25a8ciczx65;0;;;6,-46;10,-40;0,0,1,0,0,1",
"xs16_25acggzy01012ko;xs15_bdggzw1012ko;0;2,-71;13,-79;;6,-48;2,0,1,0,0,1",
"xs16_25acggzy01012ko;xs15_bdggzw1248go;0;;-12,-29;1,-65;-7,-74;0,2,0,1,1,0",
"xs16_25acggzy01012ko;xs16_xg8o64213zca1;0;-8,-52,-3,-48;-4,-52;1,-58;;9,1,-1,0,0,1",
"xs16_25iczmlz121;xs15_25iczmlz11;0;;;;-15,-82;0,0,1,0,0,1",
"xs16_25iczmlz121;xs16_w25iczggmdz1;0;5,-69;-12,-12;;-13,-89;-2,0,1,0,0,1",
"xs16_25iczw178426;xs16_g8e1246z0db;0;0,-62;-2,-54,13,-75;;6,-44;1,8,1,0,0,-1",
"xs16_25is0si52;xs15_25is0si6;0;;3,-46;-1,-46;;8,0,-1,0,0,1",
"xs16_2ege96z321;xs16_2ege93z321;0;;;13,-28,13,-12;4,-56;0,0,1,0,0,1",
"xs16_2egu16426;xs16_2egu178c;0;;7,-63;-7,-70,0,-59,9,-48;;0,0,1,0,0,1",
"xs16_2lla8oz321;xs16_39cgciczw23;0;4,-99;-12,-26,-11,-47;;-24,-126,-9,-110;-1,6,0,1,-1,0",
"xs16_2lla8oz641;xs16_2lla8oz065;0;8,-77,18,-82,22,-105;;;-8,-73;0,0,1,0,0,1",
"xs16_2lmz0mdz32;xs15_ol3zmlz11;0;;6,-34;;;2,11,-1,0,0,-1",
"xs16_2lmz0mdz32;xs16_178c48c48go;0;;4,-45;8,-25;3,-56;4,1,0,-1,1,0",
"xs16_2lmzw342156;xs15_8e12453z33;0;;6,-34;;;1,7,1,0,0,-1",
"xs16_2lmzw34628c;xs15_brz0123146;0;;6,-34;;;1,1,1,0,0,1",
"xs16_2lmzw34ako;xs15_0o4a53zdd;0;;6,-34;;;1,9,1,0,0,-1",
"xs16_312461164ko;xs16_31246116853;0;14,-84;13,-62;11,-68;7,-80;0,0,1,0,0,1",
"xs16_31e8gzy012ego;xs16_0ggo4431246z32;0;;5,-56,8,-46;-5,-62,6,-44;;2,9,0,1,-1,0",
"xs16_31eg8o653;xs16_31eg8o6426;0;15,-70;13,-74;9,-69,20,-33;16,-29;0,0,1,0,0,1",
"xs16_31egozy135a4;xs16_3lozx31ego;0;20,-90,25,-114;;14,-28;-5,-98;7,9,-1,0,0,-1",
"xs16_31egozy135a4;xs16_3lozx354ko;0;15,-86;;19,-12,24,-16;4,-80;9,7,0,-1,-1,0",
"xs16_31km96zw56;xs16_31km93zw56;0;;;13,-28,13,-12;4,-56;0,0,1,0,0,1",
"xs16_321fgc453;xs16_321fgc2ko;0;15,-70;12,-63;2,-78,9,-56;5,-76;0,0,1,0,0,1",
"xs16_32qj43146;xs16_9fg4czbd;0;;;10,-43;6,-63,16,-28,20,-35;0,0,0,1,1,0",
"xs16_32qkzw6a96;xs16_32qkzw6a9o;0;19,-89;;12,-12;-7,-74;0,0,1,0,0,1",
"xs16_32qkzw6aa6;xs16_03lk46zc452;0;14,-66;;;-6,-68;0,8,1,0,0,-1",
"xs16_32qkzy1ciic;xs16_0g8jq2sgz23;0;10,-62;;9,-20;-9,-78,6,-48;6,0,0,-1,1,0",
"xs16_33y34alla4;xs16_8k9bkk8zw23;0;10,-127,27,-121;-1,-78,19,-110;;-5,-86,-2,-143,7,-125,17,-86;14,-1,-1,0,0,1",
"xs16_33zy635861ac;xs12_35861ac;0;;2,-18;;;10,5,1,0,0,1",
"xs16_354268m93;xs16_2lla4zc96;0;;;7,-42;13,-28;8,0,0,-1,1,0",
"xs16_3542ug8426;xs16_3542ug853;0;;7,-59;-5,-66,2,-55,14,-37;9,-68;0,0,1,0,0,1",
"xs16_354cggc2ko;xs16_4a9jz4aip;0;3,-80;-1,-60;0,-64;-7,-74;0,1,0,1,1,0",
"xs16_354cggc453;xs16_354cggc2ko;0;3,-80;-1,-60;0,-64;-7,-74;9,0,-1,0,0,1",
"xs16_354cgn96;xs16_35861tic;0;3,-72;-1,-52,6,-74;-4,-59;-7,-66;0,4,1,0,0,-1",
"xs16_358go0uic;xs16_064kl3zc8421;0;;;11,-14;7,-28;8,0,0,-1,1,0",
"xs16_358gzckld;xs16_31248c0fho;0;12,-64;;;-10,-62;0,0,0,1,1,0",
"xs16_358gzw358gkc;xs15_0ok2156zca1;0;;1,-37,9,-47;1,-34;;1,9,1,0,0,-1",
"xs16_35aczw3553;xs16_03lk46z6521;0;13,-62;;;-5,-64;0,7,1,0,0,-1",
"xs16_35akggozx66;xs15_25akggozx66;0;3,-42;-7,-12;;;0,0,1,0,0,1",
"xs16_35s26z39c;xs16_35s26zbd;0;11,-85;;;-21,-117,-17,-94,-7,-89;0,0,1,0,0,1",
"xs16_35s2s53zx1;xs16_25t2s53zx1;0;;0,-48;-6,-58;;0,0,1,0,0,1",
"xs16_39cz32139c;xs16_j9cz12139c;0;2,-76;-18,-12,-11,-39,-10,-22;;;0,0,1,0,0,1",
"xs16_39m453z321;xs16_69m453z321;0;-5,-36;1,-50;;;0,0,1,0,0,1",
"xs16_39s0ca4z321;xs15_39u0ooz32;0;;;12,-12;;0,6,1,0,0,-1",
"xs16_39s0ca4z321;xs16_25a88a6z0253;0;-4,-36;0,-47;;;-1,0,0,1,1,0",
"xs16_39s0ca4z321;xs16_39c8a6z253;0;2,-69;-14,-12,-7,-29,-1,-56;-4,-60;;-1,1,0,1,1,0",
"xs16_39s0qmz023;xs16_39qb8oz32;0;2,-69;-14,-12,-7,-29,-1,-56;-4,-60;;5,1,0,-1,1,0",
"xs16_39s0qmz32;xs16_39c826z3213;0;2,-69;-14,-12,-7,-29,-1,-56;-4,-60;;-1,1,0,1,1,0",
"xs16_39s0qmz32;xs16_g39s0qmz11;0;-8,-36,-1,-53,5,-80;-4,-45;;-10,-84;-1,0,1,0,0,1",
"xs16_3iacz1215a4;xs15_178c2dio;0;;;13,-12;-1,-68;0,0,0,1,1,0",
"xs16_3iacz1215a4;xs16_04a9jz4a5121;0;-7,-101;7,-142,9,-70;0,-140,0,-84;8,-114,10,-44;5,0,-1,0,0,1",
"xs16_3iaj2ak8zw1;xs16_ciaj2ak8zw1;0;2,-48;-5,-23,-4,-47,3,-70;-11,-86,-6,-62;-13,-91;0,0,1,0,0,1",
"xs16_3lkaa4z321;xs15_3lkaa4z121;0;14,-66;;;-4,-56;0,0,1,0,0,1",
"xs16_3lkaa4z321;xs16_03lkaa4z3201;0;4,-99;-12,-26,-11,-47;;-24,-126,-9,-110;-1,0,1,0,0,1",
"xs16_3lkaa4z321;xs16_3lkaa4z641;0;9,-113;-23,-12,-8,-56;;-13,-104,-12,-121;0,0,1,0,0,1",
"xs16_3lo0kcz6421;xs16_3lo0kcz3421;0;3,-84;-19,-12,-12,-39,-11,-22;;;0,0,1,0,0,1",
"xs16_3pajc48c;xs16_3146pajo;0;17,-83;;6,-67;5,-77,11,-49,17,-28;7,4,-1,0,0,-1",
"xs16_3pm44og4c;xs16_62s53zbd;0;;;10,-47,20,-12,24,-19;6,-59;0,4,0,1,-1,0",
"xs16_4a60gs2pm;xs15_6ags2pm;0;-3,-48,8,-60;-8,-12,2,-43;;-9,-78;2,0,1,0,0,1",
"xs16_4a9jzx12ego;xs16_4a9jzxha6zx11;0;10,-76,21,-94;;;-10,-78,-7,-88;0,0,1,0,0,1",
"xs16_4a9jzx12ego;xs16_4a9jzxpia4;0;14,-106;-8,-12;15,-30;-4,-102;0,0,1,0,0,1",
"xs16_4aarzy0178c;xs16_4a9jzxd552;0;13,-98;-7,-12;14,-30;-3,-94;6,8,-1,0,0,-1",
"xs16_4alhe8z0641;xs16_4alhe8zw65;0;9,-81,19,-86,23,-109;;;-7,-77;0,0,1,0,0,1",
"xs16_4aq32acz032;xs16_4aq32acz32;0;9,-95,15,-91,21,-94;-11,-21;;-2,-89;0,0,1,0,0,1",
"xs16_5b88b5z033;xs15_5b88a6zx33;0;;-2,-12;;;5,0,-1,0,0,1",
"xs16_5b8r5426;xs15_5b8r54c;0;;;8,-34,16,-12;4,-47;0,0,1,0,0,1",
"xs16_5bo3146z032;xs16_5bo3146z32;0;9,-95,15,-91,21,-94;-11,-21;;-2,-89;0,0,1,0,0,1",
"xs16_5bo3146z032;xs16_c871arzx32;0;-8,-36,-1,-53,8,-78;-4,-45;;;0,5,0,1,-1,0",
"xs16_64213ob96;xs16_2ego3qic;0;9,-81,10,-97;-9,-12,-1,-62;;;1,4,1,0,0,-1",
"xs16_64km96zw56;xs16_39mk46zw65;0;20,-104;10,-50;;3,-90;5,0,-1,0,0,1",
"xs16_695q4ozw321;xs15_695q4ozw121;0;16,-74;;;-2,-64;0,0,1,0,0,1",
"xs16_695q4ozw321;xs16_04al5acz311;0;-5,-36;-3,-29;0,-43;;5,0,0,-1,1,0",
"xs16_696ki6zw641;xs16_696ki6zx65;0;10,-85,20,-90,24,-113;;;-6,-81;0,0,1,0,0,1",
"xs16_69960uic;xs14_3560uic;0;3,-28;;;;1,0,1,0,0,1",
"xs16_69960uic;xs14_6530f96;0;;0,-12;;;1,1,1,0,0,1",
"xs16_69acga6zx32;xs16_039q48cz2521;0;4,-55;-8,-13;-2,-42;;6,0,0,-1,1,0",
"xs16_69akg4czx56;xs16_69akg4czx146;0;8,-97;;17,-21;-17,-102,-11,-99,-5,-103;0,0,1,0,0,1",
"xs16_69b88czw652;xs16_0gjlkcz346;0;;;10,-31,18,-12;0,-66,5,-80;0,7,1,0,0,-1",
"xs16_69egmiczx1;xs16_39egmiczx1;0;1,-56;-8,-28,-8,-12;;;0,0,1,0,0,1",
"xs16_69ligozw66;xs16_0gbb8ozc452;0;1,-41;4,-39;-6,-54;;0,7,1,0,0,-1",
"xs16_69p6426z032;xs16_69p6426z32;0;;12,-67;8,-61,14,-33,20,-12;1,-83;0,0,0,1,1,0",
"xs16_8e13kcz0ca1;xs15_8e13kczw65;0;10,-72,18,-82;;;-6,-69;0,0,1,0,0,1",
"xs16_8ehdioz023;xs16_8ehdicz023;0;;;14,-12;0,-58;0,0,1,0,0,1",
"xs16_8ehjzw1012ko;xs16_31246o8zy21248c;0;;-3,-56,8,-74;-5,-58,-2,-68;;-1,-1,0,1,1,0",
"xs16_8k871aczggz11;xs12_252sga6;0;12,-58;;;;0,4,1,0,0,-1",
"xs16_8kid96z641;xs16_69dik8zx56;0;8,-77,18,-82,22,-105;;;-8,-73;5,0,-1,0,0,1",
"xs16_8kid96z641;xs16_8kic871z641;0;;5,-47;8,-33;10,-40;0,0,1,0,0,1",
"xs16_8kk31e8z641;xs16_8kk31e8z065;0;8,-77,18,-82,22,-105;;;-8,-73;0,0,1,0,0,1",
"xs16_8kk31e8z641;xs16_g8861aczc93;0;17,-135;12,-128,14,-66;8,-122,8,-66;9,-120,11,-40;0,-1,1,0,0,1",
"xs16_8kq23zx31e8;xs15_kq23zw31e8;0;2,-44;-4,-20;;;1,0,1,0,0,1",
"xs16_8kq23zx354c;xs15_kq23zw354c;0;2,-44;-4,-20;;;1,0,1,0,0,1",
"xs16_8kq23zxc871;xs17_8kq23zwc4871;0;10,-84;-11,-12;;-9,-99;0,0,1,0,0,1",
"xs16_8ljgzx1pl2;xs15_8ljgzx11da;0;;1,-49;-7,-62,1,-52;;6,9,-1,0,0,-1",
"xs16_8ljgzx1pl2;xs16_8ljgzxd552;0;;2,-68,10,-50;8,-47,9,-59;;6,9,-1,0,0,-1",
"xs16_8o032acz34a4;xs14_ci52zw12453;0;-2,-44;2,-53;-8,-69;;0,8,1,0,0,-1",
"xs16_8o032acz34a4;xs17_8o032ak8z34a4;0;17,-78;;14,-26;1,-65;0,0,1,0,0,1",
"xs16_8ow31e8z34a4;xs17_8o0321e8z34a4;0;-2,-44;3,-52;0,-67;;0,0,1,0,0,1",
"xs16_8ow6996z1226;xs14_0ok21e8z641;0;;3,-57;-1,-42,1,-56,13,-24;6,-62;0,1,0,1,1,0",
"xs16_8u164koz32;xs16_8u16853z32;0;14,-71;9,-46;7,-52;-4,-86,3,-64;0,0,1,0,0,1",
"xs16_bt06426z32;xs16_at16426z32;0;;5,-70;-13,-86,-6,-85,-5,-64;;0,0,1,0,0,1",
"xs16_c48a52z6513;xs16_c48a52z2553;0;7,-72;;;-13,-82;0,0,1,0,0,1",
"xs16_c48a52z6513;xs16_g8jd0eioz01;0;12,-90,21,-107;;;-14,-86;0,0,0,1,1,0",
"xs16_c4o0e96z321;xs16_0259acz2553;0;8,-70;-8,-12;;;-1,0,0,1,1,0",
"xs16_c4o796z321;xs14_65la8czw11;0;11,-73;;;-8,-62;5,0,0,-1,1,0",
"xs16_c4o796z321;xs16_697o4iczx11;0;8,-70;-8,-12;;;5,0,-1,0,0,1",
"xs16_c4o79cz321;xs16_c4o796z321;0;;;13,-12;1,-50;0,0,1,0,0,1",
"xs16_c4o79cz321;xs16_c4o79icz011;0;8,-70;-8,-12;;;5,5,-1,0,0,-1",
"xs16_c88m552z311;xs16_08p7871z321;0;;6,-54;-3,-62,-3,-46;;0,0,0,1,1,0",
"xs16_c8al96z311;xs16_08kaarz6221;0;;11,-54;1,-39;4,-41;5,6,-1,0,0,-1",
"xs16_ca168ozc8421;xs16_0358gz6agc23;0;4,-73,16,-91,23,-102;-9,-32;;-7,-95;0,9,1,0,0,-1",
"xs16_ca230o8zy21248c;xs14_31248gzy212453;0;;9,-59;7,-52;13,-44;10,8,-1,0,0,-1",
"xs16_ca23123z352;xs15_ca23123z33;0;;;;-11,-78;0,0,1,0,0,1",
"xs16_ca23123z352;xs16_0o4c871zbd;0;1,-50;-8,-25;;-9,-70;-2,0,0,1,1,0",
"xs16_ca23146z352;xs15_ca23146z33;0;;;;-11,-78;0,0,1,0,0,1",
"xs16_ca23146z352;xs16_0o4c871z39c;0;1,-50;-8,-25;;-9,-70;-2,0,0,1,1,0",
"xs16_ca23zx624871;xs17_kq23zx624871;0;5,-70;-6,-41;;-10,-82;0,0,1,0,0,1",
"xs16_caarzbd;xs16_caarz39c;0;6,-101;;15,-17;-21,-106,-15,-103,-9,-107;0,0,1,0,0,1",
"xs16_cahdioz023;xs16_cahdicz023;0;;;14,-12;0,-58;0,0,1,0,0,1",
"xs16_caikm96zw1;xs16_caikm93zw1;0;;;14,-28,14,-12;5,-56;0,0,1,0,0,1",
"xs16_ccy1rrz33;xs16_g8kkm96z121;0;5,-54;-7,-12;9,-30;9,-36;1,0,0,1,1,0",
"xs16_ci52z116ak8;xs16_31246o8gka4;0;18,-82,23,-106;;12,-12;-9,-90;4,10,0,-1,-1,0",
"xs16_cila8oz065;xs16_cila8oz641;0;10,-99,16,-95,22,-98;-12,-17;;-3,-93;0,0,1,0,0,1",
"xs16_dbz35ako;xs15_dbgz358go;0;;;8,-12;1,-52;0,0,1,0,0,1",
"xs16_g842156zdl8;xs16_69jzx1231e8;0;3,-58;-10,-17;;-11,-78;6,0,0,-1,1,0",
"xs16_g8421e8zdl8;xs16_32qczx124871;0;3,-58;-10,-17;;-11,-78;-2,8,1,0,0,-1",
"xs16_g8861acz0db;xs16_g8861acz1156;0;-6,-44,1,-61,10,-86;-6,-37;;;0,0,1,0,0,1",
"xs16_g88a53zdl8;xs15_g88a53zdd;0;;;;-13,-82;0,0,1,0,0,1",
"xs16_g88a53zdl8;xs16_32qczx115ac;0;3,-54;-10,-13;;-11,-74;-2,8,1,0,0,-1",
"xs16_g88e13z178c;xs16_0g88e13zol3;0;5,-80,16,-98;;;-13,-82,-10,-92;-1,0,1,0,0,1",
"xs16_g8jdioz123;xs16_g8jdicz123;0;;;14,-12;0,-58;0,0,1,0,0,1",
"xs16_gbaa4zdl8;xs15_gbaa4zdd;0;;;;-13,-78;0,0,1,0,0,1",
"xs16_gbaa4zdl8;xs16_32qczxd552;0;3,-53;-10,-12;;-11,-73;-2,8,1,0,0,-1",
"xs16_gbbo8a6z11;xs16_39u066z65;0;;;11,-34,14,-12;-2,-74,9,-48;0,5,0,1,-1,0",
"xs16_gbbo8a6z11;xs22_8u15a4w4a96z0123;0;1,-79;-6,-40,4,-56;-8,-66,2,-64;;0,4,0,1,-1,0",
"xs16_gjlka4z56;xs16_gilla4z56;0;;1,-40;-5,-50;;0,0,1,0,0,1",
"xs16_gs2596z1226;xs16_04ai31e8z311;0;;5,-47;8,-33;10,-40;0,0,0,1,1,0",
"xs16_gs2596z1ac;xs16_gs24871z1ac;0;;5,-51;8,-37;10,-44;0,0,1,0,0,1",
"xs16_gs2dioz65;xs16_gs2dicz65;0;;;14,-12;0,-58;0,0,1,0,0,1",
"xs16_j9aczdl8;xs15_j9aczdd;0;;;;-13,-74;0,0,1,0,0,1",
"xs16_j9aczdl8;xs16_32qczwc953;0;3,-53;-10,-12;;-11,-73;-2,8,1,0,0,-1",
"xs16_kc32acz1252;xs15_kc32acz123;0;11,-58;;;-7,-58;0,0,1,0,0,1",
"xs16_kc32acz1252;xs16_0kc3215a4z32;0;;;1,-70,12,-44;6,-62,9,-40;0,-1,0,1,1,0",
"xs16_ml2z1248a52;xs15_ok215a4z66;0;;;-4,-50;;0,8,1,0,0,-1",
"xs16_ml2z1248a52;xs16_ci52zw1231e8;0;-1,-53;-6,-22;-2,-42;;6,8,0,-1,-1,0",
"xs16_mmy1rrz11;xs16_g2u0uh3z11;0;;-8,-12;;11,-32;7,0,-1,0,0,1",
"xs16_o8bdzw178c;xs16_db8oz3lo;0;7,-72,18,-90;;;-11,-74,-8,-84;3,0,-1,0,0,1",
"xs16_o8bdzx3156;xs16_o8bdzx3552;0;19,-86;;;-1,-76;0,0,1,0,0,1",
"xs16_ogil96z66;xs16_0g88brzc452;0;;11,-54;1,-39;4,-41;5,7,-1,0,0,-1",
"xs16_ol3z6ahzw23;xs15_3lozha6z11;0;13,-77;;;-17,-90,-9,-80;2,0,-1,0,0,1",
"xs16_ol3zw343146;xs16_ol3zw343123;0;;;14,-15;0,-75,10,-40,14,-47;0,0,1,0,0,1",
"xs16_ra16426z23;xs16_5bo3123z32;0;;12,-67;8,-61,14,-33,20,-12;1,-83;0,0,0,1,1,0",
"xs16_ra16426z23;xs16_ra178cz23;0;;5,-63;-9,-70,-2,-59,7,-48;;0,0,1,0,0,1",
"xs16_w8o69a4z6521;xs15_w8o69a4z2521;0;15,-70;;;-5,-60;0,0,1,0,0,1",
"xs16_wg842130352z65;xs15_wg84213033z65;0;;;;14,-40;0,0,1,0,0,1",
"xs16_wg842130352z65;xs16_178c48gzy312ko;0;;13,-63;4,-52;12,-40;10,-2,-1,0,0,1",
"xs16_wg842ticz65;xs15_0g842ticz32;0;8,-69,16,-79;;;-6,-66;1,0,1,0,0,1",
"xs16_wg84c0c453z65;xs16_g84213zd553;0;16,-83;;15,-32,23,-12;0,-68,7,-63;0,2,0,1,1,0",
"xs16_wgs2596z643;xs16_3ia4zw1132ac;0;;7,-47;10,-33;12,-40;8,0,0,-1,1,0",
"xs16_wj96zmlz121;xs15_wj96zmlz11;0;;;;-15,-86;0,0,1,0,0,1",
"xs16_wj96zmlz121;xs16_y0j96zggmdz1;0;5,-69;-12,-12;;-13,-89;-2,0,1,0,0,1",
"xs16_wo443123zbd;xs16_wo443146zbd;0;6,-121;;15,-37;-21,-126,-15,-123,-9,-127;0,0,0,1,1,0",
"xs16_x8ka53zad11;xs15_x8ka52zad11;0;;5,-32;-1,-42;;0,0,1,0,0,1",
"xs16_xg842132acz321;xs16_y0g853z0cq1z65;0;;;7,-66,18,-40;12,-58,15,-36;0,-1,0,1,1,0",
"xs16_xg853zca1z352;xs15_xg853zca1z33;0;;;;-16,-98;0,0,1,0,0,1",
"xs16_xg853zca1z352;xs16_178c48gzy31248c;0;6,-77;-13,-12;;-14,-97;-2,11,0,1,-1,0",
"xs16_xgil96zc452;xs16_3ia4zw115a8o;0;;13,-62;3,-47;6,-49;7,-1,-1,0,0,1",
"xs16_y2696z4aa4zyd66;xs31_33ye66zwg8oy066y433z69mic;0;;4,-180,21,-94;21,-103;18,-206,28,-135;27,8,0,-1,-1,0",
"xs17_0358gzgs259c;xs16_0ol3z6421e8;0;;2,-40,10,-50;2,-37;;5,1,-1,0,0,1",
"xs17_064pb8oz2521;xs14_09fg4cz321;0;-1,-40,4,-62,13,-81;-2,-47;;-4,-69;6,5,0,-1,-1,0",
"xs17_08kk3123zok21;xs16_3loz122c84c;0;10,-73,18,-83;;;-8,-70;1,8,1,0,0,-1",
"xs17_08kk3146zok21;xs16_3loz122c826;0;10,-73,18,-83;;;-8,-70;1,8,1,0,0,-1",
"xs17_08o032acz69k8;xs15_ci52zw1248a6;0;-1,-48;3,-57;-7,-73;;0,9,1,0,0,-1",
"xs17_0bdz65139c;xs15_39c88gzxbd;0;3,-67;-8,-12;;;5,8,-1,0,0,-1",
"xs17_0brz4ab413;xs13_o4pb8oz01;0;;;0,-30;;5,8,0,-1,-1,0",
"xs17_0c9jz6512213;xs16_0c9jz651226;0;;;11,-34,19,-12;-1,-79;0,0,1,0,0,1",
"xs17_0g8hv04acz23;xs16_0g8hv04a4z23;0;;;14,-12;7,-51;0,0,1,0,0,1",
"xs17_0ggca52z349go;xs16_3123ckg853;0;0,-48;;-7,-79;4,-71;4,0,0,-1,1,0",
"xs17_0ggca52z349go;xs16_8o6512koz32;0;20,-90;5,-63;17,-18;3,-64;0,2,0,1,1,0",
"xs17_0gs25ak8z1246;xs16_4ap30ga6zw121;0;18,-102;17,-78;6,-65;-3,-93,1,-152,4,-92;0,7,1,0,0,-1",
"xs17_252s0gzy0116ak8;xs16_bdggzw122ak8;0;17,-101;7,-38;;12,-65;9,7,0,-1,-1,0",
"xs17_252z08kk8gzy034a4;xs13_0g4q552z121;0;;;-2,-46;;7,7,-1,0,0,1",
"xs17_2552y0ciczw6a4;xp2_0ggw7z1221y0696zw352;0;;15,-70;1,-60;;0,-4,1,0,0,1",
"xs17_2552y3oozzy98kic;xs25_w33ycgzyc6a8pa9oz0gz343;0;-2,-84,5,-68;-4,-78;;;13,18,-1,0,0,-1",
"xs17_255q8a6z0321;xs16_696o8a6z032;0;-25,-36;32,-246;-15,-229,9,-170;16,-143,18,-153;0,0,0,1,1,0",
"xs17_255q8a6z0321;xs16_696o8a6zw32;0;;;7,-38,14,-12;0,-62;0,0,0,1,1,0",
"xs17_259m86248go;xs16_03loz25aic;0;;;12,-23;6,-50,14,-28;9,4,0,-1,-1,0",
"xs17_2ego4431248c;xs16_2ego4431246;0;;;12,-31;8,-50,16,-28;0,0,1,0,0,1",
"xs17_2ll2sgzw343;xs15_4aar2qk;0;-4,-58;;-3,-78,4,-62;12,-40;5,7,0,-1,-1,0",
"xs17_2lmgmaz056;xs16_321fgbr;0;-2,-40;1,-42;;;1,7,0,1,-1,0",
"xs17_32138f12ko;xs16_db0gz3lp1;0;17,-99;12,-58;;-1,-84,17,-45;0,0,0,1,1,0",
"xs17_321egozy235a4;xs16_5b88gzx11mq;0;16,-97;8,-42;;13,-61;0,0,0,1,1,0",
"xs17_354mp3zcc;xs13_354mp3;0;9,-46;;;;0,0,1,0,0,1",
"xs17_358gzw358gka4;xs16_0ok215a4zca1;0;;1,-41,9,-51;1,-38;;1,9,1,0,0,-1",
"xs17_35a88gzca511;xs16_25a88gzca511;0;;6,-61;-4,-46;;0,0,1,0,0,1",
"xs17_39cggkcz0643;xs13_39cggkczx1;0;;;;-7,-62;0,0,1,0,0,1",
"xs17_39cz65139c;xs15_g88c93zc93;0;3,-67;-8,-12;;;0,8,1,0,0,-1",
"xs17_3iakg8oz643;xs16_39m88cz6221;0;;;9,-34,17,-12;1,-63;0,7,1,0,0,-1",
"xs17_3iar2qkzw1;xs16_32qr2qk;0;6,-52;;;-7,-62;0,0,1,0,0,1",
"xs17_3lka246z056;xs16_32akl3zx65;0;;;6,-51;4,-62,12,-40;5,0,-1,0,0,1",
"xs17_3p6gzw116ak8;xs16_3p6gzw11mq;0;;-8,-12;14,-35;-15,-115;0,0,1,0,0,1",
"xs17_3p6gzw116ak8;xs16_ggca2453z65;0;15,-103;12,-58;13,-32;9,-58;0,7,0,1,-1,0",
"xs17_4a51i4ozxbc1;xs16_4a51i4ozw4701;0;11,-73;;;-13,-86,-5,-76;0,0,1,0,0,1",
"xs17_4aab9czw652;xs16_4aab9czw252;0;12,-77;;;-9,-66;0,0,1,0,0,1",
"xs17_4ai31248czx123;xs16_ckw3lozw1243;0;;;9,-39;5,-58,13,-36;7,6,0,-1,-1,0",
"xs17_4ai3gzx116ak8;xs16_4ai3gzx11mq;0;;-7,-12;15,-35;-14,-115;0,0,1,0,0,1",
"xs17_4ai3gzx116ak8;xs16_wok21e8zdb;0;16,-107;13,-62;14,-36;10,-62;0,7,0,1,-1,0",
"xs17_4ap56zw12552;xs14_354cj96;0;;;;-1,-40;4,6,0,-1,-1,0",
"xs17_4ap56zw12552;xs15_065pa4z2521;0;13,-66;;12,-12;2,-52;5,0,-1,0,0,1",
"xs17_64kb2ak8z032;xs16_64kb2acz032;0;;;11,-12;5,-36;0,0,1,0,0,1",
"xs17_696zw259ar;xs15_c88m96z311;0;3,-48;-2,-18;2,-27;;6,3,-1,0,0,1",
"xs17_696zw4a96wcc;xs16_gs2dioz65;0;-2,-336,1,-65,9,-211,13,-571;-16,-12;;-29,-256;8,5,0,-1,1,0",
"xs17_69baa4z253;xs17_4aab9czw652;0;-3,-57;-6,-46,1,-66;13,-12;-9,-93;5,0,-1,0,0,1",
"xs17_69jzw230o8a6;xs15_69jzx1248a6;0;13,-93;-9,-12;;-15,-109;0,0,1,0,0,1",
"xs17_8k453z110c453;xs15_69jwo4czx121;0;10,-85;-10,-12;;-16,-101;6,7,0,-1,-1,0",
"xs17_8kq23zwc4871;xs20_yf33z8kih321e8zx1;0;-12,-44;-11,-69,-7,-113,8,-123;;-13,-149;-4,8,0,1,-1,0",
"xs17_8o0321e8z34a4;xs15_ci52zw124871;0;-7,-44;-1,-52;-3,-59;;0,8,1,0,0,-1",
"xs17_8o032acz34ac;xs15_ci53zw12453;0;-2,-44;2,-53;-8,-69;;0,8,1,0,0,-1",
"xs17_8o032ak8z34a4;xs15_g84215a4z1252;0;-2,-45;2,-54;-8,-70;;0,1,1,0,0,1",
"xs17_c4j146z011w352;xs16_ck312kozw123;0;15,-89,18,-82;;16,-17;-3,-92,6,-73;0,0,1,0,0,1",
"xs17_caab8oz0256;xs16_caab8oz0252;0;14,-66;;;-7,-77;0,0,1,0,0,1",
"xs17_ciligozwca4;xs16_ciligozw4a4;0;13,-81;;;-10,-70;0,0,1,0,0,1",
"xs17_ckg8jdz643;xs16_039m453z311;0;;5,-52,13,-62;5,-49;;0,1,0,1,1,0",
"xs17_g853z11642ak8;xs16_ol3zw3215a4;0;;2,-49;-6,-62,2,-52;;0,1,1,0,0,1",
"xs17_ggxok2156z1226;xs15_69jzx1i4ozy011;0;16,-83;;20,-12;0,-76;10,0,0,-1,1,0",
"xs17_gjlka4z1ac;xs16_gjlka4z56;0;9,-77;;;-15,-90,-7,-80;0,0,1,0,0,1",
"xs17_kq23zx624871;xs15_4ai3zx124871;0;6,-76;-14,-12;;-10,-83;0,0,1,0,0,1",
"xs17_o4s3qp3z01;xs16_3pq3pm;0;0,-32;-5,-23;;;6,0,-1,0,0,1",
"xs17_ok8y5696zw4aa4;xs21_32qkz321023x4aa4;0;;-19,-12,10,-76;;-14,-134,5,-123,14,-109;4,4,1,0,0,-1",
"xs17_w8o6piczca1;xs16_08o6picz65;0;9,-69,17,-79;;;-7,-66;1,0,1,0,0,1",
"xs17_w8u16413zca1;xs16_08u16413z65;0;9,-73,17,-83;;;-7,-70;1,0,1,0,0,1",
"xs17_wggraa4z696;xs14_0ggraa4z32;0;9,-46;;;;1,0,1,0,0,1",
"xs17_x8ka53z255d;xs16_x8ka52z255d;0;;5,-32;-1,-42;;0,0,1,0,0,1",
"xs18_033z628czw31156;xs14_08o0uh3z32;0;;;1,-30;;6,6,0,-1,1,0",
"xs18_08u1u8zc4521;xs16_25b8raa4;0;6,-91;-11,-12;;-7,-86;1,7,0,1,-1,0",
"xs18_09v0ca52z321;xs16_09v0ca4z321;0;;;6,-38;9,-36;0,0,1,0,0,1",
"xs18_0bdggkcz4a43;xs14_252sgz0db;0;;;;4,-44;0,8,1,0,0,-1",
"xs18_0brzcib413;xs14_69q4goz023;0;;3,-22;;;0,9,1,0,0,-1",
"xs18_0dbgz259ar;xs22_178jd2c84czy0cc;0;1,-48;-9,-20;;;4,9,0,-1,-1,0",
"xs18_0g2552z343y48kk8;xs16_699mkiczx1;0;31,-134;;20,-123,29,-48;;6,5,0,-1,1,0",
"xs18_0gj3z1qm1e8;xs14_6ikm96z01;0;;2,-18;;;0,9,0,1,-1,0",
"xs18_0gw628c4871z343;xs12_1784c826;0;8,-42;;;;11,0,-1,0,0,1",
"xs18_0o4ai3z11wo9a4;xs14_4ai3zwo9a4;0;0,-48;-3,-26;;;2,0,1,0,0,1",
"xs18_1784264kozx66;xs14_1784264ko;0;9,-46;;;;0,0,1,0,0,1",
"xs18_178kk8zccz33;xs19_0rbgzggm926z1;0;11,-100,19,-86;-8,-36;8,-57,13,-34;;10,0,0,-1,1,0",
"xs18_32ak8zy0113y0cic;xs12_0g8k871z23;0;;;;3,-50;6,0,0,-1,1,0",
"xs18_39cggka4z0643;xs14_0252sgz6413;0;;;;-7,-66;7,0,0,-1,1,0",
"xs18_3hu0oi6y0cc;xs14_3hu0oi6;0;;;;9,-28;0,0,1,0,0,1",
"xs18_6512koz4aa43;xs15_6512kozw643;0;8,-44;;;;0,0,1,0,0,1",
"xs18_653zy5oozy96996;xs26_y9ggx256z628q552y11221z032;0;20,-133;18,-105;;-12,-150,-11,-118,0,-210,13,-177;-4,1,1,0,0,1",
"xs18_696z0gw2552z343;xs20_dj8r54czzy533;0;18,-339,21,-210,45,-237;7,-104,18,-200,19,-86;25,-188,42,-104;1,-227,16,-229;25,4,0,-1,1,0",
"xs18_6996z0g88a6z023;xs22_cky06952zwhik8z056;0;;;-1,-58,9,-45;4,-56;0,-1,1,0,0,1",
"xs18_6996z0g88a6z121;xs22_cky06952zwhik8z252;0;;;-1,-58,9,-45;4,-56;0,-1,1,0,0,1",
"xs18_8k4raa4y333zw1;xs14_4a9mkk8zx1;0;;;16,-12;;0,5,1,0,0,-1",
"xs18_bdggx696zw1023;xs12_8o6413z32;0;;;8,-14;;0,6,1,0,0,-1",
"xs18_bt0uh3z23;xs16_32qbap3;0;;;4,-58,6,-40;7,-36;0,6,0,1,-1,0",
"xs18_c9jx66z354c;xs14_c9jz354c;0;;;8,-12;;0,0,1,0,0,1",
"xs18_g6p56z11y12552;xs12_354qic;0;14,-66;;;;0,5,0,1,-1,0",
"xs18_g8g031460696z121;xs12_2ll2z641;0;7,-38;;;;11,0,0,-1,1,0",
"xs18_g8g031460uiz121;xs12_31460ui;0;7,-38;;;;4,0,1,0,0,1",
"xs18_gbrz56o8go;xs14_mp3zw3123;0;;3,-22;;;0,3,1,0,0,1",
"xs18_gs2552zdmz11;xs15_drz3ego;0;;;5,-12;;0,10,1,0,0,-1",
"xs18_gs2552zdmz11;xs16_25a8og8og8o;0;;5,-50;8,-36;4,-52;4,0,0,-1,1,0",
"xs18_j1u0uh3z11;xs16_3lkq23z32;0;14,-78;;15,-12;1,-82;0,0,0,1,1,0",
"xs18_j5o652zdd;xs14_j5o652z11;0;9,-46;;;;0,0,1,0,0,1",
"xs18_o4q231248a6z01;xs15_31eozcip;0;6,-34;;;;1,3,0,1,-1,0",
"xs18_o80g8k8w33zwdb;xs14_0j9c84cz121;0;;;10,-12;;0,2,0,1,1,0",
"xs18_oe12koy0ooz23;xs14_oe12koz23;0;;;;5,-36;0,0,1,0,0,1",
"xs18_og8objozzx33;xs14_3123qp3;0;;;;-9,-70;0,4,1,0,0,-1",
"xs18_rry466zx653;xs15_4al5ak8zx11;0;2,-185,19,-124;-13,-12,-4,-145;25,-240,27,-16;-5,-128,13,-280;10,13,0,1,1,0",
"xs18_wggo8brz696;xs15_0ggo8brz32;0;9,-46;;;;1,0,1,0,0,1",
"xs18_wggo8brz696;xs16_oggo8a52z66;0;12,-74;-7,-12;;-8,-74;7,7,-1,0,0,-1",
"xs18_wggraicz696;xs15_0ggraicz32;0;9,-46;;;;1,0,1,0,0,1",
"xs18_wggraicz696;xs16_wggraicz252;0;12,-74;-7,-12;;-8,-74;0,0,1,0,0,1",
"xs18_wggrb8oz696;xs15_0ggrb8oz32;0;9,-46;;;;1,0,1,0,0,1",
"xs18_wggrb8oz696;xs16_wggrb8oz252;0;12,-74;-7,-12;;-8,-74;0,0,1,0,0,1",
"xs18_y533zzz3146k46zx121;xs14_09v04a4z32;0;;;10,-12;;6,15,0,-1,1,0",
"xs18_y633z6ikm93z01;xs14_6ikm93z01;0;;;10,-14;;0,5,1,0,0,1",
"xs19_033z628czw3115a4;xs15_w4s0c93z2521;0;;;1,-34;;0,13,0,1,-1,0",
"xs19_033zc826z3115a4;xs15_mkhjz1w252;0;;2,-18;;;0,6,1,0,0,1",
"xs19_08e13zc93zx2552;xs13_08e13zc93;0;;;;-6,-60;0,0,1,0,0,1",
"xs19_08e13zoi6zx4aa4;xs13_08e13zoi6;0;;;;-7,-64;0,0,1,0,0,1",
"xs19_08o6413z69cz033;xs15_08o6413z69c;0;;;;-10,-74;0,0,1,0,0,1",
"xs19_0ggc93zcipz066;xs15_0ggc93zcip;0;;;;-11,-74;0,0,1,0,0,1",
"xs19_0gw628c48a52z343;xs13_ci52z39c;0;8,-42;;;;12,3,0,-1,-1,0",
"xs19_0j9cga6z121zw33;xs15_0j9cga6z121;0;13,-62;;;;0,0,1,0,0,1",
"xs19_0rbgzggm926z1;xs15_03p68oz6221;0;;3,-22;;;0,3,1,0,0,1",
"xs19_25ao4kozw23y0cc;xs15_0g6pb8oz121;0;;;;2,-44;6,0,0,-1,1,0",
"xs19_2lm0ml2zw343;xs17_2ll2sgzw343;0;;1,-84;-17,-102,-8,-85;;6,0,-1,0,0,1",
"xs19_2lmz3kpzx352;xs14_08o652z69c;0;;0,-12;;;0,12,1,0,0,-1",
"xs19_32q4gozx1246zy4cc;xs15_0g8im853z23;0;;;;-6,-70;6,0,0,-1,1,0",
"xs19_33wkczx34315a4;xs15_0i5t246z121;0;;-1,-12;;;3,8,0,1,-1,0",
"xs19_354czx6248c453;xs23_x8kih32aczccwg8hzy11;0;8,-83;-7,-12,7,-48;8,-32;;0,8,1,0,0,-1",
"xs19_35icga6zw1po;xs15_0j9akoz321;0;13,-62;;;;6,0,0,-1,1,0",
"xs19_39eg8ozrq1;xs15_39eg8oz321;0;10,-50;;;;0,0,1,0,0,1",
"xs19_3lozg4cz1108kk8;xs13_31246w6413;0;;;;-8,-68;0,0,0,1,1,0",
"xs19_4a9jwcczx1qm;xs15_4a9jzx1qm;0;;;8,-12;;0,0,1,0,0,1",
"xs19_4ai3146zx123y433;xs15_4ai3146zx123;0;;;18,-12;;0,0,1,0,0,1",
"xs19_6246p6gxoozy1121;xs15_8kk8a52z065;0;;;12,-12;;7,0,0,-1,1,0",
"xs19_6246pa4z25521;xs16_4ap64koz032;0;7,-40;;;;6,0,0,-1,1,0",
"xs19_6ik8a52z121y5cc;xs15_0j5o652z121;0;;;;5,-44;0,0,0,1,1,0",
"xs19_9f0cia4zy7653;xs13_4a960ui;0;;;;6,-40;6,4,-1,0,0,-1",
"xs19_cahegoz023z33;xs15_cahegoz023;0;;;;-11,-74;0,0,1,0,0,1",
"xs19_cky06952zwhik8zw1;xs12_4ai3zx1ac;0;;;9,-12;;5,10,-1,0,0,-1",
"xs19_i5q8a52zdd;xs15_2l2s53z121;0;9,-46;;;;0,0,0,1,1,0",
"xs19_o97o4cx66zw121;xs15_c8idioz023;0;;;11,-12;;0,6,1,0,0,-1",
"xs19_wcq1e8z2521z033;xs15_8e1qczx1252;0;12,-58;;;;6,0,-1,0,0,1",
"xs19_wg8gka6w33z2543;xs15_69ak8zx1256;0;;;;9,-40;0,7,0,1,-1,0",
"xs19_y533zzz3146k46zx123;xs15_09v04a6z32;0;;;10,-12;;6,15,0,-1,1,0",
"xs19_y533zzz3146k46zx321;xs15_09v04acz32;0;;;10,-12;;6,15,0,-1,1,0",
"xs20_0256o8a6zciic;xs16_32qjc453;0;-2,-75,7,-104;;-9,-91,15,-38;-19,-114;0,1,1,0,0,1",
"xs20_033zj9ajkcz11;xs16_j9ajkcz11;0;;3,-22;;;0,5,1,0,0,1",
"xs20_033zzdj8ria4;xs16_4a9r2pm;0;;1,-14;;;6,14,-1,0,0,-1",
"xs20_0354kmz0gg0146z1221;xs14_0mk453z641;0;11,-56;;;;6,0,-1,0,0,1",
"xs20_03jz254rai3zy01;xs16_4a9mk46zx121;0;;;1,-30;;0,4,1,0,0,1",
"xs20_06icw352z2ehp;xs15_jhe8z69c;0;;;8,-12;;3,9,-1,0,0,-1",
"xs20_09v0ckz32w110oo;xs16_39s0qmz023;0;;;;-2,-50;0,6,1,0,0,-1",
"xs20_0c4lb871zoo11;xs16_c87p46z311;0;9,-48;;;;1,0,0,1,1,0",
"xs20_0gw628c0fhoz343;xs14_3hu0628c;0;8,-42;;;;11,4,-1,0,0,-1",
"xs20_0iu0dbxccz641;xs16_0iu0dbz641;0;;;;7,-40;0,0,1,0,0,1",
"xs20_178brzy36996;xs14_178bp46;0;;;10,-27;10,-44;0,0,1,0,0,1",
"xs20_253ggzwoh4f033;xs15_39c8a6zx33;0;3,-48;;;;2,9,0,1,-1,0",
"xs20_259acx33zw3552;xs16_g8jdioz123;0;-2,-40;3,-50,12,-63;2,-46,14,-29;4,-54;8,7,0,-1,-1,0",
"xs20_2llicz1226y1cc;xs16_2ege1dic;0;;;;3,-44;4,7,0,-1,-1,0",
"xs20_32qkg8gzxca10cc;xs16_0g8it248cz23;0;;;;0,-44;6,0,0,-1,1,0",
"xs20_33g8o6530oozw11;xs15_c9jz6a9o;0;16,-74;;;-7,-90,6,-80;2,10,1,0,0,-1",
"xs20_33xgzw6s1e96zw11;xs16_co2ticz23;0;;1,-14;;;2,4,1,0,0,1",
"xs20_35acggx696zy01023;xs14_0ggca53z641;0;;;10,-14;;0,6,0,1,-1,0",
"xs20_3hu0og4czy5696;xs14_3hu0og4c;0;;;;2,-46;0,0,1,0,0,1",
"xs20_4a5lmzw11023zya33;xs16_0co2ticz32;0;;;;4,-56;0,6,0,1,-1,0",
"xs20_4a6y9696x8kczy7cc;xs15_db0ga6z311;0;;14,-108,28,-122;2,-99,10,-120;4,-226,17,-174;2,7,-1,0,0,-1",
"xs20_4a9la8ozx121zzcc;xs16_4a9la8ozx121;0;19,-86;;;;0,0,1,0,0,1",
"xs20_62s53y0ccz39c;xs16_3pm44og4c;0;;;;8,-44;4,0,0,-1,1,0",
"xs20_64kb9k8woozw121;xs16_c8idik8z023;0;;;;6,-36;6,0,0,-1,1,0",
"xs20_6960tby1cczy023;xs16_bt0696z32;0;;;15,-12;;5,0,-1,0,0,1",
"xs20_696wggzwgilc1z032;xs14_3pa4zw1156;0;;1,-14;;;6,4,-1,0,0,1",
"xs20_697079iczxcc;xs16_697079ic;0;;;;-5,-58;0,0,1,0,0,1",
"xs20_8e13iak8zw6521;xs22_0696zog8421eozy0311;0;;;16,-12;-1,-79;11,7,0,-1,-1,0",
"xs20_8ox2552zjicz56;xs14_dbgzmq1;0;;;;6,-60;0,3,1,0,0,1",
"xs20_dj8r54czzy533;xs16_64kr2pm;0;;;;-2,-58;6,4,-1,0,0,-1",
"xs20_g85r8b5zpp;xs16_08eharz321;0;9,-48;;;;6,5,0,-1,-1,0",
"xs20_g8g031460uh3z121;xs14_31460uh3;0;7,-38;;;;4,0,1,0,0,1",
"xs20_j1u0oi6z11zy2oo;xs16_j1u06ioz11;0;;;;-8,-70;0,5,1,0,0,-1",
"xs20_w33z0c88gkczca23;xs16_0jiq453z32;0;;2,-18;;;0,7,1,0,0,1",
"xs20_ya33x33zo4ow4aa4z01;xs16_696ki6zw641;0;-4,-83,-4,-63;1,-62,6,-59;7,-62;;12,2,0,-1,-1,0",
"xs20_yf33z8kih321e8zx1;xs16_kq23z124871;0;;19,-86;;;8,5,0,-1,1,0",
"xs21_0gw628c2djoz343;xs15_3pm8628c;0;8,-42;;;;11,4,-1,0,0,-1",
"xs21_178j1246zw11zw8kk8;xs15_c842arzx65;0;16,-74;;;;0,5,0,1,-1,0",
"xs21_321j4k8zx11zzy5ccwoo;xs13_o861acz23;0;32,-138;;;;6,0,0,-1,1,0",
"xs21_32qkz321023x4aa4;xs15_31ek13z311;0;;;;4,-44;0,6,1,0,0,-1",
"xs21_4ai3y0o4oz011628cw1;xs15_08o6413z254c;0;;;11,-12;;0,8,1,0,0,-1",
"xs21_4s0v1aczwdl8;xs16_4s0v1aczw11;0;;;;-5,-54;0,0,1,0,0,1",
"xs21_ca4wo4o7piczy21;xs16_o4o7picz01;0;;-3,-12;;;5,0,1,0,0,1",
"xs21_ckljgx696zx1023;xs15_08u178cz32;0;;;9,-14;;0,6,0,1,-1,0",
"xs21_g88cy733z19lp13;xs17_caab8oz0256;0;;;16,-12;;0,2,1,0,0,1",
"xs21_ggxmqw6952z101243;xs14_oe1248cz23;0;;;12,-12;;6,7,-1,0,0,-1",
"xs21_gieg8ox35a4z1023;xs14_64kb9czw11;0;;;18,-12;;0,1,0,1,1,0",
"xs21_ogkai3zw65zzzy4cic;xs15_3iakgozw56;0;;;;-15,-110;5,0,-1,0,0,1",
"xs21_ok461u8z6a4x23;xs16_08u16853z32;0;4,-71;-1,-56;-3,-50;-6,-83;7,0,-1,0,0,1",
"xs21_yf696zcikm9a4zx1;xs15_4a9mkiczx1;0;;;20,-14;;6,5,-1,0,0,1",
"xs22_0358mkl3zy21z4aa4;xs16_39ege2z321;0;13,-64;;;;7,0,0,-1,1,0",
"xs22_0696zog8421eozy0311;xs16_4ai31e8zx56;0;;5,-30;;;7,5,0,-1,1,0",
"xs22_0g88g069a4xck8zw11z33;xs16_02egdbz2521;0;;;25,-12,30,-27,35,-37,39,-72;-3,-135,9,-232,11,-123;1,9,1,0,0,1",
"xs22_178jd2c84czy0cc;xs16_ca5la4z311;0;;;11,-16;0,-46;6,0,0,-1,1,0",
"xs22_2552z0o8zkq3og4c;xs16_5bo3146z032;0;;;3,-22;;0,14,1,0,0,-1",
"xs22_2596wok8z2eg853;xs15_xok21e8z253;0;;0,-12;;;8,9,-1,0,0,-1",
"xs22_2596wqmzy33421e8;xs15_gs24871z56;0;;0,-12;;;6,8,1,0,0,-1",
"xs22_3lc2pmz011zy3cic;xs16_i5pajoz11;0;;;;-6,-70;5,0,0,-1,1,0",
"xs22_3lm88gy92552z32011;xs16_3lkaa4z321;0;;;22,-12;;0,6,1,0,0,-1",
"xs22_4a9r8jdyccic;xs16_4a9r8jd;0;;;25,-12;;0,0,1,0,0,1",
"xs22_4aakl3zx56y24aa4;xs16_3lkaa4z065;0;;;;6,-44;5,0,-1,0,0,1",
"xs22_4acwo4q552z253x1;xs16_69m88cz6221;0;2,-82,10,-95,23,-102;3,-66;-2,-74,16,-31;;10,0,0,-1,1,0",
"xs22_4aic871w696zx123;xs16_178cia4z0321;0;;;10,-14;;6,0,-1,0,0,1",
"xs22_4aq4871zw123y0696;xs16_069m4koz311;0;;;;2,-46;0,0,0,1,1,0",
"xs22_653g8k48gzw349611;xs16_4a9la4ozx121;0;;0,-12;;;8,2,-1,0,0,1",
"xs22_8ka9mggzx12218kk8;xs16_g8idik8z123;0;;;;1,-48;0,6,0,1,-1,0",
"xs22_8u15a4w4a96z0123;xs15_ciaj2aczw1;0;;;10,-14;;0,0,0,1,1,0",
"xs22_c84q96zx123y36952;xs15_69q48cz321;0;;;;8,-44;5,0,-1,0,0,1",
"xs22_cky06952zwhik8z056;xs15_g0g8421eg8oz11;0;;;9,-12;;5,2,0,-1,1,0",
"xs22_cky06952zwhik8z252;xs15_358gzg8k452z01;0;;;9,-12;;0,2,1,0,0,1",
"xs22_dj8r5gzy011zy54aa4;xs16_g5r8jdz11;0;;;;-1,-64;5,0,-1,0,0,1",
"xs22_g8e13xcicz011db;xs16_321fgc453;0;;;10,-12;;4,8,0,-1,-1,0",
"xs22_gs2ibq23z47011;xs16_gs2ib8ozx32;0;9,-76;;8,-42;-11,-82,10,-40;0,0,1,0,0,1",
"xs22_o861acy18k8z023zyb652;xs13_ca168ozx32;0;;;16,-14;;5,0,-1,0,0,1",
"xs22_o8gxmqw6952zx1243;xs15_3213ia4zw65;0;;;13,-12;;7,1,0,-1,1,0",
"xs22_x696zj5o64213z11;xs16_39q453z65;0;;;1,-34;;0,5,0,1,1,0",
"xs22_xkq2raiczo4oz01;xs16_5b8ra96;0;11,-54;;;;3,4,1,0,0,-1",
"xs23_33y3o48gzwooy2116aic;xs15_0ggca96z3421;0;10,-50;0,-21;;;9,9,1,0,0,-1",
"xs23_3jgy4cicz3421gzx343;xs16_4aqb96z32;0;;16,-74;;-13,-165;3,12,1,0,0,-1",
"xs23_64kb2ak8z032y1696;xs17_64kb2ak8z032;0;;;;1,-46;0,0,1,0,0,1",
"xs23_g8e13w4a96z0113123;xs16_8u164koz32;0;;;9,-14;;0,6,0,1,-1,0",
"xs23_ggdb8ow8kicz03421;xs16_8ehikozw56;0;;;11,-12;;0,7,1,0,0,-1",
"xs23_o4iege2y32596z0121;xs16_ca9la4z311;0;;;15,-18;;0,1,0,1,1,0",
"xs23_wgxmqw6952z4701243;xs16_oe124871z23;0;;;13,-12;;7,7,-1,0,0,-1",
"xs23_wmll2y96952z65201;xs16_0c8a53z2553;0;;;22,-12;;5,7,-1,0,0,-1",
"xs23_x8kih32aczccwg8hzy11;xs15_8e12kozw643;0;14,-66;;;;3,5,0,1,-1,0",
"xs23_xmp3zoo12453zy433;xs15_69jc48a6;0;8,-56;;;-1,-64;6,7,0,-1,-1,0",
"xs23_y32596zwgzq6h156z0121;xs16_kc32acz1252;0;;;;6,-76;0,9,1,0,0,1",
"xs24_0ggci96y666z643y1ck8;xs15_0ggci96z643;0;;;;1,-78,16,-50;0,0,1,0,0,1",
"xs24_33x32qjap3zyd66;xs16_32qjap3;0;2,-40;;;10,-64;5,0,1,0,0,1",
"xs24_4akg8k8y26520oozx346;xs15_0i5q8a6z121;0;;;14,-26;;6,1,0,-1,1,0",
"xs24_y0259m861aczjjz11;xs16_259m861ac;0;8,-52;;;;4,0,1,0,0,1",
"xs24_y1696z2552wgw2552zy1343;xs18_696z0gw2552z343;0;;;;-6,-82;0,7,0,1,-1,0",
"xs25_652y4o4czcicy117853;xs14_0cq1e8z321;0;;;;-13,-114;13,8,-1,0,0,-1",
"xs25_w33ycgzyc6a8pa9oz0gz343;xs15_3iaj2aczw1;0;18,-90;4,-26;;;22,9,-1,0,0,-1",
"xs25_x252zzck8wckg8gzxoi6221;xs16_0gjlka4z641;0;14,-88;7,-40;;;3,12,1,0,0,1",
"xs25_x8kc3pcy0ck8zy3123zcc;xs16_0cp3ck8z321;0;14,-104;;;10,-64;9,0,-1,0,0,1",
"xs26_652y2o8zy23p69czy211y24a6;xs16_32qk5b8o;0;;0,-12;;3,-64;10,3,0,-1,1,0",
"xs26_6952zzyp33zybo8zy869jc23;xs15_cip68ozx32;0;4,-108;;;20,-138;12,24,1,0,0,-1",
"xs26_6996y4ciiczy02egma;xs21_yf696zcikm9a4zx1;0;;9,-59;7,-42,11,-54,23,-23;6,-74;14,9,0,-1,-1,0",
"xs26_c4g0696z69pz32w696;xs14_c9jz6ip;0;;;5,-14;-8,-66;2,2,-1,0,0,1",
"xs26_y9ggx256z628q552y11221z032;xs15_628q552z032;0;;14,-66;;;0,5,1,0,0,1",
"xs27_ojd44og4czy6ciczya4a6;xs16_35s26z39c;0;23,-102;;;;0,4,0,1,-1,0",
"xs28_04air9icy54aa4zcik8;xs15_4a9ri96;0;;;21,-74;-6,-114;1,4,1,0,0,-1",
"xs28_5b8r5gxo4oz0o4o121x1zw1;xs16_0g5r8b5z121;0;12,-68;;12,-12;;6,0,-1,0,0,1",
"xs28_g88r58goz0121y169a4zw352;xs16_4a9eg8ozw65;0;15,-79;;;4,-60;0,6,0,1,-1,0",
"xs28_o8bp4oz01221zy66996zya33;xs16_ca9diczw32;0;;;24,-12;;0,6,1,0,0,-1",
"xs28_y5696zy92552zzc4go0ooz4a43;xs16_39c8a52z033;0;;;18,-12;;0,17,0,1,1,0",
"xs31_033zy533wccz8k48gy1cczw1162ac;xs24_0ggci96y666z643y1ck8;0;;;;0,-84;0,18,0,1,-1,0",
"xs31_33ye66zwg8oy066y433z69mic;xs15_358ml96;0;;2,-62;19,-59;1,-90;4,8,0,-1,1,0",
"xs31_w696z33wo4ozy0g1zw2lc3213zx11;xs15_4ap6426z032;0;;;11,-12;;2,14,1,0,0,1",
"xs32_x32q4gf9zy211xooy166z33yd66;xs16_3iajkcz23;0;12,-116;17,-78;;;9,0,0,-1,1,0",
"xs32_y5696zgs2ug6246y02552zzw66;xs16_caarzbd;0;20,-98;;18,-12;;0,6,0,1,1,0",
"xs32_y7696z2596zzy0og4s0gzy234521zzyu66;xs15_cila8ozx32;0;;-5,-95;12,-102;2,-232;10,22,0,-1,-1,0",
"xs33_66y1354cgn96zy06952zzy4cic;xs16_354cgn96;0;6,-88,16,-116;;;;7,0,1,0,0,1",
"xs35_69a4wcicz0ggowgz122cl91y5gzyb343;xs16_4aajk46zx121;0;;;-1,-82;-1,-154;0,8,1,0,0,1",
"xs39_y3696zw25520oox33z6a8kicy066zx146;xs15_69q453z32;0;;-2,-54;3,-50;;5,11,-1,0,0,1",
"xs40_253y3gs248gzy3oo124311zx33yko4ozyq1w8kk8;xs15_4ap64k8zw121;0;;0,-136;50,-74;-7,-182;9,7,1,0,0,-1",
"xs4_252;xs16_25a8c93zw33;0;-9,-20,11,-76;3,-58,10,-63;0,-69;2,-79,4,-61,7,-41;0,2,0,1,-1,0",
"xs4_252;xs16_69araic;0;-3,-20,-2,-44;1,-45;6,-36,7,-12;-1,-53;-1,-2,0,1,1,0",
"xs4_33;xs10_3542ac;0;;-6,-12;1,-35;-4,-36;-5,3,1,0,0,1",
"xs4_33;xs14_08o6952z321;0;;-4,-19;-2,-22;3,-24;-4,-4,1,0,0,1",
"xs4_33;xs14_65la8ozx11;0;-8,-16,-2,-39;3,-42;4,-35,10,-12;-3,-46;-2,-2,1,0,0,1",
"xs4_33;xs14_g2u0696z11;0;;5,-39;-2,-40;6,-16;0,-4,1,0,0,1",
"xs4_33;xs15_08o653z69c;0;;0,-36,9,-46;4,-48,9,-14;4,-27,8,-35;8,-1,0,-1,1,0",
"xs4_33;xs15_4s0s2pmzw1;0;;;-13,-88,2,-131;8,-19,20,-16;5,-18,-1,0,0,1",
"xs4_33;xs16_2egmd1e8;0;-29,-16,-21,-26;0,-94,5,-139;-12,-178;-11,-78;-5,-5,-1,0,0,1",
"xs4_33;xs16_39s0ca4z321;0;-32,-16;20,-336;-25,-213;24,-32;0,0,0,1,-1,0",
"xs4_33;xs16_4alhe8z0641;0;;-48,-12,-38,-305,-23,-86,-16,-121;18,-110,26,-84;-43,-342,-23,-286,-15,-519;-2,16,0,1,1,0",
"xs4_33;xs16_4ap64koz32;0;-42,-157,-22,-72,-6,-101,6,-112;-28,-106,-21,-12,-15,-116;22,-69;-13,-84;-12,-10,0,1,-1,0",
"xs4_33;xs16_69baiczx32;0;;-9,-12;8,-35,15,-31;-5,-63,3,-67;-1,0,0,1,1,0",
"xs4_33;xs16_69n8jdzx1;0;;-13,-34,-13,-12;7,-50,8,-20;4,-78;-4,14,0,1,-1,0",
"xs4_33;xs19_6246p6gxoozy1121;0;-14,-23,-7,-21,-6,-49;0,-87;-7,-63;-12,-62;2,-9,0,-1,1,0",
"xs4_33;xs23_xmp3zoo12453zy433;0;-18,-16;6,-148,13,-122;-9,-67,-8,-88;-13,-80;0,-13,-1,0,0,1",
"xs5_253;xp2_0j9c826z121y57;0;-20,-30,-17,-20,-4,-202;3,-101;-7,-135;-8,-199,11,-97;-10,1,0,1,-1,0",
"xs5_253;xp2_256xe;0;;;1,-42;7,-20;0,2,1,0,0,-1",
"xs5_253;xp2_352zy2e;0;-5,-46;-11,-12;;;2,0,0,-1,1,0",
"xs5_253;xp2_3iakg8oz643xs;1;-12,-23,-4,-33,7,-79;12,-119;-14,-129;11,-20,18,-25;2,-1,1,0,0,-1",
"xs5_253;xp2_c9jy2sz9f023;1;;2,-77;-3,-65,3,-39,19,-34;5,-35,9,-54,12,-20,15,-51;8,1,0,-1,-1,0",
"xs5_253;xp2_ye7zxoozy3cczccy3ca6zzxcq1dqxgzy0121w2543;0;-22,-20;5,-112,7,-132,12,-115;-6,-116,1,-117;17,-41;-31,0,0,1,-1,0",
"xs5_253;xs11_0253zc93;0;-3,-70;-15,-12,-14,-34;-15,-135;;2,3,0,-1,-1,0",
"xs5_253;xs11_0g0s252z121;0;-2,-35;;2,-39;-8,-50,3,-37;-1,-3,0,1,1,0",
"xs5_253;xs11_253zdb;0;-1,-60;-11,-39;-9,-54;-7,-72;2,2,0,-1,-1,0",
"xs5_253;xs11_256w696;0;;;6,-12;7,-20;0,2,1,0,0,-1",
"xs5_253;xs11_256zy3cic;0;;;2,-60;15,-20;0,2,1,0,0,-1",
"xs5_253;xs11_35a8426;0;-1,-72;;-8,-50,9,-21;-10,-106,-9,-90;2,0,-1,0,0,1",
"xs5_253;xs11_696zy2253;0;-10,-20;-1,-44;;;-6,-5,1,0,0,1",
"xs5_253;xs11_69jzx56;0;;-12,-37;-5,-38;-7,-66,-4,-73;-5,4,0,1,-1,0",
"xs5_253;xs11_g88a52z23;0;;-12,-12,4,-49;1,-47;-7,-49;5,2,0,-1,-1,0",
"xs5_253;xs12_2596zca4;0;;-9,-12;;-8,-70;2,8,-1,0,0,-1",
"xs5_253;xs13_2eg8421e8;0;-10,-32,7,-88;-6,-26;-5,-69,8,-12;-5,-91;0,-2,0,1,1,0",
"xs5_253;xs13_33zy4ck8zw66;0;;;7,-55,9,-12;3,-35;10,-7,-1,0,0,1",
"xs5_253;xs14_03ia4zoj6;0;-2,-70;-4,-65;-5,-38,3,-64,10,-60;-7,-60,8,-56;-4,-2,0,1,1,0",
"xs5_253;xs14_0cp3zrm;0;-6,-69,-4,-36,3,-101;-16,-42,-1,-56;;-17,-86;-10,-3,1,0,0,1",
"xs5_253;xs14_0j96zrm;0;-2,-70;-7,-55;-5,-38,4,-60,11,-56;-7,-60,7,-60;-4,-1,0,1,1,0",
"xs5_253;xs14_3ia4zw115a4;0;-1,-22,6,-35;-5,-12;2,-22;-8,-50,3,-20;-1,5,1,0,0,-1",
"xs5_253;xs15_4a40vh246;0;-8,-20,-4,-57,2,-102;-11,-47,2,-57;;1,-99;-9,-8,1,0,0,1",
"xs5_253;xs15_8k4ra96zw1;0;-10,-40,-8,-27,-3,-26;-15,-12,-4,-34;1,-50;;-7,4,0,1,-1,0",
"xs5_253;xs15_drz122ak8;0;-6,-38;-19,-20,-10,-12,4,-66;1,-64;;-4,2,0,1,-1,0",
"xs5_253;xs16_0j5o653z121;0;-3,-40;5,-44;-9,-54,6,-35,10,-42;-7,-55,3,-61,6,-38;0,3,0,1,-1,0",
"xs5_253;xs16_w3ia4z0gb6z32;0;-2,-70;-4,-65,8,-65;-5,-38,9,-52;-7,-60,7,-65;-4,-3,0,1,1,0",
"xs5_253;xs17_ok8y5696zw4aa4;0;-8,-32;-15,-16,2,-34;-7,-46;;2,4,-1,0,0,-1",
"xs5_253;xs26_6952zzyp33zybo8zy869jc23;0;-1,-45;5,-180,19,-100;-10,-88,-5,-38,-1,-63;7,-21,12,-25;-10,10,0,1,-1,0",
"xs5_253;xs9_253y666;0;;;16,-16;12,-20;0,0,1,0,0,1",
"xs6_25a4;xp2_25a4z7;0;;;6,-38;12,-24;0,0,0,1,1,0",
"xs6_25a4;xs14_3lozx31246;0;-3,-24,5,-56;;-4,-38,4,-38;-6,-72,5,-50;5,-2,-1,0,0,1",
"xs6_25a4;xs14_69ak8zx1252;0;-5,-35;;-6,-48,7,-30;-7,-50;4,4,0,-1,-1,0",
"xs6_25a4;xs15_259m8628c;0;;-27,-12;-2,-148,13,-111,18,-26;-22,-185;-1,-1,0,1,1,0",
"xs6_25a4;xs16_69p6426z032;0;;-7,-15,0,-35;-7,-50,12,-12;-8,-57,-1,-49;3,0,-1,0,0,1",
"xs6_356;xs16_djozx35426;0;-7,-27;-5,-12,6,-34;-8,-57;;-4,3,1,0,0,-1",
"xs6_39c;xs10_33w6io;0;;;10,-12;2,-32;6,4,-1,0,0,-1",
"xs6_39c;xs10_39cw66;0;;;7,-12;5,-32;0,0,1,0,0,1",
"xs6_39c;xs11_0c93z253;0;;-12,-12;11,-27;-9,-88;3,0,-1,0,0,1",
"xs6_39c;xs11_25606io;0;;-2,-17,5,-37;-2,-26;;-4,-1,1,0,0,1",
"xs6_39c;xs11_2lmz641;0;;;-2,-26;;2,-4,-1,0,0,1",
"xs6_39c;xs13_641vg4c;0;;;-2,-53,6,-46;7,-24;4,-3,0,-1,1,0",
"xs6_39c;xs14_252sgc4go;0;-9,-24;;-15,-90;6,-25;-2,-5,0,1,1,0",
"xs6_39c;xs14_39czy06996;0;;-3,-53;-8,-50;;2,3,-1,0,0,-1",
"xs6_39c;xs14_4aajkk8zx1;0;6,-65;-9,-12,-1,-58;-1,-53;0,-70,8,-24;4,-1,-1,0,0,1",
"xs6_39c;xs14_gjloz1ac;0;6,-57;-6,-12,2,-57;-1,-45;-3,-69,5,-24;-3,0,0,1,1,0",
"xs6_39c;xs15_0j9cz1215a4;0;;;9,-12;-7,-71,3,-46;-1,0,1,0,0,1",
"xs6_39c;xs15_8kk3146z641;0;;7,-38,12,-86;1,-81,9,-35;;0,-3,0,1,1,0",
"xs6_39c;xs16_0oe13zoge3;0;-4,-24,7,-67;-1,-45;-2,-55,9,-12;0,-57;-1,-3,1,0,0,1",
"xs6_39c;xs16_rh6chr;0;5,-51;-8,-12,3,-45;0,-39;-4,-57,7,-24;3,-1,0,-1,1,0",
"xs6_696;xp2_111zydcic;0;;-14,-112;-24,-114;;-17,-6,1,0,0,1",
"xs6_696;xp2_g88gx7y1696z0121;1;;;12,-12;10,-38;15,0,-1,0,0,1",
"xs6_696;xp2_w888033z70gggy5g8hv04aczy923zy3e;1;-18,-87,-5,-86;-3,-78,2,-68;-5,-53,1,-76;-9,-75,1,-66,17,-24;7,7,0,-1,-1,0",
"xs6_696;xs11_4ai3zx123;0;;-7,-12;8,-45,15,-36;-2,-98,6,-88;10,5,-1,0,0,1",
"xs6_696;xs12_drz1226;0;;-5,-51;-5,-66,10,-34;-5,-81,10,-24,19,-32;6,0,0,-1,1,0",
"xs6_696;xs13_32qj96;0;-2,-28;-3,-29;0,-18;1,-49;0,0,0,-1,1,0",
"xs6_696;xs14_08u15a4z32;0;-11,-156,-2,-122,5,-130;-6,-76;-19,-94,-12,-90;-11,-136,-2,-154;-8,-6,-1,0,0,1",
"xs6_696;xs14_32132qr;0;-11,-28,-2,-66;-7,-38,-2,-12;11,-22;-3,-63;-2,0,0,1,1,0",
"xs6_696;xs15_05b88gz4a511;0;-13,-32,8,-83;12,-74;-9,-54,4,-61;-8,-51,12,-46;3,-1,0,-1,1,0",
"xs6_696;xs15_08u15acz32;0;-15,-27;3,-112,4,-131,16,-172;-24,-137,-12,-93;-4,-109,9,-24;-3,-9,0,1,1,0",
"xs6_696;xs15_4a9diczx32;0;-18,-131;-18,-147;-20,-102,-17,-273,-10,-113,-3,-225;-18,-90;-4,4,0,-1,-1,0",
"xs6_696;xs15_4aab88gzx311;0;;9,-63,11,-118;9,-79,37,-12;1,-197,6,-100,12,-95;7,0,1,0,0,1",
"xs6_696;xs15_dbgzw12ego;0;;;-14,-206,-10,-153,-6,-172;-3,-173,8,-95,11,-106,35,-24;-2,2,0,1,-1,0",
"xs6_696;xs16_3iaj21e8zw1;0;-14,-25,1,-152;3,-87,17,-171;-9,-100;-9,-59,7,-24;3,0,-1,0,0,-1",
"xs6_696;xs16_4a4o796zw121;0;-6,-24,-4,-52,14,-72;6,-70;-3,-40;6,-27;-3,2,0,1,-1,0",
"xs6_696;xs16_62s0fhoz011;0;1,-44;10,-50;4,-32;-11,-62;-2,-1,1,0,0,1",
"xs6_696;xs16_69fg4cz321;0;;-1,-100;-6,-116,7,-91,11,-61,15,-12;-24,-176,-21,-155,3,-113;-2,8,0,1,-1,0",
"xs6_696;xs16_8o6p96z1221;0;-15,-97,-8,-54;8,-116,10,-104;-17,-141,-17,-120;-13,-70;-2,-9,0,1,1,0",
"xs6_696;xs16_ckjaa4z641;0;;12,-86,17,-110,26,-119;-7,-137,0,-96,5,-203,7,-100;15,-189,23,-24;1,4,0,1,1,0",
"xs6_696;xs16_o5r8jdz01;0;-11,-42;-4,-54,-2,-74,6,-96;-22,-106,-13,-89;7,-25;-5,-2,1,0,0,-1",
"xs6_696;xs18_8k4raa4y333zw1;0;-24,-71,-20,-24,-2,-145;17,-171;-5,-152,4,-131;-12,-72,-9,-154,-3,-151;-5,-6,-1,0,0,1",
"xs6_696;xs20_g85r8b5zpp;0;;-3,-108;16,-24,26,-12;-3,-121,3,-81;8,-2,0,-1,1,0",
"xs6_696;xs21_ca4wo4o7piczy21;0;;;5,-96,5,-51,7,-76;15,-58,24,-24;6,-5,0,1,1,0",
"xs6_696;xs21_ogkai3zw65zzzy4cic;0;-13,-35,-6,-33,14,-134;0,-46,7,-38;7,-36;11,-63;10,5,0,-1,-1,0",
"xs6_696;xs28_5b8r5gxo4oz0o4o121x1zw1;0;-14,-57;6,-148,6,-126;1,-65;10,-24,15,-31;-3,-10,0,1,1,0",
"xs6_bd;xs11_dbz352;0;;;-2,-22;;0,3,1,0,0,-1",
"xs6_bd;xs13_8e13zqm;0;;5,-47;-6,-38;;1,-6,-1,0,0,1",
"xs6_bd;xs14_252sgc48c;0;-9,-24;;-15,-90;6,-25;-2,-5,0,1,1,0",
"xs6_bd;xs14_321fgka4;0;-9,-33,-5,-24;;-9,-87,1,-63;6,-55;0,3,0,1,-1,0",
"xs6_bd;xs14_6996zzw6426;0;;;10,-12;7,-27;12,-2,0,-1,1,0",
"xs6_bd;xs14_ggc4871z56;0;;10,-58,14,-85;-3,-76,4,-65;7,-24,13,-53;0,-4,1,0,0,1",
"xs6_bd;xs15_25a8k8zwbd;0;;;8,-12;-8,-71,2,-46;3,8,-1,0,0,-1",
"xs6_bd;xs15_4aarz0bd;0;;4,-50,5,-66;-13,-73,-6,-63;6,-24;-1,-5,1,0,0,1",
"xs6_bd;xs15_8kk3123z641;0;;7,-38,12,-86;1,-81,9,-35;;0,-3,0,1,1,0",
"xs7_178c;xp2_70ggzw12hu0ok8;1;7,-95;-13,-12,-5,-44;;-8,-93;-6,10,1,0,0,-1",
"xs7_178c;xs10_1784ko;0;;;11,-12;-1,-66;0,0,1,0,0,1",
"xs7_178c;xs11_0gbrz23;0;15,-97;-6,-12;;-12,-163;0,6,1,0,0,-1",
"xs7_178c;xs11_178c48c;0;19,-196,19,-158;;22,-12;-20,-198;0,0,1,0,0,1",
"xs7_178c;xs11_178cw66;0;;;8,-12;6,-32;0,0,1,0,0,1",
"xs7_178c;xs11_178kic;0;;;14,-12;-2,-62;0,0,1,0,0,1",
"xs7_178c;xs11_25izw1156;0;-4,-31;-1,-44;-8,-54;;-4,-2,0,1,1,0",
"xs7_178c;xs11_32acw66;0;9,-46;;;-7,-58;0,0,0,1,1,0",
"xs7_178c;xs11_32acwoo;0;12,-58;;;-4,-46;0,0,0,1,1,0",
"xs7_178c;xs11_g0s453z11;0;-5,-24;3,-49;;;3,-2,-1,0,0,1",
"xs7_178c;xs11_w4a96z66;0;-4,-24;;;;-2,4,1,0,0,-1",
"xs7_178c;xs12_0ggs252z32;0;-1,-24;0,-25;;;-3,3,0,1,-1,0",
"xs7_178c;xs12_178c0ca4;0;;;7,-12;;0,0,1,0,0,1",
"xs7_178c;xs12_178c0ck8;0;13,-77;12,-58;;7,-58;0,0,1,0,0,1",
"xs7_178c;xs12_2530354c;0;13,-88;-7,-27;16,-12;;3,7,0,-1,-1,0",
"xs7_178c;xs12_256064ko;0;;3,-22;;;-1,-4,0,1,1,0",
"xs7_178c;xs12_25606a8o;0;;-11,-12;12,-27;-8,-88;4,7,0,-1,-1,0",
"xs7_178c;xs12_69iczx113;0;12,-58;;;2,-64;6,5,0,-1,-1,0",
"xs7_178c;xs12_x178cz352;0;;-10,-12;;-8,-63;-3,0,1,0,0,1",
"xs7_178c;xs13_0c84213z253;0;-5,-24,4,-64;;-5,-63;2,-62;0,4,0,1,-1,0",
"xs7_178c;xs13_0g8ka53z23;0;;7,-38;;1,-65;0,6,1,0,0,-1",
"xs7_178c;xs13_178f123;0;-3,-53,0,-73;;12,-31;-16,-86,-7,-68,1,-63;-2,3,1,0,0,-1",
"xs7_178c;xs13_1no3123;0;-7,-36,0,-59,14,-74;-5,-21,-3,-46,7,-38;;-3,-61,12,-25;-2,1,1,0,0,1",
"xs7_178c;xs13_1no3146;0;-7,-119,0,-142,22,-102;-5,-104,-3,-129,10,-133,16,-74;;;-2,1,1,0,0,1",
"xs7_178c;xs13_32hjkczw1;0;;;-4,-73,5,-45;0,-68,10,-24;5,-2,0,-1,1,0",
"xs7_178c;xs13_32qczx1246;0;15,-105,15,-80;7,-38;;8,-83;0,0,0,1,1,0",
"xs7_178c;xs13_c9jzw1156;0;-20,-91;;-27,-130;-14,-92,-9,-157;-4,-2,0,1,1,0",
"xs7_178c;xs13_dbgzw1156;0;-4,-52,3,-64,14,-66;-3,-42;;-1,-75,5,-38;1,3,0,1,1,0",
"xs7_178c;xs13_gjloz56;0;-1,-41;0,-41;-4,-51,12,-12;1,-44;-3,3,0,1,-1,0",
"xs7_178c;xs14_08o652z254c;0;12,-70;8,-59,15,-70;4,-79;1,-79;8,3,0,-1,-1,0",
"xs7_178c;xs14_1no31e8;0;0,-71,18,-88;-8,-48,-5,-33;-8,-54,11,-25;;-2,1,1,0,0,1",
"xs7_178c;xs14_2egow31e8;0;;8,-42;7,-33;;0,-1,1,0,0,1",
"xs7_178c;xs14_2egu156;0;;;4,-20,10,-15;6,-24;0,-1,1,0,0,1",
"xs7_178c;xs14_31e8zoge2;0;;7,-38;-4,-47;;3,-6,-1,0,0,1",
"xs7_178c;xs14_3ia4zrm;0;12,-58;10,-55;6,-42,15,-38;1,-67,9,-47;0,0,0,1,1,0",
"xs7_178c;xs14_642hjkczx1;0;13,-62;7,-84,12,-65;9,-66;0,-90;5,-3,0,-1,1,0",
"xs7_178c;xs14_8e1248gzy31246;0;12,-68;8,-53,20,-90;4,-75,9,-52;1,-77,12,-52;0,3,1,0,0,-1",
"xs7_178c;xs14_8k4r9a4zw1;0;-4,-57,8,-56;-13,-12,-6,-29,1,-35;9,-29;-6,-65;-7,1,1,0,0,1",
"xs7_178c;xs14_cai3zw1156;0;;;9,-36,12,-44;0,-57,11,-24;0,3,0,1,-1,0",
"xs7_178c;xs14_db8ozca1;0;-6,-40;;-9,-69,12,-27;-9,-58,1,-59;4,3,0,-1,-1,0",
"xs7_178c;xs14_wo8a52zbd;0;-4,-52,3,-64,14,-66;-3,-42;20,-13;-1,-75,5,-38,13,-58;9,3,0,-1,1,0",
"xs7_178c;xs15_03iacz6ip;0;;14,-66;9,-39;0,-65,8,-37,18,-24;0,-1,0,1,1,0",
"xs7_178c;xs15_04al56z2521;0;2,-125;-17,-12,2,-144;1,-127,23,-18;-19,-186,6,-112;-1,11,0,1,1,0",
"xs7_178c;xs15_08u1daz321;0;;-5,-39,8,-59;-4,-49;-12,-70;3,-3,-1,0,0,1",
"xs7_178c;xs15_0ck31e8z321;0;;;6,-72,6,-44;0,-71,12,-24;6,3,-1,0,0,-1",
"xs7_178c;xs15_0drz3ego;0;;-2,-51,9,-71;-8,-82,-6,-46,-2,-54;8,-27;0,-6,1,0,0,1",
"xs7_178c;xs15_0g8objoz23;0;19,-163;8,-137;5,-148,7,-43,13,-12;-8,-97,5,-63;0,6,1,0,0,-1",
"xs7_178c;xs15_0o8a52zc453;0;16,-74;7,-39;20,-20;;8,0,0,-1,1,0",
"xs7_178c;xs15_178czy16996;0;;;13,-12;-4,-83;0,0,1,0,0,1",
"xs7_178c;xs15_252sgc453;0;-5,-25;16,-90;;10,-24;3,-5,0,-1,1,0",
"xs7_178c;xs15_25a8ozxc453;0;;20,-90;9,-56;0,-99,12,-57;8,-3,0,-1,1,0",
"xs7_178c;xs15_2egu15a4;0;12,-58,16,-83;7,-69;4,-57,14,-41;;0,-1,1,0,0,1",
"xs7_178c;xs15_31eozx12552;0;-5,-39,-5,-24;-5,-42,7,-55;-1,-60;;3,3,-1,0,0,-1",
"xs7_178c;xs15_32qkzy032ac;0;-12,-53,-6,-24;-3,-65,4,-76;-13,-85,-9,-58;;-5,-4,0,1,1,0",
"xs7_178c;xs15_6996zwo8a6;0;;;3,-47;8,-24;9,-2,0,-1,1,0",
"xs7_178c;xs15_ciab8oz023;0;2,-83,10,-79;-14,-31,-7,-35,7,-70;3,-58,10,-42,14,-12;5,-75;4,7,0,-1,-1,0",
"xs7_178c;xs15_wck31e8z311;0;;8,-42,14,-95;1,-71,8,-54;9,-32,13,-43;7,3,-1,0,0,-1",
"xs7_178c;xs16_02llicz643;0;-8,-37;0,-65;-11,-66;;3,-4,-1,0,0,1",
"xs7_178c;xs16_0g8e13zo9a6;0;;8,-50,13,-74;3,-58,11,-12;4,-49;9,0,0,-1,1,0",
"xs7_178c;xs16_0ggc453zpi6;0;;-8,-43,0,-89;-11,-94,-6,-46;;3,-3,0,-1,1,0",
"xs7_178c;xs16_0kc32acz1226;0;12,-58;8,-54;3,-45;1,-67;7,3,0,-1,-1,0",
"xs7_178c;xs16_358gzwck56zw11;0;-31,-116,-30,-24;;-25,-146,-7,-159,12,-127;-7,-153,1,-159;-6,5,0,1,-1,0",
"xs7_178c;xs16_3iacz1215a4;0;11,-54;;;-5,-64,5,-49;0,0,0,1,1,0",
"xs7_178c;xs16_4aarzwc453;0;;13,-62;16,-44,20,-128,20,-53;7,-139,8,-117;8,-2,0,-1,1,0",
"xs7_178c;xs16_4aarzy0178c;0;-11,-24;12,-98,16,-198,16,-123;-8,-139,-7,-157;;-4,-5,1,0,0,1",
"xs7_178c;xs16_64ljgozw56;0;1,-48,3,-68;-12,-12;12,-15;1,-47;-3,5,0,1,-1,0",
"xs7_178c;xs16_65ligozw56;0;-1,-62,1,-45;-5,-25;12,-12;1,-44;-3,5,0,1,-1,0",
"xs7_178c;xs16_695m88czx23;0;-3,-32,4,-52;-3,-37;12,-12;1,-44;-2,6,0,1,-1,0",
"xs7_178c;xs16_8ljgzwo9a6;0;;;2,-67;0,-76,10,-60,13,-24;9,-2,0,-1,1,0",
"xs7_178c;xs16_wml5a4z643;0;-5,-29,-1,-61;-11,-34,-4,-58,3,-46;-10,-62;;3,-4,-1,0,0,1",
"xs7_178c;xs19_08e13zoi6zx4aa4;0;;6,-88;-14,-78,-13,-96;;-1,3,1,0,0,-1",
"xs7_178c;xs20_4a9la8ozx121zzcc;0;10,-99,23,-197;-10,-31,1,-62;15,-12;-11,-117,-1,-189;5,6,-1,0,0,-1",
"xs7_178c;xs21_4ai3y0o4oz011628cw1;0;12,-134;17,-100,18,-82;4,-92;1,-143;0,3,0,1,-1,0",
"xs7_178c;xs9_178kc;0;12,-60;;12,-12;;0,0,1,0,0,1",
"xs7_2596;xp2_0ca248gx4a96zg314611z3;0;-5,-37;-8,-40,8,-51;8,-44;-11,-66;-4,4,1,0,0,-1",
"xs7_2596;xp2_33y766zy1ezxg88ge9a4zy01221;0;2,-91;-34,-12,-7,-49;15,-16;-41,-211,-38,-230;-13,-2,1,0,0,1",
"xs7_2596;xp2_y97z2ego4cw33y5ccz06421y0653;0;;2,-125,15,-70;4,-68,13,-57;10,-79,15,-80,23,-33;1,-10,1,0,0,1",
"xs7_2596;xs10_4al96;0;-6,-45,3,-113,5,-72;;;-8,-54;-1,0,1,0,0,1",
"xs7_2596;xs11_2596zzycoo;0;;;30,-12;4,-128;0,0,1,0,0,1",
"xs7_2596;xs12_4ai3zx1246;0;-10,-24;;-5,-74,-2,-89,6,-64;8,-71;4,3,0,-1,-1,0",
"xs7_2596;xs13_0j9ak8z121;0;-2,-57,8,-69;-13,-32,-4,-45;-9,-61,5,-47,12,-12;-6,-71;4,0,0,-1,1,0",
"xs7_2596;xs14_0j9akoz121;0;-15,-28,-5,-49,9,-76;-11,-21;0,-54,14,-12;-14,-95,-5,-72;3,-1,-1,0,0,1",
"xs7_2596;xs14_3pajkc;0;;7,-111;-5,-92,0,-68,9,-86;11,-65,16,-24;0,-3,0,1,1,0",
"xs7_2596;xs14_g84q552z121;0;-4,-24,8,-61;4,-62;5,-50;7,-37;-1,3,1,0,0,-1",
"xs7_2596;xs14_xg84215a4z321;0;-3,-51,5,-56;-15,-26,-6,-33,-5,-57;;-11,-66,0,-64;-8,3,1,0,0,-1",
"xs7_2596;xs15_0c4oa52z2521;0;-10,-220,-6,-141;-24,-86,-23,-16,-16,-108;11,-12;-11,-179;-10,7,1,0,0,-1",
"xs7_2596;xs15_259e0e96;0;-5,-24;5,-53,7,-73;;;3,3,0,-1,-1,0",
"xs7_2596;xs15_2eg8ob96;0;-8,-53;-5,-61,10,-89,10,-74;-7,-50,6,-61;15,-44;4,-3,0,-1,1,0",
"xs7_2596;xs15_4ap6413z32;0;-6,-36,13,-74;-6,-43,-5,-27;-8,-54,2,-40,13,-12;-7,-81,-6,-61;3,0,-1,0,0,1",
"xs7_2596;xs15_6996zzx4aic;0;-7,-24;8,-81;;;-3,-11,1,0,0,1",
"xs7_2596;xs16_0okih3zc8421;0;-13,-24,1,-39;-9,-28,-7,-16,3,-72;;12,-33;3,-3,-1,0,0,1",
"xs7_2596;xs16_39s0qmz32;0;-17,-24,-8,-38;-4,-51,6,-84,7,-70,8,-103;-6,-79;;1,0,1,0,0,-1",
"xs7_2596;xs16_5b8ozy01784c;0;-6,-24,13,-62;1,-33;-7,-64,12,-26;0,-43;4,7,-1,0,0,-1",
"xs7_2596;xs16_69la8oz321;0;-16,-129,-8,-74,1,-174,10,-111,19,-115;5,-154;12,-12;-9,-72;-2,24,0,-1,-1,0",
"xs7_2596;xs16_69p64k8zw121;0;3,-24;-2,-23;4,-24;;3,1,-1,0,0,-1",
"xs7_2596;xs17_4ap56zw12552;0;-10,-38;12,-131,14,-91;-6,-123,0,-68,6,-93;10,-71,16,-24;7,-10,0,-1,1,0",
"xs7_2596;xs19_wcq1e8z2521z033;0;-10,-24;5,-70;-11,-82,-4,-58,6,-43;8,-50;-2,3,1,0,0,-1",
"xs7_25ac;xs11_178ka6;0;;;-9,-62;-17,-90,-11,-140;-2,4,1,0,0,-1",
"xs7_25ac;xs12_0g0s256z121;0;;;7,-12;0,-38;0,6,0,1,-1,0",
"xs7_25ac;xs13_35akg84c;0;;-3,-68,5,-82;-4,-91;-10,-62,7,-56;3,3,-1,0,0,-1",
"xs7_25ac;xs13_6248n96;0;-8,-24,16,-147;12,-155;14,-85;2,-123,20,-28;4,-3,0,-1,1,0",
"xs7_25ac;xs14_0g8o653z321;0;2,-80;;13,-12;-8,-80;-5,12,1,0,0,-1",
"xs7_25ac;xs14_31248n96;0;-4,-24;5,-61,14,-89;14,-23;-1,-86,2,-61;4,-4,0,-1,1,0",
"xs7_25ac;xs15_695q88gzx121;0;14,-99;1,-79,5,-76,7,-38;15,-35;-10,-145,-3,-111;-5,6,1,0,0,-1",
"xs7_3lo;xs11_064213z33;0;;;11,-12;1,-40;0,5,0,1,-1,0",
"xs7_3lo;xs11_3lowcc;0;;;8,-12;4,-40;0,0,1,0,0,1",
"xs7_3lo;xs11_3lozcc;0;;7,-42;-3,-30;;2,4,-1,0,0,-1",
"xs7_3lo;xs12_0ml2zca1;0;;-13,-12;12,-27;-10,-96;0,8,1,0,0,-1",
"xs7_3lo;xs12_2lmzca1;0;;;-2,-26;;2,-4,-1,0,0,1",
"xs7_3lo;xs14_6421fgkc;0;;7,-38;-5,-45,1,-26;;0,4,0,1,-1,0",
"xs7_3lo;xs14_ggw3loz1252;0;;12,-59;3,-47;12,-28;6,4,-1,0,0,-1",
"xs7_3lo;xs15_3loz32ak8;0;-9,-28;;-15,-94;6,-29;2,4,-1,0,0,-1",
"xs7_3lo;xs15_3lozy0ciic;0;;-3,-53;-8,-50;;2,4,-1,0,0,-1",
"xs7_3lo;xs15_4a51ug84c;0;-9,-37,-5,-28;;-9,-91,1,-67;6,-59;4,-4,0,-1,1,0",
"xs7_3lo;xs15_ol3zw321e8;0;;10,-62,14,-89;-3,-80,4,-69;7,-28,13,-57;0,4,1,0,0,-1",
"xs7_3lo;xs15_wdrzgb6z11;0;-7,-28;3,-55,7,-47,9,-83;-8,-72,3,-52;;2,-6,-1,0,0,1",
"xs7_3lo;xs16_03loz252ak8;0;;;10,-12;-8,-79,2,-54;-1,0,1,0,0,1",
"xs7_3lo;xs16_312461164ko;0;;5,-51;-6,-42,2,-56;7,-28,12,-32;2,4,0,-1,-1,0",
"xs7_3lo;xs16_4aarzxol3;0;;8,-161,9,-143;-15,-202,-15,-127,-11,-102;12,-28;5,-5,-1,0,0,1",
"xs7_3lo;xs16_ol3zw343146;0;;7,-38,12,-86;1,-81,9,-35;;0,4,1,0,0,-1",
"xs7_3lo;xs19_3lozg4cz1108kk8;0;;14,-88,15,-70;-5,-80;;2,4,-1,0,0,-1",
"xs7_3lo;xs21_ggxmqw6952z101243;0;-5,-28;;-2,-82,0,-64;6,-53;6,4,0,-1,-1,0",
"xs8_033zoo;xp2_ggg070gggzy0ezy4g8gz0ey1320fga6zyecc;0;-2,-81,0,-65,17,-78;-9,-42,9,-75;9,-63;6,-63;27,24,-1,0,0,-1",
"xs8_178k8;xs12_0g8ka23z23;0;;-10,-16;16,-86,22,-12;;0,6,1,0,0,-1",
"xs8_178k8;xs12_0g8o652z23;0;11,-54;;;-3,-60;0,6,1,0,0,-1",
"xs8_178k8;xs12_178k871;0;17,-82;11,-128,17,-78;;;0,0,1,0,0,1",
"xs8_178k8;xs12_178ka23;0;;-16,-12,-10,-86;16,-16;;0,6,0,1,-1,0",
"xs8_178k8;xs13_25iczx1156;0;-5,-29;-3,-52,5,-51;;6,-28;4,4,-1,0,0,-1",
"xs8_178k8;xs13_2lmzw34a4;0;;3,-22;;;-1,-4,1,0,0,1",
"xs8_178k8;xs13_wggs252z252;0;-1,-28;0,-29;;;-3,4,1,0,0,-1",
"xs8_178k8;xs14_032ak8z4aa4;0;;;7,-20;8,-28;0,-1,0,1,1,0",
"xs8_178k8;xs14_c9jzw115a4;0;-20,-95;;-27,-134;-14,-96,-9,-161;-4,-2,0,1,1,0",
"xs8_178k8;xs15_8k871zw115a4;0;9,-136,16,-147,26,-188;-26,-12;;-16,-136;4,0,-1,0,0,1",
"xs8_178k8;xs16_025a8oz8k871;0;-5,-29;16,-94;;10,-28;4,-5,-1,0,0,1",
"xs8_178k8;xs16_0gs252zj4cz11;0;-4,-132;-8,-132,-3,-128,6,-92;-14,-82,-13,-100,-5,-180;;-1,4,1,0,0,-1",
"xs8_178k8;xs16_25a8og4c84c;0;;-2,-55,9,-75;-8,-86,-6,-50,-2,-58;8,-31;4,4,0,-1,-1,0",
"xs8_178k8;xs16_25a8ozy15b8o;0;-12,-57,-6,-28;-3,-69,4,-80;-13,-89,-9,-62;;4,4,0,-1,-1,0",
"xs8_252zy166;xs21_g88cy733z19lp13;0;24,-262,34,-146;;25,-14;-14,-212,-9,-130;-5,14,1,0,0,-1",
"xs8_25ak8;xs10_g8ka52z01;0;;;11,-12;1,-42;5,0,-1,0,0,1",
"xs8_25ak8;xs11_25akg8o;0;-10,-29;-1,-53;-5,-46;;4,4,0,-1,-1,0",
"xs8_25ak8;xs13_6246pic;0;-5,-35;1,-59,10,-80;-5,-69,-5,-52;-5,-64,-1,-67,6,-28;0,-3,0,1,1,0",
"xs8_25ak8;xs14_g8ka52z1ac;0;;-9,-12,8,-51;14,-48,15,-60;-4,-102;5,0,-1,0,0,1",
"xs8_31248c;xs13_0g853z8ld;0;;-7,-54;-7,-73;-12,-78;5,-1,0,-1,1,0",
"xs8_31248c;xs13_g853zdl8;0;;;9,-12;;0,3,0,1,-1,0",
"xs8_31248c;xs15_6248gu156;0;;;6,-20,12,-15;8,-24;0,-1,1,0,0,1",
"xs8_31248c;xs15_8e13zx31248c;0;;3,-45;-6,-54;;-3,-5,1,0,0,1",
"xs8_31248c;xs16_0o8a52zg853z11;0;-14,-40;;-10,-70;-7,-59;-5,3,0,1,-1,0",
"xs8_31248c;xs16_c9jz6ahzw23;0;;8,-130;-2,-146,3,-122,12,-50;7,-158,15,-46,16,-24;11,3,0,-1,-1,0",
"xs8_31248c;xs16_wbq2sgzca1;0;-2,-77;-7,-73,-3,-65,8,-103;-8,-62,-3,-87;;-3,3,0,1,-1,0",
"xs8_31248c;xs22_o8gxmqw6952zx1243;0;-1,-80,1,-70;;-6,-54;-7,-83;5,6,-1,0,0,-1",
"xs8_312ko;xs13_0354k8z6421;0;-3,-37,5,-70;;-6,-50;-7,-55;-3,4,0,1,-1,0",
"xs8_312ko;xs13_0og853z4a6;0;-6,-43;8,-80;;11,-28;-1,4,1,0,0,-1",
"xs8_312ko;xs13_0ok213z4a6;0;;-11,-12;14,-27;-8,-96;5,0,-1,0,0,1",
"xs8_312ko;xs13_2530312ko;0;-1,-28;;;;-4,0,1,0,0,1",
"xs8_312ko;xs13_2530358go;0;-10,-28;;-7,-80;7,-43;0,-4,0,1,1,0",
"xs8_312ko;xs14_xg853zg6dz11;0;;;11,-32,20,-12;-6,-74,-1,-73,2,-89;0,6,0,1,-1,0",
"xs8_312ko;xs15_354c0s4zx65;0;-7,-28,1,-55;4,-63;-5,-54,4,-54;7,-33;7,-3,-1,0,0,1",
"xs8_312ko;xs15_6agwrdzx121;0;-1,-76,1,-66;-16,-42;-6,-50;-7,-79;4,5,-1,0,0,-1",
"xs8_312ko;xs16_064kl3zca101;0;;4,-54;-6,-66,5,-45;7,-60,10,-28;4,-4,-1,0,0,1",
"xs8_312ko;xs16_25a8ozw358go;0;-14,-36;;-10,-66;-7,-55;-5,-2,0,1,1,0",
"xs8_312ko;xs16_wgbq2sgz65;0;-2,-73;-7,-69,-3,-61,8,-99;-8,-58,-3,-83;;4,-3,-1,0,0,1",
"xs8_312ko;xs16_xkc0fhoz321;0;-9,-28,-6,-60;-4,-45,7,-66;-3,-54;;-2,4,0,1,-1,0",
"xs8_32qk;xp2_wo8b5ze;1;-11,-28;1,-66;;;-2,4,1,0,0,-1",
"xs8_32qk;xs12_32qkwcc;0;;;9,-12;5,-40;0,0,1,0,0,1",
"xs8_32qk;xs12_32qkwoo;0;;;11,-12;3,-32;0,0,1,0,0,1",
"xs8_32qk;xs12_5b8ozx123;0;;-2,-39;-6,-46;;3,4,-1,0,0,-1",
"xs8_32qk;xs12_ghn84cz1;0;15,-74;11,-128,17,-78;;;0,-1,0,1,1,0",
"xs8_32qk;xs13_0ggs252z56;0;;1,-27;-2,-30;;3,-3,-1,0,0,1",
"xs8_32qk;xs13_0kq23z4a6;0;;;;-4,-38;4,0,-1,0,0,1",
"xs8_32qk;xs13_2lmzw3426;0;;-2,-12;;;-4,-1,0,1,1,0",
"xs8_32qk;xs13_kq23z6a4;0;14,-96;-8,-27;17,-12;;3,0,-1,0,0,1",
"xs8_32qk;xs14_0g8jq23z23;0;18,-148,21,-169;16,-74;26,-73;;6,0,0,-1,1,0",
"xs8_32qk;xs14_0ghn84cz32;0;;;5,-60,6,-78;7,-41,9,-53,17,-28;0,-2,0,1,1,0",
"xs8_32qk;xs14_32qk0f9;0;22,-98;12,-124,15,-145;;20,-97;0,0,1,0,0,1",
"xs8_32qk;xs14_5b8ozxc93;0;-26,-28;;-21,-177;8,-127,13,-42;3,4,-1,0,0,-1",
"xs8_32qk;xs14_ggc4871z146;0;34,-146;8,-141,13,-76;27,-75;;0,6,0,1,-1,0",
"xs8_32qk;xs15_0g8gu156z23;0;13,-62;;;-7,-69,-1,-50;6,0,0,-1,1,0",
"xs8_32qk;xs15_wghn84cz252;0;;27,-118;6,-102,13,-85,23,-86;15,-66;0,-3,0,1,1,0",
"xs8_32qk;xs16_025a8ozc4871;0;;-15,-28;-6,-47;-11,-66;-5,4,0,1,-1,0",
"xs8_32qk;xs16_0drz3eg8o;0;-7,-56,-5,-28,-1,-52;-8,-41,3,-65;;-9,-65;-6,0,0,1,1,0",
"xs8_32qk;xs16_0rdzggmbz1;0;9,-71,13,-63,15,-99;-9,-12;;-10,-88,1,-68;0,10,1,0,0,-1",
"xs8_32qk;xs16_1784c0fho;0;2,-61,13,-82;-11,-12,-8,-44;;-5,-70;0,0,0,1,1,0",
"xs8_32qk;xs16_1784cggc48c;0;11,-62,19,-147;-14,-37,-11,-12;11,-112,16,-27;-7,-74,2,-140,7,-144;0,0,0,1,1,0",
"xs8_32qk;xs16_1784cggc4go;0;12,-192,20,-112,21,-94;;11,-112;-7,-104,2,-140,7,-144;0,0,0,1,1,0",
"xs8_32qk;xs16_1784cgs252;0;;-11,-12;12,-13;-17,-110;0,0,0,1,1,0",
"xs8_32qk;xs16_2eg8objo;0;-1,-63,12,-81;-14,-77;13,-95;-10,-62,-4,-69,-2,-166;-1,0,0,1,1,0",
"xs8_32qk;xs16_32qkgozw6a4;0;;;8,-12;-4,-49,6,-35;0,0,1,0,0,1",
"xs8_32qk;xs16_32qkzx34aa4;0;8,-80;;12,-27,12,-12;-8,-75,4,-62;0,0,1,0,0,1",
"xs8_32qk;xs16_32qkzy0321e8;0;16,-78,20,-105;;13,-12,19,-41;-5,-96,2,-85;0,0,1,0,0,1",
"xs8_32qk;xs16_32qkzy032qk;0;-12,-39,-8,-28;-3,-66,4,-83;-13,-107,-7,-54;;-4,-5,1,0,0,1",
"xs8_32qk;xs16_32qkzy1ciic;0;15,-70;;;2,-73;0,0,1,0,0,1",
"xs8_32qk;xs16_8ow6996z1226;0;7,-75;-8,-12;;;3,7,-1,0,0,-1",
"xs8_32qk;xs16_adhegoz023;0;;7,-62,8,-85,17,-78;-2,-61,5,-41;6,-49;6,-1,0,-1,1,0",
"xs8_32qk;xs16_g8e123zpi6;0;-13,-28,-12,-50,-4,-162;-5,-70,4,-142,9,-166;-5,-150;;3,-1,0,-1,1,0",
"xs8_32qk;xs16_wggo8b5z696;0;0,-58;-6,-29,6,-64;-6,-61,-6,-46;;-4,4,1,0,0,-1",
"xs8_32qk;xs22_2596wqmzy33421e8;0;;-7,-12;12,-37;-4,-98,-2,-80;8,12,0,-1,-1,0",
"xs8_33w66;xs13_356o8a6;0;;;2,-22;10,-21;0,-7,1,0,0,1",
"xs8_33w66;xs24_33x32qjap3zyd66;0;-5,-143,9,-99,10,-141;-24,-52,-19,-35;-7,-58;-16,-174,-15,-134,-5,-110;-8,18,0,-1,-1,0",
"xs8_33x33;xs16_0c9jzi5dz11;0;;9,-51;-6,-58,-1,-71,2,-100,9,-54;13,-27,14,-66;5,-3,0,1,1,0",
"xs8_33yj66;xs16_65pajkc;0;3,-244,11,-55;27,-118,29,-322;17,-47,25,-236;-5,-330,-3,-126;15,-2,0,-1,1,0",
"xs8_33zcc;xp2_7wggg070gggzy3ezx66zxoo;1;;8,-125;-20,-135,-4,-100;14,-44;-3,-11,1,0,0,1",
"xs8_35ac;xs13_wggm96z252;0;;;7,-12;0,-38;6,-1,-1,0,0,1",
"xs8_35ac;xs15_35iczx115a4;0;;0,-52;-6,-46,7,-29;0,-55;-1,-2,1,0,0,1",
"xs8_3pm;xs12_xdjoz33;0;;;3,-32;7,-28;5,4,-1,0,0,-1",
"xs8_3pm;xs13_0ml2zc96;0;;;;-5,-38;0,8,1,0,0,-1",
"xs8_3pm;xs13_2lmzc96;0;13,-96;-9,-27;16,-12;;0,8,1,0,0,-1",
"xs8_3pm;xs14_0ck3146z321;0;33,-142;7,-137,12,-72;26,-71;;0,6,1,0,0,-1",
"xs8_3pm;xs15_0ggmp3z346;0;12,-58;;;-8,-65,-2,-46;5,0,-1,0,0,1",
"xs8_3pm;xs15_8o032acz346;0;3,-47;-8,-12;;;2,7,-1,0,0,-1",
"xs8_3pm;xs15_oe12453z23;0;22,-124;-8,-12;11,-37;-5,-98,-3,-80;0,6,0,1,-1,0",
"xs8_3pm;xs16_03pmz8ka23;0;;-12,-12;11,-13;-18,-110;-1,0,1,0,0,1",
"xs8_3pm;xs16_0mp3zj4cz11;0;11,-188,19,-108,20,-90;;10,-108;-8,-100,1,-136,6,-140;3,0,-1,0,0,1",
"xs8_3pm;xs16_3hu0642ac;0;1,-61,12,-82;-12,-12,-9,-44;;-6,-70;3,8,0,-1,-1,0",
"xs8_3pm;xs16_3pmzx321e8;0;15,-78,19,-105;;12,-12,18,-41;-6,-96,1,-85;0,0,1,0,0,1",
"xs8_3pm;xs16_3pq32156;0;-2,-63,11,-81;-15,-77;12,-95;-11,-62,-5,-69,-3,-166;2,7,0,-1,-1,0",
"xs8_3pm;xs16_rdzg6rz11;0;8,-71,12,-63,14,-99;-10,-12;;-11,-88,0,-68;0,10,1,0,0,-1",
"xs8_6996;xp2_032hv04a4ze;0;-13,-75;-9,-72,-6,-97;-13,-90,-4,-69;-17,-90;-12,2,1,0,0,-1",
"xs8_6996;xs12_w6996z33;0;;;4,-28;8,-24;0,-2,0,1,1,0",
"xs8_6996;xs13_25a842ak8;0;-12,-54,-10,-43;3,-86,11,-106;-4,-65;-11,-66;-8,-9,0,-1,1,0",
"xs8_6996;xs14_4a51i4ozx121;0;-3,-24,10,-50;1,-43;-1,-46,6,-32;0,-53;0,-3,1,0,0,1",
"xs8_6996;xs15_0g8o0uh3z23;0;;-31,-22;-7,-50,5,-111;-28,-138,-13,-148;-7,7,-1,0,0,-1",
"xs8_6996;xs15_4ai30o4czx121;0;-14,-57,-7,-24;6,-61,13,-98;-6,-86,13,-74,14,-44;1,-86,5,-63,13,-60;-4,-5,1,0,0,1",
"xs8_6996;xs16_c9baiczw32;0;;-8,-45;-6,-46,0,-76;8,-46;0,2,0,1,-1,0",
"xs8_6996;xs16_w8k8a53z6521;0;-6,-43,13,-81;-2,-35;-4,-38,9,-12;-3,-57;-1,4,1,0,0,-1",
"xs8_6996;xs18_y533zzz3146k46zx121;0;-29,-89,-7,-174;-11,-172;-4,-140;-19,-169,-17,-90,-12,-157;-25,4,0,1,-1,0",
"xs8_6996;xs22_gs2ibq23z47011;0;;-7,-43,-3,-12;;-8,-85,-4,-38;-2,5,1,0,0,-1",
"xs8_6996;xs4_252;0;;;;-7,-50;-6,2,1,0,0,1",
"xs8_69ic;xs16_ca1v0kczx11;0;6,-52,7,-38;2,-34;0,-22,1,-36;-3,-50;4,-1,0,-1,1,0",
"xs8_rr;xs14_32qkzw254c;0;-4,-37,13,-62;-2,-21,5,-65;-8,-46,9,-21;-8,-81,-1,-37;-2,-2,1,0,0,1",
"xs8_rr;xs14_3lmge2z01;0;;-1,-23;4,-19;5,-28;4,3,-1,0,0,-1",
"xs8_rr;xs16_4s0v1e8zw11;0;1,-36,15,-70;-3,-19;-10,-54,4,-20;0,-35;3,-1,0,-1,1,0",
"xs8_rr;xs19_32q4gozx1246zy4cc;0;-24,-28,1,-103;-6,-66;-22,-150,-10,-131;-8,-134,6,-51,11,-73;-11,-1,1,0,0,-1",
"xs8_rr;xs22_c84q96zx123y36952;0;;-2,-138,14,-66;3,-91,17,-135,20,-56;1,-253,14,-78,20,-28;4,6,0,1,-1,0",
"xs9_178426;xs12_178421e8;0;13,-63;10,-50;;4,-67,7,-45;0,0,1,0,0,1",
"xs9_178426;xs13_8ljgzx346;0;-5,-24;3,-49;;;5,3,0,-1,-1,0",
"xs9_178426;xs13_ghn8426z1;0;;-16,-12,-10,-86;14,-16;;-1,0,1,0,0,1",
"xs9_178426;xs14_0mk21e8z121;0;-5,-24;;-2,-68;10,-39;6,3,-1,0,0,-1",
"xs9_178426;xs14_178421ego;0;13,-63;10,-50;;-1,-78,7,-45;0,0,1,0,0,1",
"xs9_178426;xs14_2lmz4a9o;0;;;;5,-24;9,3,0,-1,-1,0",
"xs9_178426;xs14_2lmzo9a4;0;18,-82;11,-69;13,-50;;9,0,0,-1,1,0",
"xs9_178426;xs14_2lmzw34213;0;;3,-22;;;-1,-4,1,0,0,1",
"xs9_178426;xs14_8ljgzx34a4;0;-1,-24;0,-25;;;5,3,0,-1,-1,0",
"xs9_178426;xs15_0ghn8426z32;0;6,-86,7,-108;;;-18,-102,-10,-95,-8,-75;-2,0,1,0,0,1",
"xs9_178426;xs15_31248gzy2124871;0;;10,-61,22,-98;4,-83,9,-60,11,-41;14,-52;11,-5,-1,0,0,1",
"xs9_178426;xs15_8ljgzxpi6;0;-20,-99;;-27,-138;-14,-100,-9,-165;5,3,0,-1,-1,0",
"xs9_178426;xs16_08o032acz254c;0;;10,-50;3,-41;;8,3,0,-1,-1,0",
"xs9_178426;xs16_0o8b96zc452;0;;;12,-12;2,-40,8,-35;8,0,0,-1,1,0",
"xs9_178426;xs16_ca23zx624871;0;;;3,-43;10,-24;8,-5,-1,0,0,1",
"xs9_178426;xs16_gjl8gz1x34a4;0;7,-128,14,-139,24,-180;-26,-12;;-16,-128;5,0,0,-1,1,0",
"xs9_178426;xs23_wgxmqw6952z4701243;0;13,-87;10,-50;;3,-74,5,-84;0,7,1,0,0,-1",
"xs9_178kc;xs13_0g8kq23z23;0;;-10,-16;16,-86,22,-12;;0,6,1,0,0,-1",
"xs9_178kc;xs13_178kq23;0;;-16,-12,-10,-86;16,-16;;0,6,0,1,-1,0",
"xs9_178kc;xs14_2eg8o653;0;;9,-46;6,-34;3,-48;0,-1,1,0,0,1",
"xs9_178kc;xs15_032q48cz2521;0;;-6,-12;6,-42;-13,-83,3,-56;0,-1,0,1,1,0",
"xs9_178kc;xs15_ogkq23z66;0;10,-50;;12,-14;-5,-61,2,-42;0,5,0,1,-1,0",
"xs9_178kc;xs16_8kq23zxc871;0;;;6,-23;7,-28;0,4,0,1,-1,0",
"xs9_178kc;xs16_ck871zw115a4;0;9,-136,16,-147,26,-188;-26,-12;;-16,-136;4,0,-1,0,0,1",
"xs9_178ko;xp2_wo8a53ze;1;;0,-64;-12,-74;;4,-2,0,-1,1,0",
"xs9_178ko;xs14_2lmzw34ac;0;;3,-22;;;-1,-4,1,0,0,1",
"xs9_178ko;xs14_35iczx1156;0;-5,-29;-3,-52,5,-51;;6,-28;4,4,-1,0,0,-1",
"xs9_178ko;xs14_wggs252z652;0;-1,-28;0,-29;;;-3,4,0,1,-1,0",
"xs9_178ko;xs15_c9jzw115ac;0;-20,-95;;-27,-134;-14,-96,-9,-161;-4,-2,0,1,1,0",
"xs9_253033;xs13_178kc0cc;0;;;-15,-90,-9,-140;-11,-78;-2,-2,1,0,0,1",
"xs9_253033;xs19_25ao4kozw23y0cc;0;-1,-92,12,-109;;-8,-62;-6,-99;-4,8,1,0,0,-1",
"xs9_253y666;xs16_4a5la8czx23;0;-2,-42;16,-74,22,-98,23,-128;-3,-110,8,-115,8,-65;;15,-3,0,-1,1,0",
"xs9_25a84c;xs12_17842ak8;0;14,-67;9,-46;;3,-71,6,-49;7,4,-1,0,0,-1",
"xs9_25a84c;xs12_g8jdz56;0;-4,-31;2,-62;-11,-74;;5,0,0,-1,1,0",
"xs9_25a84c;xs13_178ka246;0;;;-9,-70;-17,-98,-11,-148;-2,4,1,0,0,-1",
"xs9_25a84c;xs14_08k453z4a43;0;14,-67;9,-46;;-2,-82,6,-49;8,0,0,-1,1,0",
"xs9_25a84c;xs14_0ci52z8ld;0;;;;4,-24;0,4,0,1,-1,0",
"xs9_25a84c;xs14_ci52zdl8;0;19,-86;10,-65;14,-46;;0,3,0,1,-1,0",
"xs9_25a84c;xs15_0ok215a4z641;0;;7,-58,16,-74;4,-79,7,-51,12,-32;;7,3,-1,0,0,-1",
"xs9_25a84c;xs15_25iczw116413;0;29,-185;-11,-26,-6,-111;34,-12;;0,0,0,1,1,0",
"xs9_25a84c;xs15_o4a5123z056;0;-7,-72,-6,-60;4,-82;;-8,-63,9,-24;-1,3,1,0,0,-1",
"xs9_25a84c;xs16_25iczw11d96;0;;;13,-12;1,-48,7,-43;0,0,0,1,1,0",
"xs9_25a84c;xs16_8o032acz34a4;0;;9,-46;4,-37;;8,3,0,-1,-1,0",
"xs9_25a84c;xs16_8ow31e8z34a4;0;;;4,-35;9,-24;8,3,0,-1,-1,0",
"xs9_25a84c;xs16_c48a52z6513;0;9,-68,18,-82;;15,-18;-8,-72,-1,-67;5,0,-1,0,0,1",
"xs9_25a84c;xs16_dj8gzw1078k8;0;-24,-24;3,-116,10,-127,20,-168;-14,-116;;5,3,0,-1,-1,0",
"xs9_25a84c;xs16_dj8gzw122ak8;0;-13,-70;-19,-98,-9,-97,-2,-114;-25,-130;;5,3,0,-1,-1,0",
"xs9_25a84c;xs16_gs248a52z56;0;14,-91;9,-46;23,-38;2,-78,4,-88;7,0,-1,0,0,1",
"xs9_25ako;xs12_3215ako;0;-10,-29;-1,-53;-5,-46;;0,-2,0,1,1,0",
"xs9_25ako;xs13_0g8o652z321;0;;3,-44;-3,-38;;4,-2,-1,0,0,1",
"xs9_25ako;xs14_0g8ka53z321;0;-7,-30;-3,-32;-5,-46;;4,-2,-1,0,0,1",
"xs9_25ako;xs14_wggm952z252;0;;;9,-12;0,-46;7,0,-1,0,0,1",
"xs9_25ako;xs15_g8ka53z1ac;0;;-3,-72,5,-86;-4,-95;-10,-66,7,-60;4,-1,0,-1,1,0",
"xs9_25ako;xs15_xg8ka52z4a43;0;;-4,-14;9,-12;0,-46;-1,7,0,1,-1,0",
"xs9_25ako;xs16_8ka53zw115a4;0;;16,-120;-18,-172,-8,-131,-1,-120;26,-28;0,4,1,0,0,-1",
"xs9_312453;xp2_j96z11we;0;2,-58;-12,-12;;;5,0,0,-1,1,0",
"xs9_312453;xs14_0j5oz8ld;0;17,-78;12,-73;12,-54;;0,-1,0,1,1,0",
"xs9_312453;xs14_0j96z8ld;0;;-7,-54;-7,-73;-12,-78;5,-1,0,-1,1,0",
"xs9_312453;xs14_0mk2156z121;0;-6,-35;8,-72;;11,-20;-1,2,1,0,0,-1",
"xs9_312453;xs14_0ml1246z121;0;-6,-20;;-3,-72;11,-35;6,2,-1,0,0,-1",
"xs9_312453;xs14_25akg84ko;0;-1,-65,2,-58,8,-86;-3,-52;-7,-58;-11,-76;-3,4,1,0,0,-1",
"xs9_312453;xs14_2lmz320123;0;;-9,-12;12,-27;-6,-80;5,6,-1,0,0,-1",
"xs9_312453;xs14_2lmzcip;0;-1,-20;;;;-4,2,0,1,-1,0",
"xs9_312453;xs14_31eg842ac;0;-3,-41,5,-74;;-6,-54;-7,-59;-3,3,1,0,0,-1",
"xs9_312453;xs14_j5o0ok8z11;0;9,-56;;11,-12;-4,-66;0,0,0,1,1,0",
"xs9_312453;xs16_08o032acz69c;0;;3,-45;-6,-54;;-3,2,0,1,-1,0",
"xs9_312453;xs16_35421fgkc;0;-4,-27,2,-32;-6,-12;;;5,0,-1,0,0,1",
"xs9_312453;xs16_j5oz110796;0;-16,-142,9,-180;-23,-97;12,-156;-32,-158,-5,-195,2,-176,9,-159;0,0,0,1,1,0",
"xs9_312453;xs16_oe1248a6z23;0;-1,-80,1,-70;-16,-46;-6,-54;-7,-83;-2,-1,1,0,0,1",
"xs9_31248go;xp2_358gzsw23;0;;;8,-42;14,-28;0,0,0,1,1,0",
"xs9_31248go;xs13_358gzx6jo;0;;;6,-41,15,-20;4,-52,8,-28,11,-48;0,0,0,1,1,0",
"xs9_31248go;xs14_0354k8zok21;0;-3,-45,5,-78;;-6,-58;-7,-63;-3,4,0,1,-1,0",
"xs9_31248go;xs14_253031248go;0;;;11,-12;;10,4,-1,0,0,-1",
"xs9_31248go;xs14_wg853zgbqz01;0;;-7,-58;-7,-77;-12,-82;6,-1,0,-1,1,0",
"xs9_31248go;xs16_31248gu156;0;;;8,-17,14,-12;8,-29;0,0,1,0,0,1",
"xs9_31248go;xs16_3213ia4z0ca1;0;-1,-84,1,-74;-16,-50;-6,-58;-7,-87;-2,5,0,1,-1,0",
"xs9_31ego;xs14_253031ego;0;;;9,-12;;8,4,-1,0,0,-1",
"xs9_31ego;xs15_wg8ka53z643;0;;-1,-57;;-7,-54;4,-3,-1,0,0,1",
"xs9_31ego;xs16_31egu156;0;;;6,-17,12,-12;6,-29;0,0,1,0,0,1",
"xs9_31ego;xs16_ggml96z56;0;-6,-39,14,-66;-1,-47,10,-51;10,-45;4,-61;6,0,0,-1,1,0",
"xs9_4aar;xp2_wraa4ze;1;;;2,-66;14,-28;5,4,-1,0,0,-1",
"xs9_4aar;xs13_4aarzx123;0;;9,-46;5,-39;;0,4,1,0,0,-1",
"xs9_4aar;xs13_ghn871z1;0;;;-14,-78,-8,-128;-12,-74;3,-1,0,-1,1,0",
"xs9_4aar;xs14_178f1246;0;-11,-28,-4,-45;-1,-61,5,-66;2,-62;6,-56;3,4,0,-1,-1,0",
"xs9_4aar;xs14_4aarzx1252;0;;5,-30;2,-27;;0,4,1,0,0,-1",
"xs9_4aar;xs15_0ghn871z32;0;-14,-28,-6,-53,-4,-41;-3,-78,-2,-60;;;3,-2,0,-1,1,0",
"xs9_4aar;xs15_4aarzxc93;0;-10,-42,-5,-127;24,-177;;29,-28;0,4,1,0,0,-1",
"xs9_4aar;xs15_caarzca1;0;-11,-28,-4,-45;-1,-61,8,-64;-5,-82,-2,-61;;0,4,1,0,0,-1",
"xs9_4aar;xs15_j9czd552;0;;-27,-12;15,-111,20,-26;-22,-193;3,8,-1,0,0,-1",
"xs9_4aar;xs16_2ege1dio;0;-4,-28;9,-76;2,-51,3,-67,4,-86,13,-43;10,-38;4,4,0,-1,-1,0",
"xs9_4aar;xs16_2ege96z321;0;-12,-58,-2,-48,12,-78,17,-102;-12,-12,-2,-53;;-5,-86;4,0,0,-1,1,0",
"xs9_4aar;xs16_wghn871z252;0;-16,-102,-6,-101,1,-118;-16,-50;;-28,-134;3,7,0,-1,-1,0",
"xs9_4aar;xs17_wggraa4z696;0;;9,-61,9,-46;-3,-64,9,-29;3,-58;7,4,-1,0,0,-1",
"xs9_4aar;xs19_2lm0ml2zw343;0;;;5,-12;1,-28;7,-1,0,-1,1,0",
"xs9_g0g853z11;xp2_07w8ozc8421;0;;4,-52;-8,-62;;0,-3,1,0,0,1",
"xs9_g0g853z11;xs13_3pczw1248c;0;;2,-43,11,-58;-5,-70,-2,-38,2,-46;;6,-3,-1,0,0,1",
"xs9_g0g853z11;xs14_0g84213z8ld;0;-6,-32;;-3,-84;11,-47;6,5,-1,0,0,-1",
"xs9_g0g853z11;xs14_0g8421egoz32;0;;-8,-21,0,-54;-2,-39;-11,-74;5,6,-1,0,0,-1",
"xs9_g0g853z11;xs14_g84213zdl8;0;;-6,-12;;;5,5,0,-1,-1,0",
"xs9_g0g853z11;xs15_y4g853zxg8421z321;0;;16,-90;-1,-67,1,-78,6,-81;10,-43,22,-32;0,-6,1,0,0,1",
"xs9_g0g853z11;xs16_069b8ozc8421;0;;4,-31,10,-50;-2,-43;;0,-3,1,0,0,1",
"xs9_g0g853z11;xs16_3213ia4z6421;0;-11,-66;-6,-60,-4,-50;-2,-63;-11,-74;-2,0,0,1,1,0",
"xs9_g0g853z11;xs16_ca230o8zy21248c;0;;;7,-35;10,-32;10,-3,-1,0,0,1"
]);